// {{MadCap}} //////////////////////////////////////////////////////////////////
// Copyright: MadCap Software, Inc - www.madcapsoftware.com ////////////////////
////////////////////////////////////////////////////////////////////////////////
// <version>12.0.0.0</version>
////////////////////////////////////////////////////////////////////////////////

//    Syntax:
//    function FMCOpenHelp( id, skinName, searchQuery, firstPick )
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    FMCOpenHelp( 'FILE_NEW', null, null, null );
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    FMCOpenHelp( 'FILE_NEW', 'BlueSkin', null, null );
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    FMCOpenHelp( 1, null, null, null );
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    FMCOpenHelp( 1, 'BlueSkin', null, null );
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    FMCOpenHelp( 'Company/Employees.htm', null, null, null );
//
//    In the following example, both the default topic and skin will be used:
//    FMCOpenHelp( null, null, null, null );
//
//    In the following example, the default topic will be used with "BlueSkin":
//    FMCOpenHelp( null, 'BlueSkin', null, null );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    FMCOpenHelp( null, null, 'quarterly report', false );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    FMCOpenHelp( null, null, 'quarterly report', true );

function FMCOpenHelp( id, skinName, searchQuery, firstPick, pathToHelpSystem )
{
    MadCap.OpenHelp(id, skinName, searchQuery, firstPick, pathToHelpSystem);
}

/*!
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v12.0.0.0
*/

/*
 RequireJS 2.1.11 Copyright (c) 2010-2014, The Dojo Foundation All Rights Reserved.
 Available via the MIT or new BSD license.
 see: http://github.com/jrburke/requirejs for details
*/
var requirejs, require, define;
(function (ca) {
    function G(b) { return "[object Function]" === M.call(b) } function H(b) { return "[object Array]" === M.call(b) } function v(b, c) { if (b) { var d; for (d = 0; d < b.length && (!b[d] || !c(b[d], d, b)) ; d += 1); } } function U(b, c) { if (b) { var d; for (d = b.length - 1; -1 < d && (!b[d] || !c(b[d], d, b)) ; d -= 1); } } function s(b, c) { return ga.call(b, c) } function j(b, c) { return s(b, c) && b[c] } function B(b, c) { for (var d in b) if (s(b, d) && c(b[d], d)) break } function V(b, c, d, g) {
        c && B(c, function (c, h) {
            if (d || !s(b, h)) g && "object" === typeof c && c && !H(c) && !G(c) && !(c instanceof
            RegExp) ? (b[h] || (b[h] = {}), V(b[h], c, d, g)) : b[h] = c
        }); return b
    } function t(b, c) { return function () { return c.apply(b, arguments) } } function da(b) { throw b; } function ea(b) { if (!b) return b; var c = ca; v(b.split("."), function (b) { c = c[b] }); return c } function C(b, c, d, g) { c = Error(c + "\nhttp://requirejs.org/docs/errors.html#" + b); c.requireType = b; c.requireModules = g; d && (c.originalError = d); return c } function ha(b) {
        function c(a, e, b) {
            var f, n, c, d, g, h, i, I = e && e.split("/"); n = I; var m = l.map, k = m && m["*"]; if (a && "." === a.charAt(0)) if (e) {
                n =
                I.slice(0, I.length - 1); a = a.split("/"); e = a.length - 1; l.nodeIdCompat && R.test(a[e]) && (a[e] = a[e].replace(R, "")); n = a = n.concat(a); d = n.length; for (e = 0; e < d; e++) if (c = n[e], "." === c) n.splice(e, 1), e -= 1; else if (".." === c) if (1 === e && (".." === n[2] || ".." === n[0])) break; else 0 < e && (n.splice(e - 1, 2), e -= 2); a = a.join("/")
            } else 0 === a.indexOf("./") && (a = a.substring(2)); if (b && m && (I || k)) {
                n = a.split("/"); e = n.length; a: for (; 0 < e; e -= 1) {
                    d = n.slice(0, e).join("/"); if (I) for (c = I.length; 0 < c; c -= 1) if (b = j(m, I.slice(0, c).join("/"))) if (b = j(b, d)) {
                        f = b;
                        g = e; break a
                    } !h && (k && j(k, d)) && (h = j(k, d), i = e)
                } !f && h && (f = h, g = i); f && (n.splice(0, g, f), a = n.join("/"))
            } return (f = j(l.pkgs, a)) ? f : a
        } function d(a) { z && v(document.getElementsByTagName("script"), function (e) { if (e.getAttribute("data-requiremodule") === a && e.getAttribute("data-requirecontext") === i.contextName) return e.parentNode.removeChild(e), !0 }) } function g(a) { var e = j(l.paths, a); if (e && H(e) && 1 < e.length) return e.shift(), i.require.undef(a), i.require([a]), !0 } function u(a) {
            var e; return [e, a];
        } function m(a, e, b, f) { var n, d, g = null, h = e ? e.name : null, l = a, m = !0, k = ""; a || (m = !1, a = "_@r" + (M += 1)); a = u(a); g = a[0]; a = a[1]; g && (g = c(g, h, f), d = j(p, g)); a && (g ? k = d && d.normalize ? d.normalize(a, function (a) { return c(a, h, f) }) : c(a, h, f) : (k = c(a, h, f), a = u(k), g = a[0], k = a[1], b = !0, n = i.nameToUrl(k))); b = g && !d && !b ? "_unnormalized" + (Q += 1) : ""; return { prefix: g, name: k, parentMap: e, unnormalized: !!b, url: n, originalName: l, isDefine: m, id: (g ? g + "!" + k : k) + b } } function q(a) {
            var e = a.id, b = j(k, e); b || (b = k[e] = new i.Module(a));
            return b
        } function r(a, e, b) { var f = a.id, n = j(k, f); if (s(p, f) && (!n || n.defineEmitComplete)) "defined" === e && b(p[f]); else if (n = q(a), n.error && "error" === e) b(n.error); else n.on(e, b) } function w(a, e) { var b = a.requireModules, f = !1; if (e) e(a); else if (v(b, function (e) { if (e = j(k, e)) e.error = a, e.events.error && (f = !0, e.emit("error", a)) }), !f) h.onError(a) } function x() { S.length && (ia.apply(A, [A.length, 0].concat(S)), S = []) } function y(a) { delete k[a]; delete W[a] } function F(a, e, b) {
            var f = a.map.id; a.error ? a.emit("error", a.error) : (e[f] =
            !0, v(a.depMaps, function (f, c) { var d = f.id, g = j(k, d); g && (!a.depMatched[c] && !b[d]) && (j(e, d) ? (a.defineDep(c, p[d]), a.check()) : F(g, e, b)) }), b[f] = !0)
        } function D() {
            var a, e, b = (a = 1E3 * l.waitSeconds) && i.startTime + a < (new Date).getTime(), f = [], c = [], h = !1, k = !0; if (!X) {
                X = !0; B(W, function (a) { var i = a.map, m = i.id; if (a.enabled && (i.isDefine || c.push(a), !a.error)) if (!a.inited && b) g(m) ? h = e = !0 : (f.push(m), d(m)); else if (!a.inited && (a.fetched && i.isDefine) && (h = !0, !i.prefix)) return k = !1 }); if (b && f.length) return a = C("timeout", "Load timeout for modules: " +
                f, null, f), a.contextName = i.contextName, w(a); k && v(c, function (a) { F(a, {}, {}) }); if ((!b || e) && h) if ((z || fa) && !Y) Y = setTimeout(function () { Y = 0; D() }, 50); X = !1
            }
        } function E(a) { s(p, a[0]) || q(m(a[0], null, !0)).init(a[1], a[2]) } function K(a) { var a = a.currentTarget || a.srcElement, e = i.onScriptLoad; a.detachEvent && !Z ? a.detachEvent("onreadystatechange", e) : a.removeEventListener("load", e, !1); e = i.onScriptError; (!a.detachEvent || Z) && a.removeEventListener("error", e, !1); return { node: a, id: a && a.getAttribute("data-requiremodule") } } function L() {
            var a;
            for (x() ; A.length;) { a = A.shift(); if (null === a[0]) return w(C("mismatch", "Mismatched anonymous define() module: " + a[a.length - 1])); E(a) }
        } var X, $, i, N, Y, l = { waitSeconds: 7, baseUrl: "./", paths: {}, bundles: {}, pkgs: {}, shim: {}, config: {} }, k = {}, W = {}, aa = {}, A = [], p = {}, T = {}, ba = {}, M = 1, Q = 1; N = {
            require: function (a) { return a.require ? a.require : a.require = i.makeRequire(a.map) }, exports: function (a) { a.usingExports = !0; if (a.map.isDefine) return a.exports ? p[a.map.id] = a.exports : a.exports = p[a.map.id] = {} }, module: function (a) {
                return a.module ?
                a.module : a.module = { id: a.map.id, uri: a.map.url, config: function () { return j(l.config, a.map.id) || {} }, exports: a.exports || (a.exports = {}) }
            }
        }; $ = function (a) { this.events = j(aa, a.id) || {}; this.map = a; this.shim = j(l.shim, a.id); this.depExports = []; this.depMaps = []; this.depMatched = []; this.pluginMaps = {}; this.depCount = 0 }; $.prototype = {
            init: function (a, e, b, f) {
                f = f || {}; if (!this.inited) {
                    this.factory = e; if (b) this.on("error", b); else this.events.error && (b = t(this, function (a) { this.emit("error", a) })); this.depMaps = a && a.slice(0); this.errback =
                    b; this.inited = !0; this.ignore = f.ignore; f.enabled || this.enabled ? this.enable() : this.check()
                }
            }, defineDep: function (a, e) { this.depMatched[a] || (this.depMatched[a] = !0, this.depCount -= 1, this.depExports[a] = e) }, fetch: function () { if (!this.fetched) { this.fetched = !0; i.startTime = (new Date).getTime(); var a = this.map; if (this.shim) i.makeRequire(this.map, { enableBuildCallback: !0 })(this.shim.deps || [], t(this, function () { return a.prefix ? this.callPlugin() : this.load() })); else return a.prefix ? this.callPlugin() : this.load() } }, load: function () {
                var a =
                this.map.url; T[a] || (T[a] = !0, i.load(this.map.id, a))
            }, check: function () {
                if (this.enabled && !this.enabling) {
                    var a, e, b = this.map.id; e = this.depExports; var f = this.exports, c = this.factory; if (this.inited) if (this.error) this.emit("error", this.error); else {
                        if (!this.defining) {
                            this.defining = !0; if (1 > this.depCount && !this.defined) {
                                if (G(c)) {
                                    if (this.events.error && this.map.isDefine || h.onError !== da) try { f = i.execCb(b, c, e, f) } catch (d) { a = d } else f = i.execCb(b, c, e, f); this.map.isDefine && void 0 === f && ((e = this.module) ? f = e.exports : this.usingExports &&
                                    (f = this.exports)); if (a) return a.requireMap = this.map, a.requireModules = this.map.isDefine ? [this.map.id] : null, a.requireType = this.map.isDefine ? "define" : "require", w(this.error = a)
                                } else f = c; this.exports = f; if (this.map.isDefine && !this.ignore && (p[b] = f, h.onResourceLoad)) h.onResourceLoad(i, this.map, this.depMaps); y(b); this.defined = !0
                            } this.defining = !1; this.defined && !this.defineEmitted && (this.defineEmitted = !0, this.emit("defined", this.exports), this.defineEmitComplete = !0)
                        }
                    } else this.fetch()
                }
            }, callPlugin: function () {
                var a =
                this.map, b = a.id, d = m(a.prefix); this.depMaps.push(d); r(d, "defined", t(this, function (f) {
                    var d, g; g = j(ba, this.map.id); var J = this.map.name, u = this.map.parentMap ? this.map.parentMap.name : null, p = i.makeRequire(a.parentMap, { enableBuildCallback: !0 }); if (this.map.unnormalized) {
                        if (f.normalize && (J = f.normalize(J, function (a) { return c(a, u, !0) }) || ""), f = m(a.prefix + "!" + J, this.map.parentMap), r(f, "defined", t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0, ignore: !0 }) })), g = j(k, f.id)) {
                            this.depMaps.push(f);
                            if (this.events.error) g.on("error", t(this, function (a) { this.emit("error", a) })); g.enable()
                        }
                    } else g ? (this.map.url = i.nameToUrl(g), this.load()) : (d = t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0 }) }), d.error = t(this, function (a) { this.inited = !0; this.error = a; a.requireModules = [b]; B(k, function (a) { 0 === a.map.id.indexOf(b + "_unnormalized") && y(a.map.id) }); w(a) }), d.fromText = t(this, function (f, c) {
                        var g = a.name, J = m(g), k = O; c && (f = c); k && (O = !1); q(J); s(l.config, b) && (l.config[g] = l.config[b]); try { h.exec(f) } catch (j) {
                            return w(C("fromtexteval",
                            "fromText eval for " + b + " failed: " + j, j, [b]))
                        } k && (O = !0); this.depMaps.push(J); i.completeLoad(g); p([g], d)
                    }), f.load(a.name, p, d, l))
                })); i.enable(d, this); this.pluginMaps[d.id] = d
            }, enable: function () {
                W[this.map.id] = this; this.enabling = this.enabled = !0; v(this.depMaps, t(this, function (a, b) {
                    var c, f; if ("string" === typeof a) {
                        a = m(a, this.map.isDefine ? this.map : this.map.parentMap, !1, !this.skipMap); this.depMaps[b] = a; if (c = j(N, a.id)) { this.depExports[b] = c(this); return } this.depCount += 1; r(a, "defined", t(this, function (a) {
                            this.defineDep(b,
                            a); this.check()
                        })); this.errback && r(a, "error", t(this, this.errback))
                    } c = a.id; f = k[c]; !s(N, c) && (f && !f.enabled) && i.enable(a, this)
                })); B(this.pluginMaps, t(this, function (a) { var b = j(k, a.id); b && !b.enabled && i.enable(a, this) })); this.enabling = !1; this.check()
            }, on: function (a, b) { var c = this.events[a]; c || (c = this.events[a] = []); c.push(b) }, emit: function (a, b) { v(this.events[a], function (a) { a(b) }); "error" === a && delete this.events[a] }
        }; i = {
            config: l, contextName: b, registry: k, defined: p, urlFetched: T, defQueue: A, Module: $, makeModuleMap: m,
            nextTick: h.nextTick, onError: w, configure: function (a) {
                a.baseUrl && "/" !== a.baseUrl.charAt(a.baseUrl.length - 1) && (a.baseUrl += "/"); var b = l.shim, c = { paths: !0, bundles: !0, config: !0, map: !0 }; B(a, function (a, b) { c[b] ? (l[b] || (l[b] = {}), V(l[b], a, !0, !0)) : l[b] = a }); a.bundles && B(a.bundles, function (a, b) { v(a, function (a) { a !== b && (ba[a] = b) }) }); a.shim && (B(a.shim, function (a, c) { H(a) && (a = { deps: a }); if ((a.exports || a.init) && !a.exportsFn) a.exportsFn = i.makeShimExports(a); b[c] = a }), l.shim = b); a.packages && v(a.packages, function (a) {
                    var b,
                    a = "string" === typeof a ? { name: a } : a; b = a.name; a.location && (l.paths[b] = a.location); l.pkgs[b] = a.name + "/" + (a.main || "main").replace(ja, "").replace(R, "")
                }); B(k, function (a, b) { !a.inited && !a.map.unnormalized && (a.map = m(b)) }); if (a.deps || a.callback) i.require(a.deps || [], a.callback)
            }, makeShimExports: function (a) { return function () { var b; a.init && (b = a.init.apply(ca, arguments)); return b || a.exports && ea(a.exports) } }, makeRequire: function (a, e) {
                function g(f, c, d) {
                    var j, l; e.enableBuildCallback && (c && G(c)) && (c.__requireJsBuild =
                    !0); if ("string" === typeof f) { if (G(c)) return w(C("requireargs", "Invalid require call"), d); if (a && s(N, f)) return N[f](k[a.id]); if (h.get) return h.get(i, f, a, g); j = m(f, a, !1, !0); j = j.id; return !s(p, j) ? w(C("notloaded", 'Module name "' + j + '" has not been loaded yet for context: ' + b + (a ? "" : ". Use require([])"))) : p[j] } L(); i.nextTick(function () { L(); l = q(m(null, a)); l.skipMap = e.skipMap; l.init(f, c, d, { enabled: !0 }); D() }); return g
                } e = e || {}; V(g, {
                    isBrowser: z, toUrl: function (b) {
                        var e, d = b.lastIndexOf("."), g = b.split("/")[0]; if (-1 !==
                        d && (!("." === g || ".." === g) || 1 < d)) e = b.substring(d, b.length), b = b.substring(0, d); return i.nameToUrl(c(b, a && a.id, !0), e, !0)
                    }, defined: function (b) { return s(p, m(b, a, !1, !0).id) }, specified: function (b) { b = m(b, a, !1, !0).id; return s(p, b) || s(k, b) }
                }); a || (g.undef = function (b) { x(); var c = m(b, a, !0), e = j(k, b); d(b); delete p[b]; delete T[c.url]; delete aa[b]; U(A, function (a, c) { a[0] === b && A.splice(c, 1) }); e && (e.events.defined && (aa[b] = e.events), y(b)) }); return g
            }, enable: function (a) { j(k, a.id) && q(a).enable() }, completeLoad: function (a) {
                var b,
                c, f = j(l.shim, a) || {}, d = f.exports; for (x() ; A.length;) { c = A.shift(); if (null === c[0]) { c[0] = a; if (b) break; b = !0 } else c[0] === a && (b = !0); E(c) } c = j(k, a); if (!b && !s(p, a) && c && !c.inited) { if (l.enforceDefine && (!d || !ea(d))) return g(a) ? void 0 : w(C("nodefine", "No define call for " + a, null, [a])); E([a, f.deps || [], f.exportsFn]) } D()
            }, nameToUrl: function (a, b, c) {
                var f, d, g; (f = j(l.pkgs, a)) && (a = f); if (f = j(ba, a)) return i.nameToUrl(f, b, c); if (h.jsExtRegExp.test(a)) f = a + (b || ""); else {
                    f = l.paths; a = a.split("/"); for (d = a.length; 0 < d; d -= 1) if (g = a.slice(0,
                    d).join("/"), g = j(f, g)) { H(g) && (g = g[0]); a.splice(0, d, g); break } f = a.join("/"); f += b || (/^data\:|\?/.test(f) || c ? "" : ".js"); f = ("/" === f.charAt(0) || f.match(/^[\w\+\.\-]+:/) ? "" : l.baseUrl) + f
                } return l.urlArgs ? f + ((-1 === f.indexOf("?") ? "?" : "&") + l.urlArgs) : f
            }, load: function (a, b) { h.load(i, a, b) }, execCb: function (a, b, c, d) { return b.apply(d, c) }, onScriptLoad: function (a) { if ("load" === a.type || ka.test((a.currentTarget || a.srcElement).readyState)) P = null, a = K(a), i.completeLoad(a.id) }, onScriptError: function (a) {
                var b = K(a); if (!g(b.id)) return w(C("scripterror",
                "Script error for: " + b.id, a, [b.id]))
            }
        }; i.require = i.makeRequire(); return i
    } var h, x, y, D, K, E, P, L, q, Q, la = /(\/\*([\s\S]*?)\*\/|([^:]|^)\/\/(.*)$)/mg, ma = /[^.]\s*require\s*\(\s*["']([^'"\s]+)["']\s*\)/g, R = /\.js$/, ja = /^\.\//; x = Object.prototype; var M = x.toString, ga = x.hasOwnProperty, ia = Array.prototype.splice, z = !!("undefined" !== typeof window && "undefined" !== typeof navigator && window.document), fa = !z && "undefined" !== typeof importScripts, ka = z && "PLAYSTATION 3" === navigator.platform ? /^complete$/ : /^(complete|loaded)$/,
    Z = "undefined" !== typeof opera && "[object Opera]" === opera.toString(), F = {}, r = {}, S = [], O = !1; if ("undefined" === typeof define) {
        if ("undefined" !== typeof requirejs) { if (G(requirejs)) return; r = requirejs; requirejs = void 0 } "undefined" !== typeof require && !G(require) && (r = require, require = void 0); h = requirejs = function (b, c, d, g) { var u, m = "_"; !H(b) && "string" !== typeof b && (u = b, H(c) ? (b = c, c = d, d = g) : b = []); u && u.context && (m = u.context); (g = j(F, m)) || (g = F[m] = h.s.newContext(m)); u && g.configure(u); return g.require(b, c, d) }; h.config = function (b) { return h(b) };
        h.nextTick = "undefined" !== typeof setTimeout ? function (b) { setTimeout(b, 4) } : function (b) { b() }; require || (require = h); h.version = "2.1.11"; h.jsExtRegExp = /^\/|:|\?|\.js$/; h.isBrowser = z; x = h.s = { contexts: F, newContext: ha }; h({}); v(["toUrl", "undef", "defined", "specified"], function (b) { h[b] = function () { var c = F._; return c.require[b].apply(c, arguments) } }); if (z && (y = x.head = document.getElementsByTagName("head")[0], D = document.getElementsByTagName("base")[0])) y = x.head = D.parentNode; h.onError = da; h.createNode = function (b) {
            var c =
            b.xhtml ? document.createElementNS("http://www.w3.org/1999/xhtml", "html:script") : document.createElement("script"); c.type = b.scriptType || "text/javascript"; c.charset = "utf-8"; c.async = !0; return c
        }; h.load = function (b, c, d) {
            var g = b && b.config || {}; if (z) return g = h.createNode(g, c, d), g.setAttribute("data-requirecontext", b.contextName), g.setAttribute("data-requiremodule", c), g.attachEvent && !(g.attachEvent.toString && 0 > g.attachEvent.toString().indexOf("[native code")) && !Z ? (O = !0, g.attachEvent("onreadystatechange", b.onScriptLoad)) :
            (g.addEventListener("load", b.onScriptLoad, !1), g.addEventListener("error", b.onScriptError, !1)), g.src = d, L = g, D ? y.insertBefore(g, D) : y.appendChild(g), L = null, g; if (fa) try { importScripts(d), b.completeLoad(c) } catch (j) { b.onError(C("importscripts", "importScripts failed for " + c + " at " + d, j, [c])) }
        }; z && !r.skipDataMain && U(document.getElementsByTagName("script"), function (b) {
            y || (y = b.parentNode); if (K = b.getAttribute("data-main")) return q = K, r.baseUrl || (E = q.split("/"), q = E.pop(), Q = E.length ? E.join("/") + "/" : "./", r.baseUrl =
            Q), q = q.replace(R, ""), h.jsExtRegExp.test(q) && (q = K), r.deps = r.deps ? r.deps.concat(q) : [q], !0
        }); define = function (b, c, d) {
            var g, h; "string" !== typeof b && (d = c, c = b, b = null); H(c) || (d = c, c = null); !c && G(d) && (c = [], d.length && (d.toString().replace(la, "").replace(ma, function (b, d) { c.push(d) }), c = (1 === d.length ? ["require"] : ["require", "exports", "module"]).concat(c))); if (O) {
                if (!(g = L)) P && "interactive" === P.readyState || U(document.getElementsByTagName("script"), function (b) { if ("interactive" === b.readyState) return P = b }), g = P; g && (b ||
                (b = g.getAttribute("data-requiremodule")), h = F[g.getAttribute("data-requirecontext")])
            } (h ? h.defQueue : S).push([b, c, d])
        }; define.amd = { jQuery: !0 }; h.exec = function (b) { return eval(b) }; h(r)
    }
})(this);/* require end */

/*! jQuery v1.8.3 jquery.com | jquery.org/license */
(function(e,t){function _(e){var t=M[e]={};return v.each(e.split(y),function(e,n){t[n]=!0}),t}function H(e,n,r){if(r===t&&e.nodeType===1){var i="data-"+n.replace(P,"-$1").toLowerCase();r=e.getAttribute(i);if(typeof r=="string"){try{r=r==="true"?!0:r==="false"?!1:r==="null"?null:+r+""===r?+r:D.test(r)?v.parseJSON(r):r}catch(s){}v.data(e,n,r)}else r=t}return r}function B(e){var t;for(t in e){if(t==="data"&&v.isEmptyObject(e[t]))continue;if(t!=="toJSON")return!1}return!0}function et(){return!1}function tt(){return!0}function ut(e){return!e||!e.parentNode||e.parentNode.nodeType===11}function at(e,t){do e=e[t];while(e&&e.nodeType!==1);return e}function ft(e,t,n){t=t||0;if(v.isFunction(t))return v.grep(e,function(e,r){var i=!!t.call(e,r,e);return i===n});if(t.nodeType)return v.grep(e,function(e,r){return e===t===n});if(typeof t=="string"){var r=v.grep(e,function(e){return e.nodeType===1});if(it.test(t))return v.filter(t,r,!n);t=v.filter(t,r)}return v.grep(e,function(e,r){return v.inArray(e,t)>=0===n})}function lt(e){var t=ct.split("|"),n=e.createDocumentFragment();if(n.createElement)while(t.length)n.createElement(t.pop());return n}function Lt(e,t){return e.getElementsByTagName(t)[0]||e.appendChild(e.ownerDocument.createElement(t))}function At(e,t){if(t.nodeType!==1||!v.hasData(e))return;var n,r,i,s=v._data(e),o=v._data(t,s),u=s.events;if(u){delete o.handle,o.events={};for(n in u)for(r=0,i=u[n].length;r<i;r++)v.event.add(t,n,u[n][r])}o.data&&(o.data=v.extend({},o.data))}function Ot(e,t){var n;if(t.nodeType!==1)return;t.clearAttributes&&t.clearAttributes(),t.mergeAttributes&&t.mergeAttributes(e),n=t.nodeName.toLowerCase(),n==="object"?(t.parentNode&&(t.outerHTML=e.outerHTML),v.support.html5Clone&&e.innerHTML&&!v.trim(t.innerHTML)&&(t.innerHTML=e.innerHTML)):n==="input"&&Et.test(e.type)?(t.defaultChecked=t.checked=e.checked,t.value!==e.value&&(t.value=e.value)):n==="option"?t.selected=e.defaultSelected:n==="input"||n==="textarea"?t.defaultValue=e.defaultValue:n==="script"&&t.text!==e.text&&(t.text=e.text),t.removeAttribute(v.expando)}function Mt(e){return typeof e.getElementsByTagName!="undefined"?e.getElementsByTagName("*"):typeof e.querySelectorAll!="undefined"?e.querySelectorAll("*"):[]}function _t(e){Et.test(e.type)&&(e.defaultChecked=e.checked)}function Qt(e,t){if(t in e)return t;var n=t.charAt(0).toUpperCase()+t.slice(1),r=t,i=Jt.length;while(i--){t=Jt[i]+n;if(t in e)return t}return r}function Gt(e,t){return e=t||e,v.css(e,"display")==="none"||!v.contains(e.ownerDocument,e)}function Yt(e,t){var n,r,i=[],s=0,o=e.length;for(;s<o;s++){n=e[s];if(!n.style)continue;i[s]=v._data(n,"olddisplay"),t?(!i[s]&&n.style.display==="none"&&(n.style.display=""),n.style.display===""&&Gt(n)&&(i[s]=v._data(n,"olddisplay",nn(n.nodeName)))):(r=Dt(n,"display"),!i[s]&&r!=="none"&&v._data(n,"olddisplay",r))}for(s=0;s<o;s++){n=e[s];if(!n.style)continue;if(!t||n.style.display==="none"||n.style.display==="")n.style.display=t?i[s]||"":"none"}return e}function Zt(e,t,n){var r=Rt.exec(t);return r?Math.max(0,r[1]-(n||0))+(r[2]||"px"):t}function en(e,t,n,r){var i=n===(r?"border":"content")?4:t==="width"?1:0,s=0;for(;i<4;i+=2)n==="margin"&&(s+=v.css(e,n+$t[i],!0)),r?(n==="content"&&(s-=parseFloat(Dt(e,"padding"+$t[i]))||0),n!=="margin"&&(s-=parseFloat(Dt(e,"border"+$t[i]+"Width"))||0)):(s+=parseFloat(Dt(e,"padding"+$t[i]))||0,n!=="padding"&&(s+=parseFloat(Dt(e,"border"+$t[i]+"Width"))||0));return s}function tn(e,t,n){var r=t==="width"?e.offsetWidth:e.offsetHeight,i=!0,s=v.support.boxSizing&&v.css(e,"boxSizing")==="border-box";if(r<=0||r==null){r=Dt(e,t);if(r<0||r==null)r=e.style[t];if(Ut.test(r))return r;i=s&&(v.support.boxSizingReliable||r===e.style[t]),r=parseFloat(r)||0}return r+en(e,t,n||(s?"border":"content"),i)+"px"}function nn(e){if(Wt[e])return Wt[e];var t=v("<"+e+">").appendTo(i.body),n=t.css("display");t.remove();if(n==="none"||n===""){Pt=i.body.appendChild(Pt||v.extend(i.createElement("iframe"),{frameBorder:0,width:0,height:0}));if(!Ht||!Pt.createElement)Ht=(Pt.contentWindow||Pt.contentDocument).document,Ht.write("<!doctype html><html><body>"),Ht.close();t=Ht.body.appendChild(Ht.createElement(e)),n=Dt(t,"display"),i.body.removeChild(Pt)}return Wt[e]=n,n}function fn(e,t,n,r){var i;if(v.isArray(t))v.each(t,function(t,i){n||sn.test(e)?r(e,i):fn(e+"["+(typeof i=="object"?t:"")+"]",i,n,r)});else if(!n&&v.type(t)==="object")for(i in t)fn(e+"["+i+"]",t[i],n,r);else r(e,t)}function Cn(e){return function(t,n){typeof t!="string"&&(n=t,t="*");var r,i,s,o=t.toLowerCase().split(y),u=0,a=o.length;if(v.isFunction(n))for(;u<a;u++)r=o[u],s=/^\+/.test(r),s&&(r=r.substr(1)||"*"),i=e[r]=e[r]||[],i[s?"unshift":"push"](n)}}function kn(e,n,r,i,s,o){s=s||n.dataTypes[0],o=o||{},o[s]=!0;var u,a=e[s],f=0,l=a?a.length:0,c=e===Sn;for(;f<l&&(c||!u);f++)u=a[f](n,r,i),typeof u=="string"&&(!c||o[u]?u=t:(n.dataTypes.unshift(u),u=kn(e,n,r,i,u,o)));return(c||!u)&&!o["*"]&&(u=kn(e,n,r,i,"*",o)),u}function Ln(e,n){var r,i,s=v.ajaxSettings.flatOptions||{};for(r in n)n[r]!==t&&((s[r]?e:i||(i={}))[r]=n[r]);i&&v.extend(!0,e,i)}function An(e,n,r){var i,s,o,u,a=e.contents,f=e.dataTypes,l=e.responseFields;for(s in l)s in r&&(n[l[s]]=r[s]);while(f[0]==="*")f.shift(),i===t&&(i=e.mimeType||n.getResponseHeader("content-type"));if(i)for(s in a)if(a[s]&&a[s].test(i)){f.unshift(s);break}if(f[0]in r)o=f[0];else{for(s in r){if(!f[0]||e.converters[s+" "+f[0]]){o=s;break}u||(u=s)}o=o||u}if(o)return o!==f[0]&&f.unshift(o),r[o]}function On(e,t){var n,r,i,s,o=e.dataTypes.slice(),u=o[0],a={},f=0;e.dataFilter&&(t=e.dataFilter(t,e.dataType));if(o[1])for(n in e.converters)a[n.toLowerCase()]=e.converters[n];for(;i=o[++f];)if(i!=="*"){if(u!=="*"&&u!==i){n=a[u+" "+i]||a["* "+i];if(!n)for(r in a){s=r.split(" ");if(s[1]===i){n=a[u+" "+s[0]]||a["* "+s[0]];if(n){n===!0?n=a[r]:a[r]!==!0&&(i=s[0],o.splice(f--,0,i));break}}}if(n!==!0)if(n&&e["throws"])t=n(t);else try{t=n(t)}catch(l){return{state:"parsererror",error:n?l:"No conversion from "+u+" to "+i}}}u=i}return{state:"success",data:t}}function Fn(){try{return new e.XMLHttpRequest}catch(t){}}function In(){try{return new e.ActiveXObject("Microsoft.XMLHTTP")}catch(t){}}function $n(){return setTimeout(function(){qn=t},0),qn=v.now()}function Jn(e,t){v.each(t,function(t,n){var r=(Vn[t]||[]).concat(Vn["*"]),i=0,s=r.length;for(;i<s;i++)if(r[i].call(e,t,n))return})}function Kn(e,t,n){var r,i=0,s=0,o=Xn.length,u=v.Deferred().always(function(){delete a.elem}),a=function(){var t=qn||$n(),n=Math.max(0,f.startTime+f.duration-t),r=n/f.duration||0,i=1-r,s=0,o=f.tweens.length;for(;s<o;s++)f.tweens[s].run(i);return u.notifyWith(e,[f,i,n]),i<1&&o?n:(u.resolveWith(e,[f]),!1)},f=u.promise({elem:e,props:v.extend({},t),opts:v.extend(!0,{specialEasing:{}},n),originalProperties:t,originalOptions:n,startTime:qn||$n(),duration:n.duration,tweens:[],createTween:function(t,n,r){var i=v.Tween(e,f.opts,t,n,f.opts.specialEasing[t]||f.opts.easing);return f.tweens.push(i),i},stop:function(t){var n=0,r=t?f.tweens.length:0;for(;n<r;n++)f.tweens[n].run(1);return t?u.resolveWith(e,[f,t]):u.rejectWith(e,[f,t]),this}}),l=f.props;Qn(l,f.opts.specialEasing);for(;i<o;i++){r=Xn[i].call(f,e,l,f.opts);if(r)return r}return Jn(f,l),v.isFunction(f.opts.start)&&f.opts.start.call(e,f),v.fx.timer(v.extend(a,{anim:f,queue:f.opts.queue,elem:e})),f.progress(f.opts.progress).done(f.opts.done,f.opts.complete).fail(f.opts.fail).always(f.opts.always)}function Qn(e,t){var n,r,i,s,o;for(n in e){r=v.camelCase(n),i=t[r],s=e[n],v.isArray(s)&&(i=s[1],s=e[n]=s[0]),n!==r&&(e[r]=s,delete e[n]),o=v.cssHooks[r];if(o&&"expand"in o){s=o.expand(s),delete e[r];for(n in s)n in e||(e[n]=s[n],t[n]=i)}else t[r]=i}}function Gn(e,t,n){var r,i,s,o,u,a,f,l,c,h=this,p=e.style,d={},m=[],g=e.nodeType&&Gt(e);n.queue||(l=v._queueHooks(e,"fx"),l.unqueued==null&&(l.unqueued=0,c=l.empty.fire,l.empty.fire=function(){l.unqueued||c()}),l.unqueued++,h.always(function(){h.always(function(){l.unqueued--,v.queue(e,"fx").length||l.empty.fire()})})),e.nodeType===1&&("height"in t||"width"in t)&&(n.overflow=[p.overflow,p.overflowX,p.overflowY],v.css(e,"display")==="inline"&&v.css(e,"float")==="none"&&(!v.support.inlineBlockNeedsLayout||nn(e.nodeName)==="inline"?p.display="inline-block":p.zoom=1)),n.overflow&&(p.overflow="hidden",v.support.shrinkWrapBlocks||h.done(function(){p.overflow=n.overflow[0],p.overflowX=n.overflow[1],p.overflowY=n.overflow[2]}));for(r in t){s=t[r];if(Un.exec(s)){delete t[r],a=a||s==="toggle";if(s===(g?"hide":"show"))continue;m.push(r)}}o=m.length;if(o){u=v._data(e,"fxshow")||v._data(e,"fxshow",{}),"hidden"in u&&(g=u.hidden),a&&(u.hidden=!g),g?v(e).show():h.done(function(){v(e).hide()}),h.done(function(){var t;v.removeData(e,"fxshow",!0);for(t in d)v.style(e,t,d[t])});for(r=0;r<o;r++)i=m[r],f=h.createTween(i,g?u[i]:0),d[i]=u[i]||v.style(e,i),i in u||(u[i]=f.start,g&&(f.end=f.start,f.start=i==="width"||i==="height"?1:0))}}function Yn(e,t,n,r,i){return new Yn.prototype.init(e,t,n,r,i)}function Zn(e,t){var n,r={height:e},i=0;t=t?1:0;for(;i<4;i+=2-t)n=$t[i],r["margin"+n]=r["padding"+n]=e;return t&&(r.opacity=r.width=e),r}function tr(e){return v.isWindow(e)?e:e.nodeType===9?e.defaultView||e.parentWindow:!1}var n,r,i=e.document,s=e.location,o=e.navigator,u=e.jQuery,a=e.$,f=Array.prototype.push,l=Array.prototype.slice,c=Array.prototype.indexOf,h=Object.prototype.toString,p=Object.prototype.hasOwnProperty,d=String.prototype.trim,v=function(e,t){return new v.fn.init(e,t,n)},m=/[\-+]?(?:\d*\.|)\d+(?:[eE][\-+]?\d+|)/.source,g=/\S/,y=/\s+/,b=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,w=/^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,E=/^<(\w+)\s*\/?>(?:<\/\1>|)$/,S=/^[\],:{}\s]*$/,x=/(?:^|:|,)(?:\s*\[)+/g,T=/\\(?:["\\\/bfnrt]|u[\da-fA-F]{4})/g,N=/"[^"\\\r\n]*"|true|false|null|-?(?:\d\d*\.|)\d+(?:[eE][\-+]?\d+|)/g,C=/^-ms-/,k=/-([\da-z])/gi,L=function(e,t){return(t+"").toUpperCase()},A=function(){i.addEventListener?(i.removeEventListener("DOMContentLoaded",A,!1),v.ready()):i.readyState==="complete"&&(i.detachEvent("onreadystatechange",A),v.ready())},O={};v.fn=v.prototype={constructor:v,init:function(e,n,r){var s,o,u,a;if(!e)return this;if(e.nodeType)return this.context=this[0]=e,this.length=1,this;if(typeof e=="string"){e.charAt(0)==="<"&&e.charAt(e.length-1)===">"&&e.length>=3?s=[null,e,null]:s=w.exec(e);if(s&&(s[1]||!n)){if(s[1])return n=n instanceof v?n[0]:n,a=n&&n.nodeType?n.ownerDocument||n:i,e=v.parseHTML(s[1],a,!0),E.test(s[1])&&v.isPlainObject(n)&&this.attr.call(e,n,!0),v.merge(this,e);o=i.getElementById(s[2]);if(o&&o.parentNode){if(o.id!==s[2])return r.find(e);this.length=1,this[0]=o}return this.context=i,this.selector=e,this}return!n||n.jquery?(n||r).find(e):this.constructor(n).find(e)}return v.isFunction(e)?r.ready(e):(e.selector!==t&&(this.selector=e.selector,this.context=e.context),v.makeArray(e,this))},selector:"",jquery:"1.8.3",length:0,size:function(){return this.length},toArray:function(){return l.call(this)},get:function(e){return e==null?this.toArray():e<0?this[this.length+e]:this[e]},pushStack:function(e,t,n){var r=v.merge(this.constructor(),e);return r.prevObject=this,r.context=this.context,t==="find"?r.selector=this.selector+(this.selector?" ":"")+n:t&&(r.selector=this.selector+"."+t+"("+n+")"),r},each:function(e,t){return v.each(this,e,t)},ready:function(e){return v.ready.promise().done(e),this},eq:function(e){return e=+e,e===-1?this.slice(e):this.slice(e,e+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(l.apply(this,arguments),"slice",l.call(arguments).join(","))},map:function(e){return this.pushStack(v.map(this,function(t,n){return e.call(t,n,t)}))},end:function(){return this.prevObject||this.constructor(null)},push:f,sort:[].sort,splice:[].splice},v.fn.init.prototype=v.fn,v.extend=v.fn.extend=function(){var e,n,r,i,s,o,u=arguments[0]||{},a=1,f=arguments.length,l=!1;typeof u=="boolean"&&(l=u,u=arguments[1]||{},a=2),typeof u!="object"&&!v.isFunction(u)&&(u={}),f===a&&(u=this,--a);for(;a<f;a++)if((e=arguments[a])!=null)for(n in e){r=u[n],i=e[n];if(u===i)continue;l&&i&&(v.isPlainObject(i)||(s=v.isArray(i)))?(s?(s=!1,o=r&&v.isArray(r)?r:[]):o=r&&v.isPlainObject(r)?r:{},u[n]=v.extend(l,o,i)):i!==t&&(u[n]=i)}return u},v.extend({noConflict:function(t){return e.$===v&&(e.$=a),t&&e.jQuery===v&&(e.jQuery=u),v},isReady:!1,readyWait:1,holdReady:function(e){e?v.readyWait++:v.ready(!0)},ready:function(e){if(e===!0?--v.readyWait:v.isReady)return;if(!i.body)return setTimeout(v.ready,1);v.isReady=!0;if(e!==!0&&--v.readyWait>0)return;r.resolveWith(i,[v]),v.fn.trigger&&v(i).trigger("ready").off("ready")},isFunction:function(e){return v.type(e)==="function"},isArray:Array.isArray||function(e){return v.type(e)==="array"},isWindow:function(e){return e!=null&&e==e.window},isNumeric:function(e){return!isNaN(parseFloat(e))&&isFinite(e)},type:function(e){return e==null?String(e):O[h.call(e)]||"object"},isPlainObject:function(e){if(!e||v.type(e)!=="object"||e.nodeType||v.isWindow(e))return!1;try{if(e.constructor&&!p.call(e,"constructor")&&!p.call(e.constructor.prototype,"isPrototypeOf"))return!1}catch(n){return!1}var r;for(r in e);return r===t||p.call(e,r)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},error:function(e){throw new Error(e)},parseHTML:function(e,t,n){var r;return!e||typeof e!="string"?null:(typeof t=="boolean"&&(n=t,t=0),t=t||i,(r=E.exec(e))?[t.createElement(r[1])]:(r=v.buildFragment([e],t,n?null:[]),v.merge([],(r.cacheable?v.clone(r.fragment):r.fragment).childNodes)))},parseJSON:function(t){if(!t||typeof t!="string")return null;t=v.trim(t);if(e.JSON&&e.JSON.parse)return e.JSON.parse(t);if(S.test(t.replace(T,"@").replace(N,"]").replace(x,"")))return(new Function("return "+t))();v.error("Invalid JSON: "+t)},parseXML:function(n){var r,i;if(!n||typeof n!="string")return null;try{e.DOMParser?(i=new DOMParser,r=i.parseFromString(n,"text/xml")):(r=new ActiveXObject("Microsoft.XMLDOM"),r.async="false",r.loadXML(n))}catch(s){r=t}return(!r||!r.documentElement||r.getElementsByTagName("parsererror").length)&&v.error("Invalid XML: "+n),r},noop:function(){},globalEval:function(t){t&&g.test(t)&&(e.execScript||function(t){e.eval.call(e,t)})(t)},camelCase:function(e){return e.replace(C,"ms-").replace(k,L)},nodeName:function(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()},each:function(e,n,r){var i,s=0,o=e.length,u=o===t||v.isFunction(e);if(r){if(u){for(i in e)if(n.apply(e[i],r)===!1)break}else for(;s<o;)if(n.apply(e[s++],r)===!1)break}else if(u){for(i in e)if(n.call(e[i],i,e[i])===!1)break}else for(;s<o;)if(n.call(e[s],s,e[s++])===!1)break;return e},trim:d&&!d.call("\ufeff\u00a0")?function(e){return e==null?"":d.call(e)}:function(e){return e==null?"":(e+"").replace(b,"")},makeArray:function(e,t){var n,r=t||[];return e!=null&&(n=v.type(e),e.length==null||n==="string"||n==="function"||n==="regexp"||v.isWindow(e)?f.call(r,e):v.merge(r,e)),r},inArray:function(e,t,n){var r;if(t){if(c)return c.call(t,e,n);r=t.length,n=n?n<0?Math.max(0,r+n):n:0;for(;n<r;n++)if(n in t&&t[n]===e)return n}return-1},merge:function(e,n){var r=n.length,i=e.length,s=0;if(typeof r=="number")for(;s<r;s++)e[i++]=n[s];else while(n[s]!==t)e[i++]=n[s++];return e.length=i,e},grep:function(e,t,n){var r,i=[],s=0,o=e.length;n=!!n;for(;s<o;s++)r=!!t(e[s],s),n!==r&&i.push(e[s]);return i},map:function(e,n,r){var i,s,o=[],u=0,a=e.length,f=e instanceof v||a!==t&&typeof a=="number"&&(a>0&&e[0]&&e[a-1]||a===0||v.isArray(e));if(f)for(;u<a;u++)i=n(e[u],u,r),i!=null&&(o[o.length]=i);else for(s in e)i=n(e[s],s,r),i!=null&&(o[o.length]=i);return o.concat.apply([],o)},guid:1,proxy:function(e,n){var r,i,s;return typeof n=="string"&&(r=e[n],n=e,e=r),v.isFunction(e)?(i=l.call(arguments,2),s=function(){return e.apply(n,i.concat(l.call(arguments)))},s.guid=e.guid=e.guid||v.guid++,s):t},access:function(e,n,r,i,s,o,u){var a,f=r==null,l=0,c=e.length;if(r&&typeof r=="object"){for(l in r)v.access(e,n,l,r[l],1,o,i);s=1}else if(i!==t){a=u===t&&v.isFunction(i),f&&(a?(a=n,n=function(e,t,n){return a.call(v(e),n)}):(n.call(e,i),n=null));if(n)for(;l<c;l++)n(e[l],r,a?i.call(e[l],l,n(e[l],r)):i,u);s=1}return s?e:f?n.call(e):c?n(e[0],r):o},now:function(){return(new Date).getTime()}}),v.ready.promise=function(t){if(!r){r=v.Deferred();if(i.readyState==="complete")setTimeout(v.ready,1);else if(i.addEventListener)i.addEventListener("DOMContentLoaded",A,!1),e.addEventListener("load",v.ready,!1);else{i.attachEvent("onreadystatechange",A),e.attachEvent("onload",v.ready);var n=!1;try{n=e.frameElement==null&&i.documentElement}catch(s){}n&&n.doScroll&&function o(){if(!v.isReady){try{n.doScroll("left")}catch(e){return setTimeout(o,50)}v.ready()}}()}}return r.promise(t)},v.each("Boolean Number String Function Array Date RegExp Object".split(" "),function(e,t){O["[object "+t+"]"]=t.toLowerCase()}),n=v(i);var M={};v.Callbacks=function(e){e=typeof e=="string"?M[e]||_(e):v.extend({},e);var n,r,i,s,o,u,a=[],f=!e.once&&[],l=function(t){n=e.memory&&t,r=!0,u=s||0,s=0,o=a.length,i=!0;for(;a&&u<o;u++)if(a[u].apply(t[0],t[1])===!1&&e.stopOnFalse){n=!1;break}i=!1,a&&(f?f.length&&l(f.shift()):n?a=[]:c.disable())},c={add:function(){if(a){var t=a.length;(function r(t){v.each(t,function(t,n){var i=v.type(n);i==="function"?(!e.unique||!c.has(n))&&a.push(n):n&&n.length&&i!=="string"&&r(n)})})(arguments),i?o=a.length:n&&(s=t,l(n))}return this},remove:function(){return a&&v.each(arguments,function(e,t){var n;while((n=v.inArray(t,a,n))>-1)a.splice(n,1),i&&(n<=o&&o--,n<=u&&u--)}),this},has:function(e){return v.inArray(e,a)>-1},empty:function(){return a=[],this},disable:function(){return a=f=n=t,this},disabled:function(){return!a},lock:function(){return f=t,n||c.disable(),this},locked:function(){return!f},fireWith:function(e,t){return t=t||[],t=[e,t.slice?t.slice():t],a&&(!r||f)&&(i?f.push(t):l(t)),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!r}};return c},v.extend({Deferred:function(e){var t=[["resolve","done",v.Callbacks("once memory"),"resolved"],["reject","fail",v.Callbacks("once memory"),"rejected"],["notify","progress",v.Callbacks("memory")]],n="pending",r={state:function(){return n},always:function(){return i.done(arguments).fail(arguments),this},then:function(){var e=arguments;return v.Deferred(function(n){v.each(t,function(t,r){var s=r[0],o=e[t];i[r[1]](v.isFunction(o)?function(){var e=o.apply(this,arguments);e&&v.isFunction(e.promise)?e.promise().done(n.resolve).fail(n.reject).progress(n.notify):n[s+"With"](this===i?n:this,[e])}:n[s])}),e=null}).promise()},promise:function(e){return e!=null?v.extend(e,r):r}},i={};return r.pipe=r.then,v.each(t,function(e,s){var o=s[2],u=s[3];r[s[1]]=o.add,u&&o.add(function(){n=u},t[e^1][2].disable,t[2][2].lock),i[s[0]]=o.fire,i[s[0]+"With"]=o.fireWith}),r.promise(i),e&&e.call(i,i),i},when:function(e){var t=0,n=l.call(arguments),r=n.length,i=r!==1||e&&v.isFunction(e.promise)?r:0,s=i===1?e:v.Deferred(),o=function(e,t,n){return function(r){t[e]=this,n[e]=arguments.length>1?l.call(arguments):r,n===u?s.notifyWith(t,n):--i||s.resolveWith(t,n)}},u,a,f;if(r>1){u=new Array(r),a=new Array(r),f=new Array(r);for(;t<r;t++)n[t]&&v.isFunction(n[t].promise)?n[t].promise().done(o(t,f,n)).fail(s.reject).progress(o(t,a,u)):--i}return i||s.resolveWith(f,n),s.promise()}}),v.support=function(){var t,n,r,s,o,u,a,f,l,c,h,p=i.createElement("div");p.setAttribute("className","t"),p.innerHTML="  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>",n=p.getElementsByTagName("*"),r=p.getElementsByTagName("a")[0];if(!n||!r||!n.length)return{};s=i.createElement("select"),o=s.appendChild(i.createElement("option")),u=p.getElementsByTagName("input")[0],r.style.cssText="top:1px;float:left;opacity:.5",t={leadingWhitespace:p.firstChild.nodeType===3,tbody:!p.getElementsByTagName("tbody").length,htmlSerialize:!!p.getElementsByTagName("link").length,style:/top/.test(r.getAttribute("style")),hrefNormalized:r.getAttribute("href")==="/a",opacity:/^0.5/.test(r.style.opacity),cssFloat:!!r.style.cssFloat,checkOn:u.value==="on",optSelected:o.selected,getSetAttribute:p.className!=="t",enctype:!!i.createElement("form").enctype,html5Clone:i.createElement("nav").cloneNode(!0).outerHTML!=="<:nav></:nav>",boxModel:i.compatMode==="CSS1Compat",submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0,boxSizingReliable:!0,pixelPosition:!1},u.checked=!0,t.noCloneChecked=u.cloneNode(!0).checked,s.disabled=!0,t.optDisabled=!o.disabled;try{delete p.test}catch(d){t.deleteExpando=!1}!p.addEventListener&&p.attachEvent&&p.fireEvent&&(p.attachEvent("onclick",h=function(){t.noCloneEvent=!1}),p.cloneNode(!0).fireEvent("onclick"),p.detachEvent("onclick",h)),u=i.createElement("input"),u.value="t",u.setAttribute("type","radio"),t.radioValue=u.value==="t",u.setAttribute("checked","checked"),u.setAttribute("name","t"),p.appendChild(u),a=i.createDocumentFragment(),a.appendChild(p.lastChild),t.checkClone=a.cloneNode(!0).cloneNode(!0).lastChild.checked,t.appendChecked=u.checked,a.removeChild(u),a.appendChild(p);if(p.attachEvent)for(l in{submit:!0,change:!0,focusin:!0})f="on"+l,c=f in p,c||(p.setAttribute(f,"return;"),c=typeof p[f]=="function"),t[l+"Bubbles"]=c;return v(function(){var n,r,s,o,u="padding:0;margin:0;border:0;display:block;overflow:hidden;",a=i.getElementsByTagName("body")[0];if(!a)return;n=i.createElement("div"),n.style.cssText="visibility:hidden;border:0;width:0;height:0;position:static;top:0;margin-top:1px",a.insertBefore(n,a.firstChild),r=i.createElement("div"),n.appendChild(r),r.innerHTML="<table><tr><td></td><td>t</td></tr></table>",s=r.getElementsByTagName("td"),s[0].style.cssText="padding:0;margin:0;border:0;display:none",c=s[0].offsetHeight===0,s[0].style.display="",s[1].style.display="none",t.reliableHiddenOffsets=c&&s[0].offsetHeight===0,r.innerHTML="",r.style.cssText="box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;padding:1px;border:1px;display:block;width:4px;margin-top:1%;position:absolute;top:1%;",t.boxSizing=r.offsetWidth===4,t.doesNotIncludeMarginInBodyOffset=a.offsetTop!==1,e.getComputedStyle&&(t.pixelPosition=(e.getComputedStyle(r,null)||{}).top!=="1%",t.boxSizingReliable=(e.getComputedStyle(r,null)||{width:"4px"}).width==="4px",o=i.createElement("div"),o.style.cssText=r.style.cssText=u,o.style.marginRight=o.style.width="0",r.style.width="1px",r.appendChild(o),t.reliableMarginRight=!parseFloat((e.getComputedStyle(o,null)||{}).marginRight)),typeof r.style.zoom!="undefined"&&(r.innerHTML="",r.style.cssText=u+"width:1px;padding:1px;display:inline;zoom:1",t.inlineBlockNeedsLayout=r.offsetWidth===3,r.style.display="block",r.style.overflow="visible",r.innerHTML="<div></div>",r.firstChild.style.width="5px",t.shrinkWrapBlocks=r.offsetWidth!==3,n.style.zoom=1),a.removeChild(n),n=r=s=o=null}),a.removeChild(p),n=r=s=o=u=a=p=null,t}();var D=/(?:\{[\s\S]*\}|\[[\s\S]*\])$/,P=/([A-Z])/g;v.extend({cache:{},deletedIds:[],uuid:0,expando:"jQuery"+(v.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(e){return e=e.nodeType?v.cache[e[v.expando]]:e[v.expando],!!e&&!B(e)},data:function(e,n,r,i){if(!v.acceptData(e))return;var s,o,u=v.expando,a=typeof n=="string",f=e.nodeType,l=f?v.cache:e,c=f?e[u]:e[u]&&u;if((!c||!l[c]||!i&&!l[c].data)&&a&&r===t)return;c||(f?e[u]=c=v.deletedIds.pop()||v.guid++:c=u),l[c]||(l[c]={},f||(l[c].toJSON=v.noop));if(typeof n=="object"||typeof n=="function")i?l[c]=v.extend(l[c],n):l[c].data=v.extend(l[c].data,n);return s=l[c],i||(s.data||(s.data={}),s=s.data),r!==t&&(s[v.camelCase(n)]=r),a?(o=s[n],o==null&&(o=s[v.camelCase(n)])):o=s,o},removeData:function(e,t,n){if(!v.acceptData(e))return;var r,i,s,o=e.nodeType,u=o?v.cache:e,a=o?e[v.expando]:v.expando;if(!u[a])return;if(t){r=n?u[a]:u[a].data;if(r){v.isArray(t)||(t in r?t=[t]:(t=v.camelCase(t),t in r?t=[t]:t=t.split(" ")));for(i=0,s=t.length;i<s;i++)delete r[t[i]];if(!(n?B:v.isEmptyObject)(r))return}}if(!n){delete u[a].data;if(!B(u[a]))return}o?v.cleanData([e],!0):v.support.deleteExpando||u!=u.window?delete u[a]:u[a]=null},_data:function(e,t,n){return v.data(e,t,n,!0)},acceptData:function(e){var t=e.nodeName&&v.noData[e.nodeName.toLowerCase()];return!t||t!==!0&&e.getAttribute("classid")===t}}),v.fn.extend({data:function(e,n){var r,i,s,o,u,a=this[0],f=0,l=null;if(e===t){if(this.length){l=v.data(a);if(a.nodeType===1&&!v._data(a,"parsedAttrs")){s=a.attributes;for(u=s.length;f<u;f++)o=s[f].name,o.indexOf("data-")||(o=v.camelCase(o.substring(5)),H(a,o,l[o]));v._data(a,"parsedAttrs",!0)}}return l}return typeof e=="object"?this.each(function(){v.data(this,e)}):(r=e.split(".",2),r[1]=r[1]?"."+r[1]:"",i=r[1]+"!",v.access(this,function(n){if(n===t)return l=this.triggerHandler("getData"+i,[r[0]]),l===t&&a&&(l=v.data(a,e),l=H(a,e,l)),l===t&&r[1]?this.data(r[0]):l;r[1]=n,this.each(function(){var t=v(this);t.triggerHandler("setData"+i,r),v.data(this,e,n),t.triggerHandler("changeData"+i,r)})},null,n,arguments.length>1,null,!1))},removeData:function(e){return this.each(function(){v.removeData(this,e)})}}),v.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=v._data(e,t),n&&(!r||v.isArray(n)?r=v._data(e,t,v.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=v.queue(e,t),r=n.length,i=n.shift(),s=v._queueHooks(e,t),o=function(){v.dequeue(e,t)};i==="inprogress"&&(i=n.shift(),r--),i&&(t==="fx"&&n.unshift("inprogress"),delete s.stop,i.call(e,o,s)),!r&&s&&s.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return v._data(e,n)||v._data(e,n,{empty:v.Callbacks("once memory").add(function(){v.removeData(e,t+"queue",!0),v.removeData(e,n,!0)})})}}),v.fn.extend({queue:function(e,n){var r=2;return typeof e!="string"&&(n=e,e="fx",r--),arguments.length<r?v.queue(this[0],e):n===t?this:this.each(function(){var t=v.queue(this,e,n);v._queueHooks(this,e),e==="fx"&&t[0]!=="inprogress"&&v.dequeue(this,e)})},dequeue:function(e){return this.each(function(){v.dequeue(this,e)})},delay:function(e,t){return e=v.fx?v.fx.speeds[e]||e:e,t=t||"fx",this.queue(t,function(t,n){var r=setTimeout(t,e);n.stop=function(){clearTimeout(r)}})},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,n){var r,i=1,s=v.Deferred(),o=this,u=this.length,a=function(){--i||s.resolveWith(o,[o])};typeof e!="string"&&(n=e,e=t),e=e||"fx";while(u--)r=v._data(o[u],e+"queueHooks"),r&&r.empty&&(i++,r.empty.add(a));return a(),s.promise(n)}});var j,F,I,q=/[\t\r\n]/g,R=/\r/g,U=/^(?:button|input)$/i,z=/^(?:button|input|object|select|textarea)$/i,W=/^a(?:rea|)$/i,X=/^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,V=v.support.getSetAttribute;v.fn.extend({attr:function(e,t){return v.access(this,v.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each(function(){v.removeAttr(this,e)})},prop:function(e,t){return v.access(this,v.prop,e,t,arguments.length>1)},removeProp:function(e){return e=v.propFix[e]||e,this.each(function(){try{this[e]=t,delete this[e]}catch(n){}})},addClass:function(e){var t,n,r,i,s,o,u;if(v.isFunction(e))return this.each(function(t){v(this).addClass(e.call(this,t,this.className))});if(e&&typeof e=="string"){t=e.split(y);for(n=0,r=this.length;n<r;n++){i=this[n];if(i.nodeType===1)if(!i.className&&t.length===1)i.className=e;else{s=" "+i.className+" ";for(o=0,u=t.length;o<u;o++)s.indexOf(" "+t[o]+" ")<0&&(s+=t[o]+" ");i.className=v.trim(s)}}}return this},removeClass:function(e){var n,r,i,s,o,u,a;if(v.isFunction(e))return this.each(function(t){v(this).removeClass(e.call(this,t,this.className))});if(e&&typeof e=="string"||e===t){n=(e||"").split(y);for(u=0,a=this.length;u<a;u++){i=this[u];if(i.nodeType===1&&i.className){r=(" "+i.className+" ").replace(q," ");for(s=0,o=n.length;s<o;s++)while(r.indexOf(" "+n[s]+" ")>=0)r=r.replace(" "+n[s]+" "," ");i.className=e?v.trim(r):""}}}return this},toggleClass:function(e,t){var n=typeof e,r=typeof t=="boolean";return v.isFunction(e)?this.each(function(n){v(this).toggleClass(e.call(this,n,this.className,t),t)}):this.each(function(){if(n==="string"){var i,s=0,o=v(this),u=t,a=e.split(y);while(i=a[s++])u=r?u:!o.hasClass(i),o[u?"addClass":"removeClass"](i)}else if(n==="undefined"||n==="boolean")this.className&&v._data(this,"__className__",this.className),this.className=this.className||e===!1?"":v._data(this,"__className__")||""})},hasClass:function(e){var t=" "+e+" ",n=0,r=this.length;for(;n<r;n++)if(this[n].nodeType===1&&(" "+this[n].className+" ").replace(q," ").indexOf(t)>=0)return!0;return!1},val:function(e){var n,r,i,s=this[0];if(!arguments.length){if(s)return n=v.valHooks[s.type]||v.valHooks[s.nodeName.toLowerCase()],n&&"get"in n&&(r=n.get(s,"value"))!==t?r:(r=s.value,typeof r=="string"?r.replace(R,""):r==null?"":r);return}return i=v.isFunction(e),this.each(function(r){var s,o=v(this);if(this.nodeType!==1)return;i?s=e.call(this,r,o.val()):s=e,s==null?s="":typeof s=="number"?s+="":v.isArray(s)&&(s=v.map(s,function(e){return e==null?"":e+""})),n=v.valHooks[this.type]||v.valHooks[this.nodeName.toLowerCase()];if(!n||!("set"in n)||n.set(this,s,"value")===t)this.value=s})}}),v.extend({valHooks:{option:{get:function(e){var t=e.attributes.value;return!t||t.specified?e.value:e.text}},select:{get:function(e){var t,n,r=e.options,i=e.selectedIndex,s=e.type==="select-one"||i<0,o=s?null:[],u=s?i+1:r.length,a=i<0?u:s?i:0;for(;a<u;a++){n=r[a];if((n.selected||a===i)&&(v.support.optDisabled?!n.disabled:n.getAttribute("disabled")===null)&&(!n.parentNode.disabled||!v.nodeName(n.parentNode,"optgroup"))){t=v(n).val();if(s)return t;o.push(t)}}return o},set:function(e,t){var n=v.makeArray(t);return v(e).find("option").each(function(){this.selected=v.inArray(v(this).val(),n)>=0}),n.length||(e.selectedIndex=-1),n}}},attrFn:{},attr:function(e,n,r,i){var s,o,u,a=e.nodeType;if(!e||a===3||a===8||a===2)return;if(i&&v.isFunction(v.fn[n]))return v(e)[n](r);if(typeof e.getAttribute=="undefined")return v.prop(e,n,r);u=a!==1||!v.isXMLDoc(e),u&&(n=n.toLowerCase(),o=v.attrHooks[n]||(X.test(n)?F:j));if(r!==t){if(r===null){v.removeAttr(e,n);return}return o&&"set"in o&&u&&(s=o.set(e,r,n))!==t?s:(e.setAttribute(n,r+""),r)}return o&&"get"in o&&u&&(s=o.get(e,n))!==null?s:(s=e.getAttribute(n),s===null?t:s)},removeAttr:function(e,t){var n,r,i,s,o=0;if(t&&e.nodeType===1){r=t.split(y);for(;o<r.length;o++)i=r[o],i&&(n=v.propFix[i]||i,s=X.test(i),s||v.attr(e,i,""),e.removeAttribute(V?i:n),s&&n in e&&(e[n]=!1))}},attrHooks:{type:{set:function(e,t){if(U.test(e.nodeName)&&e.parentNode)v.error("type property can't be changed");else if(!v.support.radioValue&&t==="radio"&&v.nodeName(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}},value:{get:function(e,t){return j&&v.nodeName(e,"button")?j.get(e,t):t in e?e.value:null},set:function(e,t,n){if(j&&v.nodeName(e,"button"))return j.set(e,t,n);e.value=t}}},propFix:{tabindex:"tabIndex",readonly:"readOnly","for":"htmlFor","class":"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder",contenteditable:"contentEditable"},prop:function(e,n,r){var i,s,o,u=e.nodeType;if(!e||u===3||u===8||u===2)return;return o=u!==1||!v.isXMLDoc(e),o&&(n=v.propFix[n]||n,s=v.propHooks[n]),r!==t?s&&"set"in s&&(i=s.set(e,r,n))!==t?i:e[n]=r:s&&"get"in s&&(i=s.get(e,n))!==null?i:e[n]},propHooks:{tabIndex:{get:function(e){var n=e.getAttributeNode("tabindex");return n&&n.specified?parseInt(n.value,10):z.test(e.nodeName)||W.test(e.nodeName)&&e.href?0:t}}}}),F={get:function(e,n){var r,i=v.prop(e,n);return i===!0||typeof i!="boolean"&&(r=e.getAttributeNode(n))&&r.nodeValue!==!1?n.toLowerCase():t},set:function(e,t,n){var r;return t===!1?v.removeAttr(e,n):(r=v.propFix[n]||n,r in e&&(e[r]=!0),e.setAttribute(n,n.toLowerCase())),n}},V||(I={name:!0,id:!0,coords:!0},j=v.valHooks.button={get:function(e,n){var r;return r=e.getAttributeNode(n),r&&(I[n]?r.value!=="":r.specified)?r.value:t},set:function(e,t,n){var r=e.getAttributeNode(n);return r||(r=i.createAttribute(n),e.setAttributeNode(r)),r.value=t+""}},v.each(["width","height"],function(e,t){v.attrHooks[t]=v.extend(v.attrHooks[t],{set:function(e,n){if(n==="")return e.setAttribute(t,"auto"),n}})}),v.attrHooks.contenteditable={get:j.get,set:function(e,t,n){t===""&&(t="false"),j.set(e,t,n)}}),v.support.hrefNormalized||v.each(["href","src","width","height"],function(e,n){v.attrHooks[n]=v.extend(v.attrHooks[n],{get:function(e){var r=e.getAttribute(n,2);return r===null?t:r}})}),v.support.style||(v.attrHooks.style={get:function(e){return e.style.cssText.toLowerCase()||t},set:function(e,t){return e.style.cssText=t+""}}),v.support.optSelected||(v.propHooks.selected=v.extend(v.propHooks.selected,{get:function(e){var t=e.parentNode;return t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex),null}})),v.support.enctype||(v.propFix.enctype="encoding"),v.support.checkOn||v.each(["radio","checkbox"],function(){v.valHooks[this]={get:function(e){return e.getAttribute("value")===null?"on":e.value}}}),v.each(["radio","checkbox"],function(){v.valHooks[this]=v.extend(v.valHooks[this],{set:function(e,t){if(v.isArray(t))return e.checked=v.inArray(v(e).val(),t)>=0}})});var $=/^(?:textarea|input|select)$/i,J=/^([^\.]*|)(?:\.(.+)|)$/,K=/(?:^|\s)hover(\.\S+|)\b/,Q=/^key/,G=/^(?:mouse|contextmenu)|click/,Y=/^(?:focusinfocus|focusoutblur)$/,Z=function(e){return v.event.special.hover?e:e.replace(K,"mouseenter$1 mouseleave$1")};v.event={add:function(e,n,r,i,s){var o,u,a,f,l,c,h,p,d,m,g;if(e.nodeType===3||e.nodeType===8||!n||!r||!(o=v._data(e)))return;r.handler&&(d=r,r=d.handler,s=d.selector),r.guid||(r.guid=v.guid++),a=o.events,a||(o.events=a={}),u=o.handle,u||(o.handle=u=function(e){return typeof v=="undefined"||!!e&&v.event.triggered===e.type?t:v.event.dispatch.apply(u.elem,arguments)},u.elem=e),n=v.trim(Z(n)).split(" ");for(f=0;f<n.length;f++){l=J.exec(n[f])||[],c=l[1],h=(l[2]||"").split(".").sort(),g=v.event.special[c]||{},c=(s?g.delegateType:g.bindType)||c,g=v.event.special[c]||{},p=v.extend({type:c,origType:l[1],data:i,handler:r,guid:r.guid,selector:s,needsContext:s&&v.expr.match.needsContext.test(s),namespace:h.join(".")},d),m=a[c];if(!m){m=a[c]=[],m.delegateCount=0;if(!g.setup||g.setup.call(e,i,h,u)===!1)e.addEventListener?e.addEventListener(c,u,!1):e.attachEvent&&e.attachEvent("on"+c,u)}g.add&&(g.add.call(e,p),p.handler.guid||(p.handler.guid=r.guid)),s?m.splice(m.delegateCount++,0,p):m.push(p),v.event.global[c]=!0}e=null},global:{},remove:function(e,t,n,r,i){var s,o,u,a,f,l,c,h,p,d,m,g=v.hasData(e)&&v._data(e);if(!g||!(h=g.events))return;t=v.trim(Z(t||"")).split(" ");for(s=0;s<t.length;s++){o=J.exec(t[s])||[],u=a=o[1],f=o[2];if(!u){for(u in h)v.event.remove(e,u+t[s],n,r,!0);continue}p=v.event.special[u]||{},u=(r?p.delegateType:p.bindType)||u,d=h[u]||[],l=d.length,f=f?new RegExp("(^|\\.)"+f.split(".").sort().join("\\.(?:.*\\.|)")+"(\\.|$)"):null;for(c=0;c<d.length;c++)m=d[c],(i||a===m.origType)&&(!n||n.guid===m.guid)&&(!f||f.test(m.namespace))&&(!r||r===m.selector||r==="**"&&m.selector)&&(d.splice(c--,1),m.selector&&d.delegateCount--,p.remove&&p.remove.call(e,m));d.length===0&&l!==d.length&&((!p.teardown||p.teardown.call(e,f,g.handle)===!1)&&v.removeEvent(e,u,g.handle),delete h[u])}v.isEmptyObject(h)&&(delete g.handle,v.removeData(e,"events",!0))},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(n,r,s,o){if(!s||s.nodeType!==3&&s.nodeType!==8){var u,a,f,l,c,h,p,d,m,g,y=n.type||n,b=[];if(Y.test(y+v.event.triggered))return;y.indexOf("!")>=0&&(y=y.slice(0,-1),a=!0),y.indexOf(".")>=0&&(b=y.split("."),y=b.shift(),b.sort());if((!s||v.event.customEvent[y])&&!v.event.global[y])return;n=typeof n=="object"?n[v.expando]?n:new v.Event(y,n):new v.Event(y),n.type=y,n.isTrigger=!0,n.exclusive=a,n.namespace=b.join("."),n.namespace_re=n.namespace?new RegExp("(^|\\.)"+b.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,h=y.indexOf(":")<0?"on"+y:"";if(!s){u=v.cache;for(f in u)u[f].events&&u[f].events[y]&&v.event.trigger(n,r,u[f].handle.elem,!0);return}n.result=t,n.target||(n.target=s),r=r!=null?v.makeArray(r):[],r.unshift(n),p=v.event.special[y]||{};if(p.trigger&&p.trigger.apply(s,r)===!1)return;m=[[s,p.bindType||y]];if(!o&&!p.noBubble&&!v.isWindow(s)){g=p.delegateType||y,l=Y.test(g+y)?s:s.parentNode;for(c=s;l;l=l.parentNode)m.push([l,g]),c=l;c===(s.ownerDocument||i)&&m.push([c.defaultView||c.parentWindow||e,g])}for(f=0;f<m.length&&!n.isPropagationStopped();f++)l=m[f][0],n.type=m[f][1],d=(v._data(l,"events")||{})[n.type]&&v._data(l,"handle"),d&&d.apply(l,r),d=h&&l[h],d&&v.acceptData(l)&&d.apply&&d.apply(l,r)===!1&&n.preventDefault();return n.type=y,!o&&!n.isDefaultPrevented()&&(!p._default||p._default.apply(s.ownerDocument,r)===!1)&&(y!=="click"||!v.nodeName(s,"a"))&&v.acceptData(s)&&h&&s[y]&&(y!=="focus"&&y!=="blur"||n.target.offsetWidth!==0)&&!v.isWindow(s)&&(c=s[h],c&&(s[h]=null),v.event.triggered=y,s[y](),v.event.triggered=t,c&&(s[h]=c)),n.result}return},dispatch:function(n){n=v.event.fix(n||e.event);var r,i,s,o,u,a,f,c,h,p,d=(v._data(this,"events")||{})[n.type]||[],m=d.delegateCount,g=l.call(arguments),y=!n.exclusive&&!n.namespace,b=v.event.special[n.type]||{},w=[];g[0]=n,n.delegateTarget=this;if(b.preDispatch&&b.preDispatch.call(this,n)===!1)return;if(m&&(!n.button||n.type!=="click"))for(s=n.target;s!=this;s=s.parentNode||this)if(s.disabled!==!0||n.type!=="click"){u={},f=[];for(r=0;r<m;r++)c=d[r],h=c.selector,u[h]===t&&(u[h]=c.needsContext?v(h,this).index(s)>=0:v.find(h,this,null,[s]).length),u[h]&&f.push(c);f.length&&w.push({elem:s,matches:f})}d.length>m&&w.push({elem:this,matches:d.slice(m)});for(r=0;r<w.length&&!n.isPropagationStopped();r++){a=w[r],n.currentTarget=a.elem;for(i=0;i<a.matches.length&&!n.isImmediatePropagationStopped();i++){c=a.matches[i];if(y||!n.namespace&&!c.namespace||n.namespace_re&&n.namespace_re.test(c.namespace))n.data=c.data,n.handleObj=c,o=((v.event.special[c.origType]||{}).handle||c.handler).apply(a.elem,g),o!==t&&(n.result=o,o===!1&&(n.preventDefault(),n.stopPropagation()))}}return b.postDispatch&&b.postDispatch.call(this,n),n.result},props:"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(e,t){return e.which==null&&(e.which=t.charCode!=null?t.charCode:t.keyCode),e}},mouseHooks:{props:"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(e,n){var r,s,o,u=n.button,a=n.fromElement;return e.pageX==null&&n.clientX!=null&&(r=e.target.ownerDocument||i,s=r.documentElement,o=r.body,e.pageX=n.clientX+(s&&s.scrollLeft||o&&o.scrollLeft||0)-(s&&s.clientLeft||o&&o.clientLeft||0),e.pageY=n.clientY+(s&&s.scrollTop||o&&o.scrollTop||0)-(s&&s.clientTop||o&&o.clientTop||0)),!e.relatedTarget&&a&&(e.relatedTarget=a===e.target?n.toElement:a),!e.which&&u!==t&&(e.which=u&1?1:u&2?3:u&4?2:0),e}},fix:function(e){if(e[v.expando])return e;var t,n,r=e,s=v.event.fixHooks[e.type]||{},o=s.props?this.props.concat(s.props):this.props;e=v.Event(r);for(t=o.length;t;)n=o[--t],e[n]=r[n];return e.target||(e.target=r.srcElement||i),e.target.nodeType===3&&(e.target=e.target.parentNode),e.metaKey=!!e.metaKey,s.filter?s.filter(e,r):e},special:{load:{noBubble:!0},focus:{delegateType:"focusin"},blur:{delegateType:"focusout"},beforeunload:{setup:function(e,t,n){v.isWindow(this)&&(this.onbeforeunload=n)},teardown:function(e,t){this.onbeforeunload===t&&(this.onbeforeunload=null)}}},simulate:function(e,t,n,r){var i=v.extend(new v.Event,n,{type:e,isSimulated:!0,originalEvent:{}});r?v.event.trigger(i,null,t):v.event.dispatch.call(t,i),i.isDefaultPrevented()&&n.preventDefault()}},v.event.handle=v.event.dispatch,v.removeEvent=i.removeEventListener?function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n,!1)}:function(e,t,n){var r="on"+t;e.detachEvent&&(typeof e[r]=="undefined"&&(e[r]=null),e.detachEvent(r,n))},v.Event=function(e,t){if(!(this instanceof v.Event))return new v.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||e.returnValue===!1||e.getPreventDefault&&e.getPreventDefault()?tt:et):this.type=e,t&&v.extend(this,t),this.timeStamp=e&&e.timeStamp||v.now(),this[v.expando]=!0},v.Event.prototype={preventDefault:function(){this.isDefaultPrevented=tt;var e=this.originalEvent;if(!e)return;e.preventDefault?e.preventDefault():e.returnValue=!1},stopPropagation:function(){this.isPropagationStopped=tt;var e=this.originalEvent;if(!e)return;e.stopPropagation&&e.stopPropagation(),e.cancelBubble=!0},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=tt,this.stopPropagation()},isDefaultPrevented:et,isPropagationStopped:et,isImmediatePropagationStopped:et},v.each({mouseenter:"mouseover",mouseleave:"mouseout"},function(e,t){v.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,s=e.handleObj,o=s.selector;if(!i||i!==r&&!v.contains(r,i))e.type=s.origType,n=s.handler.apply(this,arguments),e.type=t;return n}}}),v.support.submitBubbles||(v.event.special.submit={setup:function(){if(v.nodeName(this,"form"))return!1;v.event.add(this,"click._submit keypress._submit",function(e){var n=e.target,r=v.nodeName(n,"input")||v.nodeName(n,"button")?n.form:t;r&&!v._data(r,"_submit_attached")&&(v.event.add(r,"submit._submit",function(e){e._submit_bubble=!0}),v._data(r,"_submit_attached",!0))})},postDispatch:function(e){e._submit_bubble&&(delete e._submit_bubble,this.parentNode&&!e.isTrigger&&v.event.simulate("submit",this.parentNode,e,!0))},teardown:function(){if(v.nodeName(this,"form"))return!1;v.event.remove(this,"._submit")}}),v.support.changeBubbles||(v.event.special.change={setup:function(){if($.test(this.nodeName)){if(this.type==="checkbox"||this.type==="radio")v.event.add(this,"propertychange._change",function(e){e.originalEvent.propertyName==="checked"&&(this._just_changed=!0)}),v.event.add(this,"click._change",function(e){this._just_changed&&!e.isTrigger&&(this._just_changed=!1),v.event.simulate("change",this,e,!0)});return!1}v.event.add(this,"beforeactivate._change",function(e){var t=e.target;$.test(t.nodeName)&&!v._data(t,"_change_attached")&&(v.event.add(t,"change._change",function(e){this.parentNode&&!e.isSimulated&&!e.isTrigger&&v.event.simulate("change",this.parentNode,e,!0)}),v._data(t,"_change_attached",!0))})},handle:function(e){var t=e.target;if(this!==t||e.isSimulated||e.isTrigger||t.type!=="radio"&&t.type!=="checkbox")return e.handleObj.handler.apply(this,arguments)},teardown:function(){return v.event.remove(this,"._change"),!$.test(this.nodeName)}}),v.support.focusinBubbles||v.each({focus:"focusin",blur:"focusout"},function(e,t){var n=0,r=function(e){v.event.simulate(t,e.target,v.event.fix(e),!0)};v.event.special[t]={setup:function(){n++===0&&i.addEventListener(e,r,!0)},teardown:function(){--n===0&&i.removeEventListener(e,r,!0)}}}),v.fn.extend({on:function(e,n,r,i,s){var o,u;if(typeof e=="object"){typeof n!="string"&&(r=r||n,n=t);for(u in e)this.on(u,n,r,e[u],s);return this}r==null&&i==null?(i=n,r=n=t):i==null&&(typeof n=="string"?(i=r,r=t):(i=r,r=n,n=t));if(i===!1)i=et;else if(!i)return this;return s===1&&(o=i,i=function(e){return v().off(e),o.apply(this,arguments)},i.guid=o.guid||(o.guid=v.guid++)),this.each(function(){v.event.add(this,e,i,r,n)})},one:function(e,t,n,r){return this.on(e,t,n,r,1)},off:function(e,n,r){var i,s;if(e&&e.preventDefault&&e.handleObj)return i=e.handleObj,v(e.delegateTarget).off(i.namespace?i.origType+"."+i.namespace:i.origType,i.selector,i.handler),this;if(typeof e=="object"){for(s in e)this.off(s,n,e[s]);return this}if(n===!1||typeof n=="function")r=n,n=t;return r===!1&&(r=et),this.each(function(){v.event.remove(this,e,r,n)})},bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},live:function(e,t,n){return v(this.context).on(e,this.selector,t,n),this},die:function(e,t){return v(this.context).off(e,this.selector||"**",t),this},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return arguments.length===1?this.off(e,"**"):this.off(t,e||"**",n)},trigger:function(e,t){return this.each(function(){v.event.trigger(e,t,this)})},triggerHandler:function(e,t){if(this[0])return v.event.trigger(e,t,this[0],!0)},toggle:function(e){var t=arguments,n=e.guid||v.guid++,r=0,i=function(n){var i=(v._data(this,"lastToggle"+e.guid)||0)%r;return v._data(this,"lastToggle"+e.guid,i+1),n.preventDefault(),t[i].apply(this,arguments)||!1};i.guid=n;while(r<t.length)t[r++].guid=n;return this.click(i)},hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),v.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(e,t){v.fn[t]=function(e,n){return n==null&&(n=e,e=null),arguments.length>0?this.on(t,null,e,n):this.trigger(t)},Q.test(t)&&(v.event.fixHooks[t]=v.event.keyHooks),G.test(t)&&(v.event.fixHooks[t]=v.event.mouseHooks)}),function(e,t){function nt(e,t,n,r){n=n||[],t=t||g;var i,s,a,f,l=t.nodeType;if(!e||typeof e!="string")return n;if(l!==1&&l!==9)return[];a=o(t);if(!a&&!r)if(i=R.exec(e))if(f=i[1]){if(l===9){s=t.getElementById(f);if(!s||!s.parentNode)return n;if(s.id===f)return n.push(s),n}else if(t.ownerDocument&&(s=t.ownerDocument.getElementById(f))&&u(t,s)&&s.id===f)return n.push(s),n}else{if(i[2])return S.apply(n,x.call(t.getElementsByTagName(e),0)),n;if((f=i[3])&&Z&&t.getElementsByClassName)return S.apply(n,x.call(t.getElementsByClassName(f),0)),n}return vt(e.replace(j,"$1"),t,n,r,a)}function rt(e){return function(t){var n=t.nodeName.toLowerCase();return n==="input"&&t.type===e}}function it(e){return function(t){var n=t.nodeName.toLowerCase();return(n==="input"||n==="button")&&t.type===e}}function st(e){return N(function(t){return t=+t,N(function(n,r){var i,s=e([],n.length,t),o=s.length;while(o--)n[i=s[o]]&&(n[i]=!(r[i]=n[i]))})})}function ot(e,t,n){if(e===t)return n;var r=e.nextSibling;while(r){if(r===t)return-1;r=r.nextSibling}return 1}function ut(e,t){var n,r,s,o,u,a,f,l=L[d][e+" "];if(l)return t?0:l.slice(0);u=e,a=[],f=i.preFilter;while(u){if(!n||(r=F.exec(u)))r&&(u=u.slice(r[0].length)||u),a.push(s=[]);n=!1;if(r=I.exec(u))s.push(n=new m(r.shift())),u=u.slice(n.length),n.type=r[0].replace(j," ");for(o in i.filter)(r=J[o].exec(u))&&(!f[o]||(r=f[o](r)))&&(s.push(n=new m(r.shift())),u=u.slice(n.length),n.type=o,n.matches=r);if(!n)break}return t?u.length:u?nt.error(e):L(e,a).slice(0)}function at(e,t,r){var i=t.dir,s=r&&t.dir==="parentNode",o=w++;return t.first?function(t,n,r){while(t=t[i])if(s||t.nodeType===1)return e(t,n,r)}:function(t,r,u){if(!u){var a,f=b+" "+o+" ",l=f+n;while(t=t[i])if(s||t.nodeType===1){if((a=t[d])===l)return t.sizset;if(typeof a=="string"&&a.indexOf(f)===0){if(t.sizset)return t}else{t[d]=l;if(e(t,r,u))return t.sizset=!0,t;t.sizset=!1}}}else while(t=t[i])if(s||t.nodeType===1)if(e(t,r,u))return t}}function ft(e){return e.length>1?function(t,n,r){var i=e.length;while(i--)if(!e[i](t,n,r))return!1;return!0}:e[0]}function lt(e,t,n,r,i){var s,o=[],u=0,a=e.length,f=t!=null;for(;u<a;u++)if(s=e[u])if(!n||n(s,r,i))o.push(s),f&&t.push(u);return o}function ct(e,t,n,r,i,s){return r&&!r[d]&&(r=ct(r)),i&&!i[d]&&(i=ct(i,s)),N(function(s,o,u,a){var f,l,c,h=[],p=[],d=o.length,v=s||dt(t||"*",u.nodeType?[u]:u,[]),m=e&&(s||!t)?lt(v,h,e,u,a):v,g=n?i||(s?e:d||r)?[]:o:m;n&&n(m,g,u,a);if(r){f=lt(g,p),r(f,[],u,a),l=f.length;while(l--)if(c=f[l])g[p[l]]=!(m[p[l]]=c)}if(s){if(i||e){if(i){f=[],l=g.length;while(l--)(c=g[l])&&f.push(m[l]=c);i(null,g=[],f,a)}l=g.length;while(l--)(c=g[l])&&(f=i?T.call(s,c):h[l])>-1&&(s[f]=!(o[f]=c))}}else g=lt(g===o?g.splice(d,g.length):g),i?i(null,o,g,a):S.apply(o,g)})}function ht(e){var t,n,r,s=e.length,o=i.relative[e[0].type],u=o||i.relative[" "],a=o?1:0,f=at(function(e){return e===t},u,!0),l=at(function(e){return T.call(t,e)>-1},u,!0),h=[function(e,n,r){return!o&&(r||n!==c)||((t=n).nodeType?f(e,n,r):l(e,n,r))}];for(;a<s;a++)if(n=i.relative[e[a].type])h=[at(ft(h),n)];else{n=i.filter[e[a].type].apply(null,e[a].matches);if(n[d]){r=++a;for(;r<s;r++)if(i.relative[e[r].type])break;return ct(a>1&&ft(h),a>1&&e.slice(0,a-1).join("").replace(j,"$1"),n,a<r&&ht(e.slice(a,r)),r<s&&ht(e=e.slice(r)),r<s&&e.join(""))}h.push(n)}return ft(h)}function pt(e,t){var r=t.length>0,s=e.length>0,o=function(u,a,f,l,h){var p,d,v,m=[],y=0,w="0",x=u&&[],T=h!=null,N=c,C=u||s&&i.find.TAG("*",h&&a.parentNode||a),k=b+=N==null?1:Math.E;T&&(c=a!==g&&a,n=o.el);for(;(p=C[w])!=null;w++){if(s&&p){for(d=0;v=e[d];d++)if(v(p,a,f)){l.push(p);break}T&&(b=k,n=++o.el)}r&&((p=!v&&p)&&y--,u&&x.push(p))}y+=w;if(r&&w!==y){for(d=0;v=t[d];d++)v(x,m,a,f);if(u){if(y>0)while(w--)!x[w]&&!m[w]&&(m[w]=E.call(l));m=lt(m)}S.apply(l,m),T&&!u&&m.length>0&&y+t.length>1&&nt.uniqueSort(l)}return T&&(b=k,c=N),x};return o.el=0,r?N(o):o}function dt(e,t,n){var r=0,i=t.length;for(;r<i;r++)nt(e,t[r],n);return n}function vt(e,t,n,r,s){var o,u,f,l,c,h=ut(e),p=h.length;if(!r&&h.length===1){u=h[0]=h[0].slice(0);if(u.length>2&&(f=u[0]).type==="ID"&&t.nodeType===9&&!s&&i.relative[u[1].type]){t=i.find.ID(f.matches[0].replace($,""),t,s)[0];if(!t)return n;e=e.slice(u.shift().length)}for(o=J.POS.test(e)?-1:u.length-1;o>=0;o--){f=u[o];if(i.relative[l=f.type])break;if(c=i.find[l])if(r=c(f.matches[0].replace($,""),z.test(u[0].type)&&t.parentNode||t,s)){u.splice(o,1),e=r.length&&u.join("");if(!e)return S.apply(n,x.call(r,0)),n;break}}}return a(e,h)(r,t,s,n,z.test(e)),n}function mt(){}var n,r,i,s,o,u,a,f,l,c,h=!0,p="undefined",d=("sizcache"+Math.random()).replace(".",""),m=String,g=e.document,y=g.documentElement,b=0,w=0,E=[].pop,S=[].push,x=[].slice,T=[].indexOf||function(e){var t=0,n=this.length;for(;t<n;t++)if(this[t]===e)return t;return-1},N=function(e,t){return e[d]=t==null||t,e},C=function(){var e={},t=[];return N(function(n,r){return t.push(n)>i.cacheLength&&delete e[t.shift()],e[n+" "]=r},e)},k=C(),L=C(),A=C(),O="[\\x20\\t\\r\\n\\f]",M="(?:\\\\.|[-\\w]|[^\\x00-\\xa0])+",_=M.replace("w","w#"),D="([*^$|!~]?=)",P="\\["+O+"*("+M+")"+O+"*(?:"+D+O+"*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|("+_+")|)|)"+O+"*\\]",H=":("+M+")(?:\\((?:(['\"])((?:\\\\.|[^\\\\])*?)\\2|([^()[\\]]*|(?:(?:"+P+")|[^:]|\\\\.)*|.*))\\)|)",B=":(even|odd|eq|gt|lt|nth|first|last)(?:\\("+O+"*((?:-\\d)?\\d*)"+O+"*\\)|)(?=[^-]|$)",j=new RegExp("^"+O+"+|((?:^|[^\\\\])(?:\\\\.)*)"+O+"+$","g"),F=new RegExp("^"+O+"*,"+O+"*"),I=new RegExp("^"+O+"*([\\x20\\t\\r\\n\\f>+~])"+O+"*"),q=new RegExp(H),R=/^(?:#([\w\-]+)|(\w+)|\.([\w\-]+))$/,U=/^:not/,z=/[\x20\t\r\n\f]*[+~]/,W=/:not\($/,X=/h\d/i,V=/input|select|textarea|button/i,$=/\\(?!\\)/g,J={ID:new RegExp("^#("+M+")"),CLASS:new RegExp("^\\.("+M+")"),NAME:new RegExp("^\\[name=['\"]?("+M+")['\"]?\\]"),TAG:new RegExp("^("+M.replace("w","w*")+")"),ATTR:new RegExp("^"+P),PSEUDO:new RegExp("^"+H),POS:new RegExp(B,"i"),CHILD:new RegExp("^:(only|nth|first|last)-child(?:\\("+O+"*(even|odd|(([+-]|)(\\d*)n|)"+O+"*(?:([+-]|)"+O+"*(\\d+)|))"+O+"*\\)|)","i"),needsContext:new RegExp("^"+O+"*[>+~]|"+B,"i")},K=function(e){var t=g.createElement("div");try{return e(t)}catch(n){return!1}finally{t=null}},Q=K(function(e){return e.appendChild(g.createComment("")),!e.getElementsByTagName("*").length}),G=K(function(e){return e.innerHTML="<a href='#'></a>",e.firstChild&&typeof e.firstChild.getAttribute!==p&&e.firstChild.getAttribute("href")==="#"}),Y=K(function(e){e.innerHTML="<select></select>";var t=typeof e.lastChild.getAttribute("multiple");return t!=="boolean"&&t!=="string"}),Z=K(function(e){return e.innerHTML="<div class='hidden e'></div><div class='hidden'></div>",!e.getElementsByClassName||!e.getElementsByClassName("e").length?!1:(e.lastChild.className="e",e.getElementsByClassName("e").length===2)}),et=K(function(e){e.id=d+0,e.innerHTML="<a name='"+d+"'></a><div name='"+d+"'></div>",y.insertBefore(e,y.firstChild);var t=g.getElementsByName&&g.getElementsByName(d).length===2+g.getElementsByName(d+0).length;return r=!g.getElementById(d),y.removeChild(e),t});try{x.call(y.childNodes,0)[0].nodeType}catch(tt){x=function(e){var t,n=[];for(;t=this[e];e++)n.push(t);return n}}nt.matches=function(e,t){return nt(e,null,null,t)},nt.matchesSelector=function(e,t){return nt(t,null,null,[e]).length>0},s=nt.getText=function(e){var t,n="",r=0,i=e.nodeType;if(i){if(i===1||i===9||i===11){if(typeof e.textContent=="string")return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=s(e)}else if(i===3||i===4)return e.nodeValue}else for(;t=e[r];r++)n+=s(t);return n},o=nt.isXML=function(e){var t=e&&(e.ownerDocument||e).documentElement;return t?t.nodeName!=="HTML":!1},u=nt.contains=y.contains?function(e,t){var n=e.nodeType===9?e.documentElement:e,r=t&&t.parentNode;return e===r||!!(r&&r.nodeType===1&&n.contains&&n.contains(r))}:y.compareDocumentPosition?function(e,t){return t&&!!(e.compareDocumentPosition(t)&16)}:function(e,t){while(t=t.parentNode)if(t===e)return!0;return!1},nt.attr=function(e,t){var n,r=o(e);return r||(t=t.toLowerCase()),(n=i.attrHandle[t])?n(e):r||Y?e.getAttribute(t):(n=e.getAttributeNode(t),n?typeof e[t]=="boolean"?e[t]?t:null:n.specified?n.value:null:null)},i=nt.selectors={cacheLength:50,createPseudo:N,match:J,attrHandle:G?{}:{href:function(e){return e.getAttribute("href",2)},type:function(e){return e.getAttribute("type")}},find:{ID:r?function(e,t,n){if(typeof t.getElementById!==p&&!n){var r=t.getElementById(e);return r&&r.parentNode?[r]:[]}}:function(e,n,r){if(typeof n.getElementById!==p&&!r){var i=n.getElementById(e);return i?i.id===e||typeof i.getAttributeNode!==p&&i.getAttributeNode("id").value===e?[i]:t:[]}},TAG:Q?function(e,t){if(typeof t.getElementsByTagName!==p)return t.getElementsByTagName(e)}:function(e,t){var n=t.getElementsByTagName(e);if(e==="*"){var r,i=[],s=0;for(;r=n[s];s++)r.nodeType===1&&i.push(r);return i}return n},NAME:et&&function(e,t){if(typeof t.getElementsByName!==p)return t.getElementsByName(name)},CLASS:Z&&function(e,t,n){if(typeof t.getElementsByClassName!==p&&!n)return t.getElementsByClassName(e)}},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace($,""),e[3]=(e[4]||e[5]||"").replace($,""),e[2]==="~="&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),e[1]==="nth"?(e[2]||nt.error(e[0]),e[3]=+(e[3]?e[4]+(e[5]||1):2*(e[2]==="even"||e[2]==="odd")),e[4]=+(e[6]+e[7]||e[2]==="odd")):e[2]&&nt.error(e[0]),e},PSEUDO:function(e){var t,n;if(J.CHILD.test(e[0]))return null;if(e[3])e[2]=e[3];else if(t=e[4])q.test(t)&&(n=ut(t,!0))&&(n=t.indexOf(")",t.length-n)-t.length)&&(t=t.slice(0,n),e[0]=e[0].slice(0,n)),e[2]=t;return e.slice(0,3)}},filter:{ID:r?function(e){return e=e.replace($,""),function(t){return t.getAttribute("id")===e}}:function(e){return e=e.replace($,""),function(t){var n=typeof t.getAttributeNode!==p&&t.getAttributeNode("id");return n&&n.value===e}},TAG:function(e){return e==="*"?function(){return!0}:(e=e.replace($,"").toLowerCase(),function(t){return t.nodeName&&t.nodeName.toLowerCase()===e})},CLASS:function(e){var t=k[d][e+" "];return t||(t=new RegExp("(^|"+O+")"+e+"("+O+"|$)"))&&k(e,function(e){return t.test(e.className||typeof e.getAttribute!==p&&e.getAttribute("class")||"")})},ATTR:function(e,t,n){return function(r,i){var s=nt.attr(r,e);return s==null?t==="!=":t?(s+="",t==="="?s===n:t==="!="?s!==n:t==="^="?n&&s.indexOf(n)===0:t==="*="?n&&s.indexOf(n)>-1:t==="$="?n&&s.substr(s.length-n.length)===n:t==="~="?(" "+s+" ").indexOf(n)>-1:t==="|="?s===n||s.substr(0,n.length+1)===n+"-":!1):!0}},CHILD:function(e,t,n,r){return e==="nth"?function(e){var t,i,s=e.parentNode;if(n===1&&r===0)return!0;if(s){i=0;for(t=s.firstChild;t;t=t.nextSibling)if(t.nodeType===1){i++;if(e===t)break}}return i-=r,i===n||i%n===0&&i/n>=0}:function(t){var n=t;switch(e){case"only":case"first":while(n=n.previousSibling)if(n.nodeType===1)return!1;if(e==="first")return!0;n=t;case"last":while(n=n.nextSibling)if(n.nodeType===1)return!1;return!0}}},PSEUDO:function(e,t){var n,r=i.pseudos[e]||i.setFilters[e.toLowerCase()]||nt.error("unsupported pseudo: "+e);return r[d]?r(t):r.length>1?(n=[e,e,"",t],i.setFilters.hasOwnProperty(e.toLowerCase())?N(function(e,n){var i,s=r(e,t),o=s.length;while(o--)i=T.call(e,s[o]),e[i]=!(n[i]=s[o])}):function(e){return r(e,0,n)}):r}},pseudos:{not:N(function(e){var t=[],n=[],r=a(e.replace(j,"$1"));return r[d]?N(function(e,t,n,i){var s,o=r(e,null,i,[]),u=e.length;while(u--)if(s=o[u])e[u]=!(t[u]=s)}):function(e,i,s){return t[0]=e,r(t,null,s,n),!n.pop()}}),has:N(function(e){return function(t){return nt(e,t).length>0}}),contains:N(function(e){return function(t){return(t.textContent||t.innerText||s(t)).indexOf(e)>-1}}),enabled:function(e){return e.disabled===!1},disabled:function(e){return e.disabled===!0},checked:function(e){var t=e.nodeName.toLowerCase();return t==="input"&&!!e.checked||t==="option"&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,e.selected===!0},parent:function(e){return!i.pseudos.empty(e)},empty:function(e){var t;e=e.firstChild;while(e){if(e.nodeName>"@"||(t=e.nodeType)===3||t===4)return!1;e=e.nextSibling}return!0},header:function(e){return X.test(e.nodeName)},text:function(e){var t,n;return e.nodeName.toLowerCase()==="input"&&(t=e.type)==="text"&&((n=e.getAttribute("type"))==null||n.toLowerCase()===t)},radio:rt("radio"),checkbox:rt("checkbox"),file:rt("file"),password:rt("password"),image:rt("image"),submit:it("submit"),reset:it("reset"),button:function(e){var t=e.nodeName.toLowerCase();return t==="input"&&e.type==="button"||t==="button"},input:function(e){return V.test(e.nodeName)},focus:function(e){var t=e.ownerDocument;return e===t.activeElement&&(!t.hasFocus||t.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},active:function(e){return e===e.ownerDocument.activeElement},first:st(function(){return[0]}),last:st(function(e,t){return[t-1]}),eq:st(function(e,t,n){return[n<0?n+t:n]}),even:st(function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e}),odd:st(function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e}),lt:st(function(e,t,n){for(var r=n<0?n+t:n;--r>=0;)e.push(r);return e}),gt:st(function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e})}},f=y.compareDocumentPosition?function(e,t){return e===t?(l=!0,0):(!e.compareDocumentPosition||!t.compareDocumentPosition?e.compareDocumentPosition:e.compareDocumentPosition(t)&4)?-1:1}:function(e,t){if(e===t)return l=!0,0;if(e.sourceIndex&&t.sourceIndex)return e.sourceIndex-t.sourceIndex;var n,r,i=[],s=[],o=e.parentNode,u=t.parentNode,a=o;if(o===u)return ot(e,t);if(!o)return-1;if(!u)return 1;while(a)i.unshift(a),a=a.parentNode;a=u;while(a)s.unshift(a),a=a.parentNode;n=i.length,r=s.length;for(var f=0;f<n&&f<r;f++)if(i[f]!==s[f])return ot(i[f],s[f]);return f===n?ot(e,s[f],-1):ot(i[f],t,1)},[0,0].sort(f),h=!l,nt.uniqueSort=function(e){var t,n=[],r=1,i=0;l=h,e.sort(f);if(l){for(;t=e[r];r++)t===e[r-1]&&(i=n.push(r));while(i--)e.splice(n[i],1)}return e},nt.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},a=nt.compile=function(e,t){var n,r=[],i=[],s=A[d][e+" "];if(!s){t||(t=ut(e)),n=t.length;while(n--)s=ht(t[n]),s[d]?r.push(s):i.push(s);s=A(e,pt(i,r))}return s},g.querySelectorAll&&function(){var e,t=vt,n=/'|\\/g,r=/\=[\x20\t\r\n\f]*([^'"\]]*)[\x20\t\r\n\f]*\]/g,i=[":focus"],s=[":active"],u=y.matchesSelector||y.mozMatchesSelector||y.webkitMatchesSelector||y.oMatchesSelector||y.msMatchesSelector;K(function(e){e.innerHTML="<select><option selected=''></option></select>",e.querySelectorAll("[selected]").length||i.push("\\["+O+"*(?:checked|disabled|ismap|multiple|readonly|selected|value)"),e.querySelectorAll(":checked").length||i.push(":checked")}),K(function(e){e.innerHTML="<p test=''></p>",e.querySelectorAll("[test^='']").length&&i.push("[*^$]="+O+"*(?:\"\"|'')"),e.innerHTML="<input type='hidden'/>",e.querySelectorAll(":enabled").length||i.push(":enabled",":disabled")}),i=new RegExp(i.join("|")),vt=function(e,r,s,o,u){if(!o&&!u&&!i.test(e)){var a,f,l=!0,c=d,h=r,p=r.nodeType===9&&e;if(r.nodeType===1&&r.nodeName.toLowerCase()!=="object"){a=ut(e),(l=r.getAttribute("id"))?c=l.replace(n,"\\$&"):r.setAttribute("id",c),c="[id='"+c+"'] ",f=a.length;while(f--)a[f]=c+a[f].join("");h=z.test(e)&&r.parentNode||r,p=a.join(",")}if(p)try{return S.apply(s,x.call(h.querySelectorAll(p),0)),s}catch(v){}finally{l||r.removeAttribute("id")}}return t(e,r,s,o,u)},u&&(K(function(t){e=u.call(t,"div");try{u.call(t,"[test!='']:sizzle"),s.push("!=",H)}catch(n){}}),s=new RegExp(s.join("|")),nt.matchesSelector=function(t,n){n=n.replace(r,"='$1']");if(!o(t)&&!s.test(n)&&!i.test(n))try{var a=u.call(t,n);if(a||e||t.document&&t.document.nodeType!==11)return a}catch(f){}return nt(n,null,null,[t]).length>0})}(),i.pseudos.nth=i.pseudos.eq,i.filters=mt.prototype=i.pseudos,i.setFilters=new mt,nt.attr=v.attr,v.find=nt,v.expr=nt.selectors,v.expr[":"]=v.expr.pseudos,v.unique=nt.uniqueSort,v.text=nt.getText,v.isXMLDoc=nt.isXML,v.contains=nt.contains}(e);var nt=/Until$/,rt=/^(?:parents|prev(?:Until|All))/,it=/^.[^:#\[\.,]*$/,st=v.expr.match.needsContext,ot={children:!0,contents:!0,next:!0,prev:!0};v.fn.extend({find:function(e){var t,n,r,i,s,o,u=this;if(typeof e!="string")return v(e).filter(function(){for(t=0,n=u.length;t<n;t++)if(v.contains(u[t],this))return!0});o=this.pushStack("","find",e);for(t=0,n=this.length;t<n;t++){r=o.length,v.find(e,this[t],o);if(t>0)for(i=r;i<o.length;i++)for(s=0;s<r;s++)if(o[s]===o[i]){o.splice(i--,1);break}}return o},has:function(e){var t,n=v(e,this),r=n.length;return this.filter(function(){for(t=0;t<r;t++)if(v.contains(this,n[t]))return!0})},not:function(e){return this.pushStack(ft(this,e,!1),"not",e)},filter:function(e){return this.pushStack(ft(this,e,!0),"filter",e)},is:function(e){return!!e&&(typeof e=="string"?st.test(e)?v(e,this.context).index(this[0])>=0:v.filter(e,this).length>0:this.filter(e).length>0)},closest:function(e,t){var n,r=0,i=this.length,s=[],o=st.test(e)||typeof e!="string"?v(e,t||this.context):0;for(;r<i;r++){n=this[r];while(n&&n.ownerDocument&&n!==t&&n.nodeType!==11){if(o?o.index(n)>-1:v.find.matchesSelector(n,e)){s.push(n);break}n=n.parentNode}}return s=s.length>1?v.unique(s):s,this.pushStack(s,"closest",e)},index:function(e){return e?typeof e=="string"?v.inArray(this[0],v(e)):v.inArray(e.jquery?e[0]:e,this):this[0]&&this[0].parentNode?this.prevAll().length:-1},add:function(e,t){var n=typeof e=="string"?v(e,t):v.makeArray(e&&e.nodeType?[e]:e),r=v.merge(this.get(),n);return this.pushStack(ut(n[0])||ut(r[0])?r:v.unique(r))},addBack:function(e){return this.add(e==null?this.prevObject:this.prevObject.filter(e))}}),v.fn.andSelf=v.fn.addBack,v.each({parent:function(e){var t=e.parentNode;return t&&t.nodeType!==11?t:null},parents:function(e){return v.dir(e,"parentNode")},parentsUntil:function(e,t,n){return v.dir(e,"parentNode",n)},next:function(e){return at(e,"nextSibling")},prev:function(e){return at(e,"previousSibling")},nextAll:function(e){return v.dir(e,"nextSibling")},prevAll:function(e){return v.dir(e,"previousSibling")},nextUntil:function(e,t,n){return v.dir(e,"nextSibling",n)},prevUntil:function(e,t,n){return v.dir(e,"previousSibling",n)},siblings:function(e){return v.sibling((e.parentNode||{}).firstChild,e)},children:function(e){return v.sibling(e.firstChild)},contents:function(e){return v.nodeName(e,"iframe")?e.contentDocument||e.contentWindow.document:v.merge([],e.childNodes)}},function(e,t){v.fn[e]=function(n,r){var i=v.map(this,t,n);return nt.test(e)||(r=n),r&&typeof r=="string"&&(i=v.filter(r,i)),i=this.length>1&&!ot[e]?v.unique(i):i,this.length>1&&rt.test(e)&&(i=i.reverse()),this.pushStack(i,e,l.call(arguments).join(","))}}),v.extend({filter:function(e,t,n){return n&&(e=":not("+e+")"),t.length===1?v.find.matchesSelector(t[0],e)?[t[0]]:[]:v.find.matches(e,t)},dir:function(e,n,r){var i=[],s=e[n];while(s&&s.nodeType!==9&&(r===t||s.nodeType!==1||!v(s).is(r)))s.nodeType===1&&i.push(s),s=s[n];return i},sibling:function(e,t){var n=[];for(;e;e=e.nextSibling)e.nodeType===1&&e!==t&&n.push(e);return n}});var ct="abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",ht=/ jQuery\d+="(?:null|\d+)"/g,pt=/^\s+/,dt=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,vt=/<([\w:]+)/,mt=/<tbody/i,gt=/<|&#?\w+;/,yt=/<(?:script|style|link)/i,bt=/<(?:script|object|embed|option|style)/i,wt=new RegExp("<(?:"+ct+")[\\s/>]","i"),Et=/^(?:checkbox|radio)$/,St=/checked\s*(?:[^=]|=\s*.checked.)/i,xt=/\/(java|ecma)script/i,Tt=/^\s*<!(?:\[CDATA\[|\-\-)|[\]\-]{2}>\s*$/g,Nt={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]},Ct=lt(i),kt=Ct.appendChild(i.createElement("div"));Nt.optgroup=Nt.option,Nt.tbody=Nt.tfoot=Nt.colgroup=Nt.caption=Nt.thead,Nt.th=Nt.td,v.support.htmlSerialize||(Nt._default=[1,"X<div>","</div>"]),v.fn.extend({text:function(e){return v.access(this,function(e){return e===t?v.text(this):this.empty().append((this[0]&&this[0].ownerDocument||i).createTextNode(e))},null,e,arguments.length)},wrapAll:function(e){if(v.isFunction(e))return this.each(function(t){v(this).wrapAll(e.call(this,t))});if(this[0]){var t=v(e,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&t.insertBefore(this[0]),t.map(function(){var e=this;while(e.firstChild&&e.firstChild.nodeType===1)e=e.firstChild;return e}).append(this)}return this},wrapInner:function(e){return v.isFunction(e)?this.each(function(t){v(this).wrapInner(e.call(this,t))}):this.each(function(){var t=v(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)})},wrap:function(e){var t=v.isFunction(e);return this.each(function(n){v(this).wrapAll(t?e.call(this,n):e)})},unwrap:function(){return this.parent().each(function(){v.nodeName(this,"body")||v(this).replaceWith(this.childNodes)}).end()},append:function(){return this.domManip(arguments,!0,function(e){(this.nodeType===1||this.nodeType===11)&&this.appendChild(e)})},prepend:function(){return this.domManip(arguments,!0,function(e){(this.nodeType===1||this.nodeType===11)&&this.insertBefore(e,this.firstChild)})},before:function(){if(!ut(this[0]))return this.domManip(arguments,!1,function(e){this.parentNode.insertBefore(e,this)});if(arguments.length){var e=v.clean(arguments);return this.pushStack(v.merge(e,this),"before",this.selector)}},after:function(){if(!ut(this[0]))return this.domManip(arguments,!1,function(e){this.parentNode.insertBefore(e,this.nextSibling)});if(arguments.length){var e=v.clean(arguments);return this.pushStack(v.merge(this,e),"after",this.selector)}},remove:function(e,t){var n,r=0;for(;(n=this[r])!=null;r++)if(!e||v.filter(e,[n]).length)!t&&n.nodeType===1&&(v.cleanData(n.getElementsByTagName("*")),v.cleanData([n])),n.parentNode&&n.parentNode.removeChild(n);return this},empty:function(){var e,t=0;for(;(e=this[t])!=null;t++){e.nodeType===1&&v.cleanData(e.getElementsByTagName("*"));while(e.firstChild)e.removeChild(e.firstChild)}return this},clone:function(e,t){return e=e==null?!1:e,t=t==null?e:t,this.map(function(){return v.clone(this,e,t)})},html:function(e){return v.access(this,function(e){var n=this[0]||{},r=0,i=this.length;if(e===t)return n.nodeType===1?n.innerHTML.replace(ht,""):t;if(typeof e=="string"&&!yt.test(e)&&(v.support.htmlSerialize||!wt.test(e))&&(v.support.leadingWhitespace||!pt.test(e))&&!Nt[(vt.exec(e)||["",""])[1].toLowerCase()]){e=e.replace(dt,"<$1></$2>");try{for(;r<i;r++)n=this[r]||{},n.nodeType===1&&(v.cleanData(n.getElementsByTagName("*")),n.innerHTML=e);n=0}catch(s){}}n&&this.empty().append(e)},null,e,arguments.length)},replaceWith:function(e){return ut(this[0])?this.length?this.pushStack(v(v.isFunction(e)?e():e),"replaceWith",e):this:v.isFunction(e)?this.each(function(t){var n=v(this),r=n.html();n.replaceWith(e.call(this,t,r))}):(typeof e!="string"&&(e=v(e).detach()),this.each(function(){var t=this.nextSibling,n=this.parentNode;v(this).remove(),t?v(t).before(e):v(n).append(e)}))},detach:function(e){return this.remove(e,!0)},domManip:function(e,n,r){e=[].concat.apply([],e);var i,s,o,u,a=0,f=e[0],l=[],c=this.length;if(!v.support.checkClone&&c>1&&typeof f=="string"&&St.test(f))return this.each(function(){v(this).domManip(e,n,r)});if(v.isFunction(f))return this.each(function(i){var s=v(this);e[0]=f.call(this,i,n?s.html():t),s.domManip(e,n,r)});if(this[0]){i=v.buildFragment(e,this,l),o=i.fragment,s=o.firstChild,o.childNodes.length===1&&(o=s);if(s){n=n&&v.nodeName(s,"tr");for(u=i.cacheable||c-1;a<c;a++)r.call(n&&v.nodeName(this[a],"table")?Lt(this[a],"tbody"):this[a],a===u?o:v.clone(o,!0,!0))}o=s=null,l.length&&v.each(l,function(e,t){t.src?v.ajax?v.ajax({url:t.src,type:"GET",dataType:"script",async:!1,global:!1,"throws":!0}):v.error("no ajax"):v.globalEval((t.text||t.textContent||t.innerHTML||"").replace(Tt,"")),t.parentNode&&t.parentNode.removeChild(t)})}return this}}),v.buildFragment=function(e,n,r){var s,o,u,a=e[0];return n=n||i,n=!n.nodeType&&n[0]||n,n=n.ownerDocument||n,e.length===1&&typeof a=="string"&&a.length<512&&n===i&&a.charAt(0)==="<"&&!bt.test(a)&&(v.support.checkClone||!St.test(a))&&(v.support.html5Clone||!wt.test(a))&&(o=!0,s=v.fragments[a],u=s!==t),s||(s=n.createDocumentFragment(),v.clean(e,n,s,r),o&&(v.fragments[a]=u&&s)),{fragment:s,cacheable:o}},v.fragments={},v.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(e,t){v.fn[e]=function(n){var r,i=0,s=[],o=v(n),u=o.length,a=this.length===1&&this[0].parentNode;if((a==null||a&&a.nodeType===11&&a.childNodes.length===1)&&u===1)return o[t](this[0]),this;for(;i<u;i++)r=(i>0?this.clone(!0):this).get(),v(o[i])[t](r),s=s.concat(r);return this.pushStack(s,e,o.selector)}}),v.extend({clone:function(e,t,n){var r,i,s,o;v.support.html5Clone||v.isXMLDoc(e)||!wt.test("<"+e.nodeName+">")?o=e.cloneNode(!0):(kt.innerHTML=e.outerHTML,kt.removeChild(o=kt.firstChild));if((!v.support.noCloneEvent||!v.support.noCloneChecked)&&(e.nodeType===1||e.nodeType===11)&&!v.isXMLDoc(e)){Ot(e,o),r=Mt(e),i=Mt(o);for(s=0;r[s];++s)i[s]&&Ot(r[s],i[s])}if(t){At(e,o);if(n){r=Mt(e),i=Mt(o);for(s=0;r[s];++s)At(r[s],i[s])}}return r=i=null,o},clean:function(e,t,n,r){var s,o,u,a,f,l,c,h,p,d,m,g,y=t===i&&Ct,b=[];if(!t||typeof t.createDocumentFragment=="undefined")t=i;for(s=0;(u=e[s])!=null;s++){typeof u=="number"&&(u+="");if(!u)continue;if(typeof u=="string")if(!gt.test(u))u=t.createTextNode(u);else{y=y||lt(t),c=t.createElement("div"),y.appendChild(c),u=u.replace(dt,"<$1></$2>"),a=(vt.exec(u)||["",""])[1].toLowerCase(),f=Nt[a]||Nt._default,l=f[0],c.innerHTML=f[1]+u+f[2];while(l--)c=c.lastChild;if(!v.support.tbody){h=mt.test(u),p=a==="table"&&!h?c.firstChild&&c.firstChild.childNodes:f[1]==="<table>"&&!h?c.childNodes:[];for(o=p.length-1;o>=0;--o)v.nodeName(p[o],"tbody")&&!p[o].childNodes.length&&p[o].parentNode.removeChild(p[o])}!v.support.leadingWhitespace&&pt.test(u)&&c.insertBefore(t.createTextNode(pt.exec(u)[0]),c.firstChild),u=c.childNodes,c.parentNode.removeChild(c)}u.nodeType?b.push(u):v.merge(b,u)}c&&(u=c=y=null);if(!v.support.appendChecked)for(s=0;(u=b[s])!=null;s++)v.nodeName(u,"input")?_t(u):typeof u.getElementsByTagName!="undefined"&&v.grep(u.getElementsByTagName("input"),_t);if(n){m=function(e){if(!e.type||xt.test(e.type))return r?r.push(e.parentNode?e.parentNode.removeChild(e):e):n.appendChild(e)};for(s=0;(u=b[s])!=null;s++)if(!v.nodeName(u,"script")||!m(u))n.appendChild(u),typeof u.getElementsByTagName!="undefined"&&(g=v.grep(v.merge([],u.getElementsByTagName("script")),m),b.splice.apply(b,[s+1,0].concat(g)),s+=g.length)}return b},cleanData:function(e,t){var n,r,i,s,o=0,u=v.expando,a=v.cache,f=v.support.deleteExpando,l=v.event.special;for(;(i=e[o])!=null;o++)if(t||v.acceptData(i)){r=i[u],n=r&&a[r];if(n){if(n.events)for(s in n.events)l[s]?v.event.remove(i,s):v.removeEvent(i,s,n.handle);a[r]&&(delete a[r],f?delete i[u]:i.removeAttribute?i.removeAttribute(u):i[u]=null,v.deletedIds.push(r))}}}}),function(){var e,t;v.uaMatch=function(e){e=e.toLowerCase();var t=/(chrome)[ \/]([\w.]+)/.exec(e)||/(webkit)[ \/]([\w.]+)/.exec(e)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(e)||/(msie) ([\w.]+)/.exec(e)||e.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(e)||[];return{browser:t[1]||"",version:t[2]||"0"}},e=v.uaMatch(o.userAgent),t={},e.browser&&(t[e.browser]=!0,t.version=e.version),t.chrome?t.webkit=!0:t.webkit&&(t.safari=!0),v.browser=t,v.sub=function(){function e(t,n){return new e.fn.init(t,n)}v.extend(!0,e,this),e.superclass=this,e.fn=e.prototype=this(),e.fn.constructor=e,e.sub=this.sub,e.fn.init=function(r,i){return i&&i instanceof v&&!(i instanceof e)&&(i=e(i)),v.fn.init.call(this,r,i,t)},e.fn.init.prototype=e.fn;var t=e(i);return e}}();var Dt,Pt,Ht,Bt=/alpha\([^)]*\)/i,jt=/opacity=([^)]*)/,Ft=/^(top|right|bottom|left)$/,It=/^(none|table(?!-c[ea]).+)/,qt=/^margin/,Rt=new RegExp("^("+m+")(.*)$","i"),Ut=new RegExp("^("+m+")(?!px)[a-z%]+$","i"),zt=new RegExp("^([-+])=("+m+")","i"),Wt={BODY:"block"},Xt={position:"absolute",visibility:"hidden",display:"block"},Vt={letterSpacing:0,fontWeight:400},$t=["Top","Right","Bottom","Left"],Jt=["Webkit","O","Moz","ms"],Kt=v.fn.toggle;v.fn.extend({css:function(e,n){return v.access(this,function(e,n,r){return r!==t?v.style(e,n,r):v.css(e,n)},e,n,arguments.length>1)},show:function(){return Yt(this,!0)},hide:function(){return Yt(this)},toggle:function(e,t){var n=typeof e=="boolean";return v.isFunction(e)&&v.isFunction(t)?Kt.apply(this,arguments):this.each(function(){(n?e:Gt(this))?v(this).show():v(this).hide()})}}),v.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=Dt(e,"opacity");return n===""?"1":n}}}},cssNumber:{fillOpacity:!0,fontWeight:!0,lineHeight:!0,opacity:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{"float":v.support.cssFloat?"cssFloat":"styleFloat"},style:function(e,n,r,i){if(!e||e.nodeType===3||e.nodeType===8||!e.style)return;var s,o,u,a=v.camelCase(n),f=e.style;n=v.cssProps[a]||(v.cssProps[a]=Qt(f,a)),u=v.cssHooks[n]||v.cssHooks[a];if(r===t)return u&&"get"in u&&(s=u.get(e,!1,i))!==t?s:f[n];o=typeof r,o==="string"&&(s=zt.exec(r))&&(r=(s[1]+1)*s[2]+parseFloat(v.css(e,n)),o="number");if(r==null||o==="number"&&isNaN(r))return;o==="number"&&!v.cssNumber[a]&&(r+="px");if(!u||!("set"in u)||(r=u.set(e,r,i))!==t)try{f[n]=r}catch(l){}},css:function(e,n,r,i){var s,o,u,a=v.camelCase(n);return n=v.cssProps[a]||(v.cssProps[a]=Qt(e.style,a)),u=v.cssHooks[n]||v.cssHooks[a],u&&"get"in u&&(s=u.get(e,!0,i)),s===t&&(s=Dt(e,n)),s==="normal"&&n in Vt&&(s=Vt[n]),r||i!==t?(o=parseFloat(s),r||v.isNumeric(o)?o||0:s):s},swap:function(e,t,n){var r,i,s={};for(i in t)s[i]=e.style[i],e.style[i]=t[i];r=n.call(e);for(i in t)e.style[i]=s[i];return r}}),e.getComputedStyle?Dt=function(t,n){var r,i,s,o,u=e.getComputedStyle(t,null),a=t.style;return u&&(r=u.getPropertyValue(n)||u[n],r===""&&!v.contains(t.ownerDocument,t)&&(r=v.style(t,n)),Ut.test(r)&&qt.test(n)&&(i=a.width,s=a.minWidth,o=a.maxWidth,a.minWidth=a.maxWidth=a.width=r,r=u.width,a.width=i,a.minWidth=s,a.maxWidth=o)),r}:i.documentElement.currentStyle&&(Dt=function(e,t){var n,r,i=e.currentStyle&&e.currentStyle[t],s=e.style;return i==null&&s&&s[t]&&(i=s[t]),Ut.test(i)&&!Ft.test(t)&&(n=s.left,r=e.runtimeStyle&&e.runtimeStyle.left,r&&(e.runtimeStyle.left=e.currentStyle.left),s.left=t==="fontSize"?"1em":i,i=s.pixelLeft+"px",s.left=n,r&&(e.runtimeStyle.left=r)),i===""?"auto":i}),v.each(["height","width"],function(e,t){v.cssHooks[t]={get:function(e,n,r){if(n)return e.offsetWidth===0&&It.test(Dt(e,"display"))?v.swap(e,Xt,function(){return tn(e,t,r)}):tn(e,t,r)},set:function(e,n,r){return Zt(e,n,r?en(e,t,r,v.support.boxSizing&&v.css(e,"boxSizing")==="border-box"):0)}}}),v.support.opacity||(v.cssHooks.opacity={get:function(e,t){return jt.test((t&&e.currentStyle?e.currentStyle.filter:e.style.filter)||"")?.01*parseFloat(RegExp.$1)+"":t?"1":""},set:function(e,t){var n=e.style,r=e.currentStyle,i=v.isNumeric(t)?"alpha(opacity="+t*100+")":"",s=r&&r.filter||n.filter||"";n.zoom=1;if(t>=1&&v.trim(s.replace(Bt,""))===""&&n.removeAttribute){n.removeAttribute("filter");if(r&&!r.filter)return}n.filter=Bt.test(s)?s.replace(Bt,i):s+" "+i}}),v(function(){v.support.reliableMarginRight||(v.cssHooks.marginRight={get:function(e,t){return v.swap(e,{display:"inline-block"},function(){if(t)return Dt(e,"marginRight")})}}),!v.support.pixelPosition&&v.fn.position&&v.each(["top","left"],function(e,t){v.cssHooks[t]={get:function(e,n){if(n){var r=Dt(e,t);return Ut.test(r)?v(e).position()[t]+"px":r}}}})}),v.expr&&v.expr.filters&&(v.expr.filters.hidden=function(e){return e.offsetWidth===0&&e.offsetHeight===0||!v.support.reliableHiddenOffsets&&(e.style&&e.style.display||Dt(e,"display"))==="none"},v.expr.filters.visible=function(e){return!v.expr.filters.hidden(e)}),v.each({margin:"",padding:"",border:"Width"},function(e,t){v.cssHooks[e+t]={expand:function(n){var r,i=typeof n=="string"?n.split(" "):[n],s={};for(r=0;r<4;r++)s[e+$t[r]+t]=i[r]||i[r-2]||i[0];return s}},qt.test(e)||(v.cssHooks[e+t].set=Zt)});var rn=/%20/g,sn=/\[\]$/,on=/\r?\n/g,un=/^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,an=/^(?:select|textarea)/i;v.fn.extend({serialize:function(){return v.param(this.serializeArray())},serializeArray:function(){return this.map(function(){return this.elements?v.makeArray(this.elements):this}).filter(function(){return this.name&&!this.disabled&&(this.checked||an.test(this.nodeName)||un.test(this.type))}).map(function(e,t){var n=v(this).val();return n==null?null:v.isArray(n)?v.map(n,function(e,n){return{name:t.name,value:e.replace(on,"\r\n")}}):{name:t.name,value:n.replace(on,"\r\n")}}).get()}}),v.param=function(e,n){var r,i=[],s=function(e,t){t=v.isFunction(t)?t():t==null?"":t,i[i.length]=encodeURIComponent(e)+"="+encodeURIComponent(t)};n===t&&(n=v.ajaxSettings&&v.ajaxSettings.traditional);if(v.isArray(e)||e.jquery&&!v.isPlainObject(e))v.each(e,function(){s(this.name,this.value)});else for(r in e)fn(r,e[r],n,s);return i.join("&").replace(rn,"+")};var ln,cn,hn=/#.*$/,pn=/^(.*?):[ \t]*([^\r\n]*)\r?$/mg,dn=/^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,vn=/^(?:GET|HEAD)$/,mn=/^\/\//,gn=/\?/,yn=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,bn=/([?&])_=[^&]*/,wn=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,En=v.fn.load,Sn={},xn={},Tn=["*/"]+["*"];try{cn=s.href}catch(Nn){cn=i.createElement("a"),cn.href="",cn=cn.href}ln=wn.exec(cn.toLowerCase())||[],v.fn.load=function(e,n,r){if(typeof e!="string"&&En)return En.apply(this,arguments);if(!this.length)return this;var i,s,o,u=this,a=e.indexOf(" ");return a>=0&&(i=e.slice(a,e.length),e=e.slice(0,a)),v.isFunction(n)?(r=n,n=t):n&&typeof n=="object"&&(s="POST"),v.ajax({url:e,type:s,dataType:"html",data:n,complete:function(e,t){r&&u.each(r,o||[e.responseText,t,e])}}).done(function(e){o=arguments,u.html(i?v("<div>").append(e.replace(yn,"")).find(i):e)}),this},v.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),function(e,t){v.fn[t]=function(e){return this.on(t,e)}}),v.each(["get","post"],function(e,n){v[n]=function(e,r,i,s){return v.isFunction(r)&&(s=s||i,i=r,r=t),v.ajax({type:n,url:e,data:r,success:i,dataType:s})}}),v.extend({getScript:function(e,n){return v.get(e,t,n,"script")},getJSON:function(e,t,n){return v.get(e,t,n,"json")},ajaxSetup:function(e,t){return t?Ln(e,v.ajaxSettings):(t=e,e=v.ajaxSettings),Ln(e,t),e},ajaxSettings:{url:cn,isLocal:dn.test(ln[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded; charset=UTF-8",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":Tn},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":e.String,"text html":!0,"text json":v.parseJSON,"text xml":v.parseXML},flatOptions:{context:!0,url:!0}},ajaxPrefilter:Cn(Sn),ajaxTransport:Cn(xn),ajax:function(e,n){function T(e,n,s,a){var l,y,b,w,S,T=n;if(E===2)return;E=2,u&&clearTimeout(u),o=t,i=a||"",x.readyState=e>0?4:0,s&&(w=An(c,x,s));if(e>=200&&e<300||e===304)c.ifModified&&(S=x.getResponseHeader("Last-Modified"),S&&(v.lastModified[r]=S),S=x.getResponseHeader("Etag"),S&&(v.etag[r]=S)),e===304?(T="notmodified",l=!0):(l=On(c,w),T=l.state,y=l.data,b=l.error,l=!b);else{b=T;if(!T||e)T="error",e<0&&(e=0)}x.status=e,x.statusText=(n||T)+"",l?d.resolveWith(h,[y,T,x]):d.rejectWith(h,[x,T,b]),x.statusCode(g),g=t,f&&p.trigger("ajax"+(l?"Success":"Error"),[x,c,l?y:b]),m.fireWith(h,[x,T]),f&&(p.trigger("ajaxComplete",[x,c]),--v.active||v.event.trigger("ajaxStop"))}typeof e=="object"&&(n=e,e=t),n=n||{};var r,i,s,o,u,a,f,l,c=v.ajaxSetup({},n),h=c.context||c,p=h!==c&&(h.nodeType||h instanceof v)?v(h):v.event,d=v.Deferred(),m=v.Callbacks("once memory"),g=c.statusCode||{},b={},w={},E=0,S="canceled",x={readyState:0,setRequestHeader:function(e,t){if(!E){var n=e.toLowerCase();e=w[n]=w[n]||e,b[e]=t}return this},getAllResponseHeaders:function(){return E===2?i:null},getResponseHeader:function(e){var n;if(E===2){if(!s){s={};while(n=pn.exec(i))s[n[1].toLowerCase()]=n[2]}n=s[e.toLowerCase()]}return n===t?null:n},overrideMimeType:function(e){return E||(c.mimeType=e),this},abort:function(e){return e=e||S,o&&o.abort(e),T(0,e),this}};d.promise(x),x.success=x.done,x.error=x.fail,x.complete=m.add,x.statusCode=function(e){if(e){var t;if(E<2)for(t in e)g[t]=[g[t],e[t]];else t=e[x.status],x.always(t)}return this},c.url=((e||c.url)+"").replace(hn,"").replace(mn,ln[1]+"//"),c.dataTypes=v.trim(c.dataType||"*").toLowerCase().split(y),c.crossDomain==null&&(a=wn.exec(c.url.toLowerCase()),c.crossDomain=!(!a||a[1]===ln[1]&&a[2]===ln[2]&&(a[3]||(a[1]==="http:"?80:443))==(ln[3]||(ln[1]==="http:"?80:443)))),c.data&&c.processData&&typeof c.data!="string"&&(c.data=v.param(c.data,c.traditional)),kn(Sn,c,n,x);if(E===2)return x;f=c.global,c.type=c.type.toUpperCase(),c.hasContent=!vn.test(c.type),f&&v.active++===0&&v.event.trigger("ajaxStart");if(!c.hasContent){c.data&&(c.url+=(gn.test(c.url)?"&":"?")+c.data,delete c.data),r=c.url;if(c.cache===!1){var N=v.now(),C=c.url.replace(bn,"$1_="+N);c.url=C+(C===c.url?(gn.test(c.url)?"&":"?")+"_="+N:"")}}(c.data&&c.hasContent&&c.contentType!==!1||n.contentType)&&x.setRequestHeader("Content-Type",c.contentType),c.ifModified&&(r=r||c.url,v.lastModified[r]&&x.setRequestHeader("If-Modified-Since",v.lastModified[r]),v.etag[r]&&x.setRequestHeader("If-None-Match",v.etag[r])),x.setRequestHeader("Accept",c.dataTypes[0]&&c.accepts[c.dataTypes[0]]?c.accepts[c.dataTypes[0]]+(c.dataTypes[0]!=="*"?", "+Tn+"; q=0.01":""):c.accepts["*"]);for(l in c.headers)x.setRequestHeader(l,c.headers[l]);if(!c.beforeSend||c.beforeSend.call(h,x,c)!==!1&&E!==2){S="abort";for(l in{success:1,error:1,complete:1})x[l](c[l]);o=kn(xn,c,n,x);if(!o)T(-1,"No Transport");else{x.readyState=1,f&&p.trigger("ajaxSend",[x,c]),c.async&&c.timeout>0&&(u=setTimeout(function(){x.abort("timeout")},c.timeout));try{E=1,o.send(b,T)}catch(k){if(!(E<2))throw k;T(-1,k)}}return x}return x.abort()},active:0,lastModified:{},etag:{}});var Mn=[],_n=/\?/,Dn=/(=)\?(?=&|$)|\?\?/,Pn=v.now();v.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Mn.pop()||v.expando+"_"+Pn++;return this[e]=!0,e}}),v.ajaxPrefilter("json jsonp",function(n,r,i){var s,o,u,a=n.data,f=n.url,l=n.jsonp!==!1,c=l&&Dn.test(f),h=l&&!c&&typeof a=="string"&&!(n.contentType||"").indexOf("application/x-www-form-urlencoded")&&Dn.test(a);if(n.dataTypes[0]==="jsonp"||c||h)return s=n.jsonpCallback=v.isFunction(n.jsonpCallback)?n.jsonpCallback():n.jsonpCallback,o=e[s],c?n.url=f.replace(Dn,"$1"+s):h?n.data=a.replace(Dn,"$1"+s):l&&(n.url+=(_n.test(f)?"&":"?")+n.jsonp+"="+s),n.converters["script json"]=function(){return u||v.error(s+" was not called"),u[0]},n.dataTypes[0]="json",e[s]=function(){u=arguments},i.always(function(){e[s]=o,n[s]&&(n.jsonpCallback=r.jsonpCallback,Mn.push(s)),u&&v.isFunction(o)&&o(u[0]),u=o=t}),"script"}),v.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(e){return v.globalEval(e),e}}}),v.ajaxPrefilter("script",function(e){e.cache===t&&(e.cache=!1),e.crossDomain&&(e.type="GET",e.global=!1)}),v.ajaxTransport("script",function(e){if(e.crossDomain){var n,r=i.head||i.getElementsByTagName("head")[0]||i.documentElement;return{send:function(s,o){n=i.createElement("script"),n.async="async",e.scriptCharset&&(n.charset=e.scriptCharset),n.src=e.url,n.onload=n.onreadystatechange=function(e,i){if(i||!n.readyState||/loaded|complete/.test(n.readyState))n.onload=n.onreadystatechange=null,r&&n.parentNode&&r.removeChild(n),n=t,i||o(200,"success")},r.insertBefore(n,r.firstChild)},abort:function(){n&&n.onload(0,1)}}}});var Hn,Bn=e.ActiveXObject?function(){for(var e in Hn)Hn[e](0,1)}:!1,jn=0;v.ajaxSettings.xhr=e.ActiveXObject?function(){return!this.isLocal&&Fn()||In()}:Fn,function(e){v.extend(v.support,{ajax:!!e,cors:!!e&&"withCredentials"in e})}(v.ajaxSettings.xhr()),v.support.ajax&&v.ajaxTransport(function(n){if(!n.crossDomain||v.support.cors){var r;return{send:function(i,s){var o,u,a=n.xhr();n.username?a.open(n.type,n.url,n.async,n.username,n.password):a.open(n.type,n.url,n.async);if(n.xhrFields)for(u in n.xhrFields)a[u]=n.xhrFields[u];n.mimeType&&a.overrideMimeType&&a.overrideMimeType(n.mimeType),!n.crossDomain&&!i["X-Requested-With"]&&(i["X-Requested-With"]="XMLHttpRequest");try{for(u in i)a.setRequestHeader(u,i[u])}catch(f){}a.send(n.hasContent&&n.data||null),r=function(e,i){var u,f,l,c,h;try{if(r&&(i||a.readyState===4)){r=t,o&&(a.onreadystatechange=v.noop,Bn&&delete Hn[o]);if(i)a.readyState!==4&&a.abort();else{u=a.status,l=a.getAllResponseHeaders(),c={},h=a.responseXML,h&&h.documentElement&&(c.xml=h);try{c.text=a.responseText}catch(p){}try{f=a.statusText}catch(p){f=""}!u&&n.isLocal&&!n.crossDomain?u=c.text?200:404:u===1223&&(u=204)}}}catch(d){i||s(-1,d)}c&&s(u,f,c,l)},n.async?a.readyState===4?setTimeout(r,0):(o=++jn,Bn&&(Hn||(Hn={},v(e).unload(Bn)),Hn[o]=r),a.onreadystatechange=r):r()},abort:function(){r&&r(0,1)}}}});var qn,Rn,Un=/^(?:toggle|show|hide)$/,zn=new RegExp("^(?:([-+])=|)("+m+")([a-z%]*)$","i"),Wn=/queueHooks$/,Xn=[Gn],Vn={"*":[function(e,t){var n,r,i=this.createTween(e,t),s=zn.exec(t),o=i.cur(),u=+o||0,a=1,f=20;if(s){n=+s[2],r=s[3]||(v.cssNumber[e]?"":"px");if(r!=="px"&&u){u=v.css(i.elem,e,!0)||n||1;do a=a||".5",u/=a,v.style(i.elem,e,u+r);while(a!==(a=i.cur()/o)&&a!==1&&--f)}i.unit=r,i.start=u,i.end=s[1]?u+(s[1]+1)*n:n}return i}]};v.Animation=v.extend(Kn,{tweener:function(e,t){v.isFunction(e)?(t=e,e=["*"]):e=e.split(" ");var n,r=0,i=e.length;for(;r<i;r++)n=e[r],Vn[n]=Vn[n]||[],Vn[n].unshift(t)},prefilter:function(e,t){t?Xn.unshift(e):Xn.push(e)}}),v.Tween=Yn,Yn.prototype={constructor:Yn,init:function(e,t,n,r,i,s){this.elem=e,this.prop=n,this.easing=i||"swing",this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=s||(v.cssNumber[n]?"":"px")},cur:function(){var e=Yn.propHooks[this.prop];return e&&e.get?e.get(this):Yn.propHooks._default.get(this)},run:function(e){var t,n=Yn.propHooks[this.prop];return this.options.duration?this.pos=t=v.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):Yn.propHooks._default.set(this),this}},Yn.prototype.init.prototype=Yn.prototype,Yn.propHooks={_default:{get:function(e){var t;return e.elem[e.prop]==null||!!e.elem.style&&e.elem.style[e.prop]!=null?(t=v.css(e.elem,e.prop,!1,""),!t||t==="auto"?0:t):e.elem[e.prop]},set:function(e){v.fx.step[e.prop]?v.fx.step[e.prop](e):e.elem.style&&(e.elem.style[v.cssProps[e.prop]]!=null||v.cssHooks[e.prop])?v.style(e.elem,e.prop,e.now+e.unit):e.elem[e.prop]=e.now}}},Yn.propHooks.scrollTop=Yn.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},v.each(["toggle","show","hide"],function(e,t){var n=v.fn[t];v.fn[t]=function(r,i,s){return r==null||typeof r=="boolean"||!e&&v.isFunction(r)&&v.isFunction(i)?n.apply(this,arguments):this.animate(Zn(t,!0),r,i,s)}}),v.fn.extend({fadeTo:function(e,t,n,r){return this.filter(Gt).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=v.isEmptyObject(e),s=v.speed(t,n,r),o=function(){var t=Kn(this,v.extend({},e),s);i&&t.stop(!0)};return i||s.queue===!1?this.each(o):this.queue(s.queue,o)},stop:function(e,n,r){var i=function(e){var t=e.stop;delete e.stop,t(r)};return typeof e!="string"&&(r=n,n=e,e=t),n&&e!==!1&&this.queue(e||"fx",[]),this.each(function(){var t=!0,n=e!=null&&e+"queueHooks",s=v.timers,o=v._data(this);if(n)o[n]&&o[n].stop&&i(o[n]);else for(n in o)o[n]&&o[n].stop&&Wn.test(n)&&i(o[n]);for(n=s.length;n--;)s[n].elem===this&&(e==null||s[n].queue===e)&&(s[n].anim.stop(r),t=!1,s.splice(n,1));(t||!r)&&v.dequeue(this,e)})}}),v.each({slideDown:Zn("show"),slideUp:Zn("hide"),slideToggle:Zn("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(e,t){v.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}}),v.speed=function(e,t,n){var r=e&&typeof e=="object"?v.extend({},e):{complete:n||!n&&t||v.isFunction(e)&&e,duration:e,easing:n&&t||t&&!v.isFunction(t)&&t};r.duration=v.fx.off?0:typeof r.duration=="number"?r.duration:r.duration in v.fx.speeds?v.fx.speeds[r.duration]:v.fx.speeds._default;if(r.queue==null||r.queue===!0)r.queue="fx";return r.old=r.complete,r.complete=function(){v.isFunction(r.old)&&r.old.call(this),r.queue&&v.dequeue(this,r.queue)},r},v.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2}},v.timers=[],v.fx=Yn.prototype.init,v.fx.tick=function(){var e,n=v.timers,r=0;qn=v.now();for(;r<n.length;r++)e=n[r],!e()&&n[r]===e&&n.splice(r--,1);n.length||v.fx.stop(),qn=t},v.fx.timer=function(e){e()&&v.timers.push(e)&&!Rn&&(Rn=setInterval(v.fx.tick,v.fx.interval))},v.fx.interval=13,v.fx.stop=function(){clearInterval(Rn),Rn=null},v.fx.speeds={slow:600,fast:200,_default:400},v.fx.step={},v.expr&&v.expr.filters&&(v.expr.filters.animated=function(e){return v.grep(v.timers,function(t){return e===t.elem}).length});var er=/^(?:body|html)$/i;v.fn.offset=function(e){if(arguments.length)return e===t?this:this.each(function(t){v.offset.setOffset(this,e,t)});var n,r,i,s,o,u,a,f={top:0,left:0},l=this[0],c=l&&l.ownerDocument;if(!c)return;return(r=c.body)===l?v.offset.bodyOffset(l):(n=c.documentElement,v.contains(n,l)?(typeof l.getBoundingClientRect!="undefined"&&(f=l.getBoundingClientRect()),i=tr(c),s=n.clientTop||r.clientTop||0,o=n.clientLeft||r.clientLeft||0,u=i.pageYOffset||n.scrollTop,a=i.pageXOffset||n.scrollLeft,{top:f.top+u-s,left:f.left+a-o}):f)},v.offset={bodyOffset:function(e){var t=e.offsetTop,n=e.offsetLeft;return v.support.doesNotIncludeMarginInBodyOffset&&(t+=parseFloat(v.css(e,"marginTop"))||0,n+=parseFloat(v.css(e,"marginLeft"))||0),{top:t,left:n}},setOffset:function(e,t,n){var r=v.css(e,"position");r==="static"&&(e.style.position="relative");var i=v(e),s=i.offset(),o=v.css(e,"top"),u=v.css(e,"left"),a=(r==="absolute"||r==="fixed")&&v.inArray("auto",[o,u])>-1,f={},l={},c,h;a?(l=i.position(),c=l.top,h=l.left):(c=parseFloat(o)||0,h=parseFloat(u)||0),v.isFunction(t)&&(t=t.call(e,n,s)),t.top!=null&&(f.top=t.top-s.top+c),t.left!=null&&(f.left=t.left-s.left+h),"using"in t?t.using.call(e,f):i.css(f)}},v.fn.extend({position:function(){if(!this[0])return;var e=this[0],t=this.offsetParent(),n=this.offset(),r=er.test(t[0].nodeName)?{top:0,left:0}:t.offset();return n.top-=parseFloat(v.css(e,"marginTop"))||0,n.left-=parseFloat(v.css(e,"marginLeft"))||0,r.top+=parseFloat(v.css(t[0],"borderTopWidth"))||0,r.left+=parseFloat(v.css(t[0],"borderLeftWidth"))||0,{top:n.top-r.top,left:n.left-r.left}},offsetParent:function(){return this.map(function(){var e=this.offsetParent||i.body;while(e&&!er.test(e.nodeName)&&v.css(e,"position")==="static")e=e.offsetParent;return e||i.body})}}),v.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(e,n){var r=/Y/.test(n);v.fn[e]=function(i){return v.access(this,function(e,i,s){var o=tr(e);if(s===t)return o?n in o?o[n]:o.document.documentElement[i]:e[i];o?o.scrollTo(r?v(o).scrollLeft():s,r?s:v(o).scrollTop()):e[i]=s},e,i,arguments.length,null)}}),v.each({Height:"height",Width:"width"},function(e,n){v.each({padding:"inner"+e,content:n,"":"outer"+e},function(r,i){v.fn[i]=function(i,s){var o=arguments.length&&(r||typeof i!="boolean"),u=r||(i===!0||s===!0?"margin":"border");return v.access(this,function(n,r,i){var s;return v.isWindow(n)?n.document.documentElement["client"+e]:n.nodeType===9?(s=n.documentElement,Math.max(n.body["scroll"+e],s["scroll"+e],n.body["offset"+e],s["offset"+e],s["client"+e])):i===t?v.css(n,r,i,u):v.style(n,r,i,u)},n,o?i:t,o,null)}})}),e.jQuery=e.$=v,typeof define=="function"&&define.amd&&define.amd.jQuery&&define("jquery",[],function(){return v})})(window);

/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
*
 * v12.0.5991.25330
*/
window.MadCap={};MadCap.CreateNamespace=function(b){var d=b.split(".");var e=MadCap;for(var a=0,c=d.length;a<c;a++){var b=d[a];if(b=="MadCap"){continue}if(typeof(e[b])!="undefined"){e=e[b];continue}e[b]={};e=e[b]}return e};if(!Object.create){Object.create=function(b){if(arguments.length>1){throw new Error("Object.create implementation only accepts the first parameter.")}function a(){}a.prototype=b;return new a()}}if(typeof String.prototype.trim!=="function"){String.prototype.trim=function(){return this.replace(/^\s+|\s+$/g,"")}}if(!Array.prototype.indexOf){Array.prototype.indexOf=function(b){var a=this.length>>>0;var c=Number(arguments[1])||0;c=(c<0)?Math.ceil(c):Math.floor(c);if(c<0){c+=a}for(;c<a;c++){if(c in this&&this[c]===b){return c}}return -1}}MadCap.Extend=function(a,b){b.prototype=Object.create(a.prototype);b.prototype.constructor=b;b.prototype.base=a.prototype};MadCap.Exception=function(b,a){this.Number=b;this.Message=a};MadCap.IsIOS=function(){return MadCap.String.Contains(navigator.userAgent,"iphone")||MadCap.String.Contains(navigator.userAgent,"ipad")};MadCap.IsIBooks=function(){return MadCap.HasEpubReadingSystem()&&navigator.epubReadingSystem.name=="iBooks"};MadCap.HasEpubReadingSystem=function(){return"epubReadingSystem" in navigator};MadCap.IsSafari=function(){return MadCap.String.Contains(navigator.userAgent,"safari")&&!MadCap.String.Contains(navigator.userAgent,"chrome")};(function(){var a=MadCap.CreateNamespace("String");a.IsNullOrEmpty=function(b){if(b==null){return true}if(b.length==0){return true}return false};a.StartsWith=function(f,e,c){if(e==null){return false}if(f.length<e.length){return false}var d=f;var b=e;if(!c){d=d.toLowerCase();b=b.toLowerCase()}if(d.substring(0,b.length)==b){return true}else{return false}};a.EndsWith=function(f,e,c){if(e==null){return false}if(f.length<e.length){return false}var d=f;var b=e;if(!c){d=d.toLowerCase();b=b.toLowerCase()}if(d.substring(d.length-b.length)==b){return true}else{return false}};a.Contains=function(h,g,c){var d=c?h:h.toLowerCase();if($.isArray(g)){for(var e=0,f=g.length;e<f;e++){var b=c?g[e]:g[e].toLowerCase();if(d.indexOf(b)!=-1){return true}}return false}var b=c?g:g.toLowerCase();return d.indexOf(b)!=-1};a.Trim=function(b){return a.TrimRight(a.TrimLeft(b))};a.TrimLeft=function(d){var b=0;var c=d.length;for(b=0;b<c&&d.charAt(b)==" ";b++){}return d.substring(b,d.length)};a.TrimRight=function(c){var b=0;for(b=c.length-1;b>=0&&c.charAt(b)==" ";b--){}return c.substring(0,b+1)};a.ToBool=function(e,c){var b=c;if(e!=null){var d=e.toLowerCase();if(d!="true"&&d!="false"&&d!="1"&&d!="0"&&d!="yes"&&d!="no"){throw new MadCap.Exception(-1,"The string can not be converted to a boolean value.")}b=d=="true"||d=="1"||d=="yes"}return b};a.ToInt=function(d,b){var c=b;if(d!=null){c=parseInt(d)}return c};a.ToDashed=function(b){return b.replace(/([A-Z])/g,function(c){return"-"+c.toLowerCase()})};a.LocaleCompare=function(d,c,e){if(e){if(typeof Intl!=="undefined"&&typeof Intl.Collator!=="undefined"){var b=new Intl.Collator(e);if(b){return b.compare(d,c)}}if(String.prototype.localeCompare){return d.localeCompare(c,e)}}return d<c?-1:d>c?1:0};a.Compare=function(f,e){var h=f.length;var g=e.length;for(var d=0;d<h&&d<g;d++){var c=f.charCodeAt(d);var b=e.charCodeAt(d);if(c<b){return -1}else{if(c>b){return 1}}}if(h<g){return -1}else{if(h>g){return 1}else{return 0}}};a.IsPunctuation=function(b){var d=b.charCodeAt(0);return(d>=33&&d<=35)||(d>=37&&d<=42)||(d>=44&&d<=47)||(d==58||d==59)||(d==63||d==64)||(d>=91&&d<=93)||(d==95)||(d==123)||(d==125)||(d==161)||(d==171)||(d==173)||(d==183)||(d==187)||(d==191)||(d==894)||(d==903)||(d>=1370&&d<=1375)||(d==1417||d==1418)||(d==1470)||(d==1472)||(d==1475)||(d==1478)||(d==1523||d==1524)||(d==1548||d==1549)||(d==1563)||(d==1566||d==1567)||(d>=1642&&d<=1645)||(d==1748)||(d>=1792&&d<=1805)||(d>=2039&&d<=2041)||(d==2404||d==2405)||(d==2416)||(d==3572)||(d>=3663&&d<=3675)||(d>=3844&&d<=3858)||(d>=3898&&d<=3901)||(d==3973)||(d==4048||d==4049)||(d>=4170&&d<=4175)||(d==4347)||(d>=4961&&d<=4968)||(d==5741||d==5742)||(d==5787||d==5788)||(d>=5867&&d<=5869)||(d==5941||d==5942)||(d>=6100&&d<=6102)||(d>=6104&&d<=6106)||(d>=6144&&d<=6154)||(d==6468||d==6469)||(d==6622||d==6623)||(d==6686||d==6687)||(d>=7002&&d<=7008)||(d>=8208&&d<=8231)||(d>=8240&&d<=8259)||(d>=8261&&d<=8273)||(d>=8275&&d<=8286)||(d==8317||d==8318)||(d==8333||d==8334)||(d==9001||d==9002)||(d>=10088&&d<=10101)||(d>=10181&&d<=10182)||(d>=10214&&d<=10219)||(d>=10627&&d<=10648)||(d>=10712&&d<=10715)||(d==10748||d==10749)||(d>=11513&&d<=11516)||(d==11518||d==11519)||(d>=11776&&d<=11799)||(d==11804||d==11805)||(d>=12289&&d<=12291)||(d>=12296&&d<=12305)||(d>=12308&&d<=12319)||(d==12336)||(d==12349)||(d==12448)||(d==12539)||(d>=43124&&d<=43127)||(d==64830||d==64831)||(d>=65040&&d<=65049)||(d>=65072&&d<=65106)||(d>=65108&&d<=65121)||(d==65123)||(d==65128)||(d==65130||d==65131)||(d>=65281&&d<=65283)||(d>=65285&&d<=65290)||(d>=65292&&d<=65295)||(d==65306||d==65307)||(d==65311||d==65312)||(d>=65339&&d<=65341)||(d==65343)||(d==65371)||(d==65373)||(d>=65375&&d<=65381)};a.Split=function(h,g){var c=h.length;var f=[];var b=-1,d=-1;for(var e=0;e<=c;e++){if(e==c||g(h.charAt(e))){if(b>-1){f.push(h.slice(b,d));b=-1}}else{if(b==-1){b=e}d=e+1}}return f}})();(function(){MadCap.CreateNamespace("DEBUG");var a=MadCap.DEBUG;a.Log={};a.Log.Create=function(){var e=document.createElement("div");e.setAttribute("id","DEBUG_Log");var f=document.createElement("div");$(f).addClass("MCDebugLogHeader");f.appendChild(document.createTextNode("Log Console"));e.appendChild(f);var d=document.createElement("div");$(d).addClass("MCDebugLogBody");e.appendChild(d);var c=document.createElement("div");$(c).addClass("MCDebugLogFooter");e.appendChild(c);document.body.appendChild(e);var b=new MadCap.DragDrop(e,f)};a.Log._LoadTime=new Date();a.Log.AddLine=function(d){if(parent!=window){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"DEBUG-AddLine",[d],null);return}var f=document.getElementById("DEBUG_Log");if(f==null){return}var c=new Date();var h=c-a.Log._LoadTime;var e=document.createElement("p");$(e).addClass("MCDebugLogEntryTime");e.appendChild(document.createTextNode(h+"ms "+c.toLocaleTimeString()));var b=document.createElement("div");$(b).addClass("MCDebugLogEntry");b.appendChild(e);b.appendChild(document.createTextNode(d));var g=MadCap.Dom.GetElementsByClassName("MCDebugLogBody","div",f)[0];g.insertBefore(b,g.firstChild)}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.CreateNamespace("Dom");var a=MadCap.Dom;a.Dataset=function(c,b){return c.getAttribute("data-"+MadCap.String.ToDashed(b))};a.GetElementsByClassName=function(g,b,c){b=b||"*";c=c||document;var d=new Array();var j=c.getElementsByTagName(b);for(var e=0,h=j.length;e<h;e++){var f=j[e];if($(f).hasClass(g)){d[d.length]=f}}return d};a.GetElementsByAttribute=function(h,k,l,j){l=l||"*";j=j||document;var c=new Array();var b=j.getElementsByTagName(l);for(var g=0,e=b.length;g<e;g++){var d=b[g];var f=a.GetAttribute(d,h);if(f==k){c[c.length]=d}}return c};a.GetChildNodeByTagName=function(d,f,e){var c=null;var g=-1;for(var b=d.firstChild;b!=null;b=b.nextSibling){if(b.nodeName.toLowerCase()==f.toLowerCase()){g++;if(g==e){c=b;break}}}return c};a.GetAncestorNodeByTagName=function(d,e,f){f=f||document.body;var c=null;var b=d.parentNode;while(b!=null&&b!=f){if(b.nodeName.toLowerCase()==e.toLowerCase()){c=b;break}b=b.parentNode}return c};a.GetAttribute=function(b,e){var d=b.getAttribute(e);if(d==null){d=b.getAttribute(e.toLowerCase());if(d==null){var c=e.indexOf(":");if(c!=-1){d=b.getAttribute(e.substring(c+1,e.length))}}}return d};a.GetAttributeInt=function(e,c,b){var d=b;var f=a.GetAttribute(e,c);if(f!=null){d=parseInt(f)}return d};a.GetAttributeBool=function(e,d,c){var b=c;var f=a.GetAttribute(e,d);if(f!=null){b=MadCap.String.ToBool(f,c)}return b};a.GetScrollPosition=function(){var b=0;var c=0;if(typeof(window.pageYOffset)!="undefined"){b=window.pageXOffset;c=window.pageYOffset}else{if(typeof(document.documentElement.scrollTop)!="undefined"&&document.documentElement.scrollTop>0){b=document.documentElement.scrollLeft;c=document.documentElement.scrollTop}}return{X:b,Y:c}}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.CreateNamespace("Utilities");MadCap.Utilities.Dictionary=function(f){this._Map=new Object();this._Overflows=new Array();this._Length=0;this._IgnoreCase=f==true};var a=MadCap.Utilities.Dictionary;a.prototype.GetLength=function(f){return this._Length};a.prototype.ForEach=function(j){var f=this._Map;for(var n in f){var m=f[n];var l=j(n,m);if(l!=undefined&&!l){return}}var h=this._Overflows;for(var k=0,g=h.length;k<g;k++){var o=h[k];var l=j(o.Key,o.Value);if(l!=undefined&&!l){return}}};a.prototype.GetItem=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var h=null;if(typeof(this._Map[g])=="function"){var f=this.GetItemOverflowIndex(g);if(f>=0){h=this._Overflows[f].Value}}else{h=this._Map[g];if(typeof(h)=="undefined"){h=null}}return h};a.prototype.GetItemOverflowIndex=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var j=this._Overflows;for(var f=0,h=j.length;f<h;f++){if(j[f].Key==g){return f}}return -1};a.prototype.Remove=function(g){if(this._IgnoreCase){g=g.toLowerCase()}if(typeof(this._Map[g])=="function"){var f=this.GetItemOverflowIndex(g);if(f>=0){this._Overflows.splice(f,1);this._Length--}}else{if(typeof(this._Map[g])!="undefined"){delete (this._Map[g]);this._Length--}}};a.prototype.Add=function(f,h){if(this._IgnoreCase){f=f.toLowerCase()}if(typeof(this._Map[f])=="function"){var g=this.GetItem(f);if(g!=null){this.Remove(f)}this._Overflows[this._Overflows.length]={Key:f,Value:h}}else{this._Map[f]=h}this._Length++};a.prototype.AddUnique=function(f,h){if(this._IgnoreCase){f=f.toLowerCase()}var g=this.GetItem(f);if(typeof(g)=="undefined"||!g){this.Add(f,h)}};MadCap.Utilities.DateTime=function(h){var g=/\/Date\(([0-9]+)\)\//i;var f=g.exec(h);if(f!=null){this.Date=new Date(parseInt(f[1]))}else{this.Date=new Date(h)}};var c=MadCap.Utilities.DateTime;c.Months=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];MadCap.Utilities.TimeSpan=function(g,f){if(typeof g=="undefined"){g=new Date()}if(typeof f=="undefined"){f=new Date()}if(g>f){this.FromDate=f;this.ToDate=g}else{this.FromDate=g;this.ToDate=f}this.Ticks=this.ToDate-this.FromDate;this.Seconds=this.Ticks/1000;this.Minutes=this.Seconds/60;this.Hours=this.Minutes/60;this.Days=this.Hours/24};var b=MadCap.Utilities.TimeSpan;b.prototype.ToDurationString=function(){if(this.Minutes<1){return"Just now"}if(this.Hours<1){return parseInt(this.Minutes)+" minutes ago"}if(this.Days<1){return parseInt(this.Hours)+" hours ago"}if(this.Days<30){return parseInt(this.Days)+" days ago"}var f=c.Months[this.FromDate.getMonth()]+" "+this.FromDate.getDate();if(this.FromDate.getFullYear()!=this.ToDate.getFullYear()){f+=", "+this.FromDate.getFullYear()}return f};MadCap.Utilities.Url=function(g){var f=this;this._Segments=[];this.FullPath=null;this.Path=null;this.PlainPath=null;this.Name=null;this.Extension=null;this.NameWithExtension=null;this.FullFragment=null;this.Fragment=null;this.Query=null;this.IsAbsolute=false;this.IsFolder=false;this.QueryMap=new MadCap.Utilities.Dictionary(true);this.HashMap=new MadCap.Utilities.Dictionary(true);(function(){var p="";var w="";var s="";var q=g.indexOf("#");var n=g.indexOf("?");if(q!=-1){w=g.substring(q);if(q>n){p=g.substring(q)}else{p=g.substring(q,n)}}if(n!=-1){if(n>q){s=g.substring(n)}else{s=g.substring(n,q)}}var t=q>-1?(n>-1?Math.min(q,n):q):n;var o=g.substring(0,t==-1?g.length:t);t=o.lastIndexOf("/");var v=o.substring(0,t+1);var m=o.substring(t+1);t=m.lastIndexOf(".");var h=m.substring(0,t);var k=m.substring(t+1);var j="";t=g.indexOf(":");if(t>=0){j=g.substring(0,t)}if(!MadCap.String.IsNullOrEmpty(g)){var r=g;if(MadCap.String.EndsWith(r,"/")){r=r.substring(0,r.length-1)}f._Segments=r.split("/")}f.FullPath=g;f.Path=v;f.PlainPath=o;f.Name=h;f.Extension=k;f.NameWithExtension=m;f.Scheme=j;f.IsAbsolute=!MadCap.String.IsNullOrEmpty(j);f.IsFolder=MadCap.String.EndsWith(o,"/");f.FullFragment=w;f.Fragment=p;f.Query=s;var u=f.Query;if(!MadCap.String.IsNullOrEmpty(u)){u=u.substring(1);u=u.replace(/\+/g," ");i(u,"&",f.QueryMap)}var l=f.Fragment;if(!MadCap.String.IsNullOrEmpty(l)){l=l.substring(1);i(l,"&",f.HashMap)}function i(G,y,x){var D=G.split(y);for(var B=0,z=D.length;B<z;B++){var A=D[B];var C=A.indexOf("=");var F=null;var E=null;if(C>=0){F=decodeURIComponent(A.substring(0,C));E=decodeURIComponent(A.substring(C+1))}else{F=A}x.Add(F,E)}}})()};var e=MadCap.Utilities.Url;e.GetDocumentUrl=function(){return new e(decodeURIComponent(document.location.href))};e.GetAbsolutePath=function(h){var g=e.GetDocumentUrl();var f=new MadCap.Utilities.Url(g.PlainPath);if(!f.IsFolder){f=f.ToFolder()}return f.CombinePath(h).FullPath};e.StripInvalidCharacters=function(f){return f.replace(/(javascript:|data:|[<>])/gi,"")};e.ReplaceReservedCharacters=function(f,h){var k=/[ ()&;,!'$]/;var j=f.split("");for(var g=0;g<j.length;g++){if(j[g].charCodeAt(0)>127||j[g].match(k)){j[g]=h}}return j.join("")};e.Navigate=function(f){document.location=e.StripInvalidCharacters(f)};e.GenerateNavigateTopicPath=function(g){var h=e.GetAbsolutePath(g.PlainPath);var f=e.GetDocumentUrl().QueryMap.GetItem("skinName")||g.QueryMap.GetItem("skinName");if(f!=null){h+=("?skinName="+f)}if(g.FullFragment.indexOf("#search-")==0){h+=g.FullFragment}else{if(g.QueryMap.GetLength()>0){h+=(f==null)?"?":"&";g.QueryMap.ForEach(function(j,k){var i=["skinName","highlight"];if(k&&i.indexOf(j)==-1){h+=(j+"="+k+"&")}});h=h.slice(0,-1)}h+=g.Fragment}return h};e.NavigateTopic=function(f){var g=e.GenerateNavigateTopicPath(f);e.Navigate(g)};e.OnNavigateTopic=function(h){var f=$(this).attr("href");if(typeof f!="undefined"){var i=new e(f);if(!MadCap.String.IsNullOrEmpty(f)&&!i.IsAbsolute&&i.PlainPath){var g=e.GenerateNavigateTopicPath(i);if(g!=e.GetAbsolutePath(i.PlainPath)){MadCap.Utilities.PreventDefault(h);e.Navigate(g)}}}};e.NavigateHash=function(f){document.location.hash=e.StripInvalidCharacters(f)};e.CurrentHash=function(){return new MadCap.Utilities.Url(document.location.href).FullFragment};e.prototype.AddFile=function(i){if(typeof(i)=="string"){i=new e(i)}if(i.IsAbsolute){return i}var h=i.FullPath;if(h.charAt(0)=="/"){var j=document.location;var k=j.href.lastIndexOf(j.pathname);var g=j.href.substring(0,k);return new e(g+h)}var f=this.FullPath;if(!MadCap.String.EndsWith(f,"/")){f=f+"/"}return new e(f+h)};e.prototype.CombinePath=function(l){if(typeof(l)=="string"){l=new e(l)}if(l.IsAbsolute){throw new MadCap.Exception(-1,"Cannot combine two absolute paths.")}var j=l.FullPath;var k=l.FullPath.split("/");var o=this.FullPath;var m="";if(this.Scheme=="mk"){var n=o.indexOf("::");m=o.substring(0,n+"::".length);o=o.substring(n+"::".length)}for(var h=0,f=k.length;h<f;h++){var g=k[h];if(o.length>1&&MadCap.String.EndsWith(o,"/")){o=o.substring(0,o.length-1)}if(g=="."){o+="/"}else{if(g==".."){o=o.substring(0,o.lastIndexOf("/")+1)}else{if(o!=""&&!MadCap.String.EndsWith(o,"/")){o+="/"}o+=g}}}o=m+o;return new e(o)};e.prototype.ToQuery=function(g){var f=this.PlainPath+"?"+g+this.Fragment;return new e(f)};e.prototype.ToFolder=function(){var f=this.PlainPath;if(MadCap.String.EndsWith(f,"/")){f=f.substring(0,f.length-1)}var h=f.lastIndexOf("/");var g=f.substring(0,h+1);return new e(g)};e.prototype.ToRelative=function(n){if(typeof(n)=="string"){n=new e(n)}if(this.IsAbsolute!=n.IsAbsolute){return this}var k=0;var l=n._Segments.length;for(;k<l;k++){var g=this._Segments[k];var f=n._Segments[k];if(g!=f){break}}var m="";var o=MadCap.String.EndsWith(n.FullPath,"/")?0:1;for(var h=0;h<l-k-o;h++){m+="../"}for(var h=k;h<this._Segments.length;h++){if(h>k){m+="/"}m+=this._Segments[h]}return new e(m)};e.prototype.ToExtension=function(j){var h=this.FullPath;var i=h.lastIndexOf(".");var g=h.substring(0,i);var f=g+"."+j;return new e(f)};e.prototype.ToScheme=function(f){var h=this.FullPath;pos=h.indexOf(":");if(pos<0){return this}var g=f+":"+h.substring(pos);return new e(g)};e.prototype.ToPath=function(){return new e(this.Path)};e.prototype.ToPlainPath=function(){return new e(this.PlainPath)};e.prototype.ToNoQuery=function(){return new e(this.PlainPath+this.Fragment)};e.prototype.ToNoFragment=function(){return new e(this.PlainPath+this.Query)};MadCap.Utilities.CrossFrame={};var d=MadCap.Utilities.CrossFrame;d.MESSAGE_SEPARATOR="%%%%%";d.DATA_SEPARATOR="^^^^^";d._MessageID=0;d._MessageInfos=new Array();d._MessageHandlerFuncs=new Array();d._PostMessage=function(h,f){if(typeof h=="undefined"||h==null){return}if(h.postMessage!=null){h.postMessage(f,"*");return}var g={data:f,source:window};h.MadCap.Utilities.CrossFrame.OnMessage(g)};d.AddMessageHandler=function(h,g){var f=d._MessageHandlerFuncs.length;d._MessageHandlerFuncs[f]={HandlerFunc:h,ContextObj:g}};d.PostMessageRequest=function(n,k,l,f){d._MessageInfos[d._MessageID]=f;var h="";if(l!=null){for(var g=0,j=l.length;g<j;g++){if(g>0){h+=d.DATA_SEPARATOR}h+=l[g]}}var m="request"+d.MESSAGE_SEPARATOR+k+d.MESSAGE_SEPARATOR+h+d.MESSAGE_SEPARATOR+d._MessageID;d._PostMessage(n,m);d._MessageID++};d._PostMessageResponse=function(n,k,l,f){var h="";if(l!=null){for(var g=0,j=l.length;g<j;g++){if(g>0){h+=d.DATA_SEPARATOR}h+=l[g]}}var m="response"+d.MESSAGE_SEPARATOR+k+d.MESSAGE_SEPARATOR+h+d.MESSAGE_SEPARATOR+f;d._PostMessage(n,m);d._MessageID++};d.OnMessage=function(t){var s=t.originalEvent;var o=s.data.split(d.MESSAGE_SEPARATOR);var m=o[0];var l=o[1];var j=o[2];var f=parseInt(o[3]);var h=null;if(!MadCap.String.IsNullOrEmpty(j)){h=j.split(d.DATA_SEPARATOR);for(var p=0,g=h.length;p<g;p++){if(h[p]=="null"){h[p]=null}}}if(m=="request"){var k=false;var x=true;var v=new Array();for(var p=0,g=d._MessageHandlerFuncs.length;p<g;p++){var w=d._MessageHandlerFuncs[p];var u=w.HandlerFunc;var q=w.ContextObj;var r=null;if(q!=null){r=u.call(q,l,h,v,s.source,f)}else{r=u(l,h,v,s.source,f)}k=r.Handled;x=r.FireResponse;if(k){break}}if(!k){if(l=="DEBUG-AddLine"){var l=h[0];MadCap.DEBUG.Log.AddLine(l);k=true}else{if(l=="url"){v[v.length]=document.location.href;k=true}else{if(l=="get-title"){v[v.length]=document.title;k=true}else{if(l=="navigate"){var n=h[0];document.location.href=n;k=true}}}}}if(x){d._PostMessageResponse(s.source,l,v.length>0?v:null,f)}}else{if(m=="response"){if(d._MessageInfos[f]!=null){d._MessageInfos[f](h)}}}};if(window.postMessage!="undefined"){$(window).bind("message",d.OnMessage)}else{}MadCap.Utilities.PreventDefault=function(f){f.preventDefault?f.preventDefault():event.returnValue=false};MadCap.Utilities.AsyncForeach=function(i,g,h){i=i.slice(0);function f(){var j=i.shift();g(j,function(k){if(i.length>0){f()}else{h()}})}if(i.length>0){f()}else{h()}};MadCap.Utilities.Now=Date.now||function(){return new Date().getTime()};MadCap.Utilities.Has=function(g,f){return g!=null&&Object.prototype.hasOwnProperty.call(g,f)};MadCap.Utilities.Debounce=function(h,j,g){var m,l,f,k,n;var i=function(){var o=MadCap.Utilities.Now()-k;if(o<j&&o>0){m=setTimeout(i,j-o)}else{m=null;if(!g){n=h.apply(f,l);if(!m){f=l=null}}}};return function(){f=this;l=arguments;k=MadCap.Utilities.Now();var o=g&&!m;if(!m){m=setTimeout(i,j)}if(o){n=h.apply(f,l);f=l=null}return n}};MadCap.Utilities.Memoize=function(g,f){var h=function(k){var j=h.cache;var i=""+(f?f.apply(this,arguments):k);if(!MadCap.Utilities.Has(j,i)){j[i]=g.apply(this,arguments)}return j[i]};h.cache={};return h};MadCap.Utilities.IsRuntimeFileType=function(f){return MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")==f};MadCap.Utilities.HasRuntimeFileType=function(g){var f=MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType");return f&&f.split(";").indexOf(g)>-1};MadCap.Utilities.CreateStylesheet=function(i,j){var g=i||document,f;var h=g.createElement("style");if(j){h.setAttribute("media",j)}g.getElementsByTagName("head")[0].appendChild(h);f=g.styleSheets[g.styleSheets.length-1];return f};MadCap.Utilities.AsyncForeachParallel=function(l,j,k){var h=0;if(l.length===0){k()}var f=l.length;for(var g=0;g<f;g++){j(l[g],function(){h++;if(h===l.length){k()}})}};MadCap.Utilities.FixLink=function(h,g,i,f){if(!h.IsAbsolute){h=g.CombinePath(h);var j=h.FullPath;if(!MadCap.String.IsNullOrEmpty(i)&&i!=null&&f){h=h.ToRelative(f);j=i+h.FullPath}return j}};MadCap.Utilities.IsRTL=function(){return $("html").css("direction")==="rtl"};MadCap.Utilities.ToggleButtonState=function(f){var i=$(f);var g=i.attr("data-current-state")||"1";var h=g=="1"?2:1;MadCap.Utilities.SetButtonState(f,h)};MadCap.Utilities.SetButtonState=function(h,l){var m=$(h);var j=l==1?2:1;var k=m.attr("data-state"+l+"-class");var g=m.attr("data-state"+j+"-class");m.attr("data-current-state",l);m.removeClass(g).addClass(k);m.attr("title",m.attr("data-state"+l+"-title"));if(MadCap.Utilities.HasRuntimeFileType("SkinPreview")){var f=m.attr("data-mc-style2");if(f){var i=m.attr("data-mc-style1");if(!i){i=m.attr("data-mc-style");m.attr("data-mc-style1",i)}m.attr("data-mc-style",l==1?i:f)}}};MadCap.Utilities.LoadHandlers=Object.create(null);MadCap.Utilities.LoadScript=function(i,h,g){var f=document.createElement("script");f.src=i;f.type="text/javascript";if(f.addEventListener){$(f).error(g);$(f).load(h)}else{if(f.readyState){f.onreadystatechange=function(){if(f.readyState=="loaded"||f.readyState=="complete"){h()}}}}document.getElementsByTagName("head")[0].appendChild(f);return f};MadCap.Utilities.LoadRegisteredScript=function(m,j,i,h){var k=false;var f;$("script").each(function(n,o){var p=$(o).attr("src");if(!MadCap.String.IsNullOrEmpty(p)&&p.toLowerCase()==m.toLowerCase()){k=true;f=o}});if(k){var g=new MadCap.Utilities.Url(m).Name;var l=MadCap.Utilities.LoadHandlers[g];if(l){l(h)}j()}};MadCap.Utilities.LoadScripts=function(f,i,h,g){MadCap.Utilities.AsyncForeach(f,function(j,k){if(!MadCap.String.IsNullOrEmpty(j)){MadCap.Utilities.LoadRegisteredScript(j,k,h,g)}else{k()}},i)};MadCap.Utilities.TopicUniqueStyleSheets=Object.create(null);MadCap.Utilities.LoadStyleSheets=function(g,f){$.each(g,function(i,h){if(!MadCap.String.IsNullOrEmpty(h)){MadCap.Utilities.LoadStyleSheetUnique(h,f)}})};MadCap.Utilities.LoadStyleSheetUnique=function(i,g){var h=false;$("link").each(function(k,l){var j=$(l).attr("href");if(!MadCap.String.IsNullOrEmpty(j)&&j.toLowerCase()==i.toLowerCase()){h=true}});if(!h){var f='<link rel="stylesheet" type="text/css" href="{0}" />';cssLink=f.replace("{0}",i);if($('link[href*="'+i+'"]').length==0||!MadCap.String.Contains(i,"/Topic.css",false)){if(g){$(cssLink).insertAfter(g)}else{$("head").append(insertIndex,cssLink)}}}MadCap.Utilities.TopicUniqueStyleSheets[i]=$('link[href*="'+i+'"]')};MadCap.Utilities.RemoveTopicStylesheets=function(){$.each(MadCap.Utilities.TopicUniqueStyleSheets,function(f,g){$(g).remove()})};MadCap.Utilities.CombineRelevancy=function(h,g){var f=MadCap.Utilities.CapNumber(h,g,16,0,2);for(var j=2;j<7;j++){f=MadCap.Utilities.CapNumber(f,g,16,j,1)}f=MadCap.Utilities.CapNumber(f,g,16,7,1,7);return f};MadCap.Utilities.CalculateScore=function(g,f,h){return(Math.log(g)/Math.log(2147483647)*h)+(f*(1-h))};MadCap.Utilities.CapNumber=function(j,i,p,l,f,n){if(!n){n=Math.pow(p,f)-1}var g=Math.pow(p,l);var m=g*Math.pow(p,f);var o=~~(j%m/g);var k=~~(i%m/g);var h=Math.min(o+k,n);return j+((h-o)*g)};MadCap.Utilities.Require=function(h,i){if(!MadCap.Utilities._requireCache){MadCap.Utilities._requireCache=Object.create(null)}var f=MadCap.Utilities._requireCache;var g=h[0];var j=f[g];if(j&&j.data){i(j.data)}else{if(j&&j.callbacks){j.callbacks.push(i)}else{f[g]={callbacks:[i]};require([g],function(l){j=f[g];j.data=l;for(var k=0;k<j.callbacks.length;k++){j.callbacks[k](l)}j.callbacks=null;require.undef(g)})}}};MadCap.Utilities.GetChunkId=function(f,l,k){for(var h=0;h<f.length;h++){var g=f[h];var j=k(l,g);if(j===0){return h}else{if(j===-1){return h-1}}}return f.length-1};MadCap.Utilities.GetChunkIds=function(f,n,l){var m=[];var j=false;for(var h=0;h<f.length;h++){var g=f[h];var k=l(n,g);if(k===-1&&h===0){return m}if(k===0){if(h>0&&!j){m.push(h-1)}m.push(h);j=true}else{if(k===-1){if(h>0&&!j){m.push(h-1)}break}}}if(m.length===0){m.push(f.length-1)}return m};MadCap.Utilities.ClearRequireCache=function(){MadCap.Utilities._requireCache=null};MadCap.Utilities.StopWords=Array("a","an","the","to","of","is","for","and","or","do","be","by","he","she","on","in","at","it","not","no","are","as","but","her","his","its","non","only","than","that","then","they","this","we","were","which","with","you","into","about","after","all","also","been","can","come","from","had","has","have","me","made","many","may","more","most","near","over","some","such","their","there","these","under","use","was","when","where","against","among","became","because","between","during","each","early","found","however","include","late","later","med","other","several","through","until","who","your");MadCap.Utilities.Store=(function(){try{if(window.localStorage){return window.localStorage}}catch(h){if(console&&console.log){console.log("window.localStorage not available")}}var g="MadCap";var i=document.createElement("div");i.style.display="none";document.getElementsByTagName("head")[0].appendChild(i);if(typeof i.addBehavior=="function"){i.addBehavior("#default#userdata");i.load(g);return{getItem:function(j){return i.XMLDocument.documentElement.getAttribute(j)},setItem:function(j,k){i.XMLDocument.documentElement.setAttribute(j,k);i.save(g)},removeItem:function(j){i.removeAttribute(j);i.save(g)}}}var f="data-"+g+"-";return{getItem:function(j){var k=i.getAttribute(f+j);return k?decodeURIComponent(k):k},setItem:function(j,k){i.setAttribute(f+j,k?encodeURIComponent(k):null)},removeItem:function(j){i.removeAttribute(f+j)}}})()})();Array.prototype.Remove=function(a){if(a<0||a>this.length){throw"Index out of bounds."}this.splice(a,1)};Array.prototype.RemoveValue=function(b){for(var a=this.length-1;a>=0;a--){if(this[a]==b){this.Remove(a)}}};Array.prototype.Union=function(b){var a=[].concat(this);if(b){for(var c=0;c<b.length;c++){if(this.indexOf(b[c])===-1){a.push(b[c])}}}return a};Array.prototype.Intersect=function(b){var a=[];for(var c=0;c<b.length;c++){if(this.indexOf(b[c])!==-1){a.push(b[c])}}return a};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.Utilities.Xhr=function(d,b,c){var e=this;this._XmlDoc=null;this._XmlHttp=null;this._Args=d;this._LoadFunc=b;this._LoadContextObj=c;this.OnreadystatechangeLocal=function(){if(e._XmlDoc.readyState==4){e._XmlDoc.onreadystatechange=a._Noop;var f=null;if(e._XmlDoc.documentElement!=null){f=e._XmlDoc}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}};this.OnreadystatechangeRemote=function(){if(e._XmlHttp.readyState==4){e._XmlHttp.onreadystatechange=a._Noop;var f=null;if(e._XmlHttp.responseXML!=null&&e._XmlHttp.responseXML.documentElement!=null){f=e._XmlHttp.responseXML}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}}};var a=MadCap.Utilities.Xhr;a.prototype._LoadLocal=function(b,c){if(window.ActiveXObject){this._XmlDoc=a._GetMicrosoftXmlDomObject();this._XmlDoc.async=c;if(this._LoadFunc){this._XmlDoc.onreadystatechange=this.OnreadystatechangeLocal}try{if(!this._XmlDoc.load(b)){this._XmlDoc=null}}catch(d){this._XmlDoc=null}}else{if(window.XMLHttpRequest){this._LoadRemote(b,c)}}return this._XmlDoc};a.prototype._LoadRemote=function(b,c){this._XmlHttp=a._GetXhrObject();if(this._LoadFunc){this._XmlHttp.onreadystatechange=this.OnreadystatechangeRemote}try{this._XmlHttp.open("GET",b,c);this._XmlHttp.send(null);if(!c&&(this._XmlHttp.status==0||this._XmlHttp.status==200)){this._XmlDoc=this._XmlHttp.responseXML}}catch(d){this._XmlHttp.abort();if(this._LoadFunc){if(this._LoadContextObj==null){this._LoadFunc(null,this._Args)}else{this._LoadFunc.call(this._LoadContextObj,null,this._Args)}}}return this._XmlDoc};a.prototype.Load=function(b,d){var e=null;var c=document.location.protocol;if(c=="file:"||c=="mk:"||c=="ms-its:"||c=="app:"){e=this._LoadLocal(b,d)}else{if(c=="http:"||c=="https:"){e=this._LoadRemote(b,d)}}return e};a.LoadXmlString=function(c){var b=null;if(window.ActiveXObject){b=a._GetMicrosoftXmlDomObject();b.async=false;b.loadXML(c)}else{if(DOMParser){var d=new DOMParser();b=d.parseFromString(c,"text/xml")}}return b};a.CreateXmlDocument=function(b){var c="<"+b+" />";var d=a.LoadXmlString(c);return d};a.GetOuterXml=function(d){var b=null;if(window.ActiveXObject){b=d.xml}else{if(window.XMLSerializer){var c=new XMLSerializer();b=c.serializeToString(d)}}return b};a.ImportNode=function(c,b){if(typeof(c.importNode)=="function"){return c.importNode(b,true)}return b.cloneNode(true)};a.CallWebService=function(e,d,f,b){var c=new a(b,f,null);var g=c.Load(e,d);return g};a._MicrosoftXmlDomProgIDs=["Msxml2.DOMDocument.6.0","Msxml2.DOMDocument","Microsoft.XMLDOM"];a._MicrosoftXmlHttpProgIDs=["Msxml2.XMLHTTP.6.0","Msxml2.XMLHTTP","Microsoft.XMLHTTP"];a._MicrosoftXmlDomProgID=null;a._MicrosoftXmlHttpProgID=null;a._FilePathToXmlStringMap=new MadCap.Utilities.Dictionary();a._LoadingFilesPathMap=new MadCap.Utilities.Dictionary();a._LoadingFromQueue=false;a.ForceUseJS=false;a.Load=function(g,e,b,h,c){function l(){a._LoadingFilesPathMap.Remove(j.FullPath);var n=a._FilePathToXmlStringMap.GetItem(j.Name);if(n!=null){a._FilePathToXmlStringMap.Remove(j.Name);m=a.LoadXmlString(n)}a._LoadingFilesPathMap.ForEach(function(q,r){var p=new MadCap.Utilities.Url(q);var o=r;if(p.Name==f&&p.FullPath!=j.FullPath){a._LoadingFilesPathMap.Remove(p.FullPath);a._LoadingFromQueue=true;a.Load(p.FullPath,o.async,o.LoadFunc,o.args,o.loadContextObj);return false}return true});if(c==null){b(m,h)}else{b.call(c,m,h)}}var m=null;if(a.ForceUseJS||(Boolean(!window.ActiveXObject)&&MadCap.String.StartsWith(document.location.protocol,"file"))){var i=new MadCap.Utilities.Url(g);var j=i.ToExtension("js");var f=j.Name;a._LoadingFilesPathMap.Add(j.FullPath,{async:e,LoadFunc:b,args:h,loadContextObj:c});var k=false;a._LoadingFilesPathMap.ForEach(function(p,q){var o=new MadCap.Utilities.Url(p);var n=q;if(o.Name==f&&o.FullPath!=j.FullPath){k=true;return false}return true});if(a._LoadingFromQueue||!k){a._LoadingFromQueue=false;MadCap.Utilities.LoadScript(j.FullPath,l,l)}}else{var d=new a(h,b,c);m=d.Load(g,e)}return m};a._Noop=function(){};a._GetMicrosoftXmlDomObject=function(){var e=null;if(a._MicrosoftXmlDomProgID==null){for(var c=0;c<a._MicrosoftXmlDomProgIDs.length;c++){var d=a._MicrosoftXmlDomProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlDomProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlDomProgID)}return e};a._GetXhrObject=function(){if(window.XMLHttpRequest){return function(){return new window.XMLHttpRequest()}}else{if(window.ActiveXObject){return function(){var e=null;if(a._MicrosoftXmlHttpProgID==null){for(var c=0;c<a._MicrosoftXmlHttpProgIDs.length;c++){var d=a._MicrosoftXmlHttpProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlHttpProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlHttpProgID)}return e}}}}()})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.CreateNamespace("TextEffects");var a=MadCap.TextEffects;a.Init=function(b){a.ExpandingControl.Load(b);a.DropDownControl.Load(b);a.TogglerControl.Load(b);a.TextPopupControl.Load(b);a.TopicPopupControl.Load(b)};a.Dispose=function(b){a.ExpandingControl.UnLoad(b);a.DropDownControl.UnLoad(b);a.TogglerControl.UnLoad(b);a.TextPopupControl.UnLoad(b);a.TopicPopupControl.UnLoad(b)};$(function(){MadCap.Utilities.LoadHandlers.MadCapTextEffects=a.Init;a.Init(document)});a.TextEffectControl=function(d,c){if(this._rootEl==null){this._rootEl=d}this._hotSpotEl=null;this._bodyEls=null;this._className=c;a.TextEffectControl.Controls[a.TextEffectControl.Controls.length]=this;var b=this;(function(){b._hotSpotEl=MadCap.Dom.GetElementsByClassName(b._className+"HotSpot",null,b._rootEl)[0];b._bodyEls=MadCap.Dom.GetElementsByClassName(b._className+"Body",null,b._rootEl);var g=MadCap.Dom.GetElementsByClassName(b._className+"HotSpot",null,b._rootEl);for(var e=g.length-1;e>=0;e--){var f=g[e].parentNode;while(f!=null){if($(f).hasClass(b._className)){if(f==b._rootEl){$(g[e]).click(function(h){b.Toggle.call(b)})}else{break}}f=f.parentNode}}})()};a.UnbindTextEffectControl=function(d,c){if(this._rootEl==null){this._rootEl=d}this._hotSpotEl=null;this._bodyEls=null;this._className=c;var b=this;(function(){b._hotSpotEl=MadCap.Dom.GetElementsByClassName(b._className+"HotSpot",null,b._rootEl)[0];var g=MadCap.Dom.GetElementsByClassName(b._className+"HotSpot",null,b._rootEl);for(var e=g.length-1;e>=0;e--){var f=g[e].parentNode;while(f!=null){if($(f).hasClass(b._className)){if(f==b._rootEl){$(g[e]).unbind()}else{break}}f=f.parentNode}}$(b._hotSpotEl).unbind()})()};a.TextEffectControl.Controls=new Array();a.TextEffectControl.FindControl=function(c){for(var b=0;b<a.TextEffectControl.Controls.length;b++){if(a.TextEffectControl.Controls[b]._rootEl==c){return a.TextEffectControl.Controls[b]}}return null};a.TextEffectControl.ExpandAll=function(b){for(var c=0,d=a.TextEffectControl.Controls.length;c<d;c++){var e=a.TextEffectControl.Controls[c];if(b=="open"){e.Open(false)}else{if(b=="close"){e.Close(false)}}}};a.TextEffectControl.prototype.Open=function(){var d=$(this._rootEl);if(d.hasClass("MCToggler")){d=$(this._rootEl.parentNode).find("a.MCToggler")}d.removeClass(this._className+"_Closed");d.addClass(this._className+"_Open");var c=null;if(d.hasClass("MCToggler")){c=$(".MCToggler_Image_Icon")}else{if(d.hasClass("MCDropDown")){c=$(".MCDropDown_Image_Icon")}else{if(d.hasClass("MCExpanding")){c=$(".MCExpanding_Image_Icon")}}}var b=d.find(c);this.ToggleAltText(b[0],d,"closed");d.attr("data-mc-state","open")};a.TextEffectControl.prototype.Close=function(){var d=$(this._rootEl);if(d.hasClass("MCToggler")){d=$(this._rootEl.parentNode).find("a.MCToggler")}d.removeClass(this._className+"_Open");d.addClass(this._className+"_Closed");var c=null;if(d.hasClass("MCToggler")){c=$(".MCToggler_Image_Icon")}else{if(d.hasClass("MCDropDown")){c=$(".MCDropDown_Image_Icon")}else{if(d.hasClass("MCExpanding")){c=$(".MCExpanding_Image_Icon")}}}var b=d.find(c);this.ToggleAltText(b[0],d,"open");d.attr("data-mc-state","closed")};a.TextEffectControl.prototype.ToggleAltText=function(g,c,d){if(g!=null){var b=$(g);var f=b.attr("data-mc-alt2");var e=b.attr("alt");if(c!=null&&c.attr("data-mc-state")==d){b.attr("alt",f);b.attr("data-mc-alt2",e)}}};a.TextEffectControl.prototype.Toggle=function(){var d=$(this._rootEl);if(d.hasClass("MCToggler")){d=$(this._rootEl.parentNode).find("a.MCToggler")}var b=d.attr("data-mc-state")||"closed";var c=null;if(b=="open"){this.Close(true)}else{if(b=="closed"){this.Open(true)}}$(d.find("a")[0]).focus()};a.TextEffectControl.prototype.ResizeSlideshow=function(f,d){if(f){var e=$(f);var c=e.closest('div[class^="mc-viewport"]');if(c){var b=0;e.children().each(function(){b=b+$(this).outerHeight()});if(d){b=c.height()+Math.max(b,e.outerHeight())}else{b=c.height()-Math.max(b,e.outerHeight())}c.animate({height:b})}}};a.ExpandingControl=function(b){a.TextEffectControl.call(this,b,"MCExpanding")};MadCap.Extend(a.TextEffectControl,a.ExpandingControl);a.ExpandingControl.Load=function(c){var d=$(".MCExpanding",c);for(var b=0,e=d.length;b<e;b++){var g=d[b];var f=new a.ExpandingControl(g);f.Init()}};a.ExpandingControl.UnLoad=function(c){var d=$(".MCExpanding",c);for(var b=0,e=d.length;b<e;b++){a.UnbindTextEffectControl(d[b])}};a.ExpandingControl.prototype.Init=function(){this.Close(false)};a.ExpandingControl.prototype.Open=function(b){this.base.Open.call(this);var c=$(this._bodyEls[0]);this.ResizeSlideshow(c,true);if(b){c.css({"white-space":"nowrap"});c.hide().animate({width:"show"},function(){$(this).css({"white-space":"normal"})})}else{c.show()}};a.ExpandingControl.prototype.Close=function(c){if(!c){$(this._bodyEls[0]).hide();this.base.Close.call(this);return}var b=this;this.ResizeSlideshow(this._bodyEls[0],false);$(this._bodyEls[0]).css({"white-space":"nowrap"}).animate({width:"hide"},function(){$(this).css({"white-space":"normal"});b.base.Close.call(b)})};a.DropDownControl=function(b){a.TextEffectControl.call(this,b,"MCDropDown")};MadCap.Extend(a.TextEffectControl,a.DropDownControl);a.DropDownControl.Load=function(e){var d=$(".MCDropDown",e);for(var c=0,f=d.length;c<f;c++){var b=d[c];var g=new a.DropDownControl(b);g.Init(false)}};a.DropDownControl.UnLoad=function(d){var c=$(".MCDropDown",d);for(var b=0,e=c.length;b<e;b++){a.UnbindTextEffectControl(c[b])}};a.DropDownControl.prototype.Init=function(){this.Close(false)};a.DropDownControl.prototype.Open=function(b){this.base.Open.call(this);var c=$(this._bodyEls[0]);if(b){c.hide().slideDown()}else{c.show()}this.ResizeSlideshow(c,true)};a.DropDownControl.prototype.Close=function(c){if(!c){$(this._bodyEls[0]).hide();this.base.Close.call(this);return}var b=this;this.ResizeSlideshow(this._bodyEls[0],false);$(this._bodyEls[0]).slideUp(function(){b.base.Close.call(b)})};a.TogglerControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=new Array();this._className="MCToggler";a.TextEffectControl.Controls[a.TextEffectControl.Controls.length]=this;var b=this;(function(){var h=MadCap.Dom.Dataset(b._rootEl,"mcTargets");var d=h.split(";");for(var f=0,g=d.length;f<g;f++){var j=d[f];var e=MadCap.Dom.GetElementsByAttribute("data-mc-target-name",j,null,document.body);b._bodyEls=b._bodyEls.concat(e)}$(b._hotSpotEl).click(function(i){b.Toggle.call(b)})})()};MadCap.Extend(a.TextEffectControl,a.TogglerControl);a.TogglerControl.Load=function(c){var e=$(".MCToggler",c);for(var b=0,d=e.length;b<d;b++){var g=e[b];var f=new a.TogglerControl(g);f.Init()}};a.TogglerControl.UnLoad=function(c){var e=$(".MCToggler",c);for(var b=0,d=e.length;b<d;b++){a.UnbindTextEffectControl(e[b])}};a.TogglerControl.prototype.Init=function(){this.Close(false)};a.TogglerControl.prototype.Open=function(b){this.base.Open.call(this);for(var c=0,d=this._bodyEls.length;c<d;c++){if(b){$(this._bodyEls[c]).css({opacity:0,display:""});$(this._bodyEls[c]).animate({opacity:1},200)}else{$(this._bodyEls[c]).css({opacity:1,display:""})}}this.ResizeSlideshow(this._bodyEls[0],true)};a.TogglerControl.prototype.Close=function(c){this.base.Close.call(this);this.ResizeSlideshow(this._bodyEls[0],false);function f(g){$(g).css("display","none")}for(var d=0,e=this._bodyEls.length;d<e;d++){var b=this;if(c){$(this._bodyEls[d]).animate({opacity:0},200,function(){f(this)})}else{f(this._bodyEls[d])}}};a.TextPopupControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=null;this._className="MCTextPopup";var b=this;(function(){b._bodyEls=$("."+b._className+"Body",b._rootEl).toArray();if(jQuery.browser.mobile){$(b._hotSpotEl).click(function(d){if($(this).attr("data-mc-state")==="closed"){b.Open()}else{b.Close()}})}else{$(b._hotSpotEl).mouseover(function(d){b.Open()});$(b._hotSpotEl).mouseleave(function(d){b.Close()})}})()};MadCap.Extend(a.TextEffectControl,a.TextPopupControl);a.TextPopupControl.Load=function(d){var b=$(".MCTextPopup",d);for(var c=0,f=b.length;c<f;c++){var g=b[c];var e=new a.TextPopupControl(g);e.Init()}};a.TextPopupControl.UnLoad=function(d){var b=$(".MCTextPopup",d);for(var c=0,e=b.length;c<e;c++){a.UnbindTextEffectControl(b[c])}};a.TextPopupControl.prototype.Init=function(){this.Close(false)};a.TextPopupControl.prototype.Open=function(){this.base.Open.call(this);var z=$(this._rootEl);var j=$(this._bodyEls[0]);var e=$(".MCTextPopupArrow",z);var s=$(window);j.css("top","0");j.css("left","0");j.css("height","auto");var h=13;var m=j.offset().top;var n=j.offset().left;var w=z.offset().top-m;var k=z.offset().left-n;var l=w+this._rootEl.offsetHeight;var v=j[0].offsetWidth;var o=j[0].offsetHeight;var B=k+(z[0].offsetWidth/2);var f=B-(v/2);var y=f+v;var r=l+h;var d=s.scrollTop();var u=s.scrollLeft();var c=-e[0].offsetWidth/2;var b=s.width();var q=d+s.height()-l;if((o+h)>q){var A=w-d;if((o+h)>A){r=l;var p=parseInt(j.css("border-top-width"));var g=parseInt(j.css("border-bottom-width"));var x=parseInt(j.css("padding-top"));var i=parseInt(j.css("padding-bottom"));j.css("height",(q-p-g-x-i)+"px");j.css("overflow","auto")}else{j.addClass("MCTextPopupBodyBottom");r=w-o-h}}else{j.removeClass("MCTextPopupBodyBottom")}j.css("top",r+"px");if(y>=b+u){c+=(y-b-u)}if(f<u){c+=(f-u)}f=Math.min(f,u+b-v);f=Math.max(f,u);var t=z.closest("body");if(MadCap.HasEpubReadingSystem()){f=z.offset().left;c=-((j[0].offsetWidth/2)-(e[0].offsetWidth/2))}j.css("left",f+"px");e.css("margin-left",c+"px");j.animate({opacity:1},200)};a.TextPopupControl.prototype.Close=function(){this.base.Close.call(this);var b=$(this._bodyEls[0]);b.css("opacity",0)};a.TopicPopupControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=null;this._className="MCTopicPopup";var b=this;(function(){b._bodyEls=$("."+b._className+"Body",b._rootEl).toArray();$(b._hotSpotEl).click(function(d){b.Open();$(document.documentElement).click(function(f){b.Close();$(document.documentElement).off("click",arguments.callee)});d.stopPropagation();MadCap.Utilities.PreventDefault(d)})})()};MadCap.Extend(a.TextEffectControl,a.TopicPopupControl);a.TopicPopupControl.Load=function(d){var g=$(".MCTopicPopup",d);for(var c=0,e=g.length;c<e;c++){var b=g[c];var f=new a.TopicPopupControl(b);f.Init()}};a.TopicPopupControl.UnLoad=function(c){var e=$(".MCTopicPopup",c);for(var b=0,d=e.length;b<d;b++){a.UnbindTextEffectControl(e[b])}};a.TopicPopupControl.prototype.Init=function(){this.Close(false)};a.TopicPopupControl.prototype.Open=function(){this.base.Open.call(this);var f=$("<div></div>");f.addClass("MCTopicPopupContainer needs-pie");var b=MadCap.Dom.GetAttribute(this._hotSpotEl,"href");var k=document.createElement("iframe");$(k).addClass("MCTopicPopupBody");k.setAttribute("src",b);k.setAttribute("name","MCPopup");f.append(k);var i=document.body;f.appendTo(i);var h=$(this._rootEl);var c=h.attr("data-mc-width");var o=h.attr("data-mc-height");if(c!=null||o!=null){f.css({top:"50%",left:"50%",width:c,height:o});var e=f.width();var g=f.height();var d=$(window);var n=d.width()-100;var m=d.height()-100;if(e>n){f.css({width:n+"px"});e=n}if(g>m){f.css({height:m+"px"});g=m}f.css({"margin-top":(-g/2)+"px","margin-left":(-e/2)+"px"})}$(k).css("height","100%");if($("html").attr("data-mc-target-type")=="EPUB"){var j=($(this._hotSpotEl).offset().top-f.offset().top)-f[0].offsetHeight/2;f.css({"margin-top":j+"px",left:$(this._hotSpotEl).offset().left,"margin-left":$(this._hotSpotEl).offset().left})}f.animate({opacity:1},200);var l=a.AddBackgroundTint("dark",i);$(l).animate({opacity:0.5},200)};a.TopicPopupControl.prototype.Close=function(){this.base.Close.call(this);var b=$(".MCTopicPopupContainer");var c=b.parent();b.remove();a.RemoveBackgroundTint();if($("#topicContent").length>0){c.css("overflow","auto")}};a.CreateLinkListTree=function(q,h,e,g,o){a.RemoveLinkListTrees();if(!g){g=""}var b=$("<ul class='responsive-link-list tree inner'></ul>");var j=$(e).attr("target");for(var f=0,c=q.length;f<c;f++){var p=q[f];var m=$("<li class='IndexEntry IndexEntryLink tree-node tree-node-leaf'></li>").appendTo(b);var l=$("<div class='IndexTerm'></div>").appendTo(m);var k=$("<span class='label'></span>").appendTo(l);var d=$("<a/>").appendTo(k);d.text(p.Title);var n=p.Link;d.attr("href",g+n);m.click(o)}b.appendTo(h)};a.CreateDummyToolbarDropdown=function(h,i,c,f){var b=[];var e=new MadCap.Utilities.Url(document.location.href);var g={Title:c+"1",Link:e.PlainPath+e.Fragment};var d={Title:c+"2",Link:e.PlainPath+e.Fragment};b[0]=g;b[1]=d;a.CreateToolbarDropdown(b,h[0],i,f)};a.CreateToolbarDropdown=function(j,f,i,h){var c=$(f);var d=2;var b=c.position().left;var g=c.position().top+c.height()+d;var e="";a.CreateLinkListPopup(j,c.closest(".popup-container"),g,b,f,e,"toolbar-button-drop-down "+i,true,false,h)};a.CreateLinkListPopup=function(m,k,w,j,F,B,t,H,G,r){if(typeof t==="undefined"){t="link-list-popup"}if(typeof H==="undefined"){H=true}if(typeof G==="undefined"){G=true}a.RemoveLinkListPopups();if(!B){B=""}var l=$("<div class='"+t+" needs-pie'><ul></ul></div>");var y=l.children("ul");var I=$(F).attr("target");for(var C=0,h=m.length;C<h;C++){var D=m[C];var e=(typeof(D.Image)!="undefined");var s=(e)?$("<li><img><a></a></li>").appendTo(y):$("<li><a></a></li>").appendTo(y);var g=$("a",s);g.attr("target",I);if(I=="_popup"){g.click(a.TopicPopup_Click)}if(e){var q=$("img",s);q.attr("src",D.Image);q.attr("alt",D.Title);g.text(" "+D.Title)}else{g.text(D.Title)}var o=D.Link;g.attr("href",B+o);s.click(a.Item_Click)}l.appendTo(k);var v=l.closest(".popup-container");if(v.length==0){v=$(window)}if(r){v=$(window)}var b=v.width();var d=v.height();var c=v.scrollTop();var A=v.scrollLeft();var z=l[0].offsetWidth;var u=l[0].offsetHeight;var E=0;var p=0;if(typeof(v[0].classList)!="undefined"&&v[0].classList.contains("topicToolbarProxy")){if(typeof(v.offset())!="undefined"){E=v.offset().top;p=v.offset().left}}if(G){w=Math.min(w,c+E+d-u);w=Math.max(w,c+E)}if(H){j=Math.min(j,A+p+b-z);j=Math.max(j,A+p)}if((w==0&&j==0)||MadCap.IsIBooks()){if(H){j=$(F).offset().left+$(F).width()}if(G){w=$(F).offset().top+$(F).height()}}if(MadCap.IsIBooks()){l.css("display","inline-block");if(H){j=j-F.offsetWidth}if(G){w=w-(l[0].offsetHeight/2)}}if(H&&MadCap.Utilities.IsRTL()){var x=0;if(typeof($(F).offset())!="undefined"){x+=$(F).offset().left}if(typeof($(F).width())!="undefined"){x+=$(F).width()}var f=Math.min($(window).width()-x,l.width());j=j-f}l.css("top",w);l.css("left",j);l.hide().fadeIn(200);$triggerObject=r?$(F):$([document,F]);$triggerObject.click(function(i){l.remove();$triggerObject.off("click",arguments.callee)});$triggerObject.keydown(function(i){var i=i||windows.event;if(i.keyCode!=27&&i.keyCode!=13){return}if(!l.is(":focus")){return}l.remove();$triggerObject.off("keydown",arguments.callee)});if(!r){var n=function(i){a.RemoveLinkListPopups();v.off("click",n)};v.click(n)}l.attr("tabindex",0);l.focus()};a.Item_Click=function(d){var c=$("a",this);var b=c.attr("href");var f=c.attr("target");if(b&&!MadCap.String.IsNullOrEmpty(b)){if(f){window.open(b,f)}else{if(document.parentNode!=null&&MadCap.Utilities.HasRuntimeFileType("Topic")&&$("html").attr("data-mc-target-type")=="EPUB"){document.parentNode.open(b)}else{document.location.href=b}}}MadCap.Utilities.PreventDefault(d)};a.RemoveLinkListTrees=function(){$(".responsive-link-list").remove()};a.RemoveLinkListPopups=function(){$(".link-list-popup").remove();$(".toolbar-button-drop-down").remove()};a.AddBackgroundTint=function(c,d){if(!d){d=document.body}var b=$("<div id='mc-background-tint'></div>");b.addClass(c);b.appendTo(d);return b[0]};a.RemoveBackgroundTint=function(){$("#mc-background-tint").remove()}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(a){a.fn.fitVids=function(c){var e={customSelector:null};var d=document.createElement("div"),b=document.getElementsByTagName("base")[0]||document.getElementsByTagName("script")[0];d.className="fit-vids-style";d.innerHTML="<style>.fluid-width-video-wrapper {width: 100%;position: relative;padding: 0;} .fluid-width-video-wrapper iframe { position: absolute; top: 0; left: 0; width: 100%; height: 100%; } </style>";b.parentNode.insertBefore(d,b);if(c){a.extend(e,c)}return this.each(function(){var f=["iframe[src*='player.vimeo.com']","iframe[src*='www.youtube.com']","iframe[src*='www.kickstarter.com']"];if(e.customSelector){f.push(e.customSelector)}var g=a(this).find(f.join(","));g.each(function(){var j=a(this);if(j.parent(".fluid-width-video-wrapper").length){return}var m=j.attr("height")&&!isNaN(parseInt(j.attr("height"),10))?parseInt(j.attr("height"),10):j.height(),l=!isNaN(parseInt(j.attr("width"),10))?parseInt(j.attr("width"),10):j.width(),h=m/l;if(!j.attr("id")){var k="fitvid"+Math.floor(Math.random()*999999);j.attr("id",k)}j.wrap('<div class="fluid-width-video-wrapper"></div>').parent(".fluid-width-video-wrapper").css("padding-top",h*100+"%");j.removeAttr("height").removeAttr("width")})})}})(jQuery);!function(a){var c={},b={mode:"horizontal",slideSelector:"",infiniteLoop:!0,hideControlOnEnd:!1,speed:500,easing:null,slideMargin:0,startSlide:0,randomStart:!1,captions:!1,ticker:!1,tickerHover:!1,adaptiveHeight:!1,adaptiveHeightSpeed:500,video:!1,useCSS:!0,preloadImages:"visible",responsive:!0,touchEnabled:!0,swipeThreshold:50,oneToOneTouch:!0,preventDefaultSwipeX:!0,preventDefaultSwipeY:!1,pager:!0,pagerType:"full",pagerShortSeparator:" / ",pagerSelector:null,buildPager:null,pagerCustom:null,controls:!0,nextText:"Next",prevText:"Prev",nextSelector:null,prevSelector:null,autoControls:!1,startText:"Start",stopText:"Stop",autoControlsCombine:!1,autoControlsSelector:null,auto:!1,pause:4000,autoStart:!0,autoDirection:"next",autoHover:!1,autoDelay:0,minSlides:1,maxSlides:1,moveSlides:0,slideWidth:0,onSliderLoad:function(){},onSlideBefore:function(){},onSlideAfter:function(){},onSlideNext:function(){},onSlidePrev:function(){},slideshowClass:""};a.fn.MCSlider=function(aq){if(0==this.length){return this}if(this.length>1){return this.each(function(){a(this).MCSlider(aq)}),this}var ap={},am=this;c.el=this;var aB=a(window).width(),at=a(window).height(),ay=function(){ap.settings=a.extend({},b,aq),ap.settings.slideWidth=parseInt(ap.settings.slideWidth),ap.children=am.children(ap.settings.slideSelector),ap.children.length<ap.settings.minSlides&&(ap.settings.minSlides=ap.children.length),ap.children.length<ap.settings.maxSlides&&(ap.settings.maxSlides=ap.children.length),ap.settings.randomStart&&(ap.settings.startSlide=Math.floor(Math.random()*ap.children.length)),ap.active={index:ap.settings.startSlide},ap.carousel=ap.settings.minSlides>1||ap.settings.maxSlides>1,ap.carousel&&(ap.settings.preloadImages="all"),ap.minThreshold=ap.settings.minSlides*ap.settings.slideWidth+(ap.settings.minSlides-1)*ap.settings.slideMargin,ap.maxThreshold=ap.settings.maxSlides*ap.settings.slideWidth+(ap.settings.maxSlides-1)*ap.settings.slideMargin,ap.working=!1,ap.controls={},ap.interval=null,ap.animProp="vertical"==ap.settings.mode?"top":"left",ap.usingCSS=ap.settings.useCSS&&"fade"!=ap.settings.mode&&function(){var f=document.createElement("div"),g=["WebkitPerspective","MozPerspective","OPerspective","msPerspective"];for(var d in g){if(void 0!==f.style[g[d]]){return ap.cssPrefix=g[d].replace("Perspective","").toLowerCase(),ap.animProp="-"+ap.cssPrefix+"-transform",!0}}return !1}(),"vertical"==ap.settings.mode&&(ap.settings.maxSlides=ap.settings.minSlides),am.data("origStyle",am.attr("style")),am.children(ap.settings.slideSelector).each(function(){a(this).data("origStyle",a(this).attr("style"))}),az()},az=function(){am.wrap('<div class="mc-wrapper"><div class="mc-viewport '+ap.settings.slideshowClass+'"></div></div>'),ap.viewport=am.parent(),ap.loader=a('<div class="mc-loading" />'),ap.viewport.prepend(ap.loader),am.css({width:"horizontal"==ap.settings.mode?100*ap.children.length+215+"%":"auto",position:"relative"}),ap.usingCSS&&ap.settings.easing?am.css("-"+ap.cssPrefix+"-transition-timing-function",ap.settings.easing):ap.settings.easing||(ap.settings.easing="swing"),ax(),ap.viewport.css({width:"100%",overflow:"hidden",position:"relative"}),ap.viewport.parent().css({maxWidth:ak()}),ap.settings.pager||ap.viewport.parent().css({margin:"0 auto 0px"}),ap.children.css({"float":"horizontal"==ap.settings.mode?"left":"none",listStyle:"none",position:"relative"}),ap.children.css("width",al()),"horizontal"==ap.settings.mode&&ap.settings.slideMargin>0&&ap.children.css("marginRight",ap.settings.slideMargin),"vertical"==ap.settings.mode&&ap.settings.slideMargin>0&&ap.children.css("marginBottom",ap.settings.slideMargin),"fade"==ap.settings.mode&&(ap.children.css({position:"absolute",zIndex:0,display:"none"}),ap.children.eq(ap.settings.startSlide).css({zIndex:50,display:"block"})),ap.controls.el=a('<div class="mc-controls" />'),ap.settings.captions&&J(),ap.active.last=ap.settings.startSlide==ai()-1,ap.settings.video&&am.fitVids();var d=ap.children.eq(ap.settings.startSlide);"all"==ap.settings.preloadImages&&(d=ap.children),ap.settings.ticker?ap.settings.pager=!1:(ap.settings.pager&&F(),ap.settings.controls&&ad(),ap.settings.auto&&ap.settings.autoControls&&ab(),(ap.settings.controls||ap.settings.autoControls||ap.settings.pager)&&ap.viewport.after(ap.controls.el)),aw(d,av)},aw=function(h,f){var g=h.find('img:not([src=""])').length;if(0===g){return void f()}var d=0;h.find('img:not([src=""])').each(function(){$(this).one("load error",function(){++d===g&&f()}).each(function(){this.complete&&$(this).load()})})},av=function(){if(ap.settings.infiniteLoop&&"fade"!=ap.settings.mode&&!ap.settings.ticker){var g="vertical"==ap.settings.mode?ap.settings.minSlides:ap.settings.maxSlides,d=ap.children.slice(0,g).clone().addClass("mc-clone"),f=ap.children.slice(-g).clone().addClass("mc-clone");am.append(d).prepend(f)}ap.loader.remove(),G(),"vertical"==ap.settings.mode&&(ap.settings.adaptiveHeight=!0),ap.viewport.height(ao()),am.redrawSlider(),ap.settings.onSliderLoad(ap.active.index),ap.initialized=!0,ap.settings.responsive&&a(window).bind("resize",ae),ap.settings.auto&&ap.settings.autoStart&&aa(),ap.settings.ticker&&U(),ap.settings.pager&&Z(ap.settings.startSlide),ap.settings.controls&&s(),ap.settings.touchEnabled&&!ap.settings.ticker&&K()},ao=function(){var f=0,d=a();if("vertical"==ap.settings.mode||ap.settings.adaptiveHeight){if(ap.carousel){var g=1==ap.settings.moveSlides?ap.active.index:ap.active.index*ar();for(d=ap.children.eq(g),i=1;i<=ap.settings.maxSlides-1;i++){d=g+i>=ap.children.length?d.add(ap.children.eq(i-1)):d.add(ap.children.eq(g+i))}}else{d=ap.children.eq(ap.active.index)}}else{d=ap.children}return"vertical"==ap.settings.mode?(d.each(function(){f+=a(this).outerHeight()}),ap.settings.slideMargin>0&&(f+=ap.settings.slideMargin*(ap.settings.minSlides-1))):f=Math.max.apply(Math,d.map(function(){return a(this).outerHeight(!1)}).get()),f},ak=function(){var d="100%";return ap.settings.slideWidth>0&&(d="horizontal"==ap.settings.mode?ap.settings.maxSlides*ap.settings.slideWidth+(ap.settings.maxSlides-1)*ap.settings.slideMargin:ap.settings.slideWidth),d},al=function(){var d=ap.settings.slideWidth,f=ap.viewport.width();return 0==ap.settings.slideWidth||ap.settings.slideWidth>f&&!ap.carousel||"vertical"==ap.settings.mode?d=(f/ap.settings.minSlides):ap.settings.maxSlides>1&&"horizontal"==ap.settings.mode&&(f>ap.maxThreshold||f<ap.minThreshold&&(d=(f-ap.settings.slideMargin*(ap.settings.minSlides-1))/ap.settings.minSlides)),d},ax=function(){var d=1;if("horizontal"==ap.settings.mode&&ap.settings.slideWidth>0){if(ap.viewport.width()<ap.minThreshold){d=ap.settings.minSlides}else{if(ap.viewport.width()>ap.maxThreshold){d=ap.settings.maxSlides}else{var f=ap.children.first().width();d=Math.floor(ap.viewport.width()/f)}}}else{"vertical"==ap.settings.mode&&(d=ap.settings.minSlides)}return d},ai=function(){var f=0;if(ap.settings.moveSlides>0){if(ap.settings.infiniteLoop){f=ap.children.length/ar()}else{for(var g=0,d=0;g<ap.children.length;){++f,g=d+ax(),d+=ap.settings.moveSlides<=ax()?ap.settings.moveSlides:ax()}}}else{f=Math.ceil(ap.children.length/ax())}return f},ar=function(){return ap.settings.moveSlides>0&&ap.settings.moveSlides<=ax()?ap.settings.moveSlides:ax()},G=function(){if(ap.children.length>ap.settings.maxSlides&&ap.active.last&&!ap.settings.infiniteLoop){if("horizontal"==ap.settings.mode){var f=ap.children.last(),g=f.position();aA(-(g.left-(ap.viewport.width()-f.width())),"reset",0)}else{if("vertical"==ap.settings.mode){var d=ap.children.length-ap.settings.minSlides,g=ap.children.eq(d).position();aA(-g.top,"reset",0)}}}else{var g=ap.children.eq(ap.active.index*ar()).position();ap.active.index==ai()-1&&(ap.active.last=!0),void 0!=g&&("horizontal"==ap.settings.mode?aA(-g.left,"reset",0):"vertical"==ap.settings.mode&&aA(-g.top,"reset",0))}},aA=function(g,k,f,h){if(ap.usingCSS){var l="vertical"==ap.settings.mode?"translate3d(0, "+g+"px, 0)":"translate3d("+g+"px, 0, 0)";am.css("-"+ap.cssPrefix+"-transition-duration",f/1000+"s"),"slide"==k?(am.css(ap.animProp,l),am.bind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd",function(){am.unbind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd"),ac()})):"reset"==k?am.css(ap.animProp,l):"ticker"==k&&(am.css("-"+ap.cssPrefix+"-transition-timing-function","linear"),am.css(ap.animProp,l),am.bind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd",function(){am.unbind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd"),aA(h.resetValue,"reset",0),Q()}))}else{var d={};d[ap.animProp]=g,"slide"==k?am.animate(d,f,ap.settings.easing,function(){ac()}):"reset"==k?am.css(ap.animProp,g):"ticker"==k&&am.animate(d,speed,"linear",function(){aA(h.resetValue,"reset",0),Q()})}},aj=function(){for(var g="",d=ai(),f=0;d>f;f++){var h="";ap.settings.buildPager&&a.isFunction(ap.settings.buildPager)?(h=ap.settings.buildPager(f),ap.pagerEl.addClass("mc-custom-pager")):(h=f+1,ap.pagerEl.addClass("mc-default-pager")),g+='<div class="mc-pager-item"><a data-slide-index="'+f+'" class="mc-pager-link">'+h+"</a></div>"}ap.pagerEl.html(g)},F=function(){ap.settings.pagerCustom?ap.pagerEl=a(ap.settings.pagerCustom):(ap.pagerEl=a('<div class="mc-pager" />'),ap.settings.pagerSelector?a(ap.settings.pagerSelector).html(ap.pagerEl):ap.controls.el.addClass("mc-has-pager").append(ap.pagerEl),aj()),ap.pagerEl.delegate("a","click",an)},ad=function(){ap.controls.next=a('<a class="mc-next">'+ap.settings.nextText+"</a>"),ap.controls.prev=a('<a class="mc-prev">'+ap.settings.prevText+"</a>"),ap.controls.next.bind("click",ah),ap.controls.prev.bind("click",ag),ap.settings.nextSelector&&a(ap.settings.nextSelector).append(ap.controls.next),ap.settings.prevSelector&&a(ap.settings.prevSelector).append(ap.controls.prev),ap.settings.nextSelector||ap.settings.prevSelector||(ap.controls.directionEl=a('<div class="mc-controls-direction" />'),ap.controls.directionEl.append(ap.controls.prev).append(ap.controls.next),ap.controls.el.addClass("mc-has-controls-direction").append(ap.controls.directionEl))},ab=function(){ap.controls.start=a('<div class="mc-controls-auto-item"><a class="mc-start">'+ap.settings.startText+"</a></div>"),ap.controls.stop=a('<div class="mc-controls-auto-item"><a class="mc-stop">'+ap.settings.stopText+"</a></div>"),ap.controls.autoEl=a('<div class="mc-controls-auto" />'),ap.controls.autoEl.delegate(".mc-start","click",au),ap.controls.autoEl.delegate(".mc-stop","click",R),ap.settings.autoControlsCombine?ap.controls.autoEl.append(ap.controls.start):ap.controls.autoEl.append(ap.controls.start).append(ap.controls.stop),ap.settings.autoControlsSelector?a(ap.settings.autoControlsSelector).html(ap.controls.autoEl):ap.controls.el.addClass("mc-has-controls-auto").append(ap.controls.autoEl),af(ap.settings.autoStart?"stop":"start")},J=function(){ap.children.each(function(){var d=a(this).attr("title");void 0!=d&&(""+d).length&&a(this).append('<div class="mc-caption"><div>'+d+"</div></div>")})},ah=function(d){ap.settings.auto&&am.stopAuto(),am.goToNextSlide(),d.preventDefault()},ag=function(d){ap.settings.auto&&am.stopAuto(),am.goToPrevSlide(),d.preventDefault()},au=function(d){am.startAuto(),d.preventDefault()},R=function(d){am.stopAuto(),d.preventDefault()},an=function(g){ap.settings.auto&&am.stopAuto();var d=a(g.currentTarget),f=parseInt(d.attr("data-slide-index"));f!=ap.active.index&&am.goToSlide(f),g.preventDefault()},Z=function(f){var d=ap.children.length;return"short"==ap.settings.pagerType?(ap.settings.maxSlides>1&&(d=Math.ceil(ap.children.length/ap.settings.maxSlides)),ap.pagerEl.html(f+1+ap.settings.pagerShortSeparator+d),void 0):(ap.pagerEl.find("a").removeClass("active"),ap.pagerEl.each(function(g,h){a(h).find("a").eq(f).addClass("active")}),void 0)},ac=function(){if(ap.settings.infiniteLoop){var d="";0==ap.active.index?d=ap.children.eq(0).position():ap.active.index==ai()-1&&ap.carousel?d=ap.children.eq((ai()-1)*ar()).position():ap.active.index==ap.children.length-1&&(d=ap.children.eq(ap.children.length-1).position()),"horizontal"==ap.settings.mode?aA(-d.left,"reset",0):"vertical"==ap.settings.mode&&aA(-d.top,"reset",0)}ap.working=!1,ap.settings.onSlideAfter(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index)},af=function(d){ap.settings.autoControlsCombine?ap.controls.autoEl.html(ap.controls[d]):(ap.controls.autoEl.find("a").removeClass("active"),ap.controls.autoEl.find("a:not(.mc-"+d+")").addClass("active"))},s=function(){1==ai()?(ap.controls.prev.addClass("disabled"),ap.controls.next.addClass("disabled")):!ap.settings.infiniteLoop&&ap.settings.hideControlOnEnd&&(0==ap.active.index?(ap.controls.prev.addClass("disabled"),ap.controls.next.removeClass("disabled")):ap.active.index==ai()-1?(ap.controls.next.addClass("disabled"),ap.controls.prev.removeClass("disabled")):(ap.controls.prev.removeClass("disabled"),ap.controls.next.removeClass("disabled")))},aa=function(){ap.settings.autoDelay>0?setTimeout(am.startAuto,ap.settings.autoDelay):am.startAuto(),ap.settings.autoHover&&am.hover(function(){ap.interval&&(am.stopAuto(!0),ap.autoPaused=!0)},function(){ap.autoPaused&&(am.startAuto(!0),ap.autoPaused=null)})},U=function(){var f=0;if("next"==ap.settings.autoDirection){am.append(ap.children.clone().addClass("mc-clone"))}else{am.prepend(ap.children.clone().addClass("mc-clone"));var d=ap.children.first().position();f="horizontal"==ap.settings.mode?-d.left:-d.top}aA(f,"reset",0),ap.settings.pager=!1,ap.settings.controls=!1,ap.settings.autoControls=!1,ap.settings.tickerHover&&!ap.usingCSS&&ap.viewport.hover(function(){am.stop()},function(){var k=0;ap.children.each(function(){k+="horizontal"==ap.settings.mode?a(this).outerWidth(!0):a(this).outerHeight(!0)});var g=ap.settings.speed/k,h="horizontal"==ap.settings.mode?"left":"top",l=g*(k-Math.abs(parseInt(am.css(h))));Q(l)}),Q()},Q=function(g){speed=g?g:ap.settings.speed;var k={left:0,top:0},f={left:0,top:0};"next"==ap.settings.autoDirection?k=am.find(".mc-clone").first().position():f=ap.children.first().position();var h="horizontal"==ap.settings.mode?-k.left:-k.top,l="horizontal"==ap.settings.mode?-f.left:-f.top,d={resetValue:l};aA(h,"ticker",speed,d)},K=function(){ap.touch={start:{x:0,y:0},end:{x:0,y:0}},ap.viewport.bind("touchstart",j)},j=function(d){if(ap.working){d.preventDefault()}else{ap.touch.originalPos=am.position();var f=d.originalEvent;ap.touch.start.x=f.changedTouches[0].pageX,ap.touch.start.y=f.changedTouches[0].pageY,ap.viewport.bind("touchmove",e),ap.viewport.bind("touchend",t)}},e=function(f){var k=f.originalEvent,d=Math.abs(k.changedTouches[0].pageX-ap.touch.start.x),g=Math.abs(k.changedTouches[0].pageY-ap.touch.start.y);if(3*d>g&&ap.settings.preventDefaultSwipeX?f.preventDefault():3*g>d&&ap.settings.preventDefaultSwipeY&&f.preventDefault(),"fade"!=ap.settings.mode&&ap.settings.oneToOneTouch){var l=0;if("horizontal"==ap.settings.mode){var h=k.changedTouches[0].pageX-ap.touch.start.x;l=ap.touch.originalPos.left+h}else{var h=k.changedTouches[0].pageY-ap.touch.start.y;l=ap.touch.originalPos.top+h}aA(l,"reset",0)}},t=function(f){ap.viewport.unbind("touchmove",e);var h=f.originalEvent,d=0;if(ap.touch.end.x=h.changedTouches[0].pageX,ap.touch.end.y=h.changedTouches[0].pageY,"fade"==ap.settings.mode){var g=Math.abs(ap.touch.start.x-ap.touch.end.x);g>=ap.settings.swipeThreshold&&(ap.touch.start.x>ap.touch.end.x?am.goToNextSlide():am.goToPrevSlide(),am.stopAuto())}else{var g=0;"horizontal"==ap.settings.mode?(g=ap.touch.end.x-ap.touch.start.x,d=ap.touch.originalPos.left):(g=ap.touch.end.y-ap.touch.start.y,d=ap.touch.originalPos.top),!ap.settings.infiniteLoop&&(0==ap.active.index&&g>0||ap.active.last&&0>g)?aA(d,"reset",200):Math.abs(g)>=ap.settings.swipeThreshold?(0>g?am.goToNextSlide():am.goToPrevSlide(),am.stopAuto()):aA(d,"reset",200)}ap.viewport.unbind("touchend",t)},ae=function(){var f=a(window).width(),d=a(window).height();if(!(/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent))){(aB!=f||at!=d)&&(aB=f,at=d,am.redrawSlider())}};return am.goToSlide=function(o,k){if(!ap.working&&ap.active.index!=o){if(ap.working=!0,ap.oldIndex=ap.active.index,ap.active.index=0>o?ai()-1:o>=ai()?0:o,ap.settings.onSlideBefore(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index),"next"==k?ap.settings.onSlideNext(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index):"prev"==k&&ap.settings.onSlidePrev(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index),ap.active.last=ap.active.index>=ai()-1,ap.settings.pager&&Z(ap.active.index),ap.settings.controls&&s(),"fade"==ap.settings.mode){ap.settings.adaptiveHeight&&ap.viewport.height()!=ao()&&ap.viewport.animate({height:ao()},ap.settings.adaptiveHeightSpeed),ap.children.filter(":visible").fadeOut(ap.settings.speed).css({zIndex:0}),ap.children.eq(ap.active.index).css("zIndex",51).fadeIn(ap.settings.speed,function(){a(this).css("zIndex",50),ac()})}else{ap.settings.adaptiveHeight&&ap.viewport.height()!=ao()&&ap.viewport.animate({height:ao()},ap.settings.adaptiveHeightSpeed);var u=0,f={left:0,top:0};if(!ap.settings.infiniteLoop&&ap.carousel&&ap.active.last){if("horizontal"==ap.settings.mode){var r=ap.children.eq(ap.children.length-1);f=r.position(),u=ap.viewport.width()-r.outerWidth()}else{var h=ap.children.length-ap.settings.minSlides;f=ap.children.eq(h).position()}}else{if(ap.carousel&&ap.active.last&&"prev"==k){var p=1==ap.settings.moveSlides?ap.settings.maxSlides-ar():(ai()-1)*ar()-(ap.children.length-ap.settings.maxSlides),r=am.children(".mc-clone").eq(p);f=r.position()}else{if("next"==k&&0==ap.active.index){f=am.find("> .mc-clone").eq(ap.settings.maxSlides).position(),ap.active.last=!1}else{if(o>=0){var q=o*ar();f=ap.children.eq(q).position()}}}}if("undefined"!=typeof f){var m="horizontal"==ap.settings.mode?-(f.left-u):-f.top;aA(m,"slide",ap.settings.speed)}}}},am.goToNextSlide=function(){if(ap.settings.infiniteLoop||!ap.active.last){var d=parseInt(ap.active.index)+1;am.goToSlide(d,"next")}},am.goToPrevSlide=function(){if(ap.settings.infiniteLoop||0!=ap.active.index){var d=parseInt(ap.active.index)-1;am.goToSlide(d,"prev")}},am.startAuto=function(d){ap.interval||(ap.interval=setInterval(function(){"next"==ap.settings.autoDirection?am.goToNextSlide():am.goToPrevSlide()},ap.settings.pause),ap.settings.autoControls&&1!=d&&af("stop"))},am.stopAuto=function(d){ap.interval&&(clearInterval(ap.interval),ap.interval=null,ap.settings.autoControls&&1!=d&&af("start"))},am.getCurrentSlide=function(){return ap.active.index},am.getSlideCount=function(){return ap.children.length},am.redrawSlider=function(){ap.children.add(am.find(".mc-clone")).outerWidth(al()),ap.viewport.css("height",ao()),ap.settings.ticker||G(),ap.active.last&&(ap.active.index=ai()-1),ap.active.index>=ai()&&(ap.active.last=!0),ap.settings.pager&&!ap.settings.pagerCustom&&(aj(),Z(ap.active.index))},am.destroySlider=function(){ap.initialized&&(ap.initialized=!1,a(".mc-clone",this).remove(),ap.children.each(function(){void 0!=a(this).data("origStyle")?a(this).attr("style",a(this).data("origStyle")):a(this).removeAttr("style")}),void 0!=a(this).data("origStyle")?this.attr("style",a(this).data("origStyle")):a(this).removeAttr("style"),a(this).unwrap().unwrap(),ap.controls.el&&ap.controls.el.remove(),ap.controls.next&&ap.controls.next.remove(),ap.controls.prev&&ap.controls.prev.remove(),ap.pagerEl&&ap.pagerEl.remove(),a(".mc-caption",this).remove(),ap.controls.autoEl&&ap.controls.autoEl.remove(),clearInterval(ap.interval),ap.settings.responsive&&a(window).unbind("resize",ae))},am.reloadSlider=function(d){void 0!=d&&(aq=d),am.destroySlider(),ay()},ay(),this}}(jQuery);(function(){var a=MadCap.CreateNamespace("Slideshow");$(function(){if(MadCap.Utilities!=null&&MadCap.Utilities.LoadHandlers!=null){MadCap.Utilities.LoadHandlers.MadCapSlideshow=a.Init;a.Init(document)}});a.Init=function(b){var c;if($("html").attr("data-mc-target-type")){c=function(e,d){return e.attr("data-mc-"+d)}}else{c=function(e,d){return e.attr("madcap:"+d.replace("-",""))}}$(".MCSlider",b).each(function(q,h){var I=$(h);var l={};var u=h.className;var f=c(I,"random-start");var z=c(I,"infinite-loop");var r=c(I,"show-captions");var w=c(I,"controls");var y=c(I,"slide-width");var x=c(I,"adaptive-height");var k=c(I,"responsive");var j=c(I,"navigation");var s=true;var e=false;l.pagerCustom=null;if(j){if(j=="Thumbnails"){e=true;l.pagerCustom="#mc-pager"+(q+1).toString()}if(j=="None"){s=false}}var F=c(I,"auto-hover");var m=c(I,"auto-start");var H=c(I,"auto-controls");var d=c(I,"combine-controls");var D=c(I,"auto-direction");var E=+c(I,"auto-delay");var t=c(I,"mode");var A=+c(I,"speed");var o=+c(I,"pause");var C=+c(I,"slides-displayed");var B=c(I,"video");if(u){l.slideshowClass=u}if(f){if("true"==f.toString().toLowerCase()){l.randomStart=true}else{if("false"==f.toString().toLowerCase()){l.randomStart=false}}}if(z){if("true"==z.toString().toLowerCase()){l.infiniteLoop=true}else{if("false"==z.toString().toLowerCase()){l.infiniteLoop=false;l.hideControlOnEnd=true}}}if(r){if("true"==r.toString().toLowerCase()){l.captions=true}else{if("false"==r.toString().toLowerCase()){l.captions=false}}}if(w){if("true"==w.toString().toLowerCase()){l.controls=true}else{if("false"==w.toString().toLowerCase()){l.controls=false}}}l.pager=s;l.thumbnails=e;if(y){l.slideWidth=y}if(x){if("true"==x.toString().toLowerCase()){l.adaptiveHeight=true}else{if("false"==x.toString().toLowerCase()){l.adaptiveHeight=false}}}if(k){if("true"==k.toString().toLowerCase()){l.responsive=true}else{if("false"==k.toString().toLowerCase()){l.responsive=false}}}var p=false;if(F){if("true"==F.toString().toLowerCase()){l.autoHover=true;p=true}else{if("false"==F.toString().toLowerCase()){l.autoHover=false}}}if(m){if("true"==m.toString().toLowerCase()){l.autoStart=true;p=true}else{if("false"==m.toString().toLowerCase()){l.autoStart=false}}}if(H){if("true"==H.toString().toLowerCase()){l.autoControls=true;l.autoControlsCombine=true;p=true}else{if("false"==H.toString().toLowerCase()){l.autoControls=false;l.autoControlsCombine=false}}}if(p){l.auto=true}if(D){l.autoDirection=D}if(E){l.autoDelay=E}if(t){l.mode=t}if(A){l.speed=A}if(o){l.pause=o}if(C){l.minSlides=C;l.maxSlides=C;l.moveSlides=1;if(y){var G=y.match(/\d+/);var v=y.replace(/\d/g,"");l.slideWidth=(G/C)+v}}if(navigator.userAgent.indexOf("MSIE")!==-1){l.preloadImages="all"}l.video=true;l.useCSS=false;if(B){l.video=false}l.onSliderLoad=function(J){$(".MCSlide").css("visibility","visible")};var g;var n;if(MadCap.Utilities!=null&&MadCap.Utilities.HasRuntimeFileType("Topic")&&$("html").attr("data-mc-target-type")!="EPUB"&&$("html").attr("data-mc-target-type")!="EclipseHelp"){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(O){if(O){var K=new MadCap.Utilities.Url(decodeURIComponent(O[0]));var J=new MadCap.Utilities.Url(K.Fragment.substring(1));g=J.Fragment;n=K.QueryMap.GetItem("Highlight");if(g){g=g.substring(1);g=g.replace(".","\\.");try{l.startSlide=$("[name="+g+"]").closest(".MCSlide").index();if(l.startSlide<0){l.startSlide=0}}catch(N){l.startSlide=0}}else{if(n){var M=n.replace('"',"").split(" ");for(var L=0;L<M.length;L++){if(M[L]==""){M.splice(M[L],1);L--}}$(".MCSlide",b).each(function(P,S){for(var R=0;R<M.length;R++){if(M[R]!=""){var Q=new RegExp("\\b"+M[R]+"\\b","i");var U=$(S).attr("title");if(U!=null&&U.match(Q)){l.startSlide=P;return false}var T=$(S).text();if(T!=null&&T.match(Q)){l.startSlide=P;return false}}}if(l.startSlide<0){l.startSlide=0}})}}}I.MCSlider(l)})}else{I.MCSlider(l)}})}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.FeedbackController=function(g){var f=this;var e=0;this.Server=g;this.FeedbackServer=c(g);this.Version=-1;this.FeedbackActive=false;this.PulseServer=null;this.PulseEnabled=false;this.PulseActive=false;this.PulseUserGuid=null;function c(j,i){if(j==null){return null}if(typeof i=="undefined"){i=""}var h=new MadCap.Utilities.Url(j);h=h.CombinePath(i+"Service.FeedbackExplorer/FeedbackJsonService.asmx/");return h.FullPath}function d(w,v,o,k){if(typeof MadCap.WebHelp.FeedbackController.Shared=="undefined"){MadCap.WebHelp.FeedbackController.Shared=f}var z=document.createElement("script");var l=document.getElementsByTagName("head")[0];var s="MCLiveHelpScript_"+e++;var m=f.FeedbackServer+w+"?";m+="OnComplete="+v+"&ScriptID="+s+"&UniqueID="+(new Date()).getTime();if(o!=null){for(var x=0,j=o.length;x<j;x++){var t=o[x];var B=t[0];var u=encodeURIComponent(t[1]);m+=("&"+B+"="+u)}}if(document.body.currentStyle!=null){var q=2083;if(m.length>q){var r=m.length-q;var A={ExceedAmount:r};var y=new MadCap.FeedbackException(-1,"URL limit exceeded.",A);throw y}}var n=2048;var p=m.indexOf("?");var h=m.substring(p+1).length;if(h>n){var r=h-n;var A={ExceedAmount:r};var y=new MadCap.FeedbackException(-1,"Query string limit exceeded.",A);throw y}z.id=s;z.setAttribute("type","text/javascript");z.setAttribute("src",m);l.appendChild(z);return s}function b(h){window.setTimeout(function(){var i=document.getElementById(h);i.parentNode.removeChild(i)},10)}this.Init=(function(){var k=false;var h=false;var i=new Array();var l=3000;function j(){for(var m=0;m<i.length;m++){i[m].apply(this,arguments)}k=true}return function(m){if(k){m.apply(this,arguments);return}if(m!=null){i.push(m)}if(h){return}h=true;this.GetVersion(function(){if(this.PulseEnabled){this.GetPulseServerActivated(function(n){this.PulseActive=n&&n.toLowerCase()==="true";j.apply(this,arguments)},null,this)}else{j()}},null,this);window.setTimeout(function(){if(!k){j.apply(this,arguments)}},l)}})();this.GetUserGuid=function(){return f.PulseEnabled?f.PulseUserGuid:MadCap.Utilities.Store.getItem("LiveHelpUserGuid")};this.LogTopic=function(i,j,h){this.LogTopicOnComplete=function(k){if(h!=null){h()}b(k);this.LogTopicOnComplete=null};this.GetVersion(function(k){if(k==1){d("LogTopic","MadCap.WebHelp.FeedbackController.Shared.LogTopicOnComplete",[["TopicID",i]])}else{d("LogTopic2","MadCap.WebHelp.FeedbackController.Shared.LogTopicOnComplete",[["TopicID",i],["CSHID",j]])}})};this.LogSearch=function(h,k,i,l,j){this.LogSearchOnComplete=function(m){b(m);this.LogSearchOnComplete=null};d("LogSearch","MadCap.WebHelp.FeedbackController.Shared.LogSearchOnComplete",[["ProjectID",h],["UserGuid",k],["ResultCount",i],["Language",l],["Query",j]])};this.AddComment=function(j,l,k,i,n,m,h){this.AddCommentOnComplete=function(o){if(h!=null){h()}b(o);this.AddCommentOnComplete=null};d("AddComment","MadCap.WebHelp.FeedbackController.Shared.AddCommentOnComplete",[["TopicID",j],["UserGuid",l],["Username",k],["Subject",i],["Comment",n],["ParentCommentID",m]])};this.GetAverageRating=function(j,h,i){if(j==null){if(h!=null){h(0,0,i)}return}this.GetAverageRatingOnComplete=function(m,l,k){if(h!=null){h(l,k,i)}b(m);this.GetAverageRatingOnComplete=null};d("GetAverageRating","MadCap.WebHelp.FeedbackController.Shared.GetAverageRatingOnComplete",[["TopicID",j]])};this.SubmitRating=function(j,k,m,h,i){this.SubmitRatingOnComplete=function(n){if(h!=null){h(i)}b(n);this.SubmitRatingOnComplete=null};var l=d("SubmitRating","MadCap.WebHelp.FeedbackController.Shared.SubmitRatingOnComplete",[["TopicID",j],["Rating",k],["Comment",m]])};this.GetTopicComments=function(j,l,k,h,i){this.GetTopicCommentsOnComplete=function(o,n){if(h!=null){h(n,i)}b(o);this.GetTopicCommentsOnComplete=null};var m=d("GetTopicComments","MadCap.WebHelp.FeedbackController.Shared.GetTopicCommentsOnComplete",[["TopicID",j],["UserGuid",l],["Username",k]])};this.GetAnonymousEnabled=function(i,h,j){this.GetAnonymousEnabledOnComplete=function(l,k){if(h!=null){h(k,j)}b(l);this.GetAnonymousEnabledOnComplete=null};d("GetAnonymousEnabled","MadCap.WebHelp.FeedbackController.Shared.GetAnonymousEnabledOnComplete",[["ProjectID",i]])};this.StartActivateUser=function(m,r,p){this.StartActivateUserOnComplete=function(A,z){if(r!=null){r(z,p)}b(A);this.StartActivateUserOnComplete=null};var y=FMCGetChildNodeByAttribute(m.documentElement,"Name","Username");var j=FMCGetAttribute(y,"Value");var n=FMCGetChildNodeByAttribute(m.documentElement,"Name","EmailAddress");var i=FMCGetAttribute(n,"Value");var t=FMCGetChildNodeByAttribute(m.documentElement,"Name","FirstName");var h=FMCGetAttribute(t,"Value");var x=FMCGetChildNodeByAttribute(m.documentElement,"Name","LastName");var s=FMCGetAttribute(x,"Value");var w=FMCGetChildNodeByAttribute(m.documentElement,"Name","Country");var v=FMCGetAttribute(w,"Value");var u=FMCGetChildNodeByAttribute(m.documentElement,"Name","PostalCode");var o=FMCGetAttribute(u,"Value");var k=FMCGetChildNodeByAttribute(m.documentElement,"Name","Gender");var q=FMCGetAttribute(k,"Value");var l="";d("StartActivateUser","MadCap.WebHelp.FeedbackController.Shared.StartActivateUserOnComplete",[["Username",j],["EmailAddress",i],["FirstName",h],["LastName",s],["Country",v],["Zip",o],["Gender",q],["UILanguageOrder",l]])};this.StartActivateUser2=function(k,h,j,l){var i=MadCap.Utilities.Xhr.GetOuterXml(k);this.StartActivateUser2OnComplete=function(n,m){if(h!=null){if(l!=null){h.call(l,m,j)}else{h(m,j)}}b(n);this.StartActivateUser2OnComplete=null};d("StartActivateUser2","MadCap.WebHelp.FeedbackController.Shared.StartActivateUser2OnComplete",[["Xml",i]])};this.UpdateUserProfile=function(k,l,h,j,m){var i=MadCap.Utilities.Xhr.GetOuterXml(l);this.UpdateUserProfileOnComplete=function(o,n){if(h!=null){if(m!=null){h.call(m,n,j)}else{h(n,j)}}b(o);this.UpdateUserProfileOnComplete=null};d("UpdateUserProfile","MadCap.WebHelp.FeedbackController.Shared.UpdateUserProfileOnComplete",[["Guid",k],["Xml",i]])};this.GetUserProfile=function(j,h,i,k){this.GetUserProfileOnComplete=function(m,l){if(h!=null){if(k!=null){h.call(k,l,i)}else{h(l,i)}}b(m);this.GetUserProfileOnComplete=null};d("GetUserProfile","MadCap.WebHelp.FeedbackController.Shared.GetUserProfileOnComplete",[["Guid",j]])};this.CheckUserStatus=function(j,h,i){this.CheckUserStatusOnComplete=function(l,k){if(h!=null){h(k,i)}b(l);this.CheckUserStatusOnComplete=null};d("CheckUserStatus","MadCap.WebHelp.FeedbackController.Shared.CheckUserStatusOnComplete",[["PendingGuid",j]])};this.GetSynonymsFile=function(i,k,h,j){this.GetSynonymsFileOnComplete=function(m,l){if(h!=null){h(l,j)}b(m)};d("GetSynonymsFile","MadCap.WebHelp.FeedbackController.Shared.GetSynonymsFileOnComplete",[["ProjectID",i],["UpdatedSince",k]])};this.GetVersion=function(h,i,j){this.GetVersionOnComplete=function(l,k){if(k==null){f.Version=1}else{if(f.Version==-1&&k>4){f.FeedbackServer=c(f.Server,"Feedback/");f.PulseServer=f.Server;f.PulseEnabled=true}f.FeedbackActive=true;f.Version=k}if(h!=null){if(j!=null){h.call(j,f.Version,i)}else{h(f.Version,i)}}if(l!=null){b(l)}this.GetVersionOnComplete=null};if(f.Version==-1){d("GetVersion","MadCap.WebHelp.FeedbackController.Shared.GetVersionOnComplete")}else{this.GetVersionOnComplete(null,f.Version)}};this.GetPulseServerActivated=function(i,h,j){this.GetPulseServerActivatedOnComplete=function(l,k){if(i!=null){if(j!=null){i.call(j,k,h)}else{i(k,h)}}if(l!=null){b(l)}this.GetPulseServerActivatedOnComplete=null};d("GetPulseServerActivated","MadCap.WebHelp.FeedbackController.Shared.GetPulseServerActivatedOnComplete")};this.GetPulseStreamID=function(i,j,h,k){this.GetPulseStreamIDOnComplete=function(m,l){if(j!=null){if(k!=null){j.call(k,l,h)}else{j(l,h)}}if(m!=null){b(m)}this.GetPulseStreamIDOnComplete=null};d("GetPulseStreamID","MadCap.WebHelp.FeedbackController.Shared.GetPulseStreamIDOnComplete",[["TopicID",i]])};this.GetTopicPathByStreamID=function(j,i,h,k){this.GetTopicPathByStreamIDOnComplete=function(l,m){if(i!=null){if(k!=null){i.call(k,m,h)}else{i(m,h)}}if(l!=null){b(l)}this.GetTopicPathByStreamIDOnComplete=null};d("GetTopicPathByStreamID","MadCap.WebHelp.FeedbackController.Shared.GetTopicPathByStreamIDOnComplete",[["StreamID",j]])};this.GetTopicPathByPageID=function(h,j,i,k){this.GetTopicPathByPageIDOnComplete=function(l,m){if(j!=null){if(k!=null){j.call(k,m,i)}else{j(m,i)}}if(l!=null){b(l)}this.GetTopicPathByPageIDOnComplete=null};d("GetTopicPathByPageID","MadCap.WebHelp.FeedbackController.Shared.GetTopicPathByPageIDOnComplete",[["PageID",h]])};this.GetPulseSearchResults=function(j,l,i,h){var k=$.Deferred();this.GetPulseSearchResultsOnComplete=function(n,m){k.resolve(m);if(n!=null){b(n)}this.GetPulseSearchResultsOnComplete=null};d("GetPulseSearchResults","MadCap.WebHelp.FeedbackController.Shared.GetPulseSearchResultsOnComplete",[["ProjectID",j],["SearchQuery",l],["PageSize",i],["PageIndex",h]]);return k.promise()}};MadCap.WebHelp.LoadFeedbackController=MadCap.Utilities.Memoize(function(b){return new MadCap.WebHelp.FeedbackController(b)});MadCap.WebHelp.MockFeedbackController=function(){this.GetVersion=function(b,c,d){this.FeedbackActive=true;this.Version=3;if(b!=null){if(d!=null){b.call(d,this.Version,c)}else{b(this.Version,c)}}};this.GetAverageRating=function(d,b,c){if(b!=null){b(50,10,c)}};this.SubmitRating=function(d,e,f,b,c){if(b!=null){b(c)}};this.GetUserGuid=function(){return null}};MadCap.WebHelp.MockFeedbackController.prototype=new MadCap.WebHelp.FeedbackController(null);MadCap.CreateNamespace("Feedback");MadCap.Feedback.LoginDialog=function(c,b){this._FeedbackController=c;this._TimeoutID=-1;this._Mode=b;this._UserGuid=null;this._El=null};var a=MadCap.Feedback.LoginDialog;a.prototype._Init=function(){var c=this;this._El=$(".login-dialog");$(".login-dialog-buttons .submit-button").click(function(d){c.Submit()});$(".login-dialog-buttons .cancel-button").click(function(d){c.Hide(false)});if(this._Mode=="edit"){this._UserGuid=this._FeedbackController.GetUserGuid();this._FeedbackController.GetUserProfile(this._UserGuid,function(f,d){var e=MadCap.Utilities.Xhr.LoadXmlString(f);$(e.documentElement).children("Item").each(function(h,i){var k=$(this);var g=k.attr("Name");var j=k.attr("Value");var m=$(".login-dialog input[name='"+g+"']");if(m.attr("type")=="checkbox"){var l=MadCap.String.ToBool(j,false);m.prop("checked",l)}else{m.val(j)}})},null,this)}else{if(this._Mode=="pulse"){if(c._El.length==0){$("body").append('<div class="login-dialog pulse" />');c._El=$(".login-dialog")}var b=$("#pulse-login-frame");if(b.length==0){c._El.addClass("pulse");c._El.empty();c._El.append('<iframe id="pulse-login-frame" name="pulse-login-html5" style="visibility:hidden;" onload="this.style.visibility=\'visible\';"></iframe>');c._El.append('<button class="close-dialog"></button>');$(".close-dialog",c._El).click(function(d){c.Hide(true)});$("#pulse-login-frame").attr("src",c._FeedbackController.PulseServer+"Login")}}}};a.prototype._Cleanup=function(){$(".login-dialog-buttons .submit-button").off("click");$(".login-dialog-buttons .cancel-button").off("click");$(".submit-button").attr("disabled",null);$(".status-message-box").hide();$(".profile-item-wrapper.error").removeClass("error");window.clearTimeout(this._TimeoutID)};a.prototype.Show=function(){this._Init();var b=MadCap.TextEffects.AddBackgroundTint("light");$(b).animate({opacity:0.5},200);this._El.fadeIn(200)};a.prototype.Hide=function(b){this._Cleanup();MadCap.TextEffects.RemoveBackgroundTint();if(b){this._El.fadeOut()}else{this._El.hide()}$(this).trigger("closed")};a.prototype.Submit=function(){$(".status-message-box").hide();$(".profile-item-wrapper.error").removeClass("error");if(this._CheckErrors()){this._SetStatusMessage("required-fields-missing-message","error");return}var c=this._LoginItemsToXml();var b=this;if(this._Mode=="new"){this._FeedbackController.StartActivateUser2(c,function(d){b._CheckUserStatus(d)});this._SetStatusMessage("verification-email-sent-message")}else{if(this._Mode=="edit"){this._FeedbackController.UpdateUserProfile(this._UserGuid,c,function(d){if(d=="00000000-0000-0000-0000-000000000000"){b.Hide(true)}else{b._CheckUserStatus(d);b._SetStatusMessage("verification-email-sent-message")}})}}$(".submit-button").attr("disabled","disabled")};a.prototype._CheckUserStatus=function(c){var b=this;this._FeedbackController.CheckUserStatus(c,function(d){if(d=="Pending"){b._TimeoutID=setTimeout(function(){b._CheckUserStatus(c)},5000)}else{MadCap.Utilities.Store.setItem("LiveHelpUserGuid",d);b.Hide(true)}})};a.prototype._CheckErrors=function(){var e=false;var d=$(".login-dialog .profile-item-wrapper input, .login-dialog .profile-item-wrapper select");for(var c=0,f=d.length;c<f;c++){var b=d[c];var j=$(b);var g=j.val();var h=MadCap.String.ToBool(MadCap.Dom.Dataset(b,"required"),false);if(h&&MadCap.String.IsNullOrEmpty(g)){j.closest(".profile-item-wrapper").addClass("error");e=true}}return e};a.prototype._LoginItemsToXml=function(){var m=MadCap.Utilities.Xhr.CreateXmlDocument("FeedbackUserProfile");var h=m.documentElement;var b=$(".login-dialog .profile-item-wrapper input");for(var e=0,d=b.length;e<d;e++){var j=b[e];var g=$(j);var c=g.attr("name");var f=g.attr("type");var k=f=="checkbox"?j.checked:g.val();var l=m.createElement("Item");l.setAttribute("Name",c);l.setAttribute("Value",k.toString());h.appendChild(l)}return m};a.prototype._SetStatusMessage=function(b,c){var d=$(".status-message-box");if(c=="error"){d.addClass("error")}else{d.removeClass("error")}$(".message").hide();$("."+b).show();d.fadeIn()};MadCap.FeedbackException=function(c,b,d){MadCap.Exception.call(this,c,b);this.Data=d};MadCap.FeedbackException.prototype=new MadCap.Exception();MadCap.FeedbackException.prototype.constructor=MadCap.FeedbackException;MadCap.FeedbackException.prototype.base=MadCap.Exception.prototype})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.HelpSystem=function(v,m,n,c,E){var d=this;var r=v;var e=new MadCap.Utilities.Url(n).ToFolder().ToFolder().FullPath;var o=null;var l=new Array();var w=c;var k=E;var q=null;var C=[];var t=new MadCap.Utilities.Dictionary();var A=null;var G=new MadCap.Utilities.Dictionary();var b=false;var p=new MadCap.WebHelp.AliasFile(e+"Data/Alias.xml",this);var H=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.Toc);var h=null;var s=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.BrowseSequence);var u=new MadCap.Utilities.Dictionary();this.TargetType=null;this.DefaultStartTopic=null;this.InPreviewMode=null;this.LiveHelpOutputId=null;this.LiveHelpServer=null;this.LiveHelpEnabled=false;this.IsWebHelpPlus=false;this.ContentFolder=null;this.UseCustomTopicFileExtension=false;this.CustomTopicFileExtension=null;this.IsMultilingual=false;this.GlossaryUrl=null;this.SearchFilterSetUrl=null;this.SyncTOC=null;this.IndexPartialWordSearch=true;this.GlossaryPartialWordSearch=true;this.DefaultSkin=null;this.IsAutoMerged=false;this.LanguageUrl=null;this.BreakpointsUrl=null;this.PreventExternalUrls=false;this.IsResponsive=false;this.SearchUrl=null;this.PulsePage=null;this.LanguageCode=null;this.LanguageName=null;(function(){})();this.Load=function(J){MadCap.Utilities.Xhr.Load(n,true,function(X){var Q=0;function M(){Q++;if(Q==l.length){J()}}function Y(ab,Z){if(l.length>0){for(var aa=0;aa<l.length;aa++){l[aa].Load(ab)}}else{Z()}}b=X!=null;if(!b){J();return}this.LanguageCode=X.documentElement.getAttribute("xml:lang");this.LanguageName=X.documentElement.getAttribute("LanguageName");this.TargetType=X.documentElement.getAttribute("TargetType");this.DefaultStartTopic=X.documentElement.getAttribute("DefaultUrl");this.InPreviewMode=MadCap.Dom.GetAttributeBool(X.documentElement,"InPreviewMode",false);this.LiveHelpOutputId=X.documentElement.getAttribute("LiveHelpOutputId");this.LiveHelpServer=X.documentElement.getAttribute("LiveHelpServer");this.LiveHelpEnabled=this.LiveHelpOutputId!=null;this.MoveContentToRoot=MadCap.Dom.GetAttributeBool(X.documentElement,"MoveOutputContentToRoot",false);this.ReplaceReservedCharacters=MadCap.Dom.GetAttributeBool(X.documentElement,"ReplaceReservedCharacters",false);this.MakeFileLowerCase=MadCap.Dom.GetAttributeBool(X.documentElement,"MakeFileLowerCase",false);this.PreventExternalUrls=MadCap.Dom.GetAttributeBool(X.documentElement,"PreventExternalUrls",false);this.IsResponsive=MadCap.Dom.GetAttributeBool(X.documentElement,"EnableResponsiveOutput",false);this.IncludeGlossarySearchResults=MadCap.Dom.GetAttributeBool(X.documentElement,"IncludeGlossarySearchResults",true);this.ResultsPerPage=MadCap.Dom.GetAttributeInt(X.documentElement,"ResultsPerPage",20);var O=MadCap.Dom.GetAttributeBool(X.documentElement,"ServerEnabled",false);this.IsWebHelpPlus=(this.TargetType=="WebHelpPlus"||O)&&MadCap.String.StartsWith(document.location.protocol,"http",false);var K="";if(!this.MoveContentToRoot){K="Content/"}if(this.MakeFileLowerCase){K=K.toLowerCase()}this.ContentFolder=K;this.UseCustomTopicFileExtension=MadCap.Dom.GetAttributeBool(X.documentElement,"UseCustomTopicFileExtension",false);this.CustomTopicFileExtension=MadCap.Dom.GetAttribute(X.documentElement,"CustomTopicFileExtension");this.IsMultilingual=MadCap.Dom.GetAttributeBool(X.documentElement,"Multilingual",false);this.GlossaryUrl=F(X,"Glossary");this.TocUrl=F(X,"Toc");this.SearchUrl=F(X,"SearchUrl");this.PulsePage=F(X,"PulsePage");this.BrowseSequencesUrl=F(X,"BrowseSequence");this.IndexUrl=F(X,"Index");this.SearchFilterSetUrl=F(X,"SearchFilterSet");this.LanguageUrl=e+"Data/Language.js";this.BreakpointsUrl=e+"Data/Breakpoints.js";this.HasBrowseSequences=X.documentElement.getAttribute("BrowseSequence")!=null;this.HasToc=X.documentElement.getAttribute("Toc")!=null;I.call(this,X);this.DefaultSkin=this.GetSkin($(X.documentElement).attr("SkinID"));this.SyncTOC=this.DefaultSkin!=null&&MadCap.String.ToBool(this.DefaultSkin.AutoSyncTOC,false);this.IndexPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.IndexPartialWordSearch,true);this.GlossaryPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.GlossaryPartialWordSearch,true);this.DisplayCommunitySearchResults=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.DisplayCommunitySearchResults,true);this.CommunitySearchResultsCount=3;if(this.DefaultSkin!=null){this.CommunitySearchResultsCount=MadCap.String.ToInt(this.DefaultSkin.CommunitySearchResultsCount,3)}var R=X.getElementsByTagName("Subsystems");if(R.length>0&&R[0].getElementsByTagName("Url").length>0){var W=X.getElementsByTagName("Subsystems")[0].getElementsByTagName("Url");for(var P=0;P<W.length;P++){var T=W[P];if(!T){continue}var L=T.getAttribute("Source");var N=L.substring(0,L.lastIndexOf("/")+1);var V=T.getAttribute("TocPath");var S=T.getAttribute("BrowseSequencePath");var U=new MadCap.WebHelp.HelpSystem(this,e+N,e+N+"Data/HelpSystem.xml",V,S);l.push(U)}}this.LoadBreakpoints(function(){d.LoadLanguage(function(){if(!d.IsAutoMerged&&d.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(d.GetPath()+"Service/Service.asmx/GetSubsystems",true,function(aa,Z){$.each(aa.documentElement.childNodes,function(ab,ac){if(ac.nodeName=="Subsystems"){$.each(ac.childNodes,function(ag,ah){if(ah.nodeName=="Url"){var af=ah.getAttribute("Source");var ad=af.substring(0,af.lastIndexOf("/")+1);if(ad){var ae=new MadCap.WebHelp.HelpSystem(d,e+ad,e+ad+"Data/HelpSystem.xml",null,null);ae.IsAutoMerged=true;l.push(ae)}}})}});Y(M,J)})}else{Y(M,J)}})})},null,this)};this.GetExists=function(){return b};this.GetMasterHelpsystem=function(){var J=this;for(var K=J.GetParentSubsystem();K!=null;K=K.GetParentSubsystem()){J=K}return J};this.GetParentSubsystem=function(){return r};this.GetPath=function(){return e};this.GetCurrentTopicPath=function(){return MadCap.Utilities.Url.GetDocumentUrl().ToRelative(MadCap.Utilities.Url.GetAbsolutePath(e)).FullPath};this.GetAbsolutePath=function(){if(o==null){var J=new MadCap.Utilities.Url(e);o=J.IsAbsolute?J.FullPath:new MadCap.Utilities.Url(document.location.href).Path}return o};this.GetContentPath=function(){return e+this.ContentFolder};this.GetSkin=function(J){return u.GetItem(J)};this.GetSkinByName=function(J){var M=this.GetSkins();for(var K=0;K<M.length;K++){var L=M[K];if(L.Name==J){return L}}return null};this.GetCurrentSkin=function(){var K=MadCap.Utilities.Url.GetDocumentUrl();var J=K.QueryMap.GetItem("skinName")||K.HashMap.GetItem("skinName");if(J){var L=this.GetSkin(J);if(!L){L=this.GetSkinByName(J)}return L}else{return this.DefaultSkin}};this.GetTocPath=function(J){return J=="toc"?w:k};this.GetFullTocPath=function(J,L){var M=this.GetHelpSystem(L);if(M==null){return null}var K=new Object();K.tocPath=this.GetTocPath(J);M.ComputeTocPath(J,K);return K.tocPath};this.GetTopicPath=function(J){var P=this.GetPath();var M=!this.IsRoot;var O=this.GetMasterHelpsystem();if(M&&!masterHelpsystem.MoveContentToRoot){P="../"+P}var N=(new MadCap.Utilities.Url(document.location.href)).ToPath();var L=N.CombinePath(P+"Data/").CombinePath(J);var K=L.ToRelative(N);if(MadCap.Utilities.HasRuntimeFileType("TriPane")&&!M&&!O.MoveContentToRoot){K=K.ToRelative(O.ContentFolder)}return K};this.GetPatchedPath=function(J){if(this.ReplaceReservedCharacters){J=MadCap.Utilities.Url.ReplaceReservedCharacters(J,"_")}if(this.MakeFileLowerCase){J=J.toLowerCase()}if(this.UseCustomTopicFileExtension){J=new MadCap.Utilities.Url(J).ToExtension(this.CustomTopicFileExtension).FullPath}return J};this.GetAbsoluteTopicPath=function(K){var J=new MadCap.Utilities.Url(K);var L=(new MadCap.Utilities.Url(document.location.href)).ToPlainPath();return L.CombinePath(this.GetTopicPath("../"+J.FullPath).FullPath)};this.ComputeTocPath=function(J,K){if(r){var L=this.GetTocPath(J);if(!MadCap.String.IsNullOrEmpty(L)){K.tocPath=K.tocPath?L+"|"+K.tocPath:L}r.ComputeTocPath(J,K)}};this.GetHelpSystem=function(K){var L=null;for(var J=0;J<l.length;J++){L=l[J].GetHelpSystem(K);if(L!=null){return L}}if(MadCap.String.StartsWith(K,e,false)){return this}return null};this.GetSubsystem=function(J){return l[J]};this.GetMergedAliasIDs=function(J){p.Load(function(){function P(R){for(var Q=0,S=R.length;Q<S;Q++){O[O.length]=R[Q]}M++;if(M==N+1){J(O)}}var O=new Array();var N=l.length;var M=0;var L=p.GetIDs();P(L);for(var K=0;K<N;K++){l[K].GetMergedAliasIDs(P)}})};this.GetMergedAliasNames=function(J){p.Load(function(){function O(R){for(var Q=0,S=R.length;Q<S;Q++){K[K.length]=R[Q]}M++;if(M==N+1){J(K)}}var K=new Array();var N=l.length;var M=0;var P=p.GetNames();O(P);for(var L=0,N=l.length;L<N;L++){l[L].GetMergedAliasNames(O)}})};this.LookupCSHID=function(K,J){p.Load(function(){function L(R){if(Q){return}N++;if(R.Found){Q=true;J(R);return}if(N==O){J(P)}}var P=p.LookupID(K);if(P.Found){P.Topic=d.GetPath()+P.Topic;J(P);return}if(l.length==0){J(P);return}var Q=false;var N=0;for(var M=0,O=l.length;M<O;M++){l[M].LookupCSHID(K,L)}})};this.GetTocFile=function(){return H};this.GetBrowseSequenceFile=function(){return s};this.IsMerged=function(){return(l.length>0)};this.IsRoot=function(){return r==null};this.IsTabletLayout=function(K){if(this.IsResponsive&&this.Breakpoints){var J=this.Breakpoints.mediums.Tablet;var L=this.Breakpoints.prop;if(L=="max-width"){if(!K){K=window.innerWidth}return K<=J}else{return window.matchMedia("("+L+": "+J+"px)").matches}}return false};this.LoadLanguage=function(L,J){var K=this;require([this.LanguageUrl],function(M){K.Language=M;L.call(J,M)})};this.LoadBreakpoints=function(L,J){if(this.IsResponsive&&this.IsRoot()){var K=this;require([this.BreakpointsUrl],function(M){K.Breakpoints=M;L.call(J,M)})}else{L.call(J,null)}};this.LoadConcepts=function(){var J=$.Deferred();require([e+"Data/Concepts.js"],function(K){A=K;J.resolve(A)});return J.promise()};this.LoadAllConcepts=function(J){function O(){L++;if(L==M+1){J()}}var L=0;var M=l.length;this.LoadConcepts().then(O);for(var K=0;K<M;K++){var N=l[K];if(!N.GetExists()){O();continue}N.LoadAllConcepts(O)}};this.GetConceptsLinks=function(K){var Q=$.Deferred();var P=[];if(this.IsWebHelpPlus){function J(Y,V){var T=Y.documentElement.getElementsByTagName("Url");var S=T.length;for(var W=0;W<S;W++){var X=T[W];var Z=X.getAttribute("Title");var U=X.getAttribute("Source");U=e+((U.charAt(0)=="/")?U.substring(1,U.length):U);P[P.length]={Title:Z,Link:U}}Q.resolve(P)}MadCap.Utilities.Xhr.CallWebService(e+"Service/Service.asmx/GetTopicsForConcepts?Concepts="+K,true,J)}else{function N(S){P=P.Union(S)}K=K.replace("\\;","%%%%%");if(K==""){Q.resolve(P)}else{var M=K.split(";");var R=[];R.push(this.GetConceptsLinksLocal(M).then(N));for(var O=0;O<l.length;O++){var L=l[O];if(L.GetExists()){R.push(L.GetConceptsLinks(K).then(N))}}$.when.apply(this,R).done(function(){Q.resolve(P)})}}return Q.promise()};this.GetConceptsLinksLocal=function(O){var K=[];var N=[];for(var L=0;L<O.length;L++){var M=O[L];M=M.replace("%%%%%",";");N.push(this.GetConceptLinks(M).then(function(P){K=K.concat(P)}))}var J=$.Deferred();$.when.apply(this,N).done(function(){J.resolve(K)});return J.promise()};this.LoadTopicChunk=function(K){var J=$.Deferred();MadCap.Utilities.Require([e+"Data/SearchTopic_Chunk"+K+".js"],function(L){J.resolve(L)});return J.promise()};this.GetSearchChunkIds=function(K){var J=$.Deferred();MadCap.Utilities.Require([e+"Data/Search.js"],function(N){var L=N.t;var O=[];for(var M=0;M<K.length;M++){O.push(MadCap.Utilities.GetChunkId(L,K[M],function(Q,P){if(Q<P){return -1}else{if(Q===P){return 0}else{return 1}}}))}J.resolve(O)});return J.promise()};this.GetConceptLinks=function(L){var K=$.Deferred();var J=this;this.LoadConcepts().done(function(){var M=[];var N=A[L];if(!N){K.resolve(M)}else{J.GetSearchChunkIds(N).then(function(R){var Q=[];for(var P=0;P<R.length;P++){var O=R[P];Q.push(J.LoadTopicChunk(O).then(function(U){for(var T=0;T<N.length;T++){var S=U[N[T]];if(S){S.Url=J.GetTopicPath(S.u);M.push(S)}}}))}$.when.apply(this,Q).done(function(){K.resolve(M)})})}});return K.promise()};this.LoadToc=function(L,M,J){var K=this;var N=K[L];if(typeof N!=="undefined"){M.call(J,N)}else{this.GetToc(L,function(O){M.call(J,O)})}};this.GetToc=function(M,J){var K=this;var L=this[M+"Url"];require([L],function(R){if(typeof R=="undefined"){J(R);return}K[M]=R;R.type=M;R.helpSystem=K;R.chunks=[];R.entries=[];R.nodes={};var O=new MadCap.Utilities.Url(L).ToFolder();for(var U=0;U<R.numchunks;U++){R.chunks[U]={path:O.AddFile(R.prefix+U+".js").FullPath,loaded:false}}var Q=R.tree;var V={};R.automerge=R.tree;while(Q!=null){Q.toc=R;Q.childrenLoaded=false;R.nodes[Q.i]=Q;if(typeof Q.m!=="undefined"){V[Q.m]=Q}if(typeof Q.a!=="undefined"){R.automerge=Q}if(typeof Q.n!=="undefined"){for(var T=0;T<Q.n.length;T++){Q.n[T].parent=Q;if(T<Q.n.length-1){Q.n[T].next=Q.n[T+1]}if(T>0){Q.n[T].previous=Q.n[T-1]}}}Q=B(Q)}var P=[];var S=false;for(var T=0;T<l.length;T++){var N=l[T];if(N.GetExists()){if(!N.IsAutoMerged){N.MergeNode=V[T]}else{S=true}if(N.IsAutoMerged||typeof N.MergeNode!=="undefined"){P.push(N)}}else{f(V[T])}}if(!S&&R.automerge.a=="replace"){f(R.automerge)}if(P.length==0){J(R);return}MadCap.Utilities.AsyncForeach(P,function(W,X){i(R,W,X)},function(){J(R)})})};function f(N){var L=N.parent;var M=N.previous;var K=N.next;if(M){M.next=K;N.previous=null}if(K){K.previous=M;N.next=null}if(L){var J=N.parent.n.indexOf(N);L.n.splice(J,1);N.parent=null}}function B(K){var J=null;if(typeof K.n!="undefined"){J=K.n[0]}else{if(typeof K.next!="undefined"){J=K.next}else{J=K;while(typeof J.parent!="undefined"){if(typeof J.parent.next!="undefined"){J=J.parent.next;break}else{J=J.parent}}if(typeof J.parent=="undefined"){J=null}}}return J}function j(K){var J=null;if(typeof K.previous!="undefined"){J=K.previous;while(typeof J.n!=="undefined"&&J.n.length>0){J=J.n[J.n.length-1]}}else{if(typeof K.parent!="undefined"){J=K.parent}}return J}function y(P,O){var N="";var M=-1;var L=null;if(P.n&&P.n.length>0){N=P.toc.entries[P.i].title;if(O){N=encodeURIComponent(N)}M=0}else{M=P.parent.n.indexOf(P)+1}if(N.length>0){N+="|"}N+=("_____"+M);for(var J=P.parent;J&&typeof J.i!=="undefined";J=J.parent){if(N==null){N=""}if(N.length>0){N="|"+N}var K=J.toc.entries[J.i].title;if(O){K=encodeURIComponent(K)}N=K+N}return N}function i(K,L,J){L.GetToc(K.type,function(P){if(typeof P=="undefined"){J();return}var O=L.IsAutoMerged?K.automerge:L.MergeNode;var W=P.tree;if(typeof W.n!=="undefined"){var N=O.r==1||(L.IsAutoMerged&&O.a=="replace");var U=N||(L.IsAutoMerged&&(O.a=="before-head"||O.a=="after-head"));var Q=N||(L.IsAutoMerged&&(O.a=="before-head"||O.a=="after-tail"));var V=Q?O.parent:O;if(typeof V.n=="undefined"){V.n=[]}var R=Q?V.n.indexOf(O)+(U?0:1):U?0:V.n.length;var M=W.n.length;for(var S=0;S<M;S++){W.n[S].parent=V;V.n.splice(R+S,0,W.n[S])}if(N){V.n.splice(R+M,1)}if(R>0){V.n[R].previous=V.n[R-1];V.n[R-1].next=V.n[R]}var T=R+M-(N?1:0)-1;if(T>=0&&T+1<V.n.length){V.n[T].next=V.n[T+1];V.n[T+1].previous=V.n[T]}if(L.IsAutoMerged){K.automerge=V.n[R+M-1];K.automerge.a="after-tail"}}J()})}this.LoadTocChunk=function(L,J,K){require([L.chunks[J].path],function(M){if(!L.chunks[J].loaded){for(var O in M){for(var N=0;N<M[O].i.length;N++){L.entries[M[O].i[N]]={link:O,title:M[O].t[N],bookmark:M[O].b[N]}}}L.chunks[J].loaded=true}if(K){K(M)}})};this.GetTocEntryHref=function(W,O,S){var N=W.toc;var R=N.entries[W.i];var V=R.link+R.bookmark;var L=null;if(typeof W.m=="undefined"&&V!="___"){var K=null;var Q=new MadCap.Utilities.Url(V);var J=N.helpSystem;var P=J.GetPath();var U=J.GetMasterHelpsystem().GetContentPath();var M=typeof W.f!="undefined";if(!Q.IsAbsolute){if(!MadCap.String.IsNullOrEmpty(P)){Q=new MadCap.Utilities.Url(P).CombinePath(V);K=Q.ToRelative(U)}else{K=Q.ToRelative("/"+U)}}else{K=Q}if(M||!S){if(K.IsAbsolute){L=K.FullPath}else{L=U+K.FullPath}}else{L="#"+K.FullPath}}if(L!=null&&O){var T=y(W,true);L+=encodeURIComponent("?"+O+"Path="+T)}return L};this.FindTocNode=function(L,J,K){d.FindNode("Toc",L,J,K)};this.FindBrowseSequenceNode=function(L,J,K){d.FindNode("BrowseSequences",L,J,K)};this.FindNode=function(J,L,K,M){d.LoadToc(J,function(S){var O=new MadCap.Utilities.Url(d.GetMasterHelpsystem().GetContentPath());var P=K;var R=0;var N;if(!K.IsAbsolute){var P=!MadCap.String.IsNullOrEmpty(O.FullPath)?O.CombinePath(K):K;P=P.ToRelative(d.GetPath());P=new MadCap.Utilities.Url("/"+P.FullPath)}for(var Q=1;Q<S.chunkstart.length;Q++){if(S.chunkstart[Q]<=P.PlainPath){R++}}d.LoadTocChunk(S,R,function(T){var V=T[P.PlainPath];if(typeof V!=="undefined"){var W=null;if(!N){N=S.nodes[V.i[0]]}if(L){for(var U=0;U<V.i.length;U++){if(y(S.nodes[V.i[U]],false)==L){W=V.i[U];break}}}else{for(var U=0;U<V.i.length;U++){if(V.b[U].toLowerCase()==P.Fragment.toLowerCase()){W=V.i[U];break}}}if(W!=null){M(S.nodes[W]);return}}if(l.length>0){MadCap.Utilities.AsyncForeach(l,function(X,Y){X.FindNode(J,L,K,function(Z){if(typeof Z!=="undefined"){M(Z);return}Y()})},function(){M(N)})}else{M(N)}})})};this.LoadGlossary=function(L,J){if(typeof this.Glossary!="undefined"){L.call(J,this.Glossary);return}var K=this;this.GetGlossary(function(M){if(M&&M.terms){M.termMap=Object.create(null);for(var O=0;O<M.terms.length;O++){var N=M.terms[O];M.termMap[N.t.toLowerCase()]=N}}K.Glossary=M;L.call(J,M)})};this.GetGlossary=function(J){var K=this;require([this.GlossaryUrl],function(L){function N(){P++;if(P==Q){J(L)}}if(typeof L=="undefined"){J(L);return}var P=0;var Q=0;L.chunks=[];var O=new MadCap.Utilities.Url(d.GlossaryUrl).ToFolder();for(var S=0;S<L.numchunks;S++){L.chunks.push({helpSystem:K,path:O.AddFile(L.prefix+S+".js").FullPath})}for(var M=0;M<l.length;M++){var R=l[M];if(!R.GetExists()){continue}Q++}if(Q==0){J(L);return}for(var M=0;M<l.length;M++){var R=l[M];if(!R.GetExists()){continue}a(L,R,N)}})};this.SearchGlossary=function(L){var K=$.Deferred();var J=this;this.LoadGlossary(function(M){var P=false;if(M&&M.termMap){var O=M.termMap[L.toLowerCase()];P=typeof O!="undefined";if(P){var N=M.chunks[O.c];require([N.path],function(S){var R={term:O.t,definition:S[O.t].d,link:S[O.t].l};if(R.link){var T=N.helpSystem;var Q=(new MadCap.Utilities.Url("../")).CombinePath(R.link).FullPath;R.link=T.GetTopicPath(Q).FullPath;T.SearchDB.LoadTopicByUrl(Q).done(function(V,U){if(U){R.abstractText=U.a}K.resolve(R)})}else{K.resolve(R)}})}}if(!P){K.resolve()}},this);return K.promise()};this.LoadIndex=function(L,J){if(typeof this.Index!=="undefined"){L.call(J,this.Index);return}var K=this;this.GetIndex(function(M){K.Index=M;L.call(J,M)})};this.GetIndex=function(J){var K=this;require([this.IndexUrl],function(M){function L(){P++;if(P==Q){J(M)}}if(typeof M=="undefined"){J(M);return}var P=0;var Q=0;M.chunks=[];var O=new MadCap.Utilities.Url(d.IndexUrl).ToFolder();for(var S=0;S<M.numchunks;S++){M.chunks.push({helpSystem:K,path:O.AddFile(M.prefix+S+".js").FullPath})}for(var N=0;N<l.length;N++){var R=l[N];if(!R.GetExists()){continue}Q++}if(Q==0){J(M);return}for(var N=0;N<l.length;N++){var R=l[N];if(!R.GetExists()){continue}D(M,R,L)}})};this.LoadRootIndexEntry=function(J,K){if(J.loaded){if(K){K(J)}return}this.LoadIndex(function(L){var M=typeof J.c=="number"?[J.c]:J.c;MadCap.Utilities.AsyncForeach(M,function(P,O){var N=L.chunks[P];require([N.path],function(R){var Q=R[J.t];d.SetIndexEntryHelpSystem(Q,N.helpSystem);d.MergeIndexEntries(J,Q);O()})},function(){d.LoadIndexEntry(J);if(K){K(J)}})})};this.SetIndexEntryHelpSystem=function(J,K){if(J.l){$.each(J.l,function(L,M){M.helpSystem=K})}if(J.e){$.each(J.e,function(L,M){d.SetIndexEntryHelpSystem(M,K)})}};this.LoadIndexEntry=function(K){if(K.l){var J=[];$.each(K.l,function(M,L){var N={Title:L.t,Link:L.helpSystem.GetTopicPath(".."+L.u).FullPath};J[J.length]=N});K.linkList=d.SortLinkList(J)}if(K.e){$.each(K.e,function(L,M){d.LoadIndexEntry(M)})}K.loaded=true};this.MergeIndexEntries=function(K,J){if(J.l){if(typeof K.l=="undefined"){K.l=J.l}else{K.l=K.l.concat(J.l)}}if(J.r){if(typeof K.r=="undefined"){K.r=J.r}else{if(K.r=="SeeAlso"||J.r=="SeeAlso"){K.r="SeeAlso"}}if(typeof K.f=="undefined"){K.f=J.f}else{var M=K.f.split(";");var L=J.f.split(";");$.each(L,function(O,N){if($.inArray(M,N)){M.push(N)}});M.sort(function(Q,O){var P=Q.toLowerCase();var N=O.toLowerCase();return P<N?-1:P>N?1:0});K.f=M.join("; ")}}if(J.e){if(typeof K.e=="undefined"){K.e={}}$.each(J.e,function(N,O){if(typeof K.e[N]!=="undefined"){d.MergeIndexEntries(K.e[N],O)}else{K.e[N]=O}})}};this.FindIndexEntry=function(K,J){d.LoadIndex(function(L){if(!L.entries){L.entries={};$.each(L.terms,function(P,Q){L.entries[Q.t]=Q})}var N=K.split(":");var O=N.length;var M=L.entries[N[0]];if(M){d.LoadRootIndexEntry(M,function(Q){var R=Q;for(var P=1;P<O;P++){R=R.e[N[P]];if(!R){break}}if(J){J(Q,R)}})}else{if(J){J()}}})};this.SortLinkList=function(J){J.sort(function(L,K){var N=L.Title.toLowerCase();var M=K.Title.toLowerCase();return N<M?-1:N>M?1:0});return J};this.GetSearchDBs=function(J){var L=new Array();var K=this;require([e+"Data/Search.js"],function(Q){function N(S){if(S!=null){for(var R=0;R<S.length;R++){L[L.length]=S[R]}}O++;if(O==P){J(L)}}var O=0;var P=l.length;var M=new MadCap.WebHelp.Search.SearchDB(K);K.SearchDB=M;L[L.length]=M;M.Load(Q,function(){var R=Q.pm;if(R||P==0){J(L)}else{for(var S=0;S<P;S++){var T=l[S];if(!T.GetExists()){N(null);continue}T.GetSearchDBs(N)}}})})};this.GetConcepts=function(){return A};this.GetSearchFilters=function(){return q.map};this.ParseSearchFilterDoc=function(P){filterMap=Object.create(null);if(P!=null){var O=P.getElementsByTagName("SearchFilter");for(var L=0;L<O.length;L++){var M=O[L];var K=M.getAttribute("Name");var J=M.getAttribute("Order");var N=M.getAttribute("Concepts");if(!N){continue}filterMap[K]={c:N,o:J,group:0}}}return filterMap};this.LoadSearchFiltersLocal=function(){var J=$.Deferred();require([this.SearchFilterSetUrl],function(L){var K=null;if(L){K={map:L,count:1}}J.resolve(K)});return J.promise()};this.LoadSearchFilters=function(){var L=$.Deferred();if(!this.IsWebHelpPlus){function K(V){if(V){if(!J){J=V;for(var S in V.map){V.map[S].group=0}}else{for(var S in V.map){if(!J.map[S]){J.map[S]=V.map[S];J.map[S].group+=J.count}else{var U=J.map[S];var T=V.map[S];var R=U.c.split(";");var Q=T.c.split(";");U.c=R.Union(Q).join(";");if(MadCap.String.IsNullOrEmpty(U.cm)){U.cm=T.cm}}}J.count+=V.count}}}var J;var O=[];O.push(this.LoadSearchFiltersLocal().then(K));for(var N=0;N<l.length;N++){var P=l[N];if(P.GetExists()){O.push(P.LoadSearchFilters().then(K))}}$.when.apply(this,O).done(function(){q=J;L.resolve(J)})}else{var M=this;MadCap.Utilities.Xhr.CallWebService(e+"Service/Service.asmx/GetSearchFilters",true,function(R,Q){var S=M.ParseSearchFilterDoc(R);L.resolve({map:S})})}return L.promise()};this.AdvanceTopic=function(J,O,N,K,L){var M=null;d.FindNode(J,N,K,function(Q){if(Q){function P(S,R){S=R=="next"?B(S):j(S);if(S&&typeof S.i!=="undefined"){d.LoadTocChunk(S.toc,S.c,function(T){var V=S.toc.entries[S.i];var U=d.GetTocEntryHref(S,J,true);if(U){if(MadCap.String.StartsWith(U,"#")){U=U.substring(1)}L(U)}else{P(S,R)}})}}P(Q,O)}})};this.SetBrowseSequencePath=function(K,J){var L=$(".current-topic-index-button");if(K!=null){this.FindBrowseSequenceNode(K,J,function(M){if(M&&M.parent){L.removeClass("disabled");$(".sequence-index").text(M.parent.n.indexOf(M)+1);$(".sequence-total").text(M.parent.n.length)}else{L.addClass("disabled")}})}else{L.addClass("disabled")}};this.GetSkins=function(){var J=[];u.ForEach(function(K,L){J.push(L)});return J};function F(M,K){var L=M.documentElement.getAttribute(K);if(L==null){return null}var J=new MadCap.Utilities.Url(e);if(!J.IsAbsolute){return e+L}return J.AddFile(L).ToRelative(document.location.href).FullPath}function I(Y){var Z=$("CatapultSkin",Y.documentElement);for(var U=0,Q=Z.length;U<Q;U++){var V=Z[U];var R=$(V);var O=R.attr("SkinID");var X={};for(var T=0,N=V.attributes.length;T<N;T++){var W=V.attributes[T];X[W.name]=W.value}var P=R.children();for(var T=0,N=P.length;T<N;T++){var J=P[T];var L=J.nodeName;var M={};X[L]=M;for(var S=0,K=J.attributes.length;S<K;S++){var W=J.attributes[S];M[W.name]=W.value}}u.Add(O,X)}}function x(L,M){if(L.nodeName.toLowerCase()=="madcap:glossarychunkref"){var O=$(L);var J=O.attr("src");if(!MadCap.String.IsNullOrEmpty(J)){var K=new MadCap.Utilities.Url(M).CombinePath("../../Data/").CombinePath(J);O.attr("src","../"+K.FullPath)}}else{var N=L.getElementsByTagName("a")[0];var J=$(N).attr("href");if(!MadCap.String.IsNullOrEmpty(J)){var K=new MadCap.Utilities.Url(M).CombinePath("../../Content/").CombinePath(J);$(N).attr("href","../"+K.FullPath)}}}function g(N){for(var L=0;L<N.childNodes.length;L++){var J=N.childNodes[L];if(J.nodeName=="Entries"){for(var K=0;K<J.childNodes.length;K++){g(J.childNodes[K])}}else{if(J.nodeName=="Links"){for(var K=0;K<J.childNodes.length;K++){if(J.childNodes[K].nodeType==1){var M=MadCap.Dom.GetAttribute(J.childNodes[K],"Link");M=e+((M.charAt(0)=="/")?M.substring(1,M.length):M);J.childNodes[K].setAttribute("Link",M)}}}}}}function z(K,J){if(!J){return}for(var L=0;L<J.length;L++){K[K.length]=J[L]}}function a(K,L,J){L.GetGlossary(function(Q){if(typeof Q=="undefined"){J();return}K.chunks=K.chunks.concat(Q.chunks);for(var P=0,N=0;P<K.terms.length&&N<Q.terms.length;){var O=K.terms[P];var M=Q.terms[N];var T=O.t;var R=M.t;if(T.toLowerCase()==R.toLowerCase()){P++;N++}else{if(T.toLowerCase()>R.toLowerCase()){M.c+=K.numchunks;K.terms.splice(P,0,M);N++}else{P++}}}for(;N<Q.terms.length;N++){var S=Q.terms[N];S.c+=K.numchunks;K.terms.push(S)}K.numchunks=K.chunks.length;J()})}function D(L,K,J){K.GetIndex(function(R){if(typeof R=="undefined"){J();return}L.chunks=L.chunks.concat(R.chunks);for(var P=0,O=0;P<L.terms.length&&O<R.terms.length;){var T=L.terms[P];var S=R.terms[O];var N=T.s||T.t;var M=S.s||S.t;if(N==M&&T.t==S.t){if(typeof T.c=="number"){T.c=[T.c]}var Q=S.c;if(typeof S.c=="number"){Q=[S.c]}$.each(Q,function(W,V){T.c.push(V+L.numchunks)});T.$=(T.$===1&&S.$===1)?1:0;P++;O++}else{if(N.toLowerCase()>M.toLowerCase()||(N.toLowerCase()==M.toLowerCase()&&T.t.toLowerCase()>S.t.toLowerCase())){S.c+=L.numchunks;L.terms.splice(P,0,S);O++}else{P++}}}for(;O<R.terms.length;O++){var U=R.terms[O];U.c+=L.numchunks;L.terms.push(U)}L.numchunks=L.chunks.length;J()})}};(function(){MadCap.WebHelp.HelpSystem.LoadHelpSystem=MadCap.Utilities.Memoize(function(b){var a=$.Deferred();var c=new MadCap.WebHelp.HelpSystem(null,null,b,null,null);c.Load(function(){a.resolve(c)});return a.promise()})})();MadCap.WebHelp.TocFile=function(r,l){var b=this;var h=r;var e=l;var c=false;var i=null;var n=new Array();var j=null;var o=null;var a=new Array();(function(){})();this.Init=function(t){if(c){if(t!=null){t()}return}if(t!=null){n.push(t)}var v=null;if(l==MadCap.WebHelp.TocFile.TocType.Toc){v="Toc.xml"}else{if(l==MadCap.WebHelp.TocFile.TocType.BrowseSequence){v="BrowseSequences.xml"}}this.LoadToc(h.GetPath()+"Data/"+v,u);function u(w){c=true;i=w.documentElement;g()}};this.LoadToc=function(u,t){if(e==MadCap.WebHelp.TocFile.TocType.Toc&&h.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(h.GetPath()+"Service/Service.asmx/GetToc",true,w,null)}else{if(e==MadCap.WebHelp.TocFile.TocType.BrowseSequence&&h.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(h.GetPath()+"Service/Service.asmx/GetBrowseSequences",true,w,null)}else{var v=(u.indexOf("/")==-1)?h.GetPath()+"Data/"+u:u;MadCap.Utilities.Xhr.Load(v,false,w,null,null)}}function w(y,x){if(!y||!y.documentElement){if(t!=null){t(y)}return}if(t!=null){t(y)}}};this.LoadChunk=function(u,v,t){var w=(v.indexOf("/")==-1)?h.GetPath()+"Data/"+v:v;MadCap.Utilities.Xhr.Load(v,true,x,null,null);function x(E,z){if(!E||!E.documentElement){if(t!=null){t(u)}return}u.removeAttribute("Chunk");var y=E.documentElement;for(var B=0,D=y.childNodes.length;B<D;B++){var A=y.childNodes[B];if(A.nodeType!=1){continue}var C=null;if(typeof(E.importNode)=="function"){C=E.importNode(A,true)}else{C=A.cloneNode(true)}u.appendChild(C)}if(t!=null){t(u)}}};this.LoadMerge=function(y,t){var x=MadCap.Dom.GetAttributeInt(y,"MergeHint",-1);if(x==-1){t(y,false,null,null);return}y.removeAttribute("MergeHint");var A=k(y);var u=A.GetSubsystem(x);var v=MadCap.Dom.GetAttributeBool(y,"ReplaceMergeNode",false);if(!v){y.setAttribute("ownerHelpSystemIndex",a.length)}a[a.length]=u;var z=u.GetPath()+"Data/"+(e==MadCap.WebHelp.TocFile.TocType.Toc?"Toc.xml":"BrowseSequences.xml");var B=MadCap.Utilities.Xhr.Load(z,true,w);function w(N,K){if(!N||!N.documentElement){if(t!=null){t(y,false,null,null)}return}var G=N.documentElement;var J=null;var H=true;var D=null;var E=null;var L=y.ownerDocument;for(var I=0,F=G.childNodes.length;I<F;I++){var C=G.childNodes[I];if(C.nodeType!=1){continue}var M=null;if(typeof(L.importNode)=="function"){M=L.importNode(C,true)}else{M=C.cloneNode(true)}if(v){M.setAttribute("ownerHelpSystemIndex",a.length-1);if(H){H=false;y.parentNode.replaceChild(M,y);D=M;E=D}else{J.parentNode.insertBefore(M,J.nextSibling);E=M}J=M}else{y.appendChild(M)}}if(t!=null){t(y,v,D,E)}}};this.AdvanceTopic=function(x,w,u,v){this.GetTocNode(w,u,t);function t(y){if(y==null){v(null);return}var z=null;q(x,y,A);function A(E){var B=null;if(E!=null){B=MadCap.Dom.GetAttribute(E,"Link");B=B.substring("/".length);var H=new MadCap.Utilities.Url(B);var G=null;if(e==MadCap.WebHelp.TocFile.TocType.Toc){G="TocPath"}else{if(e==MadCap.WebHelp.TocFile.TocType.BrowseSequence){G="BrowseSequencePath"}}var D=m(E,false);var C=H.ToQuery(G+"="+encodeURIComponent(D));B=C.FullPath;var F=k(E);B=F.GetPath()+B;v(B)}else{v(B)}}}};this.GetRootNode=function(u){this.Init(t);function t(){u(i)}};this.GetTocNode=function(v,t,x){this.Init(w);function w(){j=v;o=t;var F=(v=="")?new Array(0):v.split("|");var B=-1;if(F.length>0){var z=F[F.length-1];if(MadCap.String.StartsWith(z,"_____")){B=parseInt(z.substring("_____".length));F.splice(F.length-1,1)}}var H=i;for(var D=0,A=F.length;D<A;D++){if(y(H)){return}if(u(H)){return}H=d(H,decodeURIComponent(F[D]))}if(H==null){x(null);return}if(y(H)){return}if(u(H)){return}if(B>=0){if(B==0){C=H}else{C=$(H).children("TocEntry")[B-1]}}else{var E=k(H);var G=t.ToRelative(new MadCap.Utilities.Url(E.GetPath()));var C=s(H,G.FullPath.toLowerCase(),true);if(!C){C=s(H,G.PlainPath.toLowerCase(),false)}}j=null;o=null;x(C)}function y(z){var A=MadCap.Dom.GetAttribute(z,"Chunk");if(A!=null){b.LoadChunk(z,A,function(B){b.GetTocNode(j,o,x)});return true}return false}function u(z){var A=$(z).attr("MergeHint")||-1;if(A>=0){b.LoadMerge(z,function(B){b.GetTocNode(j,o,x)});return true}return false}};this.GetEntrySequenceIndex=function(u,t,w){this.GetTocNode(u,t,v);function v(y){var x=-1;if(y!=null){x=f(y)}w(x)}};this.GetIndexTotalForEntry=function(u,t,w){this.GetTocNode(u,t,v);function v(y){var z=-1;if(y!=null){var x=y;while(x.parentNode!=i){x=x.parentNode}z=MadCap.Dom.GetAttributeInt(x,"DescendantCount",-1)}w(z)}};function g(){for(var t=0,u=n.length;t<u;t++){n[t]()}}function d(u,w){var t=null;for(var v=0;v<u.childNodes.length;v++){if(u.childNodes[v].nodeName=="TocEntry"&&MadCap.Dom.GetAttribute(u.childNodes[v],"Title")==w){t=u.childNodes[v];break}}return t}function s(v,t,x){var y=null;var B=MadCap.Dom.GetAttribute(v,"Link");if(B!=null){B=B.substring("/".length);B=B.replace(/%20/g," ");B=B.toLowerCase()}if(B==t){y=v}else{for(var w=0;w<v.childNodes.length;w++){var z=v.childNodes[w];if(z.nodeType!=1){continue}var A=MadCap.Dom.GetAttribute(z,"Link");if(A==null){continue}A=A.substring("/".length);A=A.replace(/%20/g," ");A=A.toLowerCase();if(!x){var C=A.indexOf("#");if(C!=-1){A=A.substring(0,C)}var u=A.indexOf("?");if(u!=-1){A=A.substring(0,u)}}if(A==t){y=z;break}}}return y}function q(w,t,x){if(w=="previous"){v(t)}else{if(w=="next"){z(t)}}function A(F){var B=null;if(F!=null){var E=MadCap.Dom.GetAttribute(F,"Link");if(E==null){q(w,F,x);return}var C=new MadCap.Utilities.Url(E);var D=C.Extension.toLowerCase();var G=h.GetMasterHelpsystem();if(G.UseCustomTopicFileExtension){if(D!=G.CustomTopicFileExtension){q(w,F,x);return}}else{if(D!="htm"&&D!="html"){q(w,F,x);return}}B=F}x(B)}function v(E){function F(H){var G=p(H,"TocEntry");if(G==null){D=H}else{D=G;if(y(G,F)){return}if(u(G,C)){return}}A(D)}function C(H,I,J,G){if(I){F(G)}else{F(H)}}var D=null;for(var B=E.previousSibling;B!=null;B=B.previousSibling){if(B.nodeName=="TocEntry"){D=B;break}}if(D!=null){if(y(D,F)){return}if(u(D,C)){return}F(D);return}else{if(E.parentNode.nodeType==1){D=E.parentNode}}A(D)}function z(D){function E(H){var G=$(H).children("TocEntry")[0];for(var F=H;F!=null&&G==null;F=F.parentNode){G=$(F).next("TocEntry")[0]}A(G)}function C(G,H,I,F){if(H){A(I);return}E(G)}var B=null;if(y(D,E)){return}if(u(D,C)){return}E(D)}function y(C,B){var D=MadCap.Dom.GetAttribute(C,"Chunk");if(D!=null){b.LoadChunk(C,D,B);return true}return false}function u(C,B){var D=$(C).attr("MergeHint")||-1;if(D>=0){b.LoadMerge(C,B);return true}return false}}function p(t,w){var v=$(t).children(w+":last")[0];if(v!=null){var u=p(v,w);if(u!=null){return u}return v}return null}function k(u){var w=null;var t=u;while(true){if(t==t.ownerDocument.documentElement){w=h;break}var v=MadCap.Dom.GetAttributeInt(t,"ownerHelpSystemIndex",-1);if(v>=0){w=a[v];break}t=t.parentNode}return w}function m(u){var x="";var w=-1;var v=$(u).children("TocEntry")[0];if(v!=null){x=encodeURIComponent(MadCap.Dom.GetAttribute(u,"Title"));w=0}else{w=$(u).index()+1}if(x.length>0){x+="|"}x+=("_____"+w);for(var t=u.parentNode;t!=null&&t.parentNode.nodeType==1;t=t.parentNode){if(x==null){x=""}if(x.length>0){x="|"+x}x=encodeURIComponent(MadCap.Dom.GetAttribute(t,"Title"))+x}return x}function f(w){if(w.parentNode==w.ownerDocument.documentElement){return 0}var v=0;var z=MadCap.Dom.GetAttribute(w,"Link");if(z!=null){v++}for(var t=w.previousSibling;t!=null;t=t.previousSibling){if(t.nodeType!=1){continue}var y=MadCap.Dom.GetAttributeInt(t,"DescendantCount",0);v+=y;var z=MadCap.Dom.GetAttribute(t,"Link");if(z!=null){var u=new MadCap.Utilities.Url(z);var x=u.Extension.toLowerCase();if(x=="htm"||x=="html"){v++}}}return v+f(w.parentNode)}};MadCap.WebHelp.TocFile.TocType={Toc:0,BrowseSequence:1};MadCap.WebHelp.AliasFile=function(h,a,e){var d=null;var f=a;var i=null;var g=null;(function(){})();this.Load=function(j){MadCap.Utilities.Xhr.Load(h,true,function k(l){if(l){d=l.documentElement}j()})};this.GetIDs=function(){var j=new Array();c();g.ForEach(function(k,l){j[j.length]=k;return true});return j};this.GetNames=function(){var j=new Array();c();i.ForEach(function(k,l){j[j.length]=k;return true});return j};this.LookupID=function(o){var l=false;var j=null;var m=null;if(o){if(typeof(o)=="string"&&o.indexOf(".")!=-1){var k=o.indexOf("|");if(k!=-1){j=o.substring(0,k);m=o.substring(k+1)}else{j=o}l=true}else{var n=b(o);if(n!=null){l=true;j=n.Topic;m=n.Skin}}}else{l=true}if(j){j=f.ContentFolder+j}return{Found:l,Topic:j,Skin:m}};function b(k){var j=null;c();if(i!=null){if(typeof(k)=="string"){j=i.GetItem(k);if(j==null){j=g.GetItem(k)}}else{if(typeof(k)=="number"){j=g.GetItem(k.toString())}}}return j}function c(){if(i==null){if(d){i=new MadCap.Utilities.Dictionary(true);g=new MadCap.Utilities.Dictionary();var p=d.getElementsByTagName("Map");for(var m=0;m<p.length;m++){var k=p[m].getAttribute("Link");var o=p[m].getAttribute("Skin");var l={Topic:k,Skin:o};var j=p[m].getAttribute("Name");if(j!=null){i.Add(j,l)}var n=p[m].getAttribute("ResolvedId");if(n!=null){g.Add(n,l)}}}}}};MadCap.WebHelp.IndexEntry=function(g,f){var e=MadCap.Dom.GetChildNodeByTagName(g,"Links",0).childNodes;var d=e.length;var b=0;this.Term=MadCap.Dom.GetAttribute(g,"Term");this.IndexLinks=new Array();this.Level=f;this.GeneratedReferenceType=MadCap.Dom.GetAttribute(g,"GeneratedReferenceType");for(var c=0;c<d;c++){var a=e[c];if(a.nodeType!=1){continue}this.IndexLinks[b]=new MadCap.WebHelp.IndexLink(a);b++}};MadCap.WebHelp.IndexLink=function(a){this.Title=MadCap.Dom.GetAttribute(a,"Title");this.Link=MadCap.Dom.GetAttribute(a,"Link")};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){if(!MadCap.Utilities.HasRuntimeFileType("Default")){return}var Q=MadCap.Utilities.HasRuntimeFileType("TriPane");var a=Q||MadCap.Utilities.IsRuntimeFileType("Default");var m=MadCap.Utilities.HasRuntimeFileType("SkinPreview");var o=null;var at="search-";var K=null;function ap(aW){MadCap.DEBUG.Log.AddLine(window.name+"onload");MadCap.DEBUG.Log.AddLine(window.name+"hash: "+document.location.hash);MadCap.DEBUG.Log.AddLine(window.name+"search: "+document.location.search);if($.browser.msie&&$.browser.version<=9){var aT=$("#search-field");if(aT.css("direction")=="rtl"){aT.css({"border-top-left-radius":aT.css("border-top-right-radius"),"border-top-right-radius":aT.css("border-top-left-radius"),"border-bottom-left-radius":aT.css("border-bottom-right-radius"),"border-bottom-right-radius":aT.css("border-bottom-left-radius")})}var aX=$("#contentBody");if(aX.css("direction")=="rtl"){aX.css({"border-top-left-radius":aX.css("border-top-right-radius"),"border-top-right-radius":aX.css("border-top-left-radius")})}}$("input, textarea").placeholder();$(".tabs .tabs-nav li").click(x);$("ul.navigation ul li").mouseenter(u);$("#home").click(G);$("nav.tab-bar a, a.homeLink, a.GenConceptText, a.GlossaryPageLink").click(MadCap.Utilities.Url.OnNavigateTopic);$(".search-submit").click(function(aY){ak(aY)});$("#search-field, #search-field-sidebar, .search-field").keypress(function(aY){if(aY.which!=13){return}ak(aY);aY.preventDefault()});$(".search-filter").click(function(aZ){var a0=$(this);var aY=$(".search-filter-content",this);if(a0.hasClass("open")){k(0,0,aY,a0)}else{$(this).addClass("open");if(window.PIE){$(".search-submit-wrapper").each(function(){PIE.detach(this);PIE.attach(this)})}aY.fadeIn(200);aY.css("max-height",$(window).height()-aY.offset().top)}});if(!$.browser.mobile){$(".search-filter").mouseenter(function(aY){clearTimeout(K)});$(".search-filter").mouseleave(function(aZ){var aY=$(this);var a0=$(".search-filter-content",this);k(200,500,a0,aY)})}$("#navigationResizeBar").mousedown(aq);$("#show-hide-navigation").click(I);Z(parseInt($("#navigation").css("width")));var aV=$("title");aV.attr("data-title",document.title);if(Q){$(".print-button").click(function(aY){if(!m){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"print")}});$(".expand-all-button").click(function(aZ){var aY=$(this);if(aY.hasClass("expand-all-button")){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"expand-all")}else{if(aY.hasClass("collapse-all-button")){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"collapse-all")}}MadCap.Utilities.ToggleButtonState(this)});$(".remove-highlight-button").click(function(aY){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"remove-highlight")});$("#topic").load(function(){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-title",null,function(aZ){var aY=aV.attr("data-title");var a0=aY;if(!MadCap.String.IsNullOrEmpty(aY)){a0+=" - "}document.title=a0+aZ[0]});aR=null;aF();aH()})}$(".previous-topic-button").click(function(aY){ag()});$(".next-topic-button").click(function(aY){D()});$(".side-menu-button").click(function(aY){aY.preventDefault();$(".off-canvas").toggleClass("active")});o=$(document).find(".tab")[0];var aU=$(document.documentElement).attr("data-mc-path-to-help-system");var aS="Data/HelpSystem.xml";if(aU){aS=aU+aS}if(MadCap.WebHelp&&MadCap.WebHelp.HelpSystem){MadCap.WebHelp.HelpSystem.LoadHelpSystem(aS).done(function(aZ){aB=aZ;n=new MadCap.WebHelp.SearchPane(aB,$("#searchPane"));if(aB.LiveHelpEnabled){am=MadCap.WebHelp.LoadFeedbackController(aB.LiveHelpServer)}else{if(m){am=new MadCap.WebHelp.MockFeedbackController()}}if(am!=null){am.Init(function(){if(am.PulseActive){$(document.documentElement).addClass("pulse-active");Z(parseInt($("#navigation").css("width")))}if(am.FeedbackActive){$(document.documentElement).addClass("feedback-active");t();var a0=MadCap.Utilities.Url.GetDocumentUrl();if(!Q){aF();if(!MadCap.Utilities.HasRuntimeFileType("Search")){aH()}}}})}if(Q&&aB.DefaultSkin!=null&&!MadCap.String.IsNullOrEmpty(aB.DefaultSkin.Tabs)){B()}ay();var aY=MadCap.Utilities.Url.GetDocumentUrl();if(document.location.hash.length>1){aC()}else{L(aB.DefaultStartTopic+aY.Query)}if(aY.QueryMap.GetItem("cshid")!=null){J()}al();if(Q){ad(aB.DefaultSkin)}l();C();if(!aB.IsResponsive){$("body").addClass("web")}else{if(aB.IsTabletLayout()){G()}}aB.LoadSearchFilters().then(function(a3){var a0=a3?a3.map:null;var a8=[];var bd=false;if(a0){for(var a7 in a0){var a1=a0[a7];if(!MadCap.String.IsNullOrEmpty(a1.c)){a8.push(a7);bd|=a1.o!=-1}}}if(a8.length==0){if(window.PIE){$(".search-submit-wrapper").each(function(){PIE.attach(this)})}$("#SearchTab").closest("div").empty();return}$(".search-filter-wrapper").show();if(window.PIE){$(".search-filter, .search-submit-wrapper").each(function(){PIE.attach(this)})}var a4={};a8.forEach(function(be){var bf=a0[be];if(bf.o>-1){a4[bf.o]=be}});if(bd){var bc=a8.sort(function(bf,be){if(a0[bf].group!=a0[be].group){return a0[bf].group-a0[be].group}if(a0[bf].o!=a0[be].o){return a0[bf].o-a0[be].o}return(bf<be?-1:bf>be?1:0)});a8=bc}else{var bc=a8.sort();a8=bc}if(Q&&$(".search-bar").css("display")=="none"){$("#SearchTab").closest(".tab").remove();return}var a6=$("#search ul");for(var a5=0,a2=a8.length;a5<a2;a5++){$(".search-filter-content ul").append($("<li></li>").text(a8[a5]));var ba=$("<li/>");ba.addClass("SearchFilterEntry tree-node tree-node-leaf");var bb=$('<div class="SearchFilter" />');var a9=$('<span class="label" />');a9.text(a8[a5]);bb.append(a9);ba.append(bb);a6.append(ba)}E()});aJ(aW)})}else{E()}}function E(){$(".search-filter-content li").click(function(aX){var aS=$(aX.target);var aV=aS.text().trim();var aT=aS.closest(".search-bar").children(".search-field");var aW=aT.val();var aU=aS.closest(".search-filter");var aY=aS.closest(".search-filter-content");aj(aV);g(aV,aU);k(0,0,aY,aU);aE(aW,aV)});$(".SearchFilter").click(function(aW){var aS=$(aW.target).closest(".SearchFilterEntry");var aV=$("#search-field-sidebar").val();$(".SearchFilterEntry.tree-node-selected").removeClass("tree-node-selected");if(aS.hasClass("SearchFilterEntry")){aS.addClass("tree-node-selected");var aU=aS.find(".SearchFilter").text().trim();var aT=$("#search-field-sidebar");if(!aT.attr("data-placeholder")){aT.attr("data-placeholder",aT.attr("placeholder"))}aT.attr("placeholder",aT.attr("data-placeholder")+" "+aU);aj(aU,this);aE(aV,aU)}})}function an(aS){if(Q){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-topic-id",null,function(aT){aS(aT[0])})}else{aS($("html").attr("data-mc-live-help"))}}function k(aU,aV,aS,aT){if(K){clearTimeout(K)}K=setTimeout(function(){$(aS).fadeOut(aU,function(){$(aT).removeClass("open")})},aV)}function R(aS){$(".search-field").val(aS);$("#search-field-sidebar").val(aS)}function aj(aT){$(".search-filter").data("filter",aT);if(!Q){var aS=$(".search-field");if(!aS.attr("data-placeholder")){aS.attr("data-placeholder",aS.attr("placeholder"))}aS.attr("placeholder",aS.attr("data-placeholder")+" "+aT)}else{$(".search-filter > span").text(aT)}}function g(aV,aU){var aW=$(".search-filter-content",aU);var aS=aW.children()[0];var aT=$(aS).children()[0];aV!==$(aT).text()?$(".search-filter").addClass("selected"):$(".search-filter").removeClass("selected")}function l(){var aS=$(".select-skin-button");if(m||(aB.IsResponsive&&aB.DefaultSkin!=null&&aB.GetSkins().length>1)){aS.click(function(aU){var aV=[];var aT=new MadCap.Utilities.Url(document.location.href);$.each(aB.GetSkins(),function(aW,aY){var aX={Title:aY.Name,Link:aT.PlainPath+"?skinName="+aY.SkinID+aT.Fragment};aV[aV.length]=aX});MadCap.TextEffects.CreateToolbarDropdown(aV,aS[0],"select-skin-drop-down");aU.preventDefault();aU.stopPropagation()})}else{aS.hide()}}function C(){var aS=$(".select-language-button");if(m){aS.click(function(aT){MadCap.TextEffects.CreateDummyToolbarDropdown(aS,"select-language-drop-down","Language");aT.preventDefault();aT.stopPropagation()});return}if(!aB.IsMultilingual){aS.hide();return}require([aB.GetPath()+"../languages.js"],function(aU){var aT=aU.data;if(aT.length>1){aS.click(function(aZ){var a3=[];var a2=aB.GetPath();var aX=aB.GetCurrentTopicPath();var aV=new MadCap.Utilities.Url(document.location.href);for(var aY=0;aY<aT.length;aY++){var a0="../"+aT[aY].code+"/";var aW=a2+a0+aX;var a1={Title:aT[aY].full,Link:aW};a3[a3.length]=a1}MadCap.TextEffects.CreateToolbarDropdown(a3,aS[0],"select-language-drop-down");aZ.preventDefault();aZ.stopPropagation()})}else{aS.hide()}})}var b=window.innerWidth;var aJ=MadCap.Utilities.Debounce(function(){var aU=window.innerWidth;if(aB&&aB.IsResponsive){var aX=aB.IsTabletLayout();var aT=aB.IsTabletLayout(b);if(!aX){$("#navigation").removeAttr("role");$("body").removeClass("active");$("body").addClass("web");if(aT){G()}if(o){var aV=$(o);if(!aV.hasClass("active")){var aS=aV.find("li");var aW=$(aS[0]);aW.removeClass("tabs-nav-inactive");aW.addClass("tabs-nav-active");aV.addClass("active")}}else{if(!o&&$(document).find(".tab.active").length==0){o=$($(document).find(".tab")[0]);O("Toc",o)}}}else{if($("#navigation").attr("role")!=="undefined"){$("#navigation").attr("role","complementary")}if(!aT){var aV=$(".tab.active");o=aV.length&&aV.find("li").text()!="SearchTab"?$(".tab.active"):o;$(".tab .tabs-nav-active").removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");$(".tab.active").removeClass("active")}$("body").removeClass("web")}if((aX&&!aT)||(!aX&&aT)){aM()}}Z(parseInt($("#navigation").css("width")));b=aU},50);function aM(){var aU=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var aZ=$("#navigation");var aY=$("#contentBody");var aT=$("#navigationResizeBar");var aV=!aZ.attr("style")||!aY.attr("style");var aX=!aZ.attr("data-mc-last-width")||!aY.attr("data-mc-last-width");if(aV&&aX){return}if(!aB.IsTabletLayout()){var aW=aZ.attr("data-mc-last-width");if(aW){aZ.css("width",aW);var aS=aY.attr("data-mc-last-width");if(aS){aY.css(aU,aS)}}}else{var aW=aZ.css("width");if(aW){aZ.attr("data-mc-last-width",aW);aZ.removeAttr("style");var aS=aY.css(aU);if(aS){aY.attr("data-mc-last-width",aS)}aY.removeAttr("style")}}}function z(aS){MadCap.DEBUG.Log.AddLine(window.name+"onhashchange: "+document.location.hash);if(document.location.hash.length>1){aC()}else{L(aB.DefaultStartTopic)}}function t(){$(".star-buttons").click(Y);U();$(".buttons").on("click",".login-button",function(aS){if(m){MadCap.Utilities.SetButtonState($(".login-button"),2)}else{T=new MadCap.Feedback.LoginDialog(am,am.PulseEnabled?"pulse":"new");if(!am.PulseEnabled){$(T).bind("closed",function(){U()})}T.Show()}});$(".buttons").on("click",".edit-user-profile-button",function(aT){if(m){MadCap.Utilities.SetButtonState($(".edit-user-profile-button"),1)}else{if(am.PulseEnabled){var aS="#!streams/"+(Q?am.PulseUserGuid+"/settings":"my");ab(aS)}else{T=new MadCap.Feedback.LoginDialog(am,"edit");$(T).bind("closed",function(){U()});T.Show()}}})}function ak(aU){var aT=aI(aU);if(!MadCap.String.IsNullOrEmpty(aT.Query)){var aS=at+aT.ToString();if(Q){document.location.hash=aS}else{MadCap.Utilities.Url.NavigateTopic(new MadCap.Utilities.Url(aB.SearchUrl+"#"+aS))}}}function aI(aY){var a1=$(aY.target).closest(".search-bar-container");var aZ=$("input",a1).first();var aT=$(".search-filter",a1);var a2=aZ.val();if(a2){a2=MadCap.Utilities.Url.StripInvalidCharacters(a2);a2=encodeURIComponent(a2)}var a0;var aW=a1.attr("id");if(Q&&aW&&aW.indexOf("sidebar")!=-1){a0=$(".SearchFilterEntry.tree-node-selected").text()}else{a0=aT.data("filter")}if(!a0){var aV=MadCap.Utilities.Url.CurrentHash();var aX=aV.lastIndexOf("?f=");if(aX!==-1){var aS=aV.substr(aX+3);if(aS){a0=aS}}}a0=a0?a0.trim():a0;var aU=M(a0,a1);return new MadCap.WebHelp.Search.SearchQuery(a2,aU,null)}function M(aT,aU){var aS=$.trim($(".search-filter li",aU).first().text());if(aT&&aT!=aS){return MadCap.Utilities.Url.StripInvalidCharacters(aT)}return null}function aN(aV,aS){var aU=MadCap.WebHelp.Search.SearchQuery.Parse(aV);if(!Q&&!MadCap.Utilities.HasRuntimeFileType("Search")){var aT="";if(aS){aT="?skinName="+aS}MadCap.Utilities.Url.NavigateTopic(new MadCap.Utilities.Url(aB.SearchUrl+aT+"#"+at+aU.ToString()))}else{R(aU.Query);if(!MadCap.String.IsNullOrEmpty(aU.Filter)){aj(aU.Filter);g(aU.Filter,document)}p(aU.Query,aU.Filter,aU.PageIndex)}}function aE(aT,aS){if(!Q&&m){return}if($("#searchPane").is(":visible")&&!MadCap.String.IsNullOrEmpty(aT)){aG(new MadCap.WebHelp.Search.SearchQuery(aT,M(aS),null))}}function p(a0,aU,aY,aV,aW,aS,aX){var aZ=aB.GetCurrentSkin();if(typeof aV=="undefined"){aV=true}if(typeof aW=="undefined"){aW=(!aZ&&aB.DisplayCommunitySearchResults)||(aZ&&aZ.DisplayCommunitySearchResults!="false")}if(typeof aS=="undefined"){aS=aB.CommunitySearchResultsCount}if(typeof aX=="undefined"){aX=0}if(!aY){aY=1}$("#resultList").remove();au("search");var aT=aY===1;var a1={};if(aV){a1.searchContent=true;a1.searchGlossary=aB.IncludeGlossarySearchResults&&aT;a1.content={filterName:aU}}if(aW&&(aT||!aV)){a1.searchCommunity=true;a1.community={pageSize:aS,pageIndex:aX}}n.Search(a0,a1).then(function(a2){S(a0,a2,aY)});$("body").removeClass("active")}function w(aZ,aV){var a2=$("#pagination");a2.css("display","none");$("a.specificPage",a2).remove();var aW=aV.length;if(aW>0){var aY=Math.ceil(aW/aB.ResultsPerPage);var a0=10;var a1=5;var a4=Math.max(Math.min(aZ-a1,aY-a0+1),1);var aX=Math.min(a4+a0-1,aY);var aS=$("a.previousPage",a2);if(aZ>1){aS.off("click");aS.on("click",{value:aZ-1},H);aS.css("display","inline")}else{aS.css("display","none")}var a3=$("a.nextPage",a2);if(aZ<aY){a3.off("click");a3.on("click",{value:aZ+1},H);a3.css("display","inline")}else{a3.css("display","none")}for(var aU=a4;aU<=aX;aU++){var aT=$("<a class='specificPage'>"+aU+"</a>");if(aU==aZ){aT.attr("id","selected")}a3.before(aT);aT.on("click",{value:aU},H)}a2.css("display","block")}}function H(aV){aV.preventDefault();var aT="#"+at;var aU=MadCap.Utilities.Url.CurrentHash();if(aU.indexOf(aT)==0){var aS=MadCap.WebHelp.Search.SearchQuery.Parse(aU.substring(aT.length));aS.PageIndex=aV.data.value;aG(aS)}}function aG(aV,aT,aS){var aU=aV.ToString();aU=MadCap.Utilities.Url.StripInvalidCharacters(aU);document.location.hash="#"+at+aU}function S(bi,be,a2){var aY=aB.GetCurrentSkin();var bn=(!aY&&aB.DisplayCommunitySearchResults)||(aY&&aY.DisplayCommunitySearchResults!="false");var a0=$("#results-heading")[0];var bk=$("#pagination");var aX=be.content!=null?be.content.length:0;var bf=(bn&&be.community!=null)?be.community.TotalRecords:0;var bl=be.glossary?1:0;var a7=aX+bf+bl;var a4=Q?"#":"";W(a0,"Search Heading");$(".query",a0).text('"'+decodeURIComponent(bi)+'"');$(".total-results",a0).text(a7);if(a2<1||a2>Math.ceil(aX/aB.ResultsPerPage)){bk.css("display","none")}if(a7>0){var a9=document.createElement("ul");a9.setAttribute("id","resultList");if(!be.content){a9.setAttribute("class","communitySearch")}if(be.glossary){var a8=document.createElement("li");a9.appendChild(a8);var ba=document.createElement("div");$(ba).addClass("glossary");W(ba,"Search Glossary Result");var bb=document.createElement("div");$(bb).addClass("term");W(bb,"Search Glossary Term");var bc=document.createTextNode(be.glossary.term);if(be.glossary.link){var aS=document.createElement("a");$(aS).attr("href",a4+be.glossary.link);aS.appendChild(bc);bb.appendChild(aS)}else{bb.appendChild(bc)}ba.appendChild(bb);var aZ=be.glossary.definition||be.glossary.abstractText;if(aZ){var a5=document.createElement("div");$(a5).addClass("definition");a5.appendChild(document.createTextNode(aZ));W(a5,"Search Glossary Definition");ba.appendChild(a5)}a8.appendChild(ba)}if(be.community!=null&&be.community.Activities.length>0&&bn){af(a9,bi,be.community)}var aU=aB.ResultsPerPage;if(be.content!=null&&aU>0){var bd=(a2-1)*aU;var bj=Math.min(bd+aU,be.content.length);for(var bh=bd;bh<bj;bh++){var a6=be.content[bh];var bo=a6.Title;var a3=a6.Link;var aT=a6.AbstractText;var a8=document.createElement("li");a9.appendChild(a8);var a1=document.createElement("h3");$(a1).addClass("title");a8.appendChild(a1);var bm=document.createElement("a");bm.setAttribute("href",a4+a3+"?Highlight="+bi);W(bm,"Search Result Link");bm.appendChild(document.createTextNode(bo));d(bm,be.includedTerms);a1.appendChild(bm);if(aT!=null){var bg=document.createElement("div");$(bg).addClass("description");W(bg,"Search Result Abstract");bg.appendChild(document.createTextNode(aT));d(bg,be.includedTerms);a8.appendChild(bg)}var aV=document.createElement("div");$(aV).addClass("url");a8.appendChild(aV);var aW=document.createElement("cite");W(aW,"Search Result Path");aW.appendChild(document.createTextNode(a3));aV.appendChild(aW)}}bk.before(a9)}if(aB.LiveHelpEnabled){am.LogSearch(aB.LiveHelpOutputId,null,aX,null,bi)}if(aX>aB.ResultsPerPage){w(a2,be.content)}else{bk.css("display","none")}if(MadCap.IsIOS()){$(".off-canvas-wrap").scrollTop(1)}$("#contentBodyInner, .off-canvas-wrap").scrollTop(0);$("#resultList a").first().focus()}function W(aT,aS){if(m){aT.setAttribute("data-mc-style",aS)}}function d(aS,aU){var aV=$(aS);if(aU){for(var aT=0;aT<aU.length;aT++){aV.highlight(aU[aT],null,"b")}}}function af(a4,bc,aW){var aY=(aB.PulsePage||"")+"#pulse-";var a9=Q?"#":aB.GetTopicPath("../"+aB.ContentFolder).FullPath;var a3=document.createElement("li");a3.setAttribute("id","community-results");a4.appendChild(a3);var aX=document.createElement("h3");aX.setAttribute("class","title");var a7=document.createElement("a");a7.setAttribute("href","#communitysearch-"+bc);a7.appendChild(document.createTextNode("Community Results"));aX.appendChild(a7);var aU=document.createElement("span");aU.appendChild(document.createTextNode(" ("+aW.TotalRecords+")"));aX.appendChild(aU);var a0=document.createElement("ul");a0.setAttribute("id","communityResultList");a3.appendChild(aX);a3.appendChild(a0);var aS=new Date();var aT=new Date(aS.getUTCFullYear(),aS.getUTCMonth(),aS.getUTCDate(),aS.getUTCHours(),aS.getUTCMinutes(),aS.getUTCSeconds());for(var bb=0;bb<aW.Activities.length;bb++){var bf=aW.Activities[bb];var aZ=document.createElement("li");a0.appendChild(aZ);var a5=document.createElement("a");a5.setAttribute("class","activityText");a5.setAttribute("href",aY+"#!streams/"+bf.FeedId+"/activities/"+bf.Id);a5.appendChild(document.createTextNode(bf.Text));var bd=document.createElement("div");bd.setAttribute("class","activityInfo");var aV=document.createElement("a");aV.setAttribute("class","activityCreator");aV.setAttribute("href",aY+"#!streams/"+bf.CreatedBy+"/activities");aV.appendChild(document.createTextNode(bf.CreatedByDisplayName));var ba=document.createElement("span");ba.appendChild(document.createTextNode(" to "));var a1=bf.FeedUrl!=null?a9+bf.FeedUrl:aY+"#!streams/"+bf.FeedId+"/activities";var a2=document.createElement("a");a2.setAttribute("class","activityFeed");a2.setAttribute("href",a1);a2.appendChild(document.createTextNode(bf.FeedName));var be=new MadCap.Utilities.DateTime(bf.PostedUtc);var a6=new MadCap.Utilities.TimeSpan(be.Date,aT);var a8=document.createElement("span");a8.setAttribute("class","activityTime");a8.appendChild(document.createTextNode(a6.ToDurationString()));bd.appendChild(aV);bd.appendChild(ba);bd.appendChild(a2);bd.appendChild(a8);aZ.appendChild(a5);aZ.appendChild(bd)}}function aq(aT){MadCap.DEBUG.Log.AddLine("nav resizeBar : mousedown");if($(aT.target).attr("id")=="show-hide-navigation"){return}if($(this).hasClass("nav-closed")){return}var aS=document.createElement("div");aS.setAttribute("id","mousemove-sheet");document.body.appendChild(aS);$(document).mousemove(r);$(document).mouseup(s);$(document).bind("selectstart",aA);aT.preventDefault()}function aA(aS){return false}function r(aU){MadCap.DEBUG.Log.AddLine("nav resizeBar : mousemove : "+aU.pageX);var aS=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var aT=aU.pageX;if(aS=="right"){aT=window.innerWidth-aU.pageX}f(aT)}function s(aT){MadCap.DEBUG.Log.AddLine("nav resizeBar : mouseup");$(document).off("mousemove",r);$(document).off("mouseup",s);$(document).off("selectstart",aA);var aS=$("#mousemove-sheet")[0];window.setTimeout(function(){aS.parentNode.removeChild(aS)},1)}function f(aT){var aS=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";if(aS=="left"){if(aT<175||aT>(window.innerWidth*0.85)){return}}else{if(aS=="right"){if(aT<(window.innerWidth*0.15)||aT>(window.innerWidth-175)){return}}}Z(aT);$("#navigationResizeBar").css(aS,aT+"px");$("#navigation").css("width",aT+"px");$("#contentBody").css(aS,(aT+5)+"px")}function Z(aV){var aU=$(".tabs-nav li");if(aK()===0){return}$.each(aU,function(aX,aY){var aW=$(aY);if(aW.hasClass("tab-collapsed")){aW.removeClass("tab-collapsed")}});if(aV<aK()+4){for(var aT=aU.length-1;aT>=0;aT--){var aS=$(aU[aT]);aS.addClass("tab-collapsed");if(aV>aK()+18){break}}}}function aK(){var aT=0;var aS=$(".tabs-nav li");aS.each(function(aV,aU){var aW=$(aU);if(aW.is(":visible")){aT+=parseInt(aW.css("width"))}});return aT}function G(){var aT=$(document).find(".tab");for(var aS=0;aS<aT.length;aS++){var aU=$(aT[aS]);aU.show();aU.removeClass("active")}$("#search-sidebar").removeClass("index").removeClass("glossary");$(".tabs-nav-active").removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");$(".responsive-link-list").remove()}function u(aV){var aY=$(aV.currentTarget).closest("li");var aX=aY.children("ul").first();if(aX.length){var aU=aX.width();var aT=$("html").attr("dir")=="rtl";var aW=aT?aY.offset().left:$(window).width()-aY.offset().left-aY.width();var aS=aT?"openRight":"openLeft";aX.toggleClass(aS,aU>aW)}}function I(aS){var aT=$("#navigation");if(!aT.hasClass("nav-closed")){q("hide")}else{q("show")}}function q(aV){var aS=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var aX=$("#navigation");var aT=$("#navigationResizeBar");var aW=$("#contentBody");if(aV=="show"){aT.css(aS,aT.attr("data-mc-last-width"));var aU=aW.attr("data-mc-last-width");if(aU==aW.css("left")){aU=aX.innerWidth()+aT.innerWidth()+1;aW.attr("data-mc-last-width",aU+"px")}else{aW.css(aS,aU)}aX.removeClass("nav-closed");aT.removeClass("nav-closed");aW.removeClass("nav-closed");if(aB.IsResponsive){aM()}}else{if(aV=="hide"){aW.attr("data-mc-last-width",aW.css(aS));aW.removeAttr("style");aT.attr("data-mc-last-width",aT.css(aS));aT.css(aS,0);aX.attr("data-mc-last-width",aX.css("width"));aX.addClass("nav-closed");aT.addClass("nav-closed");aW.addClass("nav-closed")}}}function aC(){if(document.location.hash.length==0){return}var aX=MadCap.Utilities.Url.GetDocumentUrl();var aW=MadCap.Utilities.Url.CurrentHash();var aV=MadCap.Utilities.Url.StripInvalidCharacters(aW);if(MadCap.String.IsNullOrEmpty(aV)){document.location.hash="";return}var aT=aV.substring(1);var aY=decodeURIComponent(aT);aY=MadCap.Utilities.Url.StripInvalidCharacters(aY);if(MadCap.String.Contains(aY,"cshid=")||MadCap.String.Contains(aY,"searchQuery=")||MadCap.String.Contains(aY,"skinName=")){J();return}else{if(MadCap.String.StartsWith(aT,at)){aN(aT.substring(at.length),null);return}else{if(MadCap.String.StartsWith(aY,"communitysearch-")){var aU=aY.substring("communitysearch-".length);R(aU);p(aU,null,1,false,true,-1,0);return}else{if(MadCap.String.StartsWith(aY,"pulse-")){var aS=aY.substring("pulse-".length);y(aS);return}}}}ao(aY)}function ao(aU){var aW=new MadCap.Utilities.Url(aU);if(aW.IsAbsolute){if(aB.PreventExternalUrls){aU=aB.DefaultStartTopic}else{var aV=aW.Query.indexOf("?");var aT=aW.Query.lastIndexOf("?");var aS="";if(aV!=aT){aS=aW.Query.substr(aV,aT)}if(aW.FullPath.indexOf("http://")!=0){aU=aB.ContentFolder+aW.ToNoQuery().FullPath+(MadCap.String.IsNullOrEmpty(aS)?"":aS)}else{aU=aW.ToNoQuery().FullPath+(MadCap.String.IsNullOrEmpty(aS)?"":aS)}}}else{aU=aB.ContentFolder+aW.ToNoQuery().FullPath}L(aU)}function L(a2){if(!a){return}var aT=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));if(!Q){var a1=new MadCap.Utilities.Url(aT.PlainPath);if(!a1.IsFolder){a1=a1.ToFolder()}var aS=a1.CombinePath(a2);MadCap.Utilities.Url.Navigate(aS.FullPath)}else{$(document.documentElement).addClass("has-topic");au("topic");try{frames.topic.location.replace(a2)}catch(aV){document.getElementById("topic").src=a2}var aY=null,a0=null,aX=null;if(!MadCap.String.IsNullOrEmpty(aT.Fragment)&&aT.Fragment.length>1){a0=aT.QueryMap.GetItem("TocPath");if(a0!=null){aY="Toc"}else{aX=aT.QueryMap.GetItem("BrowseSequencesPath");if(aX!=null){aY="BrowseSequences"}}if(aT.HashMap.GetItem("cshid")==null){var aW=aT.Query.indexOf("?");var aU=aT.Query.lastIndexOf("?");var aZ="";if(aW!=aU){aZ=aT.Query.substr(aW,aU)}aT=new MadCap.Utilities.Url(aT.Fragment.substr(1));if(!MadCap.String.IsNullOrEmpty(aZ)){aT.Query=aZ}}}else{aT=new MadCap.Utilities.Url(aB.DefaultStartTopic).ToRelative(aB.GetContentPath())}aB.SetBrowseSequencePath(aX,aT);if(aB.SyncTOC){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"sync-toc",[aY,aY=="Toc"?a0:aX,aT.FullPath],null)}}}function y(aS){$(document.documentElement).removeClass("has-topic");au("pulse");var aT=aS.substring(aS.indexOf("#"));MadCap.Utilities.CrossFrame.PostMessageRequest(frames["community-frame-html5"],"pulse-hash-changed",[aT]);am.Init(function(){if(am.PulseActive&&X()){X().location.replace(am.PulseServer+aT)}})}function ab(aS){var aT="pulse-"+aS;if(aB.PulsePage!=null){MadCap.Utilities.Url.Navigate(aB.PulsePage+"#"+aT)}else{MadCap.Utilities.Url.NavigateHash(aT)}}function al(){var aT=MadCap.Utilities.Url.GetDocumentUrl();var aS=aT.QueryMap.GetItem("skinName");aP(aS)}function e(){var aS=new MadCap.Utilities.Url(document.location.href);var aT=new MadCap.Utilities.Dictionary(true);$.each([aS.QueryMap,aS.HashMap],function(aU,aV){aV.ForEach(function(aW,aX){aT.Add(aW,aX)})});return aT}function J(){var aW=e();var aV=aW.GetItem("searchQuery".toLowerCase());var aS=aW.GetItem("skinName".toLowerCase());if(aV!=null){R(decodeURIComponent(aV));var aU=MadCap.String.ToBool(aW.GetItem("firstPick".toLowerCase()),false);if(aU){n.Search(aV,{searchContent:true}).then(function(aY){var aZ=aY.content;if(aZ.length>=1){ao(aZ[0].Link.replace(/^(Content)/,""))}})}else{aN(aV,aS)}}else{var aX=aW.GetItem("cshid");if(aX!=null){aB.LookupCSHID(aX,function(a3){var a2=e();var a4=a2.GetItem("cshid");var aY=a2.GetItem("skinName".toLowerCase());if(a3.Found){var a5=a3.Topic;var aZ=new MadCap.Utilities.Url(a5);var a0=MadCap.Utilities.Url.GetDocumentUrl();var a1="?cshid="+a4;a1+=aY?"&skinName="+aY:"";a5=new MadCap.Utilities.Url(aZ.PlainPath+a1+aZ.Fragment).FullPath;L(a5)}else{L(aB.DefaultStartTopic)}aP(aY||a3.Skin)});return}else{var aT=MadCap.Utilities.Url.GetDocumentUrl();L(aB.DefaultStartTopic+aT.Fragment)}}aP(aS)}function ax(){var aS=MadCap.Utilities.Url.CurrentHash();if(aS.indexOf("#pulse-")!=0){return""}return aS.substring("#pulse-".length)}function aP(aS){var aT=null;if(aS!=null){var aT=aB.GetSkin(aS);if(!aT){aT=aB.GetSkinByName(aS)}}if(!aT){aT=aB.DefaultSkin}c(aT)}function c(a4){if(a4==null){return}ad(a4);if(!MadCap.String.IsNullOrEmpty(a4.Tabs)){if(a4.WebHelpOptions!=null&&a4.WebHelpOptions.HideNavigationOnStartup!=null&&(MadCap.String.ToBool(a4.WebHelpOptions.HideNavigationOnStartup,false))){q("hide")}if(a4.HideNavOnStartup!=null){if(MadCap.String.ToBool(a4.HideNavOnStartup,false)){q("hide");$("#contentBody").attr("data-mc-last-width","");$("#navigation").attr("data-mc-last-width","");$("#navigationResizeBar").attr("data-mc-last-width","")}else{q("show")}}if(h(a4)=="Right"&&!m){$(document.documentElement).removeClass("left-layout").addClass("right-layout")}if(a4.NavigationPaneWidth!=null){var a2=MadCap.String.ToInt(a4.NavigationPaneWidth,300);f(a2)}var aZ=a4.Tabs.split(",");var aX=["Toc","Index","Glossary","BrowseSequences","Community"];var aV=$(".tabs");for(var aW=0,aT=aX.length;aW<aT;aW++){var aU=aX[aW];var a1=$("#"+aU+"Tab");if(a1.length==0){continue}if(aU=="Toc"){aU="TOC"}if($.inArray(aU,aZ)>=0){a1.css("display","");continue}a1.css("display","none");var aS=aV.children(".tabs-nav").children("li").index(a1);var a0=aV.children(".tabs-panels").children(":eq("+aS+")");a1.remove();a0.remove()}var aY=a4.DefaultTab;if(aY=="TOC"){aY="Toc"}O(aY,aV);ae(aY)}if(a4.Toolbar!=null&&MadCap.String.IsNullOrEmpty(a4.Toolbar.Buttons)){$(".buttons").remove()}if(!MadCap.String.IsNullOrEmpty(a4.Version)&&parseInt(a4.Version)>=2){$.each(aB.GetSkins(),function(a6,a7){$("html").removeClass(a7.SkinClass)});$("html").addClass(a4.SkinClass);if(a4.LogoUrl){var a3=new MadCap.Utilities.Url(a4.LogoUrl);if(!a3.IsAbsolute){var a5=aB.GetPatchedPath(a3.FullPath);a3=aB.GetTopicPath("../"+aB.ContentFolder+a5)}$("a.logo").attr("href",a3.FullPath)}j(a4)}}function h(aS){if(aS.WebHelpOptions!=null&&!(Q&&m)){return aS.WebHelpOptions.NavigationPanePosition}return"Left"}function j(aT){var aS=h(aT);if(Q){if(aS=="Right"){$("html").removeClass("left-layout").addClass("right-layout")}else{$("html").removeClass("right-layout").addClass("left-layout")}}else{$("aside").hide();if(aS=="Right"){$("a.menu-icon").removeClass("left-off-canvas-toggle").addClass("right-off-canvas-toggle");$("aside").removeClass("left-off-canvas-menu").addClass("right-off-canvas-menu");$(".off-canvas-list").attr("data-mc-css-sub-menu","right-submenu")}else{$("a.menu-icon").removeClass("right-off-canvas-toggle").addClass("left-off-canvas-toggle");$("aside").removeClass("right-off-canvas-menu").addClass("left-off-canvas-menu");$(".off-canvas-list").attr("data-mc-css-sub-menu","left-submenu")}}}function au(aS){$("#topic").css("display",aS=="topic"?"block":"none");$("#topicContent").css("display",aS=="topic"?"block":"none");$("#pulse").css("display",aS=="pulse"?"block":"none");$("#searchPane").css("display",aS=="search"?"block":"none")}function X(){if(frames.pulse){return frames.pulse}else{if(frames["pulse-full"]){return frames["pulse-full"]}else{return null}}}var v=null;function x(aY){var aS=$(this).attr("id");var aU=aS.substring(0,aS.length-"Tab".length);v=aU;O(aU,$(this).closest(".tabs"));if(aB.IsTabletLayout()&&aB.IsResponsive){var aW=$(document).find(".tab");for(var aV=0;aV<aW.length;aV++){var aX=$(aW[aV]);if(!aX.hasClass("active")){aX.hide()}else{aX.show()}}var aT=$("#search-sidebar");var aZ=aU.toLowerCase();aT.removeClass("index").removeClass("glossary");if(aZ=="index"||aZ=="glossary"){aT.addClass(aZ)}}ae(aU)}function O(aU,aX){var aT=$(".tabs-nav-active",aX);var aV=$("#"+aU+"Tab");var aW=aT.closest(".tab");var aS=aV.closest(".tab");aT.removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");if(aW!=null){aW.removeClass("active")}aV.removeClass("tabs-nav-inactive");aV.addClass("tabs-nav-active");if(aS!=null){aS.addClass("active")}if(aB.IsResponsive&&aU!="Search"){o=$(".tab.active")}else{o=null}}function ay(){var aS=$("ul[data-mc-toc]");aS.each(function(){var aT=new MadCap.WebHelp.TocPane("Toc",aB,this,false);aT.Init()})}function B(){var aS=aB.DefaultSkin.DefaultTab;if(aS=="TOC"){ae("Toc")}else{ae(aS)}}function ae(aS){var aT=null;if(aS=="Toc"){aT=aQ()}else{if(aS=="Index"){aT=ai()}else{if(aS=="Glossary"){aT=N()}else{if(aS=="BrowseSequences"){aT=i()}else{if(aS=="Community"){aT=aO()}}}}}if(aT||(aT&&aB.IsResponsive&&!aB.IsTabletLayout())){O(aS,aT)}}function aQ(){if(ac!=null){return}var aT=$("#toc");if(!aT.length){return}aT.addClass("loading");var aS=$('<ul class="tree" />');aT.append(aS);ac=new MadCap.WebHelp.TocPane("Toc",aB,aS[0],true);ac.Init(function(){aT.removeClass("loading")});return aT.parent()}function ai(){if(av!=null){return}var aS=$("#index");aS.addClass("loading");av=new MadCap.WebHelp.IndexPane(aB);av.Init($("#index .index-wrapper")[0],function(){aS.removeClass("loading")});return aS.parent()}function N(){if(V!=null){return}var aS=$("#glossary");aS.addClass("loading");V=new MadCap.WebHelp.GlossaryPane(aB);V.Init(aS[0],function(){aS.removeClass("loading")});return aS.parent()}function i(){if(aL!=null){return}var aT=$("#browseSequences");if(!aT.length){return}aT.addClass("loading");var aS=$('<ul class="tree" />');aT.append(aS);aL=new MadCap.WebHelp.TocPane("BrowseSequences",aB,aS[0],true);aL.Init(function(){aT.removeClass("loading")});return aT.parent()}function aO(){if(P){return}P=true;var aS=$("#community-frame-html5");am.Init(function(){if(am.PulseActive){aS.attr("src",am.PulseServer+"streams/my")}});return aS.parent()}function ad(a5){if(!a5){return}var a6=MadCap.String.ToBool(a5.UseBrowserDefaultSize,true);if(a6){return}var aV=MadCap.String.ToInt(a5.Top,0);var a3=MadCap.String.ToInt(a5.Left,0);var a4=MadCap.String.ToInt(a5.Bottom,0);var aT=MadCap.String.ToInt(a5.Right,0);var aW=MadCap.String.ToInt(a5.Width,800);var aX=MadCap.String.ToInt(a5.Height,600);var aS=a5.Anchors;if(aS){var aZ=(aS.indexOf("Top")>-1)?true:false;var aU=(aS.indexOf("Left")>-1)?true:false;var a2=(aS.indexOf("Bottom")>-1)?true:false;var aY=(aS.indexOf("Right")>-1)?true:false;var a0=(aS.indexOf("Width")>-1)?true:false;var a1=(aS.indexOf("Height")>-1)?true:false}if(aU&&aY){aW=screen.availWidth-(a3+aT)}else{if(!aU&&aY){a3=screen.availWidth-(aW+aT)}else{if(a0){a3=(screen.availWidth/2)-(aW/2)}}}if(aZ&&a2){aX=screen.availHeight-(aV+a4)}else{if(!aZ&&a2){aV=screen.availHeight-(aX+a4)}else{if(a1){aV=(screen.availHeight/2)-(aX/2)}}}if(window==top){window.resizeTo(aW,aX);window.moveTo(a3,aV)}}function aH(){var aS=aB.GetCurrentSkin();if(aS&&aS.CommentsInTopic=="false"){if(Q){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"hide-comments")}else{$(".feedback-comments-wrapper").addClass("hidden")}}else{if(Q){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"show-comments")}else{$(".feedback-comments-wrapper").removeClass("hidden")}}}function aF(){if(am==null){return}$(".star-buttons").addClass("loading");function aS(){am.GetAverageRating(aR,function(aU,aT){$(".star-buttons").removeClass("loading");aw(aU)})}if(aR==null){an(function(aT){aR=aT;aw(0);aS()})}else{aS()}}function aw(aW){var aS=$(".star-buttons");var aZ=$(".star-button",aS);var aY=aZ.length;var aX=Math.ceil(aW*aY/100);aZ.css("opacity",0);for(var aU=0;aU<aY;aU++){var aV=aZ[aU];var aT=$(aV);window.setTimeout((function(a1,a0){return function(){if(a1<=aX-1){MadCap.Utilities.SetButtonState(a0[0],2)}else{MadCap.Utilities.SetButtonState(a0[0],1)}a0.animate({opacity:1})}})(aU,aT),aU*50)}}function Y(aV){var aS=$(aV.target);if(aV.target.tagName=="IMG"){aS=aS.closest(".star-button")}if(aS.hasClass("star-button")){var aU=$(".star-button",this).length;var aT=(aS.index()+1)*100/aU;am.SubmitRating(aR,aT,null,function(){aF()})}}function A(aS){ar(aS,function(aT){if(aT){document.location.hash=aT}})}function ag(){A("previous")}function D(){A("next")}function ar(aT,aS){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-topic-url",null,function(aZ){var aW=new MadCap.Utilities.Url(decodeURIComponent(aZ[0]));var aV=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));var aX=aV.QueryMap.GetItem("TocPath");var aY=aV.QueryMap.GetItem("BrowseSequencesPath");aV=aV.ToPlainPath();if(!aV.IsFolder){aV=aV.ToFolder()}var aU=aV.CombinePath(aB.GetMasterHelpsystem().GetContentPath());aW=aW.ToRelative(aU);if(aY!=null){aB.AdvanceTopic("BrowseSequences",aT,aY,aW,aS)}else{aB.AdvanceTopic("Toc",aT,aX,aW,aS)}})}function F(){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-bs-path",null,function(aZ){function aW(a0){var a1=$(".current-topic-index-button");if(a0==-1){a1.addClass("disabled");return}a1.removeClass("disabled");$(".sequence-index").text(a0);aT.GetIndexTotalForEntry(aV,aS,function(a2){$(".sequence-total").text(a2)})}var aV=aZ[0];var aS=new MadCap.Utilities.Url(decodeURIComponenet(aZ[1]));var aY=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));aY=new MadCap.Utilities.Url(aY.PlainPath);var aU=MadCap.String.EndsWith(aY.FullPath,"/")?aY:aY.ToFolder();aS=aS.ToRelative(aU);if(aV!=null){var aX=aB.GetFullTocPath("browsesequences",aS.FullPath);if(aX){aV=aV?aX+"|"+aV:aX}}if(MadCap.String.IsNullOrEmpty(aV)||MadCap.String.StartsWith(aV,"_____")){aW(-1);return}var aT=aB.GetBrowseSequenceFile();aT.GetEntrySequenceIndex(aV,aS,aW)})}function U(){aa=am.GetUserGuid();var aS=$(".login-button");if(aS.length==0){aS=$(".edit-user-profile-button")}MadCap.Utilities.SetButtonState(aS[0],aa==null?1:2)}function aD(){if(T!=null){T.Hide(true)}}function az(aZ){var a1=$("#topicContent");if(a1.length==0){var aW=$("#topic").parent();aW.append("<div id='topicContent'></div>");a1=$("#topicContent")}else{a1.empty()}a1.append(aZ[2]);var a0=$(aZ[1]);var aX=[],a2=[],a6=[];var a8=new MadCap.Utilities.Url(aZ[0]);var a3=new MadCap.Utilities.Url(document.location.href);var aT=a3.ToFolder().ToRelative(a8);$.each(a0,function(ba,bb){if(!MadCap.String.IsNullOrEmpty(bb.localName)){var a9=bb.localName.toLowerCase();if(a9=="script"){var bc=new MadCap.Utilities.Url($(bb).attr("src"));if(!bc.IsAbsolute){bc=bc.ToRelative(aT)}aX.push(bc.FullPath)}else{if(a9=="link"){a6.push(bb)}}}});var aV=a8.ToFolder().ToRelative(a3.PlainPath);ah(a6,aV,"href");$.each(a6,function(ba,bb){if($(bb).attr("mc-topic-css")){var a9=$(bb).attr("href");a9=a9.replace(".css","-topic.css");a2.push(a9)}else{a2.push($(bb).attr("href"))}});MadCap.Utilities.LoadStyleSheets(a2,$('link[href*="Styles.css"]')[0]);MadCap.Utilities.LoadScripts(aX,function(){},function(){},a1);var a4=new MadCap.Utilities.Url(document.location.href);aT=a8.ToFolder().ToRelative(a4.PlainPath);var aS=a1.find('a[href][href!="javascript:void(0);"]');aS=aS.not('[class*="MCPopupThumbnailLink"]').not('[class*="MCTopicPopup"]');var aY=a1.find('[class*="MCTopicPopup"]');var a5=a1.find('a[class="MCPopupThumbnailLink"]');var a7=a1.find("img[src]");var aU=a1.find("area[href]");ah(aS,aT,"href","#");ah(aY,aT,"href");ah(a7,aT,"src");ah(a5,aT,"href");ah(aU,aT,"href","#");$(".MCWebHelpFramesetLink",a1).hide()}function ah(aS,aT,aU,aV){$.each(aS,function(aY,aZ){var aX=$(aZ);var aW=new MadCap.Utilities.Url(aX.attr(aU));if(!aW.IsAbsolute){var a0=MadCap.Utilities.FixLink(aW,aT,aV,aB.ContentFolder);aX.attr(aU,a0)}})}MadCap.Utilities.CrossFrame.AddMessageHandler(function(a1,aY,be,bf,aS){var a9={Handled:false,FireResponse:true};if(a1=="get-href"){be[be.length]=document.location.href;a9.Handled=true;a9.FireResponse=true}if(a1=="get-return-url"){var aX=new MadCap.Utilities.Url(document.location.href);var bd=null;if(aX.Fragment.length>1){var bc=new MadCap.Utilities.Url(aX.Fragment.substring(1));bd=aX.QueryMap.GetItem("returnUrl")}be[be.length]=bd;a9.Handled=true;a9.FireResponse=true}else{if(a1=="navigate"){var a8=aY[0];if(a8){MadCap.Utilities.Url.NavigateHash(a8)}a9.Handled=true;a9.FireResponse=true}else{if(a1=="navigate-topic"){var a8=aY[0];if(!Q){var a5=aB.GetAbsoluteTopicPath("../"+aB.ContentFolder+a8);MadCap.Utilities.Url.Navigate(a5.FullPath)}var bc=new MadCap.Utilities.Url(a8);if(bc.IsAbsolute){var aW=new MadCap.Utilities.Url(document.location.href);aW=new MadCap.Utilities.Url(aW.PlainPath);var a7=MadCap.String.EndsWith(aW.FullPath,"/")?aW:aW.ToFolder();var a2=a7.CombinePath(aB.ContentFolder);bc=bc.ToRelative(a2)}if(bc.FullPath){var a3=MadCap.Utilities.Url.StripInvalidCharacters(bc.FullPath);var a6=MadCap.Utilities.Url.CurrentHash();if(a6.substring(1)==a3){document.location.hash=null}document.location.hash=a3}a9.Handled=true}else{if(a1=="navigate-home"){var bh=Q?new MadCap.Utilities.Url(document.location.href):aB.GetAbsoluteTopicPath("../"+aB.DefaultStartTopic);MadCap.Utilities.Url.Navigate(bh.PlainPath);a9.Handled=true}else{if(a1=="navigate-pulse"){var a8=aY[0];var aT=MadCap.Utilities.Url.CurrentHash();if(aT.length>1&&a8){var bb=a8.toLowerCase();if(bb==="feedback/account/register"||a8.toLowerCase()==="forgotpassword"){var aX=new MadCap.Utilities.Url(aT.substring(1));var bd=aX.QueryMap.GetItem("returnUrl");if(bd!=null){bd=escape(bd)}else{bd=aT.substring(1)}a8+="?returnUrl="+bd}}if(a8){ab(a8)}a9.Handled=true}else{if(a1=="navigate-previous"){ag();a9.Handled=true}else{if(a1=="navigate-next"){D();a9.Handled=true}else{if(a1=="login-user"||a1=="login-pulse"){if(aa==null){var a4=a1=="login-pulse"?"pulse":"new";T=new MadCap.Feedback.LoginDialog(am,a4);if(a4=="new"){$(T).bind("closed",function(){U();be[be.length]=aa;MadCap.Utilities.CrossFrame._PostMessageResponse(bf,a1,be.length>0?be:null,aS)})}T.Show();a9.Handled=true;a9.FireResponse=false}else{be[be.length]=aa;a9.Handled=true;a9.FireResponse=true}}else{if(a1=="get-csh-id"){be[be.length]=e().GetItem("cshid");a9.Handled=true;a9.FireResponse=true}else{if(a1=="get-user-guid"){be[be.length]=aa;a9.Handled=true;a9.FireResponse=true}else{if(a1=="get-topic-path-by-stream-id"){var aZ=aY[0];am.GetTopicPathByStreamID(aZ,function(bi){be[be.length]=bi;MadCap.Utilities.CrossFrame._PostMessageResponse(bf,a1,be.length>0?be:null,aS)},null,null);a9.Handled=true;a9.FireResponse=false}else{if(a1=="get-topic-path-by-page-id"){var aV=aY[0];am.GetTopicPathByPageID(aV,function(bi){be[be.length]=bi;MadCap.Utilities.CrossFrame._PostMessageResponse(bf,a1,be.length>0?be:null,aS)},null,null);a9.Handled=true;a9.FireResponse=false}else{if(a1=="hash-changed"){var a3=aY[0];a3=a3.substring(1);history.pushState(null,null,document.location.pathname+document.location.hash+"$"+a3);a9.Handled=true;a9.FireResponse=false}else{if(a1=="forward-ajax-open-success"){var bg=aY[0];var ba=parseInt(aY[1]);var a0=aY[2];au("pulse");MadCap.Utilities.CrossFrame.PostMessageRequest(X(),"ajax-open-success",[bg,ba,a0]);a9.Handled=true;a9.FireResponse=false}else{if(a1=="get-pulse-hash"){var aU="";var aT=MadCap.Utilities.Url.CurrentHash();if(aT.indexOf("#pulse-")==0){aU=aT.substring("#pulse-".length)}be[be.length]=aU;a9.Handled=true;a9.FireResponse=true}else{if(a1=="login-complete"||a1=="logout-complete"){MadCap.Utilities.CrossFrame.PostMessageRequest(X(),"reload");MadCap.Utilities.CrossFrame.PostMessageRequest(frames["community-frame-html5"],"reload");MadCap.Utilities.CrossFrame.PostMessageRequest(frames["topiccomments-html5"],"reload");MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"reload-pulse");aD();U();a9.Handled=true;a9.FireResponse=false}else{if(a1=="close-login-dialog"){aD();a9.Handled=true;a9.FireResponse=false}else{if(a1=="set-pulse-login-id"){if(am!=null){am.PulseUserGuid=aY[0]}U();a9.Handled=true;a9.FireResponse=false}else{if(a1=="get-parent-window-width"){be[be.length]=window.innerWidth;a9.Handled=true;a9.FireResponse=true}else{if(a1=="set-topic-content"){az(aY);a9.Handled=true;a9.FireResponse=false}}}}}}}}}}}}}}}}}}}}return a9},null);$(ap);$(window).resize(aJ);if(Q||!m){$(window).hashchange(z)}var ac=null;var av=null;var n=null;var V=null;var aL=null;var P=null;var aB=null;var am=null;var aR=null;var aa=null;var T=null})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){if(!MadCap.Utilities.HasRuntimeFileType("Default")){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");var b=window.external&&window.external.attached&&window.external.attached();MadCap.WebHelp.TocPane=function(e,i,g,d){var f=this;this._Init=false;this._RuntimeFileType=e;this._RootUl=g;this._CanSync=d;this._HelpSystem=i;this._TocFile=this._RuntimeFileType=="Toc"?this._HelpSystem.GetTocFile():this._HelpSystem.GetBrowseSequenceFile();this._LoadedNodes=[];var h=null;var c=null;MadCap.Utilities.CrossFrame.AddMessageHandler(this.OnMessage,this);this._Initializing=false;this._InitOnCompleteFuncs=new Array();this.TreeNode_Expand=function(s){var t=s.target;var w=$(t).closest("li")[0];if(w==null){return}var v=$(w);var o=v.hasClass(f._TreeNodeLeafClass);if(!o){v.toggleClass(f._TreeNodeExpandedClass).toggleClass(f._TreeNodeCollapsedClass)}var k=v.find("> div img");var u=k.attr("data-mc-alt2");var r=k.attr("alt");if(u!=""){k.attr("alt",u);k.attr("data-mc-alt2",r)}if(f._IncludeIndicator){var x=v.find("> div a");if(x[0]!=null){var j=x.attr("href");if(!MadCap.String.IsNullOrEmpty(j)){f._SelectNode(w)}if(x[0]!=t){var q=x.attr("target");if(!MadCap.String.IsNullOrEmpty(j)){if(q!=null){window.open(j,q)}else{document.location.href=j}}}}}var n=f._LoadedNodes[v.attr("data-mc-id")];if(typeof n.n=="undefined"||n.n.length==0){n.childrenLoaded=true}if(!n.childrenLoaded){var m=$("a",v).first();var p=$("<ul/>");var l=$(f._RootUl).attr("data-mc-css-sub-menu")||"tree inner";p.addClass(l);if(b){p.attr("data-mc-style","Navigation Panel Item")}f.LoadTocChildren(n,p,function(){v.append(p);if(f._DeferExpandEvent){setTimeout(function(){m.trigger(f._ExpandEvent)},100)}});if(f._DeferExpandEvent){s.stopImmediatePropagation();return false}}if(o){$("body").removeClass("active");MadCap.Utilities.Url.OnNavigateTopic.call(t,s)}}};var a=MadCap.WebHelp.TocPane;a.prototype.OnMessage=function(i,f,h){var g={Handled:false,FireResponse:true};if(i=="sync-toc"){var c=f[0];var e=f[1];var d=new MadCap.Utilities.Url(f[2]);if(this._CanSync&&(c==null||c==this._RuntimeFileType)){this.SyncTOC(e,d);g.Handled=true}}return g};a.prototype.Init=function(c){if(this._Init){if(c!=null){c()}return}if(c!=null){this._InitOnCompleteFuncs.push(c)}if(this._Initializing){return}this._Initializing=true;var e=$(this._RootUl);this._SubMenuClass=e.attr("data-mc-css-sub-menu")||"tree inner";this._TreeNodeClass=e.attr("data-mc-css-tree-node")||"tree-node";this._TreeNodeCollapsedClass=e.attr("data-mc-css-tree-node-collapsed")||"tree-node-collapsed";this._TreeNodeExpandedClass=e.attr("data-mc-css-tree-node-expanded")||"tree-node-expanded";this._TreeNodeLeafClass=e.attr("data-mc-css-tree-node-leaf")||"tree-node-leaf";this._TreeNodeSelectedClass=e.attr("data-mc-css-tree-node-leaf")||"tree-node-selected";this._IncludeBack=MadCap.Dom.GetAttributeBool(this._RootUl,"data-mc-include-back",false);this._IncludeParentLink=MadCap.Dom.GetAttributeBool(this._RootUl,"data-mc-include-parent-link",false);this._IncludeIcon=MadCap.Dom.GetAttributeBool(this._RootUl,"data-mc-include-icon",true);this._IncludeIndicator=MadCap.Dom.GetAttributeBool(this._RootUl,"data-mc-include-indicator",true);this._DeferExpandEvent=MadCap.Dom.GetAttributeBool(this._RootUl,"data-mc-defer-expand-event",false);this._ExpandEvent=e.attr("data-mc-expand-event")||"click";this._BackLink=e.attr("data-mc-back-link")||"Back";var d=this;e.attr("data-mc-chunk","Data/"+this._RuntimeFileType+".xml");this.CreateToc(this._RootUl,function(){d._Init=true;for(var f=0;f<d._InitOnCompleteFuncs.length;f++){d._InitOnCompleteFuncs[f]()}})};a.prototype.CreateToc=function(e,c){var f=true;if(this._RuntimeFileType=="Toc"){f=this._HelpSystem.HasToc}else{f=this._HelpSystem.HasBrowseSequences}if(!f){if(c!=null){c()}return}var d=this;d._HelpSystem.LoadToc(this._RuntimeFileType,function(i,h){var g=$(e);if(b){g.attr("data-mc-style","Navigation Panel Item")}d.LoadTocChildren(i.tree,g,function(){this._Init=true;if(c!=null){c()}})},null)};a.prototype.LoadTocChildren=function(h,f,d){var e=typeof h.n!=="undefined"?h.n.length:0;var k=0;if(e==0){h.childrenLoaded=true}if(h.childrenLoaded){if(d){d()}return}if(h.parent){if(this._IncludeBack){var l=$('<li class="back"/>');l.addClass(this._TreeNodeClass);var g=$('<a href="#" />');g.text(this._BackLink);l.append(g);f.append(l)}if(this._IncludeParentLink&&this._HelpSystem.GetTocEntryHref(h)!=null){var l=$("<li/>");l.addClass(this._TreeNodeClass);l.addClass(this._TreeNodeLeafClass);f.append(l);this.LoadTocNode(h,l,null)}}for(var j=0;j<e;j++){var c=h.n[j];var l=$("<li/>");l.addClass(this._TreeNodeClass);l.addClass(this._TreeNodeCollapsedClass);f.append(l);this.LoadTocNode(c,l,function(){k++;if(k==e){h.childrenLoaded=true;if(d!=null){d()}}})}};a.prototype.LoadTocNode=function(f,e,c){var d=this;var g=f.toc;this._HelpSystem.LoadTocChunk(g,f.c,function(q){var r=g.entries[f.i];var l=typeof f.f!="undefined";var j=typeof f.n=="undefined"||f.n.length==0;var n=d._CanSync&&!l?d._RuntimeFileType:null;var i=d._HelpSystem.GetTocEntryHref(f,n,d._CanSync);var k=$("<a/>");if(l){k.attr("target",f.f)}if(i!=null){k.attr("href",i)}else{k.attr("href","javascript:void(0);")}k.text(r.title);if(typeof f.s!="undefined"){e.addClass(f.s)}if(j){e.removeClass(d._TreeNodeCollapsedClass);e.addClass(d._TreeNodeLeafClass)}if(d._IncludeIcon){var s="default";var m=d._HelpSystem.Language;for(className in m){if(e.hasClass(className)){s=className;break}}var h=$("<img/>");h.attr("src","Skins/Default/Stylesheets/Images/transparent.gif");h.addClass("toc-icon");if(d._IncludeIndicator&&typeof f.w!=="undefined"&&f.w==1){h.attr("alt",m[s]["MarkAsNewIconAlternateText"])}else{if(e.hasClass(d._TreeNodeLeafClass)){h.attr("alt",m[s]["TopicIconAlternateText"])}else{h.attr("alt",m[s]["ClosedBookIconAlternateText"]);h.attr("data-mc-alt2",m[s]["OpenBookIconAlternateText"])}}if(h.prop("src")!=""){k.prepend(h)}}if(d._IncludeIndicator){var p=$("<div/>");if(typeof f.w!=="undefined"&&f.w==1){p.append("<span class='new-indicator'></span>")}var o=$('<span class="label" />');o.append(k);p.append(o);k=p}k.on(d._ExpandEvent,d.TreeNode_Expand);f.el=e;e.append(k);e.attr("data-mc-id",d._LoadedNodes.length);d._LoadedNodes.push(f);if(c!=null){c()}})};a.prototype.SyncTOC=function(e,d){var c=this;var f=$("."+this._TreeNodeSelectedClass+" a",this._RootUl);if(f.length>0){var g=f[0];if(g.href===document.location.href){return}}this.Init(function(){function j(l){if(typeof l!=="undefined"&&l!=null){var k=[];var m=l;while(typeof m!=="undefined"&&!m.childrenLoaded){k.unshift(m);m=m.parent}MadCap.Utilities.AsyncForeach(k,function(q,p){var o=$(q.el);var n=$("<ul/>");n.addClass(c._SubMenuClass);c.LoadTocChildren(q,n,function(){o.append(n);p()})},function(){var n=l.el[0];c._UnhideNode(n);c._SelectNode(n)})}}function h(k){c._HelpSystem.FindNode(c._RuntimeFileType,e,k,function(m){if(!m){if(!MadCap.String.IsNullOrEmpty(k.Fragment)||!MadCap.String.IsNullOrEmpty(k.Query)){var l=new MadCap.Utilities.Url(k.PlainPath);c._HelpSystem.FindNode(c._RuntimeFileType,e,l,j)}}else{j(m)}})}var i=d.HashMap.GetItem("cshid");if(i!=null){c._HelpSystem.LookupCSHID(i,function(l){var k=l.Found?new MadCap.Utilities.Url(l.Topic).ToRelative(c._HelpSystem.GetContentPath()):new MadCap.Utilities.Url(c._HelpSystem.DefaultStartTopic);h(k)})}else{h(d)}})};a.prototype._UnhideNode=function(c){var e=MadCap.Dom.GetAncestorNodeByTagName(c,"li",this._RootUl);while(e!=null){var d=$(e);d.removeClass(this._TreeNodeCollapsedClass);d.addClass(this._TreeNodeExpandedClass);e=MadCap.Dom.GetAncestorNodeByTagName(e,"li",this._RootUl)}};a.prototype.NavigateTopic=function(f){var g=$("."+this._TreeNodeSelectedClass,this._RootUl)[0];if(g==null){g=$("."+this._TreeNodeClass,this._RootUl)[0]}if(this.NeedsCreateToc(g)){var e=this;this.CreateToc(g,function(){e.NavigateTopic(f)});return}var c=f=="previous"?this._GetPrevious(g):this._GetNext(g);if(c==null){return}this._SelectNode(c);var d=$("> div a",c)[0];if(d!=null){document.location.href=$(d).attr("href")}this._UnhideNode(c)};a.prototype._SelectNode=function(d){var c=$(d);$("."+this._TreeNodeSelectedClass,this._RootUl).removeClass(this._TreeNodeSelectedClass);c.addClass(this._TreeNodeSelectedClass);c.scrollintoview()};a.prototype._GetNext=function(e){var d=$(e);var f="."+this._TreeNodeClass;if(d.find(f).length>0){return d.find(f)[0]}if(d.next(f).length>0){return d.next(f)[0]}var c=d;while(true){var g=$(c.parent().closest(f,this._RootUl));if(g.length==0){break}if(g.next(f).length>0){return g.next(f)[0]}c=g}return null};a.prototype._GetPrevious=function(e){var d=$(e);var f="."+this._TreeNodeClass;var c=d.prev(f);if(c.length==0){if(d.parent().closest(f,this._RootUl).length>0){return d.parent().closest(f,this._RootUl)[0]}else{return null}}if(c.find(f).length>0){return c.find(f).last()[0]}return c[0]}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){if(!MadCap.Utilities.HasRuntimeFileType("TriPane")){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.IndexPane=function(c){var b=this;this._Init=false;this._ContainerEl=null;this._HelpSystem=c;this._EntryHeight=-1;this._IndexEntryCount=0;this._IndexEntries=Object.create(null);this._IndexDivs=new Array();this._XmlDoc=null;this._Chunks=null;this._AlphaMap=new MadCap.Utilities.Dictionary();this._LiCached=null;this._SeePrefix=null;this._SeeAlsoPrefix=null;this.GetPath=function(d,e){return MadCap.String.IsNullOrEmpty(d)?new MadCap.Utilities.Url(e).ToRelative("/Content/").FullPath:"../"+new MadCap.Utilities.Url(d+e).FullPath};this.LoadRootEntry=function(e,d){var g=$(e);var f=g.data("entry");b._HelpSystem.LoadRootIndexEntry(f,function(i){if(i.e&&!i.childrenLoaded){var h=$("<ul/>");h.addClass("tree inner");b.LoadEntries(h,i.e);g.append(h)}i.childrenLoaded=true;g.data("entry",i);if(d){d(i,g)}})};this.LoadEntries=function(g,d){var f=this;if(!$.isArray(d)){var e=[];$.each(d,function(h,i){if(!i.t){i.t=h}e.push(i)});e.sort(function(i,h){var k=(i.s||i.t).toLowerCase();var j=(h.s||h.t).toLowerCase();return MadCap.String.LocaleCompare(k,j,b._HelpSystem.LanguageCode)});d=e}$.each(d,function(q,v){var r=$("<li/>");r.addClass("IndexEntry tree-node tree-node-collapsed");var l=v.t;var o=v.r=="See";var h=v.r=="SeeAlso";var j=$("<div/>");j.addClass("IndexTerm");var t=$("<span/>").addClass("label");j.append(t);var u=true;if(o){l=f._SeePrefix+": "+v.f;j.addClass("see");v.seeAlsoLinks=[v.f]}else{if(h){l=f._SeeAlsoPrefix+": ";v.seeAlsoLinks=[];seeAlsoLinks=v.f.split("; ");if(seeAlsoLinks.length>1){var k=$("<a/>").text(l);t.append(k);for(var n=0;n<seeAlsoLinks.length;n++){var s=seeAlsoLinks[n];var p=$("<a/>").addClass("seeAlsoLink").text(s);t.append(p);v.seeAlsoLinks.push(s);if(n<seeAlsoLinks.length-1){t.append("; ")}}u=false}else{l+=v.f;v.seeAlsoLinks.push(v.f)}j.addClass("see-also")}}if(u){var k=$("<a/>").text(l);t.append(k)}r.append(j);v.isRoot=typeof v.$!=="undefined";if(v.e){var m=$("<ul/>");m.addClass("tree inner");f.LoadEntries(m,v.e);r.append(m)}else{if(v.$===1||!v.isRoot){r.removeClass("tree-node-collapsed");r.addClass("tree-node-leaf")}}g.append(r);v.el=r[0];r.data("entry",v);if(!o&&!h){if(typeof f._IndexEntries[l]=="undefined"){f._IndexEntries[l]=[v]}else{f._IndexEntries[l].push(v)}}})};this.FindEntry=function(e,d){b._HelpSystem.FindIndexEntry(e,function(f,g){if(!g){return}b.LoadRootEntry(f.el,function(){if(d){d(g)}})})};this.SelectEntry=function(i,m,j,k,n){$(".tree-node-selected",b._ContainerEl).removeClass("tree-node-selected");j.addClass("tree-node-selected");if(!m){return}MadCap.TextEffects.RemoveLinkListTrees();var l=i.pageY-k.offset().top;var d=i.pageX-k.offset().left;var f=!this._HelpSystem.IsTabletLayout()||!this._HelpSystem.IsResponsive;if(m.r&&!n){var h=$(".seeAlsoLink",j).index(i.target);var g=m.seeAlsoLinks[0];if(h>=0){g=m.seeAlsoLinks[h]}g=g.replace(", ",":");this.FindEntry(g,function(e){j=$(e.el);$container=f?$(b._ContainerEl).parent():$("#navigation");b._UnhideNode(j[0]);b.SelectEntry(i,e,j,k,true);$container.animate({scrollTop:$container.scrollTop()+j.offset().top-$container.offset().top})});return}else{if(m.linkList&&m.linkList.length>1&&!n){if(f){MadCap.TextEffects.CreateLinkListPopup(m.linkList,b._ContainerEl,l,d,k,"#")}else{MadCap.TextEffects.CreateLinkListTree(m.linkList,j,k,"#",function(o){b.TreeNode_Click(o);MadCap.TextEffects.Item_Click.call($(o.currentTarget),[o])})}MadCap.Utilities.PreventDefault(i);i.stopPropagation()}else{if(m.linkList&&m.linkList.length==1){document.location.href="#"+m.linkList[0].Link}}}if(j.hasClass("tree-node-expanded")&&!n){j.removeClass("tree-node-expanded");j.addClass("tree-node-collapsed")}else{if(j.hasClass("tree-node-collapsed")){j.removeClass("tree-node-collapsed");j.addClass("tree-node-expanded")}}};this.TreeNode_Click=function(h){var d=MadCap.Dom.GetAncestorNodeByTagName(h.target,"li");if(d==null){return}if($(h.target).closest(".link-list-popup").length>0){return}var g=$(this);var i=$(d);MadCap.Utilities.PreventDefault(h);var f=i.data("entry");if(!i.hasClass("IndexEntryLink")&&(!f||f.isRoot)){b.LoadRootEntry(d,function(e,j){b.SelectEntry(h,e,j,g)})}else{b.SelectEntry(h,f,i,g)}};this.Search=function(){var d=this.value.toLowerCase();b._Terms.each(function(){var e=$(this);var f=e.parent().parent();var g=b._HelpSystem.IndexPartialWordSearch?e.text().toLowerCase().indexOf(d)!=-1:MadCap.String.StartsWith(e.text(),d,false);f.css("display",g?"block":"none");if(b._HelpSystem.IndexPartialWordSearch){e.removeHighlight("highlightIndex");if(g){e.highlight(d,"highlightIndex")}}})}};var a=MadCap.WebHelp.IndexPane;a.prototype.Init=function(e,b){if(this._Init){if(b!=null){b()}return}var d=this;d._ContainerEl=e;var c=$(this._ContainerEl.parentNode);this._SeePrefix=c.attr("data-see-prefix")||"See";this._SeeAlsoPrefix=c.attr("data-see-also-prefix")||"See Also";d._HelpSystem.LoadIndex(function(h,g){var f=$("<ul/>");f.addClass("tree");d.LoadEntries(f,h.terms);var j=$(d._ContainerEl);j.click(d.TreeNode_Click);j.append(f);var i=$("#search-index");i.bind("keyup",d.Search);$("#responsive-search-index").bind("keyup",d.Search);d._Terms=$(".IndexEntry a",this._ContainerEl);d._Init=true;if(b!=null){b()}},null)};a.prototype._UnhideNode=function(c){var b=MadCap.Dom.GetAncestorNodeByTagName(c,"li",this._ContainerEl);while(b!=null){var d=$(b);d.removeClass("tree-node-collapsed");d.addClass("tree-node-expanded");b=MadCap.Dom.GetAncestorNodeByTagName(b,"li",this._ContainerEl)}}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){if(!MadCap.Utilities.HasRuntimeFileType("TriPane")){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.GlossaryPane=function(c){var b=this;this._Init=false;this._ContainerEl=null;this._HelpSystem=c;MadCap.Utilities.CrossFrame.AddMessageHandler(this.OnMessage,this);this.TreeNode_Click=function(j){var d=MadCap.Dom.GetAncestorNodeByTagName(j.target,"li");if(d==null){return}var l=$(d);var i=$("a",l);var h=i.text();var k=l.attr("data-chunk");var f=b._HelpSystem.Glossary.chunks[k].path;var g=new MadCap.Utilities.Url(f).ToFolder().ToFolder();MadCap.Utilities.PreventDefault(j);require([f],function(n){var o=n[h];$(".tree-node-selected",b._ContainerEl).removeClass("tree-node-selected");l.addClass("tree-node-selected");var e=$(".GlossaryPageTerm",d);if(!MadCap.String.IsNullOrEmpty(o.d)&&!e.hasClass("MCDropDownHead")){e.addClass("MCDropDownHead MCDropDownHotSpot");var s=$("<div/>");s.addClass("GlossaryPageDefinition MCDropDownBody");s.append(o.d);l.addClass("MCDropDown");l.append(e);l.append(s);var p=new MadCap.TextEffects.DropDownControl(l[0]);p.Init(false);p.Open(true)}if(!MadCap.String.IsNullOrEmpty(o.l)){var m=i.attr("href");if(MadCap.String.IsNullOrEmpty(m)){var q=g.CombinePath(o.l).ToRelative(b._HelpSystem.GetContentPath()).FullPath;m=encodeURI(q);i.attr("href",m)}document.location.href="#"+m}else{if(l.hasClass("tree-node-expanded")){l.removeClass("tree-node-expanded");l.addClass("tree-node-collapsed")}else{if(l.hasClass("tree-node-collapsed")){l.removeClass("tree-node-collapsed");l.addClass("tree-node-expanded");if($("li",l.parent()).last()[0]==l[0]){var r=$(b._ContainerEl);r.animate({scrollTop:r[0].scrollHeight},500)}}}}})};this.Search=function(){var d=this.value.toLowerCase();b._Terms.each(function(){var e=$(this);var f=e.parent().parent();var g=b._HelpSystem.GlossaryPartialWordSearch?e.text().toLowerCase().indexOf(d)!=-1:MadCap.String.StartsWith(e.text(),d,false);f.css("display",g?"block":"none");if(b._HelpSystem.GlossaryPartialWordSearch){e.removeHighlight("highlightGlossary");if(g){e.highlight(d,"highlightGlossary")}}})}};var a=MadCap.WebHelp.GlossaryPane;a.prototype.OnMessage=function(e,b,d){var c={Handled:false,FireResponse:true};return c};a.prototype.Init=function(d,b){if(this._Init){if(b!=null){b()}return}var c=this;c._ContainerEl=d;c._HelpSystem.LoadGlossary(function(f,l){var h=$("<ul/>");h.addClass("tree");var k=f.terms.sort(function(p,i){return MadCap.String.LocaleCompare(p.s||p.t,i.s||i.t,c._HelpSystem.LanguageCode)});for(var g=0;g<k.length;g++){var n=k[g];var m=$("<li/>");m.addClass("GlossaryPageEntry tree-node tree-node-collapsed");m.attr("data-chunk",n.c);var e=$("<div/>");e.addClass("GlossaryPageTerm");e.append('<span class="label"><a>'+n.t+"</a></span>");m.append(e);h.append(m)}var o=$(c._ContainerEl);o.click(c.TreeNode_Click);o.append(h);var j=$("#search-glossary");j.bind("keyup",c.Search);$("#responsive-search-glossary").bind("keyup",c.Search);c._Terms=$(".GlossaryPageTerm a",c._ContainerEl);c._Init=true;if(b!=null){b()}},null)};a.prototype._SelectNode=function(b){$(".tree-node-selected",this._ContainerEl).removeClass("tree-node-selected");$(b).addClass("tree-node-selected")}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){var a=MadCap.CreateNamespace("WebHelp.Search");a.Tokenizer=function(){var g="";var h=-1;var f=new Array();this.Tokenize=function(l){var k=null;g=l;h=-1;for(var j=0;k=i();j++){f[j]=k}return f};function c(){return g.charAt(h+1)}function e(){h++}function d(){var j="";for(;;){var k=c();if(!k){break}if(k=='"'){e();break}else{e();j+=k}}return(j=="")?null:j}function i(){var n=c();var k=null;var j="";if(!n){k=null}else{if(a.IsWhiteSpace(n)){for(n=c();a.IsWhiteSpace(n);n=c()){e();j+=n}k=new a.Token(j,a.Token.WhiteSpace)}else{if(n=="("){e();k=new a.Token(n,a.Token.LeftParen)}else{if(n==")"){e();k=new a.Token(n,a.Token.RightParen)}else{if(n=="^"||n=="!"){e();k=new a.Token(n,a.Token.Not)}else{if(n=="+"||n=="&"){e();k=new a.Token(n,a.Token.And)}else{if(n=="|"){e();k=new a.Token(n,a.Token.Or)}else{if(n=='"'){e();var m=d();k=new a.Token(m,(m==null)?a.Token.Error:a.Token.Phrase)}else{if(a.IsTermSeparator(n)){e();k=new a.Token(n,a.Token.TermSeparator)}else{for(n=c();a.IsNameChar(n);n=c()){e();j+=n}if(j=="and"||j=="AND"){k=new a.Token(j,a.Token.And)}else{if(j=="or"||j=="OR"){k=new a.Token(j,a.Token.Or)}else{if(j=="not"||j=="NOT"){k=new a.Token(j,a.Token.Not)}else{var l=a.Token.Word;if(MadCap.WebHelp.SearchPane.SearchDBs[0].SearchType=="NGram"){l=a.Token.Phrase}k=new a.Token(j,l)}}}}}}}}}}}}return k}};a.Token=function(c,e){var d=c;var f=e;this.GetTokenText=function(){return d};this.GetType=function(){return f}};var b=a.Token;b.Eof=0;b.Error=1;b.WhiteSpace=2;b.Phrase=3;b.Word=4;b.RightParen=5;b.LeftParen=6;b.Not=7;b.And=8;b.Or=9;b.ImplicitAnd=10;b.TermSeparator=11;a.Parser=function(g){var i=this;var k=g;var d=-1;var h=new a.Tokenizer();var c=h.Tokenize(k);this.ParseExpression=function(){var n=j();f();if(e()==a.Token.Eof){return n}else{if(e()==a.Token.And||e()==a.Token.Or||e()==a.Token.Not){l();var m=new a.Node(c[d],n,this.ParseExpression());return m}else{if(e()==a.Token.Word||e()==a.Token.Phrase||e()==a.Token.Not||e()==a.Token.LeftParen){var m=new a.Node(new a.Token(n.GetToken().GetTokenText()+" "+c[d+1].GetTokenText(),a.Token.ImplicitAnd),n,this.ParseExpression());return m}else{if(e()==a.Token.RightParen){return n}}}}throw gInvalidTokenLabel};function l(){d++}function j(){f();if(e()==a.Token.Word){l();return new a.Node(c[d],null,null)}else{if(e()==a.Token.Phrase){l();return new a.Node(c[d],null,null)}else{if(e()==a.Token.LeftParen){l();var m=c[d];var n=new a.Node(m,i.ParseExpression(),null);if(e()!=a.Token.RightParen){throw"Missing right paren ')'."}l();return n}}}throw gInvalidTokenLabel}function e(){if(c[d+1]==null){return a.Token.Eof}else{return c[d+1].GetType()}}function f(){for(;e()==a.Token.WhiteSpace||e()==a.Token.TermSeparator;){l()}}};a.Node=function(e,f,d){var c=e;var h=f;var g=d;this.Evaluate=function(k,i){var j=this;var l=c.GetType();if(l==a.Token.Word||l==a.Token.Phrase){this.EvaluatePhrase(k).then(i)}else{if(l==a.Token.And||l==a.Token.ImplicitAnd||l==a.Token.Or||l==a.Token.Not){h.Evaluate(k,function(m){g.Evaluate(k,function(n){if(c.GetType()==a.Token.And||c.GetType()==a.Token.ImplicitAnd){i(a.IntersectResults(m,n))}else{if(c.GetType()==a.Token.Or){i(a.UnionResults(m,n))}else{if(c.GetType()==a.Token.Not){i(a.SubtractResults(m,n))}}}})})}else{if(l==a.Token.LeftParen){if(h){h.Evaluate(k,i)}else{i(null)}}else{i(null)}}}};this.EvaluatePhrase=function(n){var q=this;var r=$.Deferred();var i=c.GetTokenText();var k=c.GetType()==a.Token.Phrase;var p=[];var o=Object.create(null);o.results=Object.create(null);o.terms=[];o.ignore=MadCap.Utilities.StopWords.indexOf(i)>-1;if(!o.ignore){o.terms.push(i);for(var m=0;m<MadCap.WebHelp.SearchPane.SearchDBs.length;m++){var l=MadCap.WebHelp.SearchPane.SearchDBs[m];p.push(l.LookupPhrase(i,k,n).then(function(j,s){if(s){dbIndex=MadCap.WebHelp.SearchPane.SearchDBs.indexOf(j);o.results[dbIndex]={data:s}}}))}}$.when.apply(this,p).done(function(){r.resolve(o)});return r.promise()};this.GetToken=function(){return c}};a.LoadResultData=function(h){var k=[];var i=0;var d=h.results;for(var f in d){var e=MadCap.WebHelp.SearchPane.SearchDBs[f];var g=d[f];k.push(e.LoadTopics(g).then(function(m){i+=m.count}))}var l=MadCap.WebHelp.SearchPane.SearchDBs[0].RelevanceWeight;var j=$.Deferred();var c=[];$.when.apply(this,k).done(function(){for(var r in d){var n=MadCap.WebHelp.SearchPane.SearchDBs[r];var p=d[r];for(var o in p.data){var t=p.data[o];var q=n.HelpSystem.GetTopicPath(t.u).FullPath;var m=t.i*p.count/i;var s=MadCap.Utilities.CalculateScore(t.r,m,l);c.push(new a.SearchResult(s,t.t,q,t.a))}}j.resolve(c,h.terms)});return j.promise()};a.IsNameChar=function(d){if(!d){return false}else{if(d=='"'){return false}else{if(d=="+"){return false}else{if(d=="^"){return false}else{if(d=="|"){return false}else{if(d=="&"){return false}else{if(a.IsWhiteSpace(d)){return false}else{if(a.IsTermSeparator(d)){return false}else{return true}}}}}}}}};a.IsWhiteSpace=function(d){if(!d){return false}else{if(d==" "){return true}else{if(d.charCodeAt(0)==12288){return true}else{return false}}}};a.IsTermSeparator=function(d){return(MadCap.String.IsPunctuation(d)&&d!="'"&&d!="_")||d==">"||d=="<"||d=="="};a.SplitPhrase=function(f){var e=null;var c=MadCap.WebHelp.SearchPane.SearchDBs[0];if(c.SearchType=="NGram"){e=new Array(Math.max(0,f.length-(c.NGramSize+1)));for(var d=0;d<f.length-c.NGramSize+1;d++){e[d]=f.substring(d,d+c.NGramSize)}}else{e=MadCap.String.Split(f,function(g){return a.IsWhiteSpace(g)||a.IsTermSeparator(g)})}return e};a.FilterResults=function(e,d,j,c){if((e.ignore&&d.ignore)||d.ignore){return e}else{if(e.ignore){return d}}var i=Object.create(null);i.results=Object.create(null);var k=i.results;for(var h in e.results){k[h]=Object.create(null);k[h].data=Object.create(null);var g=e.results[h].data;var f=d.results[h];if(f){f=f.data}j(g,f,k[h].data)}i.terms=c(e.terms,d.terms);return i};a.UnionResults=function(d,c){return a.FilterResults(d,c,function(f,j,e){for(var h in f){e[h]=f[h]}if(j){for(var h in j){var i=f[h];var g=j[h];if(i){e[h]={r:MadCap.Utilities.CombineRelevancy(i.r,g.r)}}else{e[h]=g}}}},function(f,e){return f.Union(e)})};a.IntersectResults=function(d,c){return a.FilterResults(d,c,function(f,i,e){if(i){for(var h in f){var g=i[h];if(g){e[h]={r:MadCap.Utilities.CombineRelevancy(f[h].r,g.r)}}}}},function(f,e){return f.Union(e)})};a.SubtractResults=function(d,c){if(d.ignore||c.ignore){return d}return a.FilterResults(d,c,function(f,i,e){if(i){for(var h in f){var g=i[h];if(!g){e[h]=f[h]}}}},function(f,e){return f})}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.SearchPane=function(f,e){this._Init=false;this._Container=e;this._HelpSystem=f;this._FeedbackController=null;this._Parser=null;this._Filters=null;this._Set=null;this._FilteredSet=null;this._Highlight="";this._DownloadedSynonymXmlDocRootNode=null};var c=MadCap.WebHelp.SearchPane;c.SearchDBs=new Array();c.prototype.Init=function(e){if(this._Init){if(e){e.call(this)}return}var h=this;if(this._HelpSystem.LiveHelpEnabled){this._FeedbackController=MadCap.WebHelp.LoadFeedbackController(this._HelpSystem.LiveHelpServer);this._FeedbackController.Init(function(){if(h._FeedbackController.FeedbackActive){h._FeedbackController.GetSynonymsFile(h._HelpSystem.LiveHelpOutputId,null,function(k,i){var j=MadCap.Utilities.Xhr.LoadXmlString(k);if(j!=null){h._DownloadedSynonymXmlDocRootNode=j.documentElement}g()},null)}else{g()}})}else{g()}function g(){if(!h._HelpSystem.IsWebHelpPlus){h._HelpSystem.GetSearchDBs(f)}else{f(null)}}function f(i){c.SearchDBs=i;h._Filters=new b.Filters(h._HelpSystem);h._Filters.Load(function(){h._Init=true;if(e){e.call(h)}})}};c.prototype.Search=function(g,f){if(MadCap.String.IsNullOrEmpty(MadCap.String.Trim(g))){return}this._Container.addClass("loading");var e=$.Deferred();this.Init(function(){var j={};var h=[];if(f.searchContent){var i=f.content?f.content.filterName:null;var k=!this._HelpSystem.IsWebHelpPlus?this.DoSearch(g,i):this.DoSearchWebHelpPlus(g,i);h.push(k.then(function(m,n){j.content=m;j.includedTerms=n}))}if(f.searchGlossary){h.push(this._HelpSystem.SearchGlossary(g).then(function(m){j.glossary=m}))}if(f.searchCommunity){if(this._FeedbackController&&this._FeedbackController.PulseActive){var l=this._FeedbackController.GetPulseSearchResults(this._HelpSystem.LiveHelpOutputId,g,f.community.pageSize,f.community.pageIndex);h.push(l.then(function(m){j.community=m}))}}$.when.apply(this,h).done($.proxy(function(){this._Container.removeClass("loading");e.resolve(j)},this))});return e.promise()};c.prototype.DoSearch=function(k,i){var g=$.Deferred();this._Parser=new b.Parser(k);var f=null;try{f=this._Parser.ParseExpression()}catch(j){alert("Ensure that the search string is properly formatted.");f=null}if(!f){return g.resolve()}var e=c.SearchDBs[0];if(this._DownloadedSynonymXmlDocRootNode!=null&&e.DownloadedSynonymFile==null){e.DownloadedSynonymFile=new b.SynonymFile(this._DownloadedSynonymXmlDocRootNode,e.Stemmer)}var h=this;f.Evaluate(i,function(l){b.LoadResultData(l).then(function(m,n){h._Set=m;if(h._Set){h._Set.sort(function(p,o){return o.Score-p.Score})}MadCap.Utilities.ClearRequireCache();g.resolve(h._Set,n)})});return g.promise()};c.prototype.DoSearchWebHelpPlus=function(m,k){var h=this;var g=$.Deferred();function f(A,v){var y=[];var p=A.getElementsByTagName("Result");var s=p.length;var u=new MadCap.Utilities.Url(document.location.pathname);if(!h._HelpSystem.SearchUrl){if(!MadCap.String.EndsWith(document.location.pathname,"/")){u=u.ToFolder()}u=u.CombinePath(h._HelpSystem.ContentFolder)}for(var q=0;q<s;q++){var z=p[q];var o=MadCap.Dom.GetAttributeInt(z,"Rank",-1);var x=z.getAttribute("Title");var w=z.getAttribute("Link");var t=new MadCap.Utilities.Url(w).ToRelative(u);var n=z.getAttribute("AbstractText");if(MadCap.String.IsNullOrEmpty(x)){x=z.getAttribute("Filename")}var r=new b.SearchResult(o,x,t.FullPath,unescape(n));y.push(r)}g.resolve(y)}MadCap.Utilities.Xhr.CallWebService(h._HelpSystem.GetPath()+"Service/Service.asmx/GetSearchResults?SearchString="+encodeURIComponent(m)+"&FilterName="+encodeURIComponent(k),true,f,null);var l=m.split(" ");var e=true;this._Highlight="?Highlight=";for(var j=0;j<l.length;j++){if(!e){this._Highlight+="||"}else{e=false}this._Highlight+=l[j]}return g.promise()};var b=MadCap.CreateNamespace("WebHelp.Search");MadCap.WebHelp.Search.SearchDB=function(e){this.RelevanceWeight=0;this.TopicChunkMap=null;this.UrlChunkMap=null;this.StemChunkMap=null;this.PhraseChunkMap=null;this.HelpSystem=e;this.SearchType=null;this.NGramSize=0;this.Stemmer=null;this.SynonymFile=null;this.DownloadedSynonymFile=null;this.LoadChunkCompleteFuncs=new MadCap.Utilities.Dictionary()};var a=b.SearchDB;a.prototype.Load=function(g,e){var f=this;this.LoadStemmer(this.HelpSystem.LanguageName,function(){MadCap.Utilities.Xhr.Load(f.HelpSystem.GetPath()+"Data/Synonyms.xml",true,function(h){if(h!=null){f.SynonymFile=new b.SynonymFile(h.documentElement,f.Stemmer)}f._LoadSearchDB(g,e)},null,this)})};a.prototype.LoadStemmer=function(j,e){var f=["danish","dutch","english","finnish","french","german","hungarian","italian","norwegian","portuguese","romanian","russian","spanish"];var i=null;this.Stemmer={stemWord:function(k){if(k!=null){k=k.toLowerCase()}if(i!=null){k=i.stemWord(k)}return k}};if(j!=null&&f.indexOf(j.toLowerCase())!=-1){var h="stemmer-"+j.toLowerCase()+".amd.min.js";var g=MadCap.Utilities.HasRuntimeFileType("SkinPreview")?"../WebHelp2/Scripts/Stemmers/":this.HelpSystem.GetPath()+"Resources/Scripts/";require([g+h],function(k){i=new k[j+"Stemmer"];e()})}else{e()}};a.prototype.GetTermPhrases=function(h,f,i){var o=this;var k=new MadCap.Utilities.Dictionary();var g=this.Stemmer.stemWord(h);var l=new MadCap.Utilities.Dictionary();k.Add(g,true);if(!f){if(this.SynonymFile!=null){this.SynonymFile.AddSynonymStems(h,g,k)}if(this.DownloadedSynonymFile!=null){this.DownloadedSynonymFile.AddSynonymStems(h,g,k)}}var e=Object.create(null);var j=[];k.ForEach(function(r,s){if(o.SearchType=="NGram"){for(var q=0;q<r.length-o.NGramSize+1;q++){var p=r.substring(q,q+o.NGramSize);j.push(p)}}else{j.push(r)}});var n=[];$.each(j,function(p,q){n.push(o.LoadStem(q).then(function(s){for(var r in s){if(!f||r==h.toLowerCase()){var t=s[r];if(i){t=i.Intersect(t)}l.Add(r,t)}}}))});var m=$.Deferred();$.when.apply(this,n).done(function(){m.resolve(h,l)});return m.promise()};a.prototype.LookupPhrase=function(m,k,e){var o=this;var w=$.Deferred();var f=b.SplitPhrase(m);var h=null;var n=[];var l=new MadCap.Utilities.Dictionary();if(m){m=m.trim()}if(!m||MadCap.Utilities.StopWords.indexOf(m)>-1){w.resolve(o,null);return w.promise()}var j;if(e){j=[];var r=this.HelpSystem.GetMasterHelpsystem().GetSearchFilters();if(r){var u=r[e];if(u){var g=u.c;var v=g.split(";");var t=this.HelpSystem.GetConcepts();for(var q=0;q<v.length;q++){var s=v[q];j=j.Union(t[s])}}}}for(var q=0;q<f.length;q++){var p=f[q];n.push(this.GetTermPhrases(p,k,j).then(function(i,x){l.Add(i,x)}))}$.when.apply(o,n).done(function(){var A;l.ForEach(function(C,B){var D=[];B.ForEach(function(E,F){D=D.Union(F)});if(!A){A=D}else{A=A.Intersect(D)}});var x=Object.create(null);var z=[];l.ForEach(function(C,B){x[C]=Object.create(null);B.ForEach(function(D,F){var E=F.Intersect(A);$.each(E,function(G,H){z.push(o.LoadPhrase(D,H).then(function(I,K){var J=x[C][I];if(K){if(!J){x[C][I]=K}else{J.r=MadCap.Utilities.CombineRelevancy(J.r,K.r);$.extend(true,J.w,K.w)}}}))})})});var y=Object.create(null);var i=Object.create(null);$.when.apply(this,z).done(function(){$.each(A,function(G,J){var L=0;if(!k){L=x[f[0]][J].r}else{var K=x[f[0]][J].w;for(var C in K){var D=K[C];for(var I=1;I<f.length;I++){var H=parseInt(C);var F=f[I];var E=x[F][J].w;var B=E[H+I];if(B){D=Math.max(D,B)}else{D=0;break}}L=MadCap.Utilities.CombineRelevancy(L,D)}}if(L>0){i[J]={r:L}}});w.resolve(o,i)})});return w.promise()};a.prototype.LoadTopics=function(h){var e=[];var i=h.data;for(var g in i){e.push(this.LoadTopic(g).then(function(j,k){$.extend(i[j],k)}))}h.count=e.length;var f=$.Deferred();$.when.apply(this,e).done(function(){f.resolve(h)});return f.promise()};a.prototype._LoadSearchDB=function(f,e){this.TopicChunkMap=f.t;this.UrlChunkMap=f.u;this.StemChunkMap=f.s;this.PhraseChunkMap=f.p;this.RelevanceWeight=f.r;this.SearchType=f.st;this.NGramSize=f.n;if(e){e()}};a.prototype.LookupPhraseChunkId=function(e,j){var f=this.PhraseChunkMap.length;for(var g=0;g<f;g++){var h=this.PhraseChunkMap[g][0];var k=MadCap.String.Compare(e,h);if(k==0){if(j<this.PhraseChunkMap[g][1]){return g-1}else{if(j==this.PhraseChunkMap[g][1]){return g}}}else{if(k==-1){return g-1}}}return f-1};a.prototype.LoadTopic=function(g){var f=$.Deferred();var e=MadCap.Utilities.GetChunkId(this.TopicChunkMap,g,function(i,h){if(i<h){return -1}else{if(i==h){return 0}else{return 1}}});if(e==-1){f.resolve()}else{MadCap.Utilities.Require([this.HelpSystem.GetPath()+"Data/SearchTopic_Chunk"+e],function(h){f.resolve(g,h[g])})}return f.promise()};a.prototype.LoadUrl=function(g){var f=$.Deferred();var e=MadCap.Utilities.GetChunkId(this.UrlChunkMap,g,function(i,h){return MadCap.String.Compare(i,h)});if(e==-1){f.resolve()}else{MadCap.Utilities.Require([this.HelpSystem.GetPath()+"Data/SearchUrl_Chunk"+e],function(h){f.resolve(g,h[g])})}return f.promise()};a.prototype.LoadTopicByUrl=function(f){var e=this;return this.LoadUrl(f).then(function(g,h){return e.LoadTopic(h)})};a.prototype.LoadStem=function(j){var g=this;var f=$.Deferred();var i=MadCap.Utilities.GetChunkIds(this.StemChunkMap,j,function(l,k){return MadCap.String.Compare(l,k)});if(i.length===0){f.resolve()}else{var h=[];var e=Object.create(null);$.each(i,function(l,k){h.push(g.LoadStemChunk(k).then(function(m){$.extend(e,m[j])}))});$.when.apply(this,h).done(function(){f.resolve(e)},this)}return f.promise()};a.prototype.LoadStemChunk=function(f){var e=$.Deferred();MadCap.Utilities.Require([this.HelpSystem.GetPath()+"Data/SearchStem_Chunk"+f],function(g){e.resolve(g)});return e.promise()};a.prototype.LoadPhrase=function(e,h){var g=$.Deferred();var f=this.LookupPhraseChunkId(e,h);MadCap.Utilities.Require([this.HelpSystem.GetPath()+"Data/SearchPhrase_Chunk"+f],function(j){var i;if(j[e]){i=j[e][h]}g.resolve(h,i)});return g.promise()};b.SearchQuery=function(g,f,e){function h(m,o){var l=false;for(var k=0;k<o.length;k++){var j=o[k][0];var n=o[k][1];if(!MadCap.String.IsNullOrEmpty(n)){m+=(l?"&":"?")+j+"="+encodeURIComponent(n);l=true}}return m}this.Query=g;this.Filter=f;this.PageIndex=e;this.ToString=function(){return h(this.Query,[[b.SearchQuery._filter,this.Filter],[b.SearchQuery._pageIndex,this.PageIndex]])}};b.SearchQuery._filter="f";b.SearchQuery._pageIndex="p";b.SearchQuery.Parse=function(i){var g=new MadCap.Utilities.Url(i);var h=g.PlainPath;if(!MadCap.String.IsNullOrEmpty(h)){h=decodeURIComponent(h)}var f=g.QueryMap.GetItem(b.SearchQuery._filter);if(f){f=decodeURIComponent(f)}var e=g.QueryMap.GetItem(b.SearchQuery._pageIndex);if(e!=null){e=parseInt(e)}return new b.SearchQuery(h,f,e)};b.SearchResult=function(h,g,f,e){this.Score=h;this.Title=g;this.Link=f;this.AbstractText=e};b.Filters=function(f){var e=f;this.Load=function(g){e.LoadSearchFilters().then(function(){e.LoadAllConcepts(function(){g()})},null,null)}};b.SynonymFile=function(e,f){this.Stemmer=f;this.WordToStem=new MadCap.Utilities.Dictionary(true);this.Directionals=new MadCap.Utilities.Dictionary(true);this.DirectionalStems=new MadCap.Utilities.Dictionary(true);this.Groups=new MadCap.Utilities.Dictionary(true);this.GroupStems=new MadCap.Utilities.Dictionary(true);this.GroupStemSources=new MadCap.Utilities.Dictionary(true);this.LoadSynonymFile(e)};var d=b.SynonymFile;d.prototype.LoadSynonymFile=function(E){var D=MadCap.Dom.GetChildNodeByTagName(E,"Groups",0);var l=MadCap.Dom.GetChildNodeByTagName(E,"Directional",0);if(l!=null){var o=l.childNodes.length;for(var A=0;A<o;A++){var n=l.childNodes[A];if(n.nodeName=="DirectionalSynonym"){var y=MadCap.Dom.GetAttribute(n,"From");var m=MadCap.Dom.GetAttribute(n,"To");var r=MadCap.Dom.GetAttributeBool(n,"Stem",false);var g=MadCap.Dom.GetAttribute(n,"FromStem");var p=MadCap.Dom.GetAttribute(n,"ToStem");if(r){if(g==null){g=this.Stemmer.stemWord(y)}}if(p==null){p=this.Stemmer.stemWord(m)}if(y!=null&&m!=null){if(r){this.DirectionalStems.Add(g,p);this.WordToStem.Add(y,g);this.WordToStem.Add(m,p)}else{this.Directionals.Add(y,p);this.WordToStem.Add(m,p)}}}}}if(D!=null){var o=D.childNodes.length;for(var A=0;A<o;A++){var n=D.childNodes[A];if(n.nodeName=="SynonymGroup"){var v=new Array();var w=new Array();var r=MadCap.Dom.GetAttributeBool(n,"Stem",false);var t=n.childNodes.length;for(var z=0;z<t;z++){var C=n.childNodes[z];if(C.nodeType!=1){continue}v.push(C.firstChild.nodeValue)}for(var z=0;z<t;z++){var C=n.childNodes[z];if(C.nodeType!=1){continue}var F=MadCap.Dom.GetAttribute(C,"Stem");if(F==null){F=this.Stemmer.stemWord(C.firstChild.nodeValue)}this.WordToStem.Add(C.firstChild.nodeValue,F);w.push(F)}var u=v.length;for(var z=0;z<u;z++){var B=v[z];var f=w[z];for(var x=0;x<u;x++){var e=v[x];if(r){var s=this.GroupStemSources.GetItem(B);if(s==null){s=new MadCap.Utilities.Dictionary();this.GroupStemSources.Add(B,s)}s.Add(e,f)}else{var s=this.GroupStemSources.GetItem(B);if(s==null){s=new MadCap.Utilities.Dictionary();this.Groups.Add(B,s)}s.Add(e,f)}}}var q=w.length;for(var z=0;z<q;z++){var f=w[z];for(var x=0;x<q;x++){var h=w[x];var s=this.GroupStems.GetItem(f);if(s==null){s=new MadCap.Utilities.Dictionary();this.GroupStems.Add(f,s)}s.Add(h,f)}}}}}};d.prototype.AddSynonymStems=function(e,i,g){var f=this.Directionals.GetItem(e);if(f!=null){g.AddUnique(f)}f=this.DirectionalStems.GetItem(i);if(f!=null){g.AddUnique(f)}var h=this.Groups.GetItem(e);if(h!=null){h.ForEach(function(j,k){g.AddUnique(j);return true})}h=this.GroupStems.GetItem(i);if(h!=null){h.ForEach(function(j,k){g.AddUnique(j);return true})}}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v12.0.5991.25330
 */
(function(){if(!MadCap.Utilities.HasRuntimeFileType("Topic")){return}MadCap.CreateNamespace("Topic");var F=MadCap.Topic;var e=MadCap.TextEffects;F.Expand=function(J){var K=new e.ExpandingControl(J.parentNode);K.Toggle()};F.DropDown=function(J){var K=new e.DropDownControl(J.parentNode.parentNode);K.Toggle()};F.Toggle=function(J){var K=new e.TogglerControl(J);K.Toggle()};F.ThumbPopup_Click=function(J){var K=F.ShowThumbnailPopup(J,this,"click");if(J.preventDefault){J.preventDefault()}};F.ThumbPopup_Hover=function(J){var K=F.ShowThumbnailPopup(J,this,"mouseleave")};F.ShowThumbnailPopup=function(al,am,ah){var ag=10;var ab=1;var X=10;var N=$(am).children("img")[0];var aa=parseInt(MadCap.Dom.Dataset(N,"mcWidth"));var U=parseInt(MadCap.Dom.Dataset(N,"mcHeight"));var J=U/aa;var aj=document.documentElement.clientWidth-((ag+ab+X)*2);var af=document.documentElement.clientHeight-((ag+ab+X)*2);if(U>af){U=af;aa=U/J}if(aa>aj){aa=aj;U=aa*J}var P=new MadCap.Utilities.Url(document.location.href);var ak=$(N).offset().top;var ao=$(N).offset().left;var ar=MadCap.Dom.GetAttribute(am,"href");var ae=MadCap.Dom.GetAttribute(am,"data-mc-popup-alt");var Z=U+((ab+X)*2);var W=aa+((ab+X)*2);var V=(ak+(N.offsetHeight/2))-(Z/2);var R=(ao+(N.offsetWidth/2))-(W/2);var Q=MadCap.Dom.GetScrollPosition();var ac=Q.Y;var L=ac+document.documentElement.clientHeight;var an=Q.X;var K=an+document.documentElement.clientWidth;var S=ac+ag;var ad=an+ag;var T=L-ag;var M=K-ag;if(V<S){V=S}if(R<ad){R=ad}if(V+Z>T){V=T-Z}if(R+W>M){R=M-W}var O=$("<div></div>");O.addClass("MCPopupContainer");var ai=document.createElement("img");$(ai).addClass("MCPopupFullImage");ai.setAttribute("src",ar);ai.setAttribute("alt",ae);ai.setAttribute("tabindex","0");O.bind(ah,function(){MadCap.DEBUG.Log.AddLine(ah);O.animate({top:aq,left:Y},200,function(){O.remove()});$(ai).animate({width:N.offsetWidth,height:N.offsetHeight},200);$(ap).animate({opacity:0},200,function(){MadCap.TextEffects.RemoveBackgroundTint()})});O.bind("keydown",function(at){var at=at||window.event;if(at.keyCode!=27&&at.keyCode!=13){return}O.remove();MadCap.TextEffects.RemoveBackgroundTint()});O.append(ai);document.body.appendChild(O[0]);var aq=ak-(ab+X);var Y=ao-(ab+X);if(MadCap.IsIBooks()){$idealContainer=$(am).parentsUntil("body").last();aa=$idealContainer[0].offsetWidth*0.9;U=aa*J;R=$idealContainer.offset().left;O.css({top:aq,left:Y}).animate({top:V,left:R,width:aa,height:U},200)}else{O.css({top:aq,left:Y}).animate({top:V,left:R},200)}$(ai).css({width:N.offsetWidth,height:N.offsetHeight}).animate({width:aa,height:U},200);var ap=MadCap.TextEffects.AddBackgroundTint(null,document.body);$(ap).animate({opacity:0.5},200);ai.focus()};F.HelpControl_Click=function(K){var J=this;F.GetHelpControlLinks(this,function(R){var M=new MadCap.Utilities.Url(document.location.href);for(var N=R.length-1;N>=0;N--){var L=R[N];L.Title="t" in L?L.t:"Title" in L?L.Title:null;var O="Url" in L?L.Url:"Link" in L?L.Link:null;if(O!=null&&typeof O!="string"){if(O.FullPath==M.FullPath){R.Remove(N)}O=O.ToRelative(M);L.Link=O.FullPath}}if(!$(J).hasClass("MCHelpControl-Related")){R.sort(function(T,S){return T.Title.localeCompare(S.Title)})}var P=new MadCap.Utilities.Dictionary();for(var N=R.length-1;N>=0;N--){var Q=R[N];var O=Q.Link;if(P.GetItem(O)){R.Remove(N);continue}P.Add(Q.Link,true)}e.CreateLinkListPopup(R,document.body,K.pageY,K.pageX,J)},null);K.preventDefault();K.stopPropagation()};F.GetHelpControlLinks=function(P,T){var S=new Array();var L=$(P);if(w&&!w.InPreviewMode){if(l()){var O=L.attr("data-mc-keywords");if(O!=null){if(O==""){T(S)}var R=O.split(";");MadCap.Utilities.AsyncForeach(R,function(U,V){w.FindIndexEntry(U,function(W,X){if(X!=null&&X.linkList){S=S.concat(X.linkList)}V()})},function(){T(w.SortLinkList(S))});return}else{var N=L.attr("data-mc-concepts");if(N!=null){w.GetConceptsLinks(N).then(T);return}}}}var K=L.attr("data-mc-topics");if(K!=null){topicPairs=K.split("||");if(topicPairs==""){T(S)}for(var Q=0,M=topicPairs.length;Q<M;Q++){var J=topicPairs[Q].split("|");S[S.length]={Title:J[0],Link:J[1]}}}T(S)};F.Hyperlink_Onclick=function(N){var M=$(this);if(M.hasClass("MCTopicPopup")||M.hasClass("MCPopupThumbnailLink")||M.hasClass("MCHelpControl")||M.hasClass("reply-comment-button")){return}var J=MadCap.Dom.GetAttribute(this,"href");if(J==null||MadCap.String.StartsWith(J,"http:")||MadCap.String.StartsWith(J,"https:")){return}var L=MadCap.Dom.GetAttribute(this,"target");if(L!=null){return}if(l()){var K=new MadCap.Utilities.Url(document.location.href);if(MadCap.String.StartsWith(J,"#")){K=new MadCap.Utilities.Url(K.PlainPath+J)}else{if(MadCap.String.Contains(J,"javascript")){return}else{K=K.ToFolder().CombinePath(J)}}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-topic",[K.FullPath],null);N.preventDefault()}else{MadCap.Utilities.Url.OnNavigateTopic.call(M,N)}};F.ScrollToBookmark=function(L){var J=$("#"+L);if(J.length==0){J=$("[name = '"+L+"']")}if(J.length>0){if(v(J[0],false)){var K=J.offset().top;$("html, body").animate({scrollTop:K})}}};$(function(J){MadCap.Utilities.LoadHandlers.MadCapTopic=F.Init;H(J)});function m(J){h()}function h(){var J=$(".feedback-comments-wrapper");if(w&&w.IsResponsive&&parent!=window){J.addClass("feedback-embedded");MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-parent-window-width",null,function(L){var K=parseInt(L[0]);if(w.IsTabletLayout(K)){if(!J.hasClass("responsive")){J.addClass("responsive")}}else{if(J.hasClass("responsive")){J.removeClass("responsive")}}})}else{if(J.hasClass("responsive")){J.removeClass("responsive")}}}function H(J){$(window).resize(m);$(window).hashchange(I);F.Init(document)}F.Init=function(M){$("input, textarea",M).placeholder();var P=MadCap.Utilities.Url.CurrentHash();if(P.length>0){var L=new MadCap.Utilities.Url(P.substring(1));A(L.ToNoQuery().FullPath)}if(l()||b()){$(".MCWebHelpFramesetLink",M).hide()}$(M).on("click","a, area",MadCap.Topic.Hyperlink_Onclick);$(".MCPopupThumbnailPopup",M).click(MadCap.Topic.ThumbPopup_Click);$(".MCPopupThumbnailHover",M).mouseover(MadCap.Topic.ThumbPopup_Hover);$("a.MCHelpControl",M).click(MadCap.Topic.HelpControl_Click);$(".print-button",M).click(function(T){window.print()});$(".expand-all-button",M).click(function(U){var T=$(this);if(T.hasClass("expand-all-button")){MadCap.TextEffects.TextEffectControl.ExpandAll("open")}else{if(T.hasClass("collapse-all-button")){MadCap.TextEffects.TextEffectControl.ExpandAll("close")}}MadCap.Utilities.ToggleButtonState(this)});$(".remove-highlight-button",M).click(function(T){s()});$(".previous-topic-button",M).click(function(T){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-previous")});$(".next-topic-button",M).click(function(T){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-next")});if(MadCap.String.Contains(navigator.userAgent,"iphone",false)){window.scrollTo(0,1)}if(MadCap.IsIOS()){var K=$("<div id='ios-wrapper'></div>").appendTo(document.body);var R=K[0];for(var Q=document.body.childNodes.length-2;Q>=0;Q--){var O=document.body.childNodes[Q];R.insertBefore(O,R.firstChild)}}x();var S=parent;if(b()){S=parent.parent}var N=$(document.documentElement).attr("data-mc-path-to-help-system");if(N){var J=new MadCap.Utilities.Url(N).CombinePath("Data/HelpSystem.xml");MadCap.WebHelp.HelpSystem.LoadHelpSystem(J.FullPath).done(function(T){w=T;C()})}};function C(){B();if(w&&w.LiveHelpEnabled){r=MadCap.WebHelp.LoadFeedbackController(w.LiveHelpServer);r.Init(function(){if(r.FeedbackActive){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-csh-id",null,function(J){var K=J!=null?J[0]:null;if(c!=null){$(document.documentElement).addClass("has-topic");r.LogTopic(c,K,function(){var L=$(".feedback-comments-wrapper");if(!b()&&!y()&&!f()){if(!r.PulseEnabled){L.removeClass("hidden");u=$("#new-comment-form").attr("data-comment-length-exceeded-message")||"The maximum comment length was exceeded by {n} characters.";r.GetAnonymousEnabled(w.LiveHelpOutputId,function(N){D=N;if(N){$(document.documentElement).addClass("feedback-anonymous-enabled")}});var M=MadCap.Utilities.Store.getItem("LiveHelpUsername");$(".username").val(M);$(".comment-submit").click(q);$(".feedback-comments-wrapper .comments").on("click",".reply-comment-button",n);a()}else{if(r.PulseActive){p(function(N){if(N){var O=r.PulseServer+N;k(O)}else{r.GetPulseStreamID(c,function(P){if(P=="00000000-0000-0000-0000-000000000000"){return}var Q=r.PulseServer+"streams/"+P+"/activities?frame=stream";k(Q)})}})}}}})}})}});h()}}function I(K){var J=new MadCap.Utilities.Url(document.location.href);if(!MadCap.String.IsNullOrEmpty(J.Fragment)){var L=J.Fragment.substring(1);L=MadCap.Utilities.Url.StripInvalidCharacters(L);F.ScrollToBookmark(L)}}function A(J){J=MadCap.Utilities.Url.StripInvalidCharacters(J);var K=$("[name='"+J+"']");if(K.length>0){v(K[0],false)}}function l(){return window.name=="topic"&&!MadCap.Utilities.HasRuntimeFileType("Default")}function b(){return window.name=="MCPopup"&&!MadCap.Utilities.HasRuntimeFileType("Default")}function y(){return $("html").hasClass("templateTopic")}function f(){var J=$(document.documentElement).attr("data-mc-community-features");return J&&J.toLowerCase()=="disabled"}function B(){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(M){if(M){var K=new MadCap.Utilities.Url(decodeURIComponent(M[0]));var J=new MadCap.Utilities.Url(K.Fragment.substring(1));var L=K.QueryMap.GetItem("BrowseSequencesPath");w.SetBrowseSequencePath(L,J)}})}function q(M){var J=$(this).closest(".comment-form-wrapper");var L=null;var Q=J.children(".username-field").val();var K=J.children(".subject-field").val();var P=J.find(".body-field").val();var N=null;var O=J.parent();if(O.hasClass("comment")){N=O.attr("data-mc-comment-id")}z(Q,K,P,N)}function z(O,K,N,M){if(D){MadCap.Utilities.Store.setItem("LiveHelpUsername",O);try{r.AddComment(c,null,O,K,N,M,a)}catch(J){var L=u.replace(/{n}/g,J.Data.ExceedAmount);alert(L)}}else{MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"login-user",null,function(S){var R=S[0];if(R!=null){try{r.AddComment(c,R,O,K,N,M,a)}catch(P){var Q=u.replace(/{n}/g,P.Data.ExceedAmount);alert(Q)}}})}}function n(K){K.preventDefault();var L=$(this).closest(".comment");if(L.children(".comment-form-wrapper")[0]!=null){return}var J=$("#new-comment-form").clone();J.attr("id",null);J.children(".comment-submit").click(q);L.children(".buttons").after(J);J.hide().slideDown()}function a(){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-user-guid",null,function(K){var J=K[0];r.GetTopicComments(c,J,null,function(L){var N=MadCap.Utilities.Xhr.LoadXmlString(L);var M=$(".comments");M.children().not(".mc-template").remove();t(N.documentElement,M)})})}function t(U,R){var T=$(U).children("Comment");var J=$(".comments .comment.mc-template");for(var Q=0,M=T.length;Q<M;Q++){var V=$(T[Q]);var P=V.attr("User");var S=V.attr("DateUTC")||V.attr("Date");var N=V.attr("Subject");var L=V.attr("CommentID");var K=V.children("Body").text();var O=J.clone();O.removeClass("mc-template");O.attr("data-mc-comment-id",L);$(".username",O).text(P);$(".timestamp",O).text(S);$(".subject",O).text(N);$(".body",O).text(K);$(R).append(O);t(V.children("Comments")[0],O)}}function p(J){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(N){var K=null;if(N){var M=new MadCap.Utilities.Url(decodeURIComponent(N[0]));var L=new MadCap.Utilities.Url(M.Fragment.substring(1));K=M.QueryMap.GetItem("PulsePath")}J(K)})}function k(L){var J=$(".feedback-comments-wrapper");J.empty();var K=$("<iframe name='topiccomments-html5' class='pulse-frame pulse-loading' title='Topic Comments' frameborder='0'></iframe>");K.appendTo(J);if(!($.browser.msie&&parseInt($.browser.version,10)===7)){K.attr("onload","this.className='pulse-frame';")}K.attr("src",L);if(!E){J.removeClass("hidden")}}function s(){for(var J=1;J<=10;J++){$("body").removeHighlight("SearchHighlight"+J)}}function x(){function J(K){if(typeof K.nextElementSibling=="undefined"){return K.nextSibling==null||K.nextSibling.nodeType==1?K.nextSibling:J(K.nextSibling)}else{return K.nextElementSibling}}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(S){if(S){var L=new MadCap.Utilities.Url(decodeURIComponent(S[0]));var O=L.QueryMap.GetItem("Highlight");if(MadCap.String.IsNullOrEmpty(O)){return}var P=O.match(/"[^"]*"/g);if(P!=null){for(var Q=0;Q<P.length;Q++){O=O.replace(P[Q],"")}}var T=O.replace('"',"").split(" ");for(var R=0;R<T.length;R++){if(T[R]==""){T.splice(T[R],1);R--}}if(P!=null){for(var Q=0;Q<P.length;Q++){T.push(P[Q].replace(/"/g,""))}}for(var R=0;R<T.length;R++){if($.inArray(T[R].toLowerCase(),MadCap.Utilities.StopWords)!=-1){T.splice(R,1);R--}}for(var U=0;U<T.length;U++){var M=Array("*[class*='MCExpandingBody']","*[class*='MCDropDownHotSpot']","*[data-mc-target-name]");for(var W=0;W<M.length;W++){var K=$(M[W]);for(var N=0;N<K.length;N++){var V=J(K[N].parentElement);if((K[N].textContent!=null&&K[N].textContent.toLowerCase().indexOf(T[U].toLowerCase())>=0)||(V!=null&&V.textContent!=null&&V.textContent.toLowerCase().indexOf(T[U].toLowerCase())>=0)){v(W!=2?K[N]:K[N].firstChild)}}}$("body").highlight(T[U],"SearchHighlight SearchHighlight"+(U+1))}}})}function j(M,K,J,L){if(M==""){return}i(document.body,M,K,J,L);if(g&&g.offsetTop>document.documentElement.clientHeight){document.documentElement.scrollTop=g.offsetTop}}function d(M){for(var L=M.childNodes.length-1;L>=1;L--){var J=M.childNodes[L];var K=J.previousSibling;if(J.nodeType==3&&K.nodeType==3){K.nodeValue=K.nodeValue+J.nodeValue;M.removeChild(J)}}for(var L=0;L<M.childNodes.length;L++){d(M.childNodes[L])}}function i(V,M,N,T,S){var Y=null;if(S=="NGram"){Y=new RegExp(M,"g"+(T?"":"i"))}else{var K=M.replace(/([*^$+?.()[\]{}|\\])/g,"\\$1");Y=new RegExp("(^|\\s|[.,;!#$/:?'\"()[\\]{}|=+*_\\-\\\\])"+K+"($|\\s|[.,;!#$/:?'\"()[\\]{}|=+*_\\-\\\\])","g"+(T?"":"i"))}for(var Q=V.childNodes.length-1;Q>=0;Q--){var L=V.childNodes[Q];i(L,M,N,T,S);if(L.nodeType!=3||L.parentNode.nodeName=="SCRIPT"){continue}var P=L;var X=P.nodeValue;for(var R=Y.exec(X);R!=null;R=Y.exec(X)){var U=R.index+(S=="NGram"?0:R[1].length);var J=U+M.length;var W=document.createElement("span");W.className="highlight";W.style.fontWeight="bold";W.style.backgroundColor=N.split(",")[0];W.style.color=N.split(",")[1];var O=document.createElement("span");O.className="SearchHighlight"+(G+1);O.appendChild(document.createTextNode(X.substring(U,J)));W.appendChild(O);P.nodeValue=X.substring(0,U);P.parentNode.insertBefore(W,P.nextSibling);P.parentNode.insertBefore(document.createTextNode(X.substring(J,X.length)),W.nextSibling);P=P.nextSibling.nextSibling;X=P.nodeValue;if(g==null||W.offsetTop<g.offsetTop){g=W}v(W)}}}function v(L,J){if(typeof J=="undefined"){J=true}var R=false;for(var Q=L.parentNode;Q.nodeName!="BODY";Q=Q.parentNode){var U=$(Q);if(U.hasClass("MCExpanding")){var O=e.TextEffectControl.FindControl(U[0]);if(O==null){O=new MadCap.Topic.ExpandingControl(Q)}O.Open(J);R=true}else{if(U.hasClass("MCDropDown")){var O=e.TextEffectControl.FindControl(U[0]);if(O==null){O=new MadCap.Topic.DropDownControl(Q)}O.Open(J);R=true}else{var P=$(Q).attr("data-mc-target-name");if(P!=null){var T=MadCap.Dom.GetElementsByClassName("MCToggler",null,document.body);for(var N=0,K=T.length;N<K;N++){var S=$(T[N]).attr("data-mc-targets").split(";");var V=false;for(var M=0;M<S.length;M++){if(S[M]==P){V=true;break}}if(!V){continue}var O=e.TextEffectControl.FindControl(T[N]);if(O==null){O=new MadCap.Topic.TogglerControl(T[N])}O.Open(J);R=true;break}}}}}return R}MadCap.Utilities.CrossFrame.AddMessageHandler(function(P,L,O){var N={Handled:false,FireResponse:true};if(P=="print"){window.focus();window.print();N.Handled=true}else{if(P=="expand-all"){MadCap.TextEffects.TextEffectControl.ExpandAll("open");N.Handled=true}else{if(P=="collapse-all"){MadCap.TextEffects.TextEffectControl.ExpandAll("close");N.Handled=true}else{if(P=="get-topic-id"){O[O.length]=c;N.Handled=true}else{if(P=="get-topic-url"){O[O.length]=document.location.href;N.Handled=true}else{if(P=="remove-highlight"){s();N.Handled=true}else{if(P=="get-bs-path"){var K=new MadCap.Utilities.Url(document.location.href);var M=K.QueryMap.GetItem("BrowseSequencePath");if(M==null){M=MadCap.Dom.Dataset(document.documentElement,"mcBrowseSequencePath")}O[O.length]=M;O[O.length]=K.FullPath;N.Handled=true}else{if(P=="reload-pulse"){MadCap.Utilities.CrossFrame.PostMessageRequest(frames["topiccomments-html5"],"reload");N.Handled=true}else{if(P=="logout-complete"){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"logout-complete");N.Handled=true}else{if(P=="set-pulse-login-id"){if(r!=null){r.PulseUserGuid=L[0]}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"set-pulse-login-id",L);N.Handled=true}else{if(P=="resize-pulse"){var J=$(".pulse-frame");J.attr("scrolling","no");J.css("overflow","hidden");J.height(L[1]);N.Handled=true}else{if(P=="show-comments"){E=false;N.Handled=true}else{if(P=="hide-comments"){E=true;N.Handled=true}}}}}}}}}}}}}return N},null);var o=new Array("#ffff66,#000000","#a0ffff,#000000","#99ff99,#000000","#ff9999,#000000","#ff66ff,#000000","#880000,#ffffff","#00aa00,#ffffff","#886800,#ffffff","#004699,#ffffff","#990099,#ffffff");var G=0;var g=null;var w=null;var r=null;var E=true;var D=false;var c=MadCap.Dom.Dataset(document.documentElement,"mcLiveHelp");var u=null})();

//    Syntax:
//    function MadCap.OpenHelp(id, skinName, searchQuery, firstPick)
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    MadCap.OpenHelp('FILE_NEW', null, null, null);
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    MadCap.OpenHelp('FILE_NEW', 'BlueSkin', null, null);
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    MadCap.OpenHelp(1, null, null, null);
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    MadCap.OpenHelp(1, 'BlueSkin', null, null);
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    MadCap.OpenHelp('Company/Employees.htm', null, null, null);
//
//    In the following example, both the default topic and skin will be used:
//    MadCap.OpenHelp(null, null, null, null);
//
//    In the following example, the default topic will be used with "BlueSkin":
//    MadCap.OpenHelp(null, 'BlueSkin', null, null);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', false);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', true);

(function ()
{
var helpSystemName = "BVD_Help.htm";

    MadCap.OpenHelp = function (id, skinName, searchQuery, firstPick, pathToHelpSystem)
    {
        var cshFileName = helpSystemName.substring(0, helpSystemName.lastIndexOf(".")) + ".js";
        var webHelpPath = null;
        var webHelpFile = null;
        var cshFileUrl = new MadCap.Utilities.Url(helpSystemName);

        if (pathToHelpSystem == null)
        {
            var scriptNodes = document.getElementsByTagName("script");
            var found = false;

            for (var i = 0; i < scriptNodes.length; i++)
            {
                var src = scriptNodes[i].src;
                var srcUrl = new MadCap.Utilities.Url(MadCap.String.Trim(src));

                if (srcUrl.NameWithExtension.toLowerCase() == cshFileName.toLowerCase())
                {
                    var locUrl = new MadCap.Utilities.Url(document.location.href).ToFolder();

                    webHelpPath = locUrl.AddFile(srcUrl);
                    webHelpPath = webHelpPath.ToFolder();

                    found = true;

                    break;
                }
            }

            if (!found)
                throw "CSH failed: could not find MadCap CSH script in page.";
        }
        else
        {
            webHelpPath = new MadCap.Utilities.Url(pathToHelpSystem);
        }

        webHelpFile = webHelpPath.AddFile(cshFileUrl);

        var webHelpPath = webHelpFile.ToFolder().FullPath;
        var helpSystemFile = webHelpPath + "Data/HelpSystem.xml";
        var helpSystem = new MadCap.WebHelp.HelpSystem(null, null, helpSystemFile, null, null);

        helpSystem.Load(function ()
        {
            helpSystem.LookupCSHID(id, function (idInfo)
            {
                function OnGetSkinComplete()
                {
                    var cshString = webHelpFile.FullPath;

                    if (id)
                        cshString += "#cshid=" + id;

                    if (skinName)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "skinName=" + skinName;
                    }

                    if (searchQuery)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "searchQuery=" + searchQuery;

                        if (firstPick)
                            cshString += "&firstPick=true";
                    }

                    var win = window.open(cshString, "_MCWebHelpCSH", browserOptions + size);

                    // Bug 32051: Windows 7 64-bit is returning null from the call to window.open().
                    if (win != null)
                        win.focus();
                }

                skinName = skinName || idInfo.Skin;

                // Browser setup options

                var browserOptions = "";
                var size = "";

                if (skinName)
                {
                    var skin = helpSystem.GetSkin(skinName);

                    if (skin)
                    {
                        var useDefault = MadCap.String.ToBool(skin.UseDefaultBrowserSetup, true);

                        if (!useDefault)
                        {
                            var toolbar = "no";
                            var menu = "no";
                            var locationBar = "no";
                            var statusBar = "no";
                            var resizable = "no";
                            var setup = skin.BrowserSetup;

                            if (setup)
                            {
                                toolbar = (setup.indexOf("Toolbar") > -1) ? "yes" : "no";
                                menu = (setup.indexOf("Menu") > -1) ? "yes" : "no";
                                locationBar = (setup.indexOf("LocationBar") > -1) ? "yes" : "no";
                                statusBar = (setup.indexOf("StatusBar") > -1) ? "yes" : "no";
                                resizable = (setup.indexOf("Resizable") > -1) ? "yes" : "no";
                            }

                            browserOptions = "toolbar=" + toolbar + ", menubar=" + menu + ", location=" + locationBar + ", status=" + statusBar + ", resizable=" + resizable;
                        }

                        var windowSize = LoadSize(skin);

                        if (windowSize)
                            size = ", top=" + windowSize.topPx + ", left=" + windowSize.leftPx + ", width=" + windowSize.widthPx + ", height=" + windowSize.heightPx;
                    }

                    OnGetSkinComplete();
                }
                else
                {
                    OnGetSkinComplete();
                }
            });
        });
    }

    function LoadSize(skin)
    {
        var useDefaultSize = MadCap.String.ToBool(skin.UseBrowserDefaultSize, true);

        if (useDefaultSize)
            return null;

        var topPx = MadCap.String.ToInt(skin.Top, 0);
        var leftPx = MadCap.String.ToInt(skin.Left, 0);
        var bottomPx = MadCap.String.ToInt(skin.Bottom, 0);
        var rightPx = MadCap.String.ToInt(skin.Right, 0);
        var widthPx = MadCap.String.ToInt(skin.Width, 800);
        var heightPx = MadCap.String.ToInt(skin.Height, 600);

        var anchors = skin.Anchors;

        if (anchors)
        {
            var aTop = (anchors.indexOf("Top") > -1) ? true : false;
            var aLeft = (anchors.indexOf("Left") > -1) ? true : false;
            var aBottom = (anchors.indexOf("Bottom") > -1) ? true : false;
            var aRight = (anchors.indexOf("Right") > -1) ? true : false;
            var aWidth = (anchors.indexOf("Width") > -1) ? true : false;
            var aHeight = (anchors.indexOf("Height") > -1) ? true : false;
        }

        if (aLeft && aRight)
            widthPx = screen.width - (leftPx + rightPx);
        else if (!aLeft && aRight)
            leftPx = screen.width - (widthPx + rightPx);
        else if (aWidth)
            leftPx = (screen.width / 2) - (widthPx / 2);

        if (aTop && aBottom)
            heightPx = screen.height - (topPx + bottomPx);
        else if (!aTop && aBottom)
            topPx = screen.height - (heightPx + bottomPx);
        else if (aHeight)
            topPx = (screen.height / 2) - (heightPx / 2);

        //

        var windowSize = {};
        windowSize.topPx = topPx;
        windowSize.leftPx = leftPx;
        windowSize.widthPx = widthPx;
        windowSize.heightPx = heightPx;

        return windowSize;
    }
})();
